#############################################################################
## Name:        lib/Wx/Wx_Exp.pm
## Purpose:     export lists (AUTOGENERATED, DO NOT EDIT)
## Author:      Mattia Barbon
## Modified by:
## Licence:     This program is free software; you can redistribute it and/or
##              modify it under the same terms as Perl itself
#############################################################################

package Wx::Wx_Exp; # for RPM


package Wx;

push @EXPORT_OK, qw(wxAPPLY
wxALPHA_OPAQUE
wxALPHA_TRANSPARENT
wxALIGN_LEFT
wxALIGN_CENTRE
wxALIGN_CENTER
wxALIGN_RIGHT
wxALIGN_TOP
wxALIGN_BOTTOM
wxALIGN_CENTER_VERTICAL
wxALIGN_CENTER_HORIZONTAL
wxALIGN_CENTRE_VERTICAL
wxALIGN_CENTRE_HORIZONTAL
wxALL
wxACCEL_ALT
wxACCEL_CTRL
wxACCEL_NORMAL
wxACCEL_SHIFT
wxAND
wxAND_INVERT
wxAND_REVERSE
wxADJUST_MINSIZE
wxAbove
wxAbsolute
wxAsIs
wxALWAYS_SHOW_SB
wxANIMATION_TYPE_ANI
wxANIMATION_TYPE_ANY
wxANIMATION_TYPE_GIF
wxANIMATION_TYPE_INVALID
wxAC_DEFAULT_STYLE
wxAC_NO_AUTORESIZE
wxBATTERY_NORMAL_STATE
wxBATTERY_LOW_STATE
wxBATTERY_CRITICAL_STATE
wxBATTERY_SHUTDOWN_STATE
wxBATTERY_UNKNOWN_STATE
wxBITMAP_TYPE_BMP
wxBITMAP_TYPE_BMP_RESOURCE
wxBITMAP_TYPE_CUR
wxBITMAP_TYPE_CUR_RESOURCE
wxBITMAP_TYPE_ICO
wxBITMAP_TYPE_ICO_RESOURCE
wxBITMAP_TYPE_GIF
wxBITMAP_TYPE_XBM
wxBITMAP_TYPE_XPM
wxBITMAP_TYPE_JPEG
wxBITMAP_TYPE_PNG
wxBITMAP_TYPE_PNM
wxBITMAP_TYPE_PCX
wxBITMAP_TYPE_ANY
wxBITMAP_TYPE_TIF
wxBITMAP_TYPE_ANI
wxBITMAP_TYPE_GIF_RESOURCE
wxBITMAP_TYPE_ICON
wxBITMAP_TYPE_ICON_RESOURCE
wxBITMAP_TYPE_IFF
wxBITMAP_TYPE_INVALID
wxBITMAP_TYPE_JPEG_RESOURCE
wxBITMAP_TYPE_MACCURSOR
wxBITMAP_TYPE_MACCURSOR_RESOURCE
wxBITMAP_TYPE_PCX_RESOURCE
wxBITMAP_TYPE_PICT
wxBITMAP_TYPE_PICT_RESOURCE
wxBITMAP_TYPE_PNG_RESOURCE
wxBITMAP_TYPE_PNM_RESOURCE
wxBITMAP_TYPE_RESOURCE
wxBITMAP_TYPE_TGA
wxBITMAP_TYPE_TIF_RESOURCE
wxBITMAP_TYPE_XBM_DATA
wxBITMAP_TYPE_XPM_DATA
wxBI_EXPAND
wxBOLD
wxBOTH
wxBOTTOM
wxBU_TOP
wxBU_LEFT
wxBU_BOTTOM
wxBU_AUTODRAW
wxBU_RIGHT
wxBU_NOAUTODRAW
wxBU_EXACTFIT
wxBDIAGONAL_HATCH
wxBottom
wxBelow
wxBROWSER_NEW_WINDOW
wxBROWSER_NOBUSYCURSOR
wxBUFFER_VIRTUAL_AREA
wxBUFFER_CLIENT_AREA
wxBG_STYLE_SYSTEM
wxBG_STYLE_COLOUR
wxBG_STYLE_CUSTOM
wxBK_DEFAULT
wxBK_TOP
wxBK_BOTTOM
wxBK_LEFT
wxBK_RIGHT
wxBK_BUTTONBAR
wxBK_HITTEST_NOWHERE
wxBK_HITTEST_ONICON
wxBK_HITTEST_ONLABEL
wxBK_HITTEST_ONITEM
wxBK_HITTEST_ONPAGE
wxBORDER_DEFAULT
wxBORDER_DOUBLE
wxBORDER_MASK
wxBORDER_RAISED
wxBORDER_SIMPLE
wxBORDER_STATIC
wxBORDER_SUNKEN
wxBORDER_THEME
wxBORDER_NONE
wxBACKWARD
wxBLIT_00220326
wxBLIT_007700E6
wxBLIT_00990066
wxBLIT_00AA0029
wxBLIT_00DD0228
wxBLIT_BLACKNESS
wxBLIT_DSTINVERT
wxBLIT_MERGEPAINT
wxBLIT_NOTSCRCOPY
wxBLIT_NOTSRCERASE
wxBLIT_SRCAND
wxBLIT_SRCCOPY
wxBLIT_SRCERASE
wxBLIT_SRCINVERT
wxBLIT_SRCPAINT
wxBLIT_WHITENESS
wxBRUSHSTYLE_BDIAGONAL_HATCH
wxBRUSHSTYLE_CROSSDIAG_HATCH
wxBRUSHSTYLE_CROSS_HATCH
wxBRUSHSTYLE_FDIAGONAL_HATCH
wxBRUSHSTYLE_FIRST_HATCH
wxBRUSHSTYLE_HORIZONTAL_HATCH
wxBRUSHSTYLE_INVALID
wxBRUSHSTYLE_LAST_HATCH
wxBRUSHSTYLE_SOLID
wxBRUSHSTYLE_STIPPLE
wxBRUSHSTYLE_STIPPLE_MASK
wxBRUSHSTYLE_STIPPLE_MASK_OPAQUE
wxBRUSHSTYLE_TRANSPARENT
wxBRUSHSTYLE_VERTICAL_HATCH
wxCANCEL
wxCAPTION
wxCAP_ROUND
wxCAP_PROJECTING
wxCAP_BUTT
wxCB_SIMPLE
wxCB_DROPDOWN
wxCB_READONLY
wxCB_SORT
wxCC_SPECIAL_DCLICK
wxCC_STD_BUTTON
wxCP_DEFAULT_STYLE
wxCP_NO_TLW_RESIZE
wxCENTER
wxCENTRE
wxCENTER_ON_SCREEN
wxCENTRE_ON_SCREEN
wxCLIP_CHILDREN
wxCHOICEDLG_STYLE
wxCHANGE_DIR
wxCLIP_SIBLINGS
wxCHK_2STATE
wxCHK_3STATE
wxCHK_ALLOW_3RD_STATE_FOR_USER
wxCHK_UNCHECKED
wxCHK_CHECKED
wxCHK_UNDETERMINED
wxCHB_BOTTOM
wxCHB_TOP
wxCHB_ALIGN_MASK
wxCHB_DEFAULT
wxCHB_LEFT
wxCHB_RIGHT
wxCLRP_SHOW_LABEL
wxCLRP_USE_TEXTCTRL
wxCLRP_DEFAULT_STYLE
wxCLEAR
wxCOPY
wxCONFIG_USE_SUBDIR
wxCONFIG_USE_LOCAL_FILE
wxCONFIG_USE_GLOBAL_FILE
wxCONFIG_USE_RELATIVE_PATH
wxCURSOR_ARROW
wxCURSOR_ARROWWAIT
wxCURSOR_RIGHT_ARROW
wxCURSOR_BULLSEYE
wxCURSOR_CHAR
wxCURSOR_CROSS
wxCURSOR_HAND
wxCURSOR_IBEAM
wxCURSOR_LEFT_BUTTON
wxCURSOR_MAGNIFIER
wxCURSOR_MIDDLE_BUTTON
wxCURSOR_NO_ENTRY
wxCURSOR_PAINT_BRUSH
wxCURSOR_PENCIL
wxCURSOR_POINT_LEFT
wxCURSOR_POINT_RIGHT
wxCURSOR_QUESTION_ARROW
wxCURSOR_RIGHT_BUTTON
wxCURSOR_SIZENESW
wxCURSOR_SIZENS
wxCURSOR_SIZENWSE
wxCURSOR_SIZEWE
wxCURSOR_SIZING
wxCURSOR_SPRAYCAN
wxCURSOR_WAIT
wxCURSOR_WATCH
wxCURSOR_BLANK
wxCURSOR_DEFAULT
wxCURSOR_COPY_ARROW
wxCURSOR_BASED_ARROW_DOWN
wxCURSOR_BASED_ARROW_UP
wxCURSOR_CROSS_REVERSE
wxCURSOR_DOUBLE_ARROW
wxCROSSDIAG_HATCH
wxCROSS_HATCH
wxCLOSE_BOX
wxCLOSE
wxCentreX
wxCentreY
wxCenterX
wxCenterY
wxC2S_NAME
wxC2S_CSS_SYNTAX
wxC2S_HTML_SYNTAX
wxDECORATIVE
wxDEFAULT
wxDEFAULT_DIALOG_STYLE
wxDEFAULT_FRAME_STYLE
wxDEFAULT_CONTROL_BORDER
wxDIALOG_MODAL
wxDIALOG_EX_METAL
wxDOUBLE_BORDER
wxDIALOG_NO_PARENT
wxDIALOG_EX_CONTEXTHELP
wxDD_NEW_DIR_BUTTON
wxDD_DEFAULT_STYLE
wxDD_CHANGE_DIR
wxDD_DIR_MUST_EXIST
wxDOT
wxDOT_DASH
wxDIR
wxDIRP_DIR_MUST_EXIST
wxDIRP_CHANGE_DIR
wxDIRP_USE_TEXTCTRL
wxDIRP_DEFAULT_STYLE
wxDOWN
wxDIRCTRL_DIR_ONLY
wxDIRCTRL_SELECT_FIRST
wxDIRCTRL_SHOW_FILTERS
wxDIRCTRL_3D_INTERNAL
wxDIRCTRL_EDIT_LABELS
wxEQUIV
wxEVENT_PROPAGATE_NONE
wxEVENT_PROPAGATE_MAX
wxEVT_COMMAND_LISTBOOK_PAGE_CHANGED
wxEVT_COMMAND_LISTBOOK_PAGE_CHANGING
wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGED
wxEVT_COMMAND_CHOICEBOOK_PAGE_CHANGING
wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGED
wxEVT_COMMAND_TOOLBOOK_PAGE_CHANGING
wxEVT_COMMAND_TREEBOOK_PAGE_CHANGED
wxEVT_COMMAND_TREEBOOK_PAGE_CHANGING
wxEVT_COMMAND_TREEBOOK_NODE_COLLAPSED
wxEVT_COMMAND_TREEBOOK_NODE_EXPANDED
wxEVT_COMMAND_HYPERLINK
wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED
wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING
wxEVT_COMMAND_BUTTON_CLICKED
wxEVT_COMMAND_CHECKBOX_CLICKED
wxEVT_COMMAND_CHOICE_SELECTED
wxEVT_COMMAND_LISTBOX_SELECTED
wxEVT_COMMAND_LISTBOX_DOUBLECLICKED
wxEVT_COMMAND_CHECKLISTBOX_TOGGLED
wxEVT_COMMAND_TEXT_UPDATED
wxEVT_COMMAND_TEXT_ENTER
wxEVT_COMMAND_MENU_SELECTED
wxEVT_COMMAND_TOOL_CLICKED
wxEVT_COMMAND_SLIDER_UPDATED
wxEVT_COMMAND_RADIOBOX_SELECTED
wxEVT_COMMAND_RADIOBUTTON_SELECTED
wxEVT_COMMAND_SCROLLBAR_UPDATED
wxEVT_COMMAND_VLBOX_SELECTED
wxEVT_COMMAND_COMBOBOX_SELECTED
wxEVT_COMMAND_TOGGLEBUTTON_CLICKED
wxEVT_COMMAND_TEXT_MAXLEN
wxEVT_COMMAND_TEXT_URL
wxEVT_COMMAND_TEXT_COPY
wxEVT_COMMAND_TEXT_CUT
wxEVT_COMMAND_TEXT_PASTE
wxEVT_COMMAND_TOOL_RCLICKED
wxEVT_COMMAND_TOOL_ENTER
wxEVT_COMMAND_SPINCTRL_UPDATED
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED
wxEVT_COMMAND_SPLITTER_UNSPLIT
wxEVT_COMMAND_SPLITTER_DOUBLECLICKED
wxEVT_TIMER
wxEVT_TASKBAR_MOVE
wxEVT_TASKBAR_LEFT_DOWN
wxEVT_TASKBAR_LEFT_UP
wxEVT_TASKBAR_RIGHT_DOWN
wxEVT_TASKBAR_RIGHT_UP
wxEVT_TASKBAR_LEFT_DCLICK
wxEVT_TASKBAR_RIGHT_DCLICK
wxEVT_COMMAND_FIND
wxEVT_COMMAND_FIND_NEXT
wxEVT_COMMAND_FIND_REPLACE
wxEVT_COMMAND_FIND_REPLACE_ALL
wxEVT_COMMAND_FIND_CLOSE
wxEVT_LEFT_DOWN
wxEVT_LEFT_UP
wxEVT_LEFT_DCLICK
wxEVT_MIDDLE_DOWN
wxEVT_MIDDLE_UP
wxEVT_MIDDLE_DCLICK
wxEVT_RIGHT_DOWN
wxEVT_RIGHT_UP
wxEVT_RIGHT_DCLICK
wxEVT_MOTION
wxEVT_ENTER_WINDOW
wxEVT_LEAVE_WINDOW
wxEVT_SET_FOCUS
wxEVT_KILL_FOCUS
wxEVT_SASH_DRAGGED
wxEVT_NC_LEFT_DOWN
wxEVT_NC_LEFT_UP
wxEVT_NC_MIDDLE_DOWN
wxEVT_NC_MIDDLE_UP
wxEVT_NC_RIGHT_DOWN
wxEVT_NC_RIGHT_UP
wxEVT_NC_MOTION
wxEVT_NC_ENTER_WINDOW
wxEVT_NC_LEAVE_WINDOW
wxEVT_NC_LEFT_DCLICK
wxEVT_NC_MIDDLE_DCLICK
wxEVT_NC_RIGHT_DCLICK
wxEVT_CHAR
wxEVT_CHAR_HOOK
wxEVT_CHILD_FOCUS
wxEVT_NAVIGATION_KEY
wxEVT_KEY_DOWN
wxEVT_KEY_UP
wxEVT_SET_CURSOR
wxEVT_SCROLL_TOP
wxEVT_SCROLL_BOTTOM
wxEVT_SCROLL_LINEUP
wxEVT_SCROLL_LINEDOWN
wxEVT_SCROLL_PAGEUP
wxEVT_SCROLL_PAGEDOWN
wxEVT_SCROLL_THUMBTRACK
wxEVT_SCROLL_THUMBRELEASE
wxEVT_SCROLLWIN_TOP
wxEVT_SCROLLWIN_BOTTOM
wxEVT_SCROLLWIN_LINEUP
wxEVT_SCROLLWIN_LINEDOWN
wxEVT_SCROLLWIN_PAGEUP
wxEVT_SCROLLWIN_PAGEDOWN
wxEVT_SCROLLWIN_THUMBTRACK
wxEVT_SCROLLWIN_THUMBRELEASE
wxEVT_SIZE
wxEVT_MOVE
wxEVT_CLOSE_WINDOW
wxEVT_END_SESSION
wxEVT_QUERY_END_SESSION
wxEVT_ACTIVATE_APP
wxEVT_POWER_SUSPENDING
wxEVT_POWER_SUSPENDED
wxEVT_POWER_SUSPEND_CANCEL
wxEVT_POWER_RESUME
wxEVT_POWER
wxEVT_ACTIVATE
wxEVT_CREATE
wxEVT_DESTROY
wxEVT_SHOW
wxEVT_ICONIZE
wxEVT_MAXIMIZE
wxEVT_PAINT
wxEVT_ERASE_BACKGROUND
wxEVT_NC_PAINT
wxEVT_MENU_HIGHLIGHT
wxEVT_MENU_OPEN
wxEVT_MENU_CLOSE
wxEVT_CONTEXT_MENU
wxEVT_SYS_COLOUR_CHANGED
wxEVT_QUERY_NEW_PALETTE
wxEVT_PALETTE_CHANGED
wxEVT_JOY_BUTTON_DOWN
wxEVT_JOY_BUTTON_UP
wxEVT_JOY_MOVE
wxEVT_JOY_ZMOVE
wxEVT_DROP_FILES
wxEVT_INIT_DIALOG
wxEVT_IDLE
wxEVT_UPDATE_UI
wxEVT_MOVING
wxEVT_SIZING
wxEVT_END_PROCESS
wxEVT_COMMAND_LEFT_CLICK
wxEVT_COMMAND_LEFT_DCLICK
wxEVT_COMMAND_RIGHT_CLICK
wxEVT_COMMAND_RIGHT_DCLICK
wxEVT_COMMAND_SET_FOCUS
wxEVT_COMMAND_KILL_FOCUS
wxEVT_COMMAND_ENTER
wxEVT_HELP
wxEVT_DETAILED_HELP
wxEXPAND
wxEXEC_SYNC
wxEXEC_ASYNC
wxEXEC_NOHIDE
wxEXEC_NODISABLE
wxEXEC_BLOCK
wxEXEC_NOEVENTS
wxEXEC_MAKE_GROUP_LEADER
wxEAST
wxEL_ALLOW_NEW
wxEL_ALLOW_EDIT
wxEL_ALLOW_DELETE
wxEL_NO_REORDER
wxEL_DEFAULT_STYLE
wxEXTEND_LAST_ON_EACH_LINE
wxFromStart
wxFromCurrent
wxFromEnd
wxFDIAGONAL_HATCH
wxFD_OPEN
wxFD_SAVE
wxFD_OVERWRITE_PROMPT
wxFD_FILE_MUST_EXIST
wxFD_MULTIPLE
wxFD_CHANGE_DIR
wxFD_DEFAULT_STYLE
wxFD_PREVIEW
wxFILE_MUST_EXIST
wxFLOOD_SURFACE
wxFLOOD_BORDER
wxFIXED_MINSIZE
wxFLEX_GROWMODE_NONE
wxFLEX_GROWMODE_SPECIFIED
wxFLEX_GROWMODE_ALL
wxFRAME_FLOAT_ON_PARENT
wxFRAME_NO_WINDOW_MENU
wxFRAME_NO_TASKBAR
wxFRAME_TOOL_WINDOW
wxFRAME_EX_CONTEXTHELP
wxFRAME_EX_METAL
wxFRAME_SHAPED
wxFILE
wxFR_DOWN
wxFR_WHOLEWORD
wxFR_MATCHCASE
wxFR_REPLACEDIALOG
wxFR_NOUPDOWN
wxFR_NOMATCHCASE
wxFR_NOWHOLEWORD
wxFONTFAMILY_DEFAULT
wxFONTFAMILY_DECORATIVE
wxFONTFAMILY_ROMAN
wxFONTFAMILY_SCRIPT
wxFONTFAMILY_SWISS
wxFONTFAMILY_MODERN
wxFONTFAMILY_TELETYPE
wxFONTFAMILY_MAX
wxFONTFAMILY_UNKNOWN
wxFONTSTYLE_NORMAL
wxFONTSTYLE_ITALIC
wxFONTSTYLE_SLANT
wxFONTSTYLE_MAX
wxFONTWEIGHT_NORMAL
wxFONTWEIGHT_LIGHT
wxFONTWEIGHT_BOLD
wxFONTWEIGHT_MAX
wxFONTFLAG_DEFAULT
wxFONTFLAG_ITALIC
wxFONTFLAG_SLANT
wxFONTFLAG_LIGHT
wxFONTFLAG_BOLD
wxFONTFLAG_ANTIALIASED
wxFONTFLAG_NOT_ANTIALIASED
wxFONTFLAG_UNDERLINED
wxFONTFLAG_STRIKETHROUGH
wxFONTFLAG_MASK
wxFONTENCODING_DEFAULT
wxFONTENCODING_SYSTEM
wxFONTENCODING_ISO8859_1
wxFONTENCODING_ISO8859_2
wxFONTENCODING_ISO8859_3
wxFONTENCODING_ISO8859_4
wxFONTENCODING_ISO8859_5
wxFONTENCODING_ISO8859_6
wxFONTENCODING_ISO8859_7
wxFONTENCODING_ISO8859_8
wxFONTENCODING_ISO8859_9
wxFONTENCODING_ISO8859_10
wxFONTENCODING_ISO8859_11
wxFONTENCODING_ISO8859_12
wxFONTENCODING_ISO8859_13
wxFONTENCODING_ISO8859_14
wxFONTENCODING_ISO8859_15
wxFONTENCODING_KOI8
wxFONTENCODING_ALTERNATIVE
wxFONTENCODING_BULGARIAN
wxFONTENCODING_CP437
wxFONTENCODING_CP850
wxFONTENCODING_CP852
wxFONTENCODING_CP855
wxFONTENCODING_CP866
wxFONTENCODING_CP874
wxFONTENCODING_CP1250
wxFONTENCODING_CP1251
wxFONTENCODING_CP1252
wxFONTENCODING_CP1253
wxFONTENCODING_CP1254
wxFONTENCODING_CP1255
wxFONTENCODING_CP1256
wxFONTENCODING_CP1257
wxFONTENCODING_UTF7
wxFONTENCODING_UTF8
wxFONTENCODING_UNICODE
wxFONTENCODING_BIG5
wxFONTENCODING_CP12_MAX
wxFONTENCODING_CP932
wxFONTENCODING_CP936
wxFONTENCODING_CP949
wxFONTENCODING_CP950
wxFONTENCODING_EUC_JP
wxFONTENCODING_GB2312
wxFONTENCODING_ISO2022_JP
wxFONTENCODING_ISO8859_MAX
wxFONTENCODING_KOI8_U
wxFONTENCODING_MACARABIC
wxFONTENCODING_MACARABICEXT
wxFONTENCODING_MACARMENIAN
wxFONTENCODING_MACBENGALI
wxFONTENCODING_MACBURMESE
wxFONTENCODING_MACCELTIC
wxFONTENCODING_MACCENTRALEUR
wxFONTENCODING_MACCHINESESIMP
wxFONTENCODING_MACCHINESETRAD
wxFONTENCODING_MACCROATIAN
wxFONTENCODING_MACCYRILLIC
wxFONTENCODING_MACDEVANAGARI
wxFONTENCODING_MACDINGBATS
wxFONTENCODING_MACETHIOPIC
wxFONTENCODING_MACGAELIC
wxFONTENCODING_MACGEORGIAN
wxFONTENCODING_MACGREEK
wxFONTENCODING_MACGUJARATI
wxFONTENCODING_MACGURMUKHI
wxFONTENCODING_MACHEBREW
wxFONTENCODING_MACICELANDIC
wxFONTENCODING_MACJAPANESE
wxFONTENCODING_MACKANNADA
wxFONTENCODING_MACKEYBOARD
wxFONTENCODING_MACKHMER
wxFONTENCODING_MACKOREAN
wxFONTENCODING_MACLAOTIAN
wxFONTENCODING_MACMALAJALAM
wxFONTENCODING_MACMAX
wxFONTENCODING_MACMIN
wxFONTENCODING_MACMONGOLIAN
wxFONTENCODING_MACORIYA
wxFONTENCODING_MACROMAN
wxFONTENCODING_MACROMANIAN
wxFONTENCODING_MACSINHALESE
wxFONTENCODING_MACSYMBOL
wxFONTENCODING_MACTAMIL
wxFONTENCODING_MACTELUGU
wxFONTENCODING_MACTHAI
wxFONTENCODING_MACTIBETAN
wxFONTENCODING_MACTURKISH
wxFONTENCODING_MACVIATNAMESE
wxFONTENCODING_MAX
wxFONTENCODING_SHIFT_JIS
wxFONTENCODING_UTF16
wxFONTENCODING_UTF16BE
wxFONTENCODING_UTF16LE
wxFONTENCODING_UTF32
wxFONTENCODING_UTF32BE
wxFONTENCODING_UTF32LE
wxFULLSCREEN_NOMENUBAR
wxFULLSCREEN_NOTOOLBAR
wxFULLSCREEN_NOSTATUSBAR
wxFULLSCREEN_NOBORDER
wxFULLSCREEN_NOCAPTION
wxFULLSCREEN_ALL
wxFULL_REPAINT_ON_RESIZE
wxFLP_OPEN
wxFLP_SAVE
wxFLP_OVERWRITE_PROMPT
wxFLP_FILE_MUST_EXIST
wxFLP_CHANGE_DIR
wxFLP_DEFAULT_STYLE
wxFLP_USE_TEXTCTRL
wxFNTP_USE_TEXTCTRL
wxFNTP_DEFAULT_STYLE
wxFNTP_FONTDESC_AS_LABEL
wxFNTP_USEFONT_FOR_LABEL
wxFNTP_MAXPOINT_SIZE
wxFORWARD
wxFC_OPEN
wxFC_SAVE
wxFC_MULTIPLE
wxFC_NOSHOWHIDDEN
wxFILTER_ALPHA
wxFILTER_ALPHANUMERIC
wxFILTER_ASCII
wxFILTER_EXCLUDE_CHAR_LIST
wxFILTER_EXCLUDE_LIST
wxFILTER_INCLUDE_CHAR_LIST
wxFILTER_INCLUDE_LIST
wxFILTER_NONE
wxFILTER_NUMERIC
wxGA_HORIZONTAL
wxGA_VERTICAL
wxGA_PROGRESSBAR
wxGA_SMOOTH
wxGROW
wxHELP
wxHIDE_READONLY
wxHORIZONTAL
wxHORIZONTAL_HATCH
wxHSCROLL
wxHeight
wxHLB_DEFAULT_STYLE
wxHLB_MULTIPLE
wxHL_CONTEXTMENU
wxHL_ALIGN_LEFT
wxHL_ALIGN_RIGHT
wxHL_ALIGN_CENTRE
wxHL_DEFAULT_STYLE
wxICONIZE
wxICON_EXCLAMATION
wxICON_HAND
wxICON_QUESTION
wxICON_INFORMATION
wxICON_WARNING
wxICON_ERROR
wxID_ANY
wxID_OPEN
wxID_CLOSE
wxID_NEW
wxID_SAVE
wxID_SAVEAS
wxID_REVERT
wxID_EXIT
wxID_UNDO
wxID_REDO
wxID_PRINT
wxID_PRINT_SETUP
wxID_PREVIEW
wxID_ABOUT
wxID_HELP_CONTENTS
wxID_HELP_COMMANDS
wxID_HELP_PROCEDURES
wxID_HELP_CONTEXT
wxID_HELP_SEARCH
wxID_HELP_INDEX
wxID_PAGE_SETUP
wxID_HELP
wxID_HIGHEST
wxID_LOWEST
wxID_CUT
wxID_COPY
wxID_PASTE
wxID_CLEAR
wxID_FIND
wxID_DUPLICATE
wxID_SELECTALL
wxID_FILE1
wxID_FILE2
wxID_FILE3
wxID_FILE4
wxID_FILE5
wxID_FILE6
wxID_FILE7
wxID_FILE8
wxID_FILE9
wxID_OK
wxID_CANCEL
wxID_APPLY
wxID_YES
wxID_NO
wxID_STATIC
wxID_CONTEXT_HELP
wxID_YESTOALL
wxID_NOTOALL
wxID_ABORT
wxID_RETRY
wxID_IGNORE
wxID_ADD
wxID_BOLD
wxID_BACKWARD
wxID_DOWN
wxID_UP
wxID_FORWARD
wxID_HOME
wxID_INDENT
wxID_INDEX
wxID_ITALIC
wxID_JUSTIFY_CENTER
wxID_JUSTIFY_LEFT
wxID_JUSTIFY_FILL
wxID_JUSTIFY_RIGHT
wxID_PREFERENCES
wxID_PROPERTIES
wxID_REFRESH
wxID_REMOVE
wxID_REVERT_TO_SAVED
wxID_STOP
wxID_SYSTEM_MENU
wxID_UNDELETE
wxID_UNDERLINE
wxID_UNINDENT
wxID_ZOOM_100
wxID_ZOOM_FIT
wxID_ZOOM_IN
wxID_ZOOM_OUT
wxID_CLOSE_ALL
wxID_CLOSE_FRAME
wxID_DEFAULT
wxID_DELETE
wxID_EDIT
wxID_FILE
wxID_FILEDLGG
wxID_ICONIZE_FRAME
wxID_MAXIMIZE_FRAME
wxID_MORE
wxID_MOVE_FRAME
wxID_REPLACE
wxID_REPLACE_ALL
wxID_RESET
wxID_RESIZE_FRAME
wxID_RESTORE_FRAME
wxID_SETUP
wxID_VIEW_DETAILS
wxID_VIEW_LARGEICONS
wxID_VIEW_LIST
wxID_VIEW_SMALLICONS
wxID_VIEW_SORTDATE
wxID_VIEW_SORTNAME
wxID_VIEW_SORTSIZE
wxID_VIEW_SORTTYPE
wxID_SEPARATOR
wxIMAGELIST_DRAW_NORMAL
wxIMAGELIST_DRAW_TRANSPARENT
wxIMAGELIST_DRAW_SELECTED
wxIMAGELIST_DRAW_FOCUSED
wxIMAGE_RESOLUTION_INCHES
wxIMAGE_RESOLUTION_CM
wxIMAGE_QUALITY_NORMAL
wxIMAGE_QUALITY_HIGH
wxIDLE_PROCESS_ALL
wxIDLE_PROCESS_SPECIFIED
wxINVERT
wxITALIC
wxInRegion
wxITEM_SEPARATOR
wxITEM_NORMAL
wxITEM_CHECK
wxITEM_RADIO
wxITEM_DROPDOWN
wxJOIN_BEVEL
wxJOIN_ROUND
wxJOIN_MITER
wxJOYSTICK1
wxJOYSTICK2
wxJOY_BUTTON1
wxJOY_BUTTON2
wxJOY_BUTTON3
wxJOY_BUTTON4
wxJOY_BUTTON_ANY
WXK_NONE
WXK_CONTROL_A
WXK_CONTROL_B
WXK_CONTROL_C
WXK_CONTROL_D
WXK_CONTROL_E
WXK_CONTROL_F
WXK_CONTROL_G
WXK_CONTROL_H
WXK_CONTROL_I
WXK_CONTROL_J
WXK_CONTROL_K
WXK_CONTROL_L
WXK_CONTROL_M
WXK_CONTROL_N
WXK_CONTROL_O
WXK_CONTROL_P
WXK_CONTROL_Q
WXK_CONTROL_R
WXK_CONTROL_S
WXK_CONTROL_U
WXK_CONTROL_V
WXK_CONTROL_W
WXK_CONTROL_X
WXK_CONTROL_Y
WXK_CONTROL_Z
WXK_RAW_CONTROL
WXK_WINDOWS_LEFT
WXK_WINDOWS_RIGHT
WXK_WINDOWS_MENU
WXK_COMMAND
WXK_WINDOWS_LEFT
WXK_WINDOWS_RIGHT
WXK_WINDOWS_MENU
WXK_COMMAND
WXK_BACK
WXK_TAB
WXK_RETURN
WXK_ESCAPE
WXK_SPACE
WXK_DELETE
WXK_START
WXK_LBUTTON
WXK_RBUTTON
WXK_CANCEL
WXK_MBUTTON
WXK_CLEAR
WXK_SHIFT
WXK_ALT
WXK_CONTROL
WXK_MENU
WXK_PAUSE
WXK_CAPITAL
WXK_PRIOR
WXK_NEXT
WXK_END
WXK_HOME
WXK_LEFT
WXK_UP
WXK_RIGHT
WXK_DOWN
WXK_SELECT
WXK_PRINT
WXK_EXECUTE
WXK_SNAPSHOT
WXK_INSERT
WXK_HELP
WXK_NUMPAD0
WXK_NUMPAD1
WXK_NUMPAD2
WXK_NUMPAD3
WXK_NUMPAD4
WXK_NUMPAD5
WXK_NUMPAD6
WXK_NUMPAD7
WXK_NUMPAD8
WXK_NUMPAD9
WXK_MULTIPLY
WXK_ADD
WXK_SEPARATOR
WXK_SUBTRACT
WXK_DECIMAL
WXK_DIVIDE
WXK_F1
WXK_F2
WXK_F3
WXK_F4
WXK_F5
WXK_F6
WXK_F7
WXK_F8
WXK_F9
WXK_F10
WXK_F11
WXK_F12
WXK_F13
WXK_F14
WXK_F15
WXK_F16
WXK_F17
WXK_F18
WXK_F19
WXK_F20
WXK_F21
WXK_F22
WXK_F23
WXK_F24
WXK_NUMLOCK
WXK_SCROLL
WXK_NUMPAD_SPACE
WXK_NUMPAD_TAB
WXK_NUMPAD_ENTER
WXK_NUMPAD_F1
WXK_NUMPAD_F2
WXK_NUMPAD_F3
WXK_NUMPAD_F4
WXK_NUMPAD_HOME
WXK_NUMPAD_LEFT
WXK_NUMPAD_UP
WXK_NUMPAD_RIGHT
WXK_NUMPAD_DOWN
WXK_NUMPAD_PAGEUP
WXK_NUMPAD_PAGEDOWN
WXK_NUMPAD_END
WXK_NUMPAD_BEGIN
WXK_NUMPAD_INSERT
WXK_NUMPAD_DELETE
WXK_NUMPAD_EQUAL
WXK_NUMPAD_MULTIPLY
WXK_NUMPAD_ADD
WXK_NUMPAD_SEPARATOR
WXK_NUMPAD_SUBTRACT
WXK_NUMPAD_DECIMAL
WXK_NUMPAD_DIVIDE
WXK_SPECIAL1
WXK_SPECIAL2
WXK_SPECIAL3
WXK_SPECIAL4
WXK_SPECIAL5
WXK_SPECIAL6
WXK_SPECIAL7
WXK_SPECIAL8
WXK_SPECIAL9
WXK_SPECIAL10
WXK_SPECIAL11
WXK_SPECIAL12
WXK_SPECIAL13
WXK_SPECIAL14
WXK_SPECIAL15
WXK_SPECIAL16
WXK_SPECIAL17
WXK_SPECIAL18
WXK_SPECIAL19
WXK_SPECIAL20
WXK_PAGEUP
WXK_PAGEDOWN
WXK_PRIOR
WXK_NEXT
WXK_NUMPAD_PRIOR
WXK_NUMPAD_NEXT
wxKILL_OK
wxKILL_BAD_SIGNAL
wxKILL_ACCESS_DENIED
wxKILL_NO_PROCESS
wxKILL_ERROR
wxKILL_NOCHILDREN
wxKILL_CHILDREN
wxLB_SINGLE
wxLB_MULTIPLE
wxLB_EXTENDED
wxLB_HSCROLL
wxLB_ALWAYS_SB
wxLB_NEEDED_SB
wxLB_OWNERDRAW
wxLB_SORT
wxLB_INT_HEIGHT
wxLB_DEFAULT
wxLB_TOP
wxLB_BOTTOM
wxLB_LEFT
wxLB_RIGHT
wxLB_ALIGN_MASK
wxLEFT
wxLIGHT
wxLI_HORIZONTAL
wxLI_VERTICAL
wxLONG_DASH
wxLeft
wxLeftOf
wxLOCALE_LOAD_DEFAULT
wxLOCALE_CONV_ENCODING
wxLayout_Default
wxLayout_LeftToRight
wxLayout_RightToLeft
wxLANGUAGE_DEFAULT
wxLANGUAGE_UNKNOWN
wxLANGUAGE_ABKHAZIAN
wxLANGUAGE_AFAR
wxLANGUAGE_AFRIKAANS
wxLANGUAGE_ALBANIAN
wxLANGUAGE_AMHARIC
wxLANGUAGE_ARABIC
wxLANGUAGE_ARABIC_ALGERIA
wxLANGUAGE_ARABIC_BAHRAIN
wxLANGUAGE_ARABIC_EGYPT
wxLANGUAGE_ARABIC_IRAQ
wxLANGUAGE_ARABIC_JORDAN
wxLANGUAGE_ARABIC_KUWAIT
wxLANGUAGE_ARABIC_LEBANON
wxLANGUAGE_ARABIC_LIBYA
wxLANGUAGE_ARABIC_MOROCCO
wxLANGUAGE_ARABIC_OMAN
wxLANGUAGE_ARABIC_QATAR
wxLANGUAGE_ARABIC_SAUDI_ARABIA
wxLANGUAGE_ARABIC_SUDAN
wxLANGUAGE_ARABIC_SYRIA
wxLANGUAGE_ARABIC_TUNISIA
wxLANGUAGE_ARABIC_UAE
wxLANGUAGE_ARABIC_YEMEN
wxLANGUAGE_ARMENIAN
wxLANGUAGE_ASSAMESE
wxLANGUAGE_AYMARA
wxLANGUAGE_AZERI
wxLANGUAGE_AZERI_CYRILLIC
wxLANGUAGE_AZERI_LATIN
wxLANGUAGE_BASHKIR
wxLANGUAGE_BASQUE
wxLANGUAGE_BELARUSIAN
wxLANGUAGE_BENGALI
wxLANGUAGE_BHUTANI
wxLANGUAGE_BIHARI
wxLANGUAGE_BISLAMA
wxLANGUAGE_BRETON
wxLANGUAGE_BULGARIAN
wxLANGUAGE_BURMESE
wxLANGUAGE_CAMBODIAN
wxLANGUAGE_CATALAN
wxLANGUAGE_CHINESE
wxLANGUAGE_CHINESE_SIMPLIFIED
wxLANGUAGE_CHINESE_TRADITIONAL
wxLANGUAGE_CHINESE_HONGKONG
wxLANGUAGE_CHINESE_MACAU
wxLANGUAGE_CHINESE_SINGAPORE
wxLANGUAGE_CHINESE_TAIWAN
wxLANGUAGE_CORSICAN
wxLANGUAGE_CROATIAN
wxLANGUAGE_CZECH
wxLANGUAGE_DANISH
wxLANGUAGE_DUTCH
wxLANGUAGE_DUTCH_BELGIAN
wxLANGUAGE_ENGLISH
wxLANGUAGE_ENGLISH_UK
wxLANGUAGE_ENGLISH_US
wxLANGUAGE_ENGLISH_AUSTRALIA
wxLANGUAGE_ENGLISH_BELIZE
wxLANGUAGE_ENGLISH_BOTSWANA
wxLANGUAGE_ENGLISH_CANADA
wxLANGUAGE_ENGLISH_CARIBBEAN
wxLANGUAGE_ENGLISH_DENMARK
wxLANGUAGE_ENGLISH_EIRE
wxLANGUAGE_ENGLISH_JAMAICA
wxLANGUAGE_ENGLISH_NEW_ZEALAND
wxLANGUAGE_ENGLISH_PHILIPPINES
wxLANGUAGE_ENGLISH_SOUTH_AFRICA
wxLANGUAGE_ENGLISH_TRINIDAD
wxLANGUAGE_ENGLISH_ZIMBABWE
wxLANGUAGE_ESPERANTO
wxLANGUAGE_ESTONIAN
wxLANGUAGE_FAEROESE
wxLANGUAGE_FARSI
wxLANGUAGE_FIJI
wxLANGUAGE_FINNISH
wxLANGUAGE_FRENCH
wxLANGUAGE_FRENCH_BELGIAN
wxLANGUAGE_FRENCH_CANADIAN
wxLANGUAGE_FRENCH_LUXEMBOURG
wxLANGUAGE_FRENCH_MONACO
wxLANGUAGE_FRENCH_SWISS
wxLANGUAGE_FRISIAN
wxLANGUAGE_GALICIAN
wxLANGUAGE_GEORGIAN
wxLANGUAGE_GERMAN
wxLANGUAGE_GERMAN_AUSTRIAN
wxLANGUAGE_GERMAN_BELGIUM
wxLANGUAGE_GERMAN_LIECHTENSTEIN
wxLANGUAGE_GERMAN_LUXEMBOURG
wxLANGUAGE_GERMAN_SWISS
wxLANGUAGE_GREEK
wxLANGUAGE_GREENLANDIC
wxLANGUAGE_GUARANI
wxLANGUAGE_GUJARATI
wxLANGUAGE_HAUSA
wxLANGUAGE_HEBREW
wxLANGUAGE_HINDI
wxLANGUAGE_HUNGARIAN
wxLANGUAGE_ICELANDIC
wxLANGUAGE_INDONESIAN
wxLANGUAGE_INTERLINGUA
wxLANGUAGE_INTERLINGUE
wxLANGUAGE_INUKTITUT
wxLANGUAGE_INUPIAK
wxLANGUAGE_IRISH
wxLANGUAGE_ITALIAN
wxLANGUAGE_ITALIAN_SWISS
wxLANGUAGE_JAPANESE
wxLANGUAGE_JAVANESE
wxLANGUAGE_KANNADA
wxLANGUAGE_KASHMIRI
wxLANGUAGE_KASHMIRI_INDIA
wxLANGUAGE_KAZAKH
wxLANGUAGE_KERNEWEK
wxLANGUAGE_KINYARWANDA
wxLANGUAGE_KIRGHIZ
wxLANGUAGE_KIRUNDI
wxLANGUAGE_KONKANI
wxLANGUAGE_KOREAN
wxLANGUAGE_KURDISH
wxLANGUAGE_LAOTHIAN
wxLANGUAGE_LATIN
wxLANGUAGE_LATVIAN
wxLANGUAGE_LINGALA
wxLANGUAGE_LITHUANIAN
wxLANGUAGE_MACEDONIAN
wxLANGUAGE_MALAGASY
wxLANGUAGE_MALAY
wxLANGUAGE_MALAYALAM
wxLANGUAGE_MALAY_BRUNEI_DARUSSALAM
wxLANGUAGE_MALAY_MALAYSIA
wxLANGUAGE_MALTESE
wxLANGUAGE_MANIPURI
wxLANGUAGE_MAORI
wxLANGUAGE_MARATHI
wxLANGUAGE_MOLDAVIAN
wxLANGUAGE_MONGOLIAN
wxLANGUAGE_NAURU
wxLANGUAGE_NEPALI
wxLANGUAGE_NEPALI_INDIA
wxLANGUAGE_NORWEGIAN_BOKMAL
wxLANGUAGE_NORWEGIAN_NYNORSK
wxLANGUAGE_OCCITAN
wxLANGUAGE_ORIYA
wxLANGUAGE_OROMO
wxLANGUAGE_PASHTO
wxLANGUAGE_POLISH
wxLANGUAGE_PORTUGUESE
wxLANGUAGE_PORTUGUESE_BRAZILIAN
wxLANGUAGE_PUNJABI
wxLANGUAGE_QUECHUA
wxLANGUAGE_RHAETO_ROMANCE
wxLANGUAGE_ROMANIAN
wxLANGUAGE_RUSSIAN
wxLANGUAGE_RUSSIAN_UKRAINE
wxLANGUAGE_SAMI
wxLANGUAGE_SAMOAN
wxLANGUAGE_SANGHO
wxLANGUAGE_SANSKRIT
wxLANGUAGE_SCOTS_GAELIC
wxLANGUAGE_SERBIAN
wxLANGUAGE_SERBIAN_CYRILLIC
wxLANGUAGE_SERBIAN_LATIN
wxLANGUAGE_SERBO_CROATIAN
wxLANGUAGE_SESOTHO
wxLANGUAGE_SETSWANA
wxLANGUAGE_SHONA
wxLANGUAGE_SINDHI
wxLANGUAGE_SINHALESE
wxLANGUAGE_SISWATI
wxLANGUAGE_SLOVAK
wxLANGUAGE_SLOVENIAN
wxLANGUAGE_SOMALI
wxLANGUAGE_SPANISH
wxLANGUAGE_SPANISH_ARGENTINA
wxLANGUAGE_SPANISH_BOLIVIA
wxLANGUAGE_SPANISH_CHILE
wxLANGUAGE_SPANISH_COLOMBIA
wxLANGUAGE_SPANISH_COSTA_RICA
wxLANGUAGE_SPANISH_DOMINICAN_REPUBLIC
wxLANGUAGE_SPANISH_ECUADOR
wxLANGUAGE_SPANISH_EL_SALVADOR
wxLANGUAGE_SPANISH_GUATEMALA
wxLANGUAGE_SPANISH_HONDURAS
wxLANGUAGE_SPANISH_MEXICAN
wxLANGUAGE_SPANISH_MODERN
wxLANGUAGE_SPANISH_NICARAGUA
wxLANGUAGE_SPANISH_PANAMA
wxLANGUAGE_SPANISH_PARAGUAY
wxLANGUAGE_SPANISH_PERU
wxLANGUAGE_SPANISH_PUERTO_RICO
wxLANGUAGE_SPANISH_URUGUAY
wxLANGUAGE_SPANISH_US
wxLANGUAGE_SPANISH_VENEZUELA
wxLANGUAGE_SUNDANESE
wxLANGUAGE_SWAHILI
wxLANGUAGE_SWEDISH
wxLANGUAGE_SWEDISH_FINLAND
wxLANGUAGE_TAGALOG
wxLANGUAGE_TAJIK
wxLANGUAGE_TAMIL
wxLANGUAGE_TATAR
wxLANGUAGE_TELUGU
wxLANGUAGE_THAI
wxLANGUAGE_TIBETAN
wxLANGUAGE_TIGRINYA
wxLANGUAGE_TONGA
wxLANGUAGE_TSONGA
wxLANGUAGE_TURKISH
wxLANGUAGE_TURKMEN
wxLANGUAGE_TWI
wxLANGUAGE_UIGHUR
wxLANGUAGE_UKRAINIAN
wxLANGUAGE_URDU
wxLANGUAGE_URDU_INDIA
wxLANGUAGE_URDU_PAKISTAN
wxLANGUAGE_UZBEK
wxLANGUAGE_UZBEK_CYRILLIC
wxLANGUAGE_UZBEK_LATIN
wxLANGUAGE_VALENCIAN
wxLANGUAGE_VIETNAMESE
wxLANGUAGE_VOLAPUK
wxLANGUAGE_WELSH
wxLANGUAGE_WOLOF
wxLANGUAGE_XHOSA
wxLANGUAGE_YIDDISH
wxLANGUAGE_YORUBA
wxLANGUAGE_ZHUANG
wxLANGUAGE_ZULU
wxLANGUAGE_USER_DEFINED
wxMAXIMIZE
wxMAXIMIZE_BOX
wxMENU_TEAROFF
wxMINIMIZE
wxMINIMIZE_BOX
wxMODERN
wxMULTIPLE
wxMAJOR_VERSION
wxMINOR_VERSION
wxMM_TWIPS
wxMM_POINTS
wxMM_METRIC
wxMM_LOMETRIC
wxMM_TEXT
wxMORE
wxMB_DOCKABLE
wxMOUSE_BTN_ANY
wxMOUSE_BTN_NONE
wxMOUSE_BTN_LEFT
wxMOUSE_BTN_MIDDLE
wxMOUSE_BTN_RIGHT
wxMOUSE_BTN_AUX1
wxMOUSE_BTN_AUX2
wxMOD_NONE
wxMOD_ALT
wxMOD_CONTROL
wxMOD_SHIFT
wxMOD_WIN
wxMOD_ALTGR
wxMOD_META
wxMOD_CMD
wxMOD_ALL
wxNB_FIXEDWIDTH
wxNB_LEFT
wxNB_RIGHT
wxNB_BOTTOM
wxNB_TOP
wxNB_MULTILINE
wxNB_HITTEST_NOWHERE
wxNB_HITTEST_ONICON
wxNB_HITTEST_ONLABEL
wxNB_HITTEST_ONITEM
wxNB_HITTEST_ONPAGE
wxNB_DEFAULT
wxNB_FLAT
wxNB_NOPAGETHEME
wxNO
wxNO_BORDER
wxNO_3D
wxNO_FULL_REPAINT_ON_RESIZE
wxNORMAL
wxNOT_FOUND
wxNO_DEFAULT
wxNAND
wxNOR
wxNO_OP
wxNORTH
wxNavigateBackward
wxNavigateForward
wxNavigateWinChange
wxNavigateFromTab
wxOK
wxOPEN
wxOVERWRITE_PROMPT
wxODDEVEN_RULE
wxOR
wxOR_INVERT
wxOR_REVERSE
wxOutRegion
wxODCB_DCLICK_CYCLES
wxODCB_STD_CONTROL_PAINT
wxODCB_PAINTING_CONTROL
wxODCB_PAINTING_SELECTED
wxPROCESS_ENTER
wxPD_APP_MODAL
wxPD_AUTO_HIDE
wxPD_CAN_ABORT
wxPD_ELAPSED_TIME
wxPD_ESTIMATED_TIME
wxPD_REMAINING_TIME
wxPD_SMOOTH
wxPD_CAN_SKIP
wxPOWER_SOCKET
wxPOWER_BATTERY
wxPOWER_UNKNOWN
wxPB_USE_TEXTCTRL
wxPercentOf
wxPartRegion
wxPROP_DEPRECATED
wxPROP_OBJECT_GRAPH
wxPROP_ENUM_STORE_LONG
wxPROP_DONT_STREAM
wxPROPSHEET_DEFAULT
wxPROPSHEET_NOTEBOOK
wxPROPSHEET_TOOLBOOK
wxPROPSHEET_CHOICEBOOK
wxPROPSHEET_LISTBOOK
wxPROPSHEET_BUTTONTOOLBOOK
wxPROPSHEET_TREEBOOK
wxPROPSHEET_SHRINKTOFIT
wxPENSTYLE_BDIAGONAL_HATCH
wxPENSTYLE_CROSSDIAG_HATCH
wxPENSTYLE_CROSS_HATCH
wxPENSTYLE_DOT
wxPENSTYLE_DOT_DASH
wxPENSTYLE_FDIAGONAL_HATCH
wxPENSTYLE_FIRST_HATCH
wxPENSTYLE_HORIZONTAL_HATCH
wxPENSTYLE_INVALID
wxPENSTYLE_LAST_HATCH
wxPENSTYLE_LONG_DASH
wxPENSTYLE_SHORT_DASH
wxPENSTYLE_SOLID
wxPENSTYLE_STIPPLE
wxPENSTYLE_STIPPLE_MASK
wxPENSTYLE_STIPPLE_MASK_OPAQUE
wxPENSTYLE_TRANSPARENT
wxPENSTYLE_USER_DASH
wxPENSTYLE_VERTICAL_HATCH
wxRAISED_BORDER
wxRA_SPECIFY_ROWS
wxRA_SPECIFY_COLS
wxRA_HORIZONTAL
wxRA_LEFTTORIGHT
wxRA_TOPTOBOTTOM
wxRA_USE_CHECKBOX
wxRA_VERTICAL
wxRB_GROUP
wxRB_SINGLE
wxRB_USE_CHECKBOX
wxRESIZE_BORDER
wxRETAINED
wxRIGHT
wxROMAN
wxRight
wxRightOf
wxRESET
wxROP_BLACK
wxROP_COPYPEN
wxROP_MASKNOTPEN
wxROP_MASKPEN
wxROP_MASKPENNOT
wxROP_MERGENOTPEN
wxROP_MERGEPEN
wxROP_MERGEPENNOT
wxROP_NOP
wxROP_NOT
wxROP_NOTCOPYPEN
wxROP_NOTMASKPEN
wxROP_NOTMERGEPEN
wxROP_NOTXORPEN
wxROP_WHITE
wxROP_XORPEN
wxSPLASH_CENTRE_ON_PARENT
wxSPLASH_CENTRE_ON_SCREEN
wxSPLASH_NO_CENTRE
wxSPLASH_CENTER_ON_PARENT
wxSPLASH_CENTER_ON_SCREEN
wxSPLASH_NO_CENTER
wxSPLASH_TIMEOUT
wxSPLASH_NO_TIMEOUT
wxSAVE
wxSB_HORIZONTAL
wxSB_VERTICAL
wxSHOW_SB_ALWAYS
wxSHOW_SB_NEVER
wxSHOW_SB_DEFAULT
wxSB_NORMAL
wxSB_FLAT
wxSB_RAISED
wxSCRIPT
wxSIMPLE_BORDER
wxSLANT
wxSTATIC_BORDER
wxSTAY_ON_TOP
wxST_NO_AUTORESIZE
wxST_ELLIPSIZE_START
wxST_ELLIPSIZE_MIDDLE
wxST_ELLIPSIZE_END
wxST_MARKUP
wxST_SIZEGRIP
wxSUNKEN_BORDER
wxSYSTEM_MENU
wxSWISS
wxSL_HORIZONTAL
wxSL_VERTICAL
wxSL_AUTOTICKS
wxSL_LABELS
wxSL_LEFT
wxSL_RIGHT
wxSL_TOP
wxSL_SELRANGE
wxSL_BOTH
wxSL_BOTTOM
wxSL_TICKS
wxSL_INVERSE
wxSIZE_AUTO_WIDTH
wxSIZE_AUTO_HEIGHT
wxSIZE_AUTO
wxSIZE_USE_EXISTING
wxSIZE_ALLOW_MINUS_ONE
wxSIZE_FORCE
wxSIGNONE
wxSIGHUP
wxSIGINT
wxSIGQUIT
wxSIGILL
wxSIGTRAP
wxSIGABRT
wxSIGEMT
wxSIGFPE
wxSIGKILL
wxSIGBUS
wxSIGSEGV
wxSIGSYS
wxSIGPIPE
wxSIGALRM
wxSIGTERM
wxSP_HORIZONTAL
wxSP_VERTICAL
wxSP_ARROW_KEYS
wxSP_WRAP
wxSP_3D
wxSP_3DSASH
wxSP_3DBORDER
wxSP_FULLSASH
wxSP_BORDER
wxSP_NOBORDER
wxSP_PERMIT_UNSPLIT
wxSP_LIVE_UPDATE
wxSP_NOSASH
wxSP_NO_XP_THEME
wxSPLIT_HORIZONTAL
wxSPLIT_VERTICAL
wxSHAPED
wxSHORT_DASH
wxSTIPPLE
wxSTIPPLE_MASK_OPAQUE
wxSET
wxSRC_INVERT
wxSOLID
wxSASH_STATUS_OK
wxSASH_STATUS_OUT_OF_RANGE
wxSASH_TOP
wxSASH_RIGHT
wxSASH_BOTTOM
wxSASH_LEFT
wxSASH_NONE
wxSW_3D
wxSW_3DSASH
wxSW_3DBORDER
wxSW_BORDER
wxSOUND_SYNC
wxSOUND_ASYNC
wxSOUND_LOOP
wxSameAs
wxSYS_OEM_FIXED_FONT
wxSYS_ANSI_FIXED_FONT
wxSYS_ANSI_VAR_FONT
wxSYS_SYSTEM_FONT
wxSYS_DEVICE_DEFAULT_FONT
wxSYS_DEFAULT_GUI_FONT
wxSYS_ICONTITLE_FONT
wxSYS_SYSTEM_FIXED_FONT
wxSYS_COLOUR_SCROLLBAR
wxSYS_COLOUR_BACKGROUND
wxSYS_COLOUR_ACTIVECAPTION
wxSYS_COLOUR_INACTIVECAPTION
wxSYS_COLOUR_MENU
wxSYS_COLOUR_WINDOW
wxSYS_COLOUR_WINDOWFRAME
wxSYS_COLOUR_MENUTEXT
wxSYS_COLOUR_WINDOWTEXT
wxSYS_COLOUR_CAPTIONTEXT
wxSYS_COLOUR_ACTIVEBORDER
wxSYS_COLOUR_INACTIVEBORDER
wxSYS_COLOUR_APPWORKSPACE
wxSYS_COLOUR_HIGHLIGHT
wxSYS_COLOUR_HIGHLIGHTTEXT
wxSYS_COLOUR_BTNFACE
wxSYS_COLOUR_BTNSHADOW
wxSYS_COLOUR_GRAYTEXT
wxSYS_COLOUR_BTNTEXT
wxSYS_COLOUR_INACTIVECAPTIONTEXT
wxSYS_COLOUR_BTNHIGHLIGHT
wxSYS_COLOUR_3DDKSHADOW
wxSYS_COLOUR_3DLIGHT
wxSYS_COLOUR_INFOTEXT
wxSYS_COLOUR_INFOBK
wxSYS_COLOUR_LISTBOX
wxSYS_COLOUR_DESKTOP
wxSYS_COLOUR_3DFACE
wxSYS_COLOUR_3DSHADOW
wxSYS_COLOUR_3DHIGHLIGHT
wxSYS_COLOUR_3DHILIGHT
wxSYS_COLOUR_BTNHILIGHT
wxSYS_COLOUR_MAX
wxSYS_MOUSE_BUTTONS
wxSYS_BORDER_X
wxSYS_BORDER_Y
wxSYS_CURSOR_X
wxSYS_CURSOR_Y
wxSYS_DCLICK_X
wxSYS_DCLICK_Y
wxSYS_DRAG_X
wxSYS_DRAG_Y
wxSYS_EDGE_X
wxSYS_EDGE_Y
wxSYS_HSCROLL_ARROW_X
wxSYS_HSCROLL_ARROW_Y
wxSYS_HTHUMB_X
wxSYS_ICON_X
wxSYS_ICON_Y
wxSYS_ICONSPACING_X
wxSYS_ICONSPACING_Y
wxSYS_WINDOWMIN_X
wxSYS_WINDOWMIN_Y
wxSYS_SCREEN_X
wxSYS_SCREEN_Y
wxSYS_FRAMESIZE_X
wxSYS_FRAMESIZE_Y
wxSYS_SMALLICON_X
wxSYS_SMALLICON_Y
wxSYS_HSCROLL_Y
wxSYS_VSCROLL_X
wxSYS_VSCROLL_ARROW_X
wxSYS_VSCROLL_ARROW_Y
wxSYS_VTHUMB_Y
wxSYS_CAPTION_Y
wxSYS_MENU_Y
wxSYS_NETWORK_PRESENT
wxSYS_PENWINDOWS_PRESENT
wxSYS_SHOW_SOUNDS
wxSYS_SWAP_BUTTONS
wxSYS_SCREEN_NONE
wxSYS_SCREEN_TINY
wxSYS_SCREEN_PDA
wxSYS_SCREEN_SMALL
wxSYS_SCREEN_DESKTOP
wxSYS_DCLICK_MSEC
wxSYS_DEFAULT_PALETTE
wxSYS_TABLET_PRESENT
wxSYS_CAN_DRAW_FRAME_DECORATIONS
wxSYS_CAN_ICONIZE_FRAME
wxSYS_COLOUR_HOTLIGHT
wxSYS_COLOUR_GRADIENTACTIVECAPTION
wxSYS_COLOUR_GRADIENTINACTIVECAPTION
wxSYS_COLOUR_MENUHILIGHT
wxSYS_COLOUR_MENUBAR
wxSTOCK_NOFLAGS
wxSTOCK_WITH_MNEMONIC
wxSTOCK_WITH_ACCELERATOR
wxSTOCK_MENU
wxSOUTH
wxSETUP
wxTAB_TRAVERSAL
wxTB_FLAT
wxTB_DOCKABLE
wxTB_HORIZONTAL
wxTB_VERTICAL
wxTB_3DBUTTONS
wxTB_TEXT
wxTB_NOICONS
wxTB_HORZ_LAYOUT
wxTB_HORZ_TEXT
wxTB_NO_TOOLTIPS
wxTB_RIGHT
wxTB_BOTTOM
wxTB_LEFT
wxTB_TOP
wxTB_NOALIGN
wxTB_NODIVIDER
wxTOOL_STYLE_BUTTON
wxTOOL_STYLE_CONTROL
wxTOOL_STYLE_SEPARATOR
wxTELETYPE
wxTE_PROCESS_ENTER
wxTE_PROCESS_TAB
wxTE_MULTILINE
wxTE_NOHIDESEL
wxTE_NO_VSCROLL
wxTE_PASSWORD
wxTE_READONLY
wxTE_RICH
wxTE_RICH2
wxTE_LEFT
wxTE_RIGHT
wxTE_CENTRE
wxTE_CENTER
wxTE_AUTO_URL
wxTE_DONTWRAP
wxTE_WORDWRAP
wxTE_CHARWRAP
wxTE_BESTWRAP
wxTE_HT_UNKNOWN
wxTE_HT_BEFORE
wxTE_HT_ON_TEXT
wxTE_HT_BELOW
wxTE_HT_BEYOND
wxTE_AUTO_SCROLL
wxTE_CAPITALIZE
wxTHICK_FRAME
wxTEXT_ALIGNMENT_DEFAULT
wxTEXT_ALIGNMENT_LEFT
wxTEXT_ALIGNMENT_CENTRE
wxTEXT_ALIGNMENT_CENTER
wxTEXT_ALIGNMENT_RIGHT
wxTEXT_ALIGNMENT_JUSTIFIED
wxTEXT_ATTR_TEXT_COLOUR
wxTEXT_ATTR_BACKGROUND_COLOUR
wxTEXT_ATTR_FONT_FACE
wxTEXT_ATTR_FONT_SIZE
wxTEXT_ATTR_FONT_WEIGHT
wxTEXT_ATTR_FONT_ITALIC
wxTEXT_ATTR_FONT_UNDERLINE
wxTEXT_ATTR_FONT
wxTEXT_ATTR_ALIGNMENT
wxTEXT_ATTR_LEFT_INDENT
wxTEXT_ATTR_RIGHT_INDENT
wxTEXT_ATTR_TABS
wxTEXT_ATTR_EFFECT_NONE
wxTEXT_ATTR_EFFECT_CAPITALS
wxTEXT_ATTR_EFFECT_SMALL_CAPITALS
wxTEXT_ATTR_EFFECT_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_SHADOW
wxTEXT_ATTR_EFFECT_EMBOSS
wxTEXT_ATTR_EFFECT_OUTLINE
wxTEXT_ATTR_EFFECT_ENGRAVE
wxTEXT_ATTR_EFFECT_SUPERSCRIPT
wxTEXT_ATTR_EFFECT_SUBSCRIPT
wxTEXT_ATTR_EFFECTS
wxTEXT_ATTR_FONT_ENCODING
wxTEXT_ATTR_OUTLINE_LEVEL
wxTEXT_TYPE_ANY
wxTINY_CAPTION_HORIZ
wxTINY_CAPTION_VERT
wxTIMER_CONTINUOUS
wxTIMER_ONE_SHOT
wxTOP
wxTRANSPARENT_WINDOW
wxTRANSPARENT
wxTop
wxTBK_HORZ_LAYOUT
wxTBK_BUTTONBAR
Type_Boolean
Type_Float
Type_Integer
Type_String
Type_Unknown
wxT_VOID
wxT_BOOL
wxT_CHAR
wxT_UCHAR
wxT_INT
wxT_UINT
wxT_LONG
wxT_ULONG
wxT_FLOAT
wxT_DOUBLE
wxT_STRING
wxT_SET
wxT_ENUM
wxT_CUSTOM
wxT_LAST_SIMPLE_TYPE_KIND
wxT_OBJECT_PTR
wxT_OBJECT
wxT_COLLECTION
wxT_DELEGATE
wxUnconstrained
wxUSER_DASH
wxUSER_ATTENTION_INFO
wxUSER_ATTENTION_ERROR
wxUPDATE_UI_NONE
wxUPDATE_UI_RECURSE
wxUPDATE_UI_FROMIDLE
wxUPDATE_UI_PROCESS_ALL
wxUPDATE_UI_PROCESS_SPECIFIED
wxUP
wxVERTICAL
wxVERTICAL_HATCH
wxVSCROLL
wxWANTS_CHARS
wxWINDING_RULE
wxWidth
wxWIZARD_EX_HELPBUTTON
wxWIZARD_HALIGN_CENTRE
wxWIZARD_HALIGN_LEFT
wxWIZARD_HALIGN_RIGHT
wxWIZARD_TILE
wxWIZARD_VALIGN_BOTTOM
wxWIZARD_VALIGN_CENTRE
wxWIZARD_VALIGN_TOP
wxWS_EX_VALIDATE_RECURSIVELY
wxWS_EX_BLOCK_EVENTS
wxWS_EX_TRANSIENT
wxWS_EX_PROCESS_IDLE
wxWS_EX_PROCESS_UI_UPDATES
wxWS_EX_CONTEXTHELP
wxWEST
wxWINDOW_VARIANT_NORMAL
wxWINDOW_VARIANT_SMALL
wxWINDOW_VARIANT_MINI
wxWINDOW_VARIANT_LARGE
wxXOR
wxYES
wxYES_NO
wxYES_DEFAULT
wxVERSION_STRING
wxMEDIABACKEND_DIRECTSHOW
wxMEDIABACKEND_QUICKTIME
wxMEDIABACKEND_MCI
wxMEDIABACKEND_GSTREAMER
wxMEDIABACKEND_REALPLAYER
wxMEDIABACKEND_WMP10
wxPG_ATTR_UNITS
wxPG_ATTR_HINT
wxPG_ATTR_INLINE_HELP
wxPG_ATTR_DEFAULT_VALUE
wxPG_ATTR_MIN
wxPG_ATTR_MAX
wxPG_ATTR_AUTOCOMPLETE
wxPG_BOOL_USE_CHECKBOX
wxPG_BOOL_USE_DOUBLE_CLICK_CYCLING
wxPG_FLOAT_PRECISION
wxPG_STRING_PASSWORD
wxPG_UINT_BASE
wxPG_UINT_PREFIX
wxPG_FILE_WILDCARD
wxPG_FILE_SHOW_FULL_PATH
wxPG_FILE_SHOW_RELATIVE_PATH
wxPG_FILE_INITIAL_PATH
wxPG_FILE_DIALOG_TITLE
wxPG_DIR_DIALOG_MESSAGE
wxPG_ARRAY_DELIMITER
wxPG_DATE_FORMAT
wxPG_DATE_PICKER_STYLE
wxPG_ATTR_SPINCTRL_STEP
wxPG_ATTR_SPINCTRL_WRAP
wxPG_ATTR_MULTICHOICE_USERSTRINGMODE
wxPG_COLOUR_ALLOW_CUSTOM
wxPG_COLOUR_HAS_ALPHA
wxTheClipboard
wxDefaultValidator
wxFormatInvalid
wxDefaultPosition
wxDefaultSize
wxThePrintPaperDatabase
wxNullAnimation
wxNullBitmap
wxNullIcon
wxNullColour
wxNullCursor
wxNullFont
wxNullPen
wxNullBrush
wxNullPalette
wxNullAcceleratorTable
wxRED
wxGREEN
wxBLUE
wxBLACK
wxWHITE
wxCYAN
wxLIGHT_GREY
wxSTANDARD_CURSOR
wxHOURGLASS_CURSOR
wxCROSS_CURSOR
wxNORMAL_FONT
wxSMALL_FONT
wxITALIC_FONT
wxSWISS_FONT
wxRED_PEN
wxGREEN_PEN
wxCYAN_PEN
wxBLACK_PEN
wxWHITE_PEN
wxTRANSPARENT_PEN
wxBLACK_DASHED_PEN
wxGREY_PEN
wxMEDIUM_GREY_PEN
wxLIGHT_GREY_PEN
wxBLUE_BRUSH
wxGREEN_BRUSH
wxWHITE_BRUSH
wxBLACK_BRUSH
wxGREY_BRUSH
wxMEDIUM_GREY_BRUSH
wxLIGHT_GREY_BRUSH
wxTRANSPARENT_BRUSH
wxCYAN_BRUSH
wxRED_BRUSH
wxIMAGE_OPTION_BMP_FORMAT
wxIMAGE_OPTION_CUR_HOTSPOT_X
wxIMAGE_OPTION_CUR_HOTSPOT_Y
wxIMAGE_OPTION_FILENAME
wxIMAGE_OPTION_QUALITY
wxIMAGE_OPTION_RESOLUTION
wxIMAGE_OPTION_RESOLUTIONX
wxIMAGE_OPTION_RESOLUTIONY
wxIMAGE_OPTION_RESOLUTIONUNIT
wxIMAGE_OPTION_BITSPERSAMPLE
wxIMAGE_OPTION_COMPRESSION
wxIMAGE_OPTION_IMAGEDESCRIPTOR
wxIMAGE_OPTION_PNG_BITDEPTH
wxIMAGE_OPTION_PNG_FORMAT
wxIMAGE_OPTION_SAMPLESPERPIXEL
wxFileSelectorDefaultWildcardStr
wxGRID_VALUE_STRING
wxGRID_VALUE_BOOL
wxGRID_VALUE_NUMBER
wxGRID_VALUE_FLOAT
wxGRID_VALUE_CHOICE
wxGRID_VALUE_TEXT
wxGRID_VALUE_LONG
wxEVT_COMMAND_LIST_BEGIN_DRAG
wxEVT_COMMAND_LIST_BEGIN_RDRAG
wxEVT_COMMAND_LIST_BEGIN_LABEL_EDIT
wxEVT_COMMAND_LIST_CACHE_HINT
wxEVT_COMMAND_LIST_COL_RIGHT_CLICK
wxEVT_COMMAND_LIST_COL_BEGIN_DRAG
wxEVT_COMMAND_LIST_COL_DRAGGING
wxEVT_COMMAND_LIST_COL_END_DRAG
wxEVT_COMMAND_LIST_END_LABEL_EDIT
wxEVT_COMMAND_LIST_DELETE_ITEM
wxEVT_COMMAND_LIST_DELETE_ALL_ITEMS
wxEVT_COMMAND_LIST_SET_INFO
wxEVT_COMMAND_LIST_GET_INFO
wxEVT_COMMAND_LIST_ITEM_SELECTED
wxEVT_COMMAND_LIST_ITEM_DESELECTED
wxEVT_COMMAND_LIST_KEY_DOWN
wxEVT_COMMAND_LIST_INSERT_ITEM
wxEVT_COMMAND_LIST_COL_CLICK
wxEVT_COMMAND_LIST_ITEM_RIGHT_CLICK
wxEVT_COMMAND_LIST_ITEM_MIDDLE_CLICK
wxEVT_COMMAND_LIST_ITEM_ACTIVATED
wxEVT_COMMAND_LIST_ITEM_FOCUSED
wxIMAGE_LIST_NORMAL
wxIMAGE_LIST_SMALL
wxIMAGE_LIST_STATE
wxLIST_AUTOSIZE
wxLIST_AUTOSIZE_USEHEADER
wxLIST_ALIGN_DEFAULT
wxLIST_ALIGN_LEFT
wxLIST_ALIGN_TOP
wxLIST_ALIGN_SNAP_TO_GRID
wxLIST_FIND_UP
wxLIST_FIND_DOWN
wxLIST_FIND_LEFT
wxLIST_FIND_RIGHT
wxLIST_FORMAT_LEFT
wxLIST_FORMAT_RIGHT
wxLIST_FORMAT_CENTRE
wxLIST_FORMAT_CENTER
wxLIST_HITTEST_ABOVE
wxLIST_HITTEST_BELOW
wxLIST_HITTEST_NOWHERE
wxLIST_HITTEST_ONITEMICON
wxLIST_HITTEST_ONITEMLABEL
wxLIST_HITTEST_ONITEMRIGHT
wxLIST_HITTEST_ONITEMSTATEICON
wxLIST_HITTEST_TOLEFT
wxLIST_HITTEST_TORIGHT
wxLIST_HITTEST_ONITEM
wxLIST_GETSUBITEMRECT_WHOLEITEM
wxLIST_MASK_STATE
wxLIST_MASK_TEXT
wxLIST_MASK_IMAGE
wxLIST_MASK_DATA
wxLIST_MASK_WIDTH
wxLIST_MASK_FORMAT
wxLIST_NEXT_ABOVE
wxLIST_NEXT_ALL
wxLIST_NEXT_BELOW
wxLIST_NEXT_LEFT
wxLIST_NEXT_RIGHT
wxLIST_RECT_BOUNDS
wxLIST_RECT_ICON
wxLIST_RECT_LABEL
wxLIST_STATE_DONTCARE
wxLIST_STATE_DROPHILITED
wxLIST_STATE_FOCUSED
wxLIST_STATE_SELECTED
wxLIST_STATE_CUT
wxLIST_SET_ITEM
wxLC_VRULES
wxLC_HRULES
wxLC_ICON
wxLC_SMALL_ICON
wxLC_LIST
wxLC_REPORT
wxLC_ALIGN_TOP
wxLC_ALIGN_LEFT
wxLC_AUTOARRANGE
wxLC_USER_TEXT
wxLC_EDIT_LABELS
wxLC_NO_HEADER
wxLC_NO_SORT_HEADER
wxLC_SINGLE_SEL
wxLC_SORT_ASCENDING
wxLC_SORT_DESCENDING
wxLC_VIRTUAL
wxEVT_COMMAND_TREE_BEGIN_DRAG
wxEVT_COMMAND_TREE_BEGIN_RDRAG
wxEVT_COMMAND_TREE_BEGIN_LABEL_EDIT
wxEVT_COMMAND_TREE_END_LABEL_EDIT
wxEVT_COMMAND_TREE_DELETE_ITEM
wxEVT_COMMAND_TREE_GET_INFO
wxEVT_COMMAND_TREE_SET_INFO
wxEVT_COMMAND_TREE_ITEM_EXPANDED
wxEVT_COMMAND_TREE_ITEM_EXPANDING
wxEVT_COMMAND_TREE_ITEM_COLLAPSED
wxEVT_COMMAND_TREE_ITEM_COLLAPSING
wxEVT_COMMAND_TREE_SEL_CHANGED
wxEVT_COMMAND_TREE_SEL_CHANGING
wxEVT_COMMAND_TREE_KEY_DOWN
wxEVT_COMMAND_TREE_ITEM_ACTIVATED
wxEVT_COMMAND_TREE_ITEM_MENU
wxEVT_COMMAND_TREE_ITEM_RIGHT_CLICK
wxEVT_COMMAND_TREE_ITEM_MIDDLE_CLICK
wxEVT_COMMAND_TREE_END_DRAG
wxEVT_COMMAND_TREE_STATE_IMAGE_CLICK
wxEVT_COMMAND_TREE_ITEM_GETTOOLTIP
wxTR_DEFAULT_STYLE
wxTR_EDIT_LABELS
wxTR_EXTENDED
wxTR_FULL_ROW_HIGHLIGHT
wxTR_HAS_BUTTONS
wxTR_HAS_VARIABLE_ROW_HEIGHT
wxTR_HIDE_ROOT
wxTR_LINES_AT_ROOT
wxTR_MULTIPLE
wxTR_NO_BUTTONS
wxTR_NO_LINES
wxTR_ROW_LINES
wxTR_SINGLE
wxTR_TWIST_BUTTONS
wxTreeItemIcon_Normal
wxTreeItemIcon_Selected
wxTreeItemIcon_Expanded
wxTreeItemIcon_SelectedExpanded
wxTREE_HITTEST_ABOVE
wxTREE_HITTEST_BELOW
wxTREE_HITTEST_NOWHERE
wxTREE_HITTEST_ONITEMBUTTON
wxTREE_HITTEST_ONITEMICON
wxTREE_HITTEST_ONITEMINDENT
wxTREE_HITTEST_ONITEMLABEL
wxTREE_HITTEST_ONITEMRIGHT
wxTREE_HITTEST_ONITEMSTATEICON
wxTREE_HITTEST_TOLEFT
wxTREE_HITTEST_TORIGHT
wxTREE_HITTEST_ONITEMUPPERPART
wxTREE_HITTEST_ONITEMLOWERPART
wxTREE_HITTEST_ONITEM
wxAUI_DOCK_NONE
wxAUI_DOCK_TOP
wxAUI_DOCK_RIGHT
wxAUI_DOCK_BOTTOM
wxAUI_DOCK_LEFT
wxAUI_DOCK_CENTER
wxAUI_DOCK_CENTRE
wxAUI_MGR_ALLOW_FLOATING
wxAUI_MGR_ALLOW_ACTIVE_PANE
wxAUI_MGR_TRANSPARENT_DRAG
wxAUI_MGR_TRANSPARENT_HINT
wxAUI_MGR_VENETIAN_BLINDS_HINT
wxAUI_MGR_RECTANGLE_HINT
wxAUI_MGR_HINT_FADE
wxAUI_MGR_NO_VENETIAN_BLINDS_FADE
wxAUI_MGR_DEFAULT
wxAUI_ART_SASH_SIZE
wxAUI_ART_CAPTION_SIZE
wxAUI_ART_GRIPPER_SIZE
wxAUI_ART_PANE_BORDER_SIZE
wxAUI_ART_PANE_BUTTON_SIZE
wxAUI_ART_BACKGROUND_COLOUR
wxAUI_ART_SASH_COLOUR
wxAUI_ART_ACTIVE_CAPTION_COLOUR
wxAUI_ART_ACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_ART_INACTIVE_CAPTION_COLOUR
wxAUI_ART_INACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_ART_ACTIVE_CAPTION_TEXT_COLOUR
wxAUI_ART_INACTIVE_CAPTION_TEXT_COLOUR
wxAUI_ART_BORDER_COLOUR
wxAUI_ART_GRIPPER_COLOUR
wxAUI_ART_CAPTION_FONT
wxAUI_ART_GRADIENT_TYPE
wxAUI_DOCKART_SASH_SIZE
wxAUI_DOCKART_CAPTION_SIZE
wxAUI_DOCKART_GRIPPER_SIZE
wxAUI_DOCKART_PANE_BORDER_SIZE
wxAUI_DOCKART_PANE_BUTTON_SIZE
wxAUI_DOCKART_BACKGROUND_COLOUR
wxAUI_DOCKART_SASH_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_TEXT_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_TEXT_COLOUR
wxAUI_DOCKART_BORDER_COLOUR
wxAUI_DOCKART_GRIPPER_COLOUR
wxAUI_DOCKART_CAPTION_FONT
wxAUI_DOCKART_GRADIENT_TYPE
wxAUI_GRADIENT_NONE
wxAUI_GRADIENT_VERTICAL
wxAUI_GRADIENT_HORIZONTAL
wxAUI_BUTTON_STATE_NORMAL
wxAUI_BUTTON_STATE_HOVER
wxAUI_BUTTON_STATE_PRESSED
wxAUI_BUTTON_STATE_DISABLED
wxAUI_BUTTON_STATE_HIDDEN
wxAUI_BUTTON_CLOSE
wxAUI_BUTTON_MAXIMIZE_RESTORE
wxAUI_BUTTON_MINIMIZE
wxAUI_BUTTON_PIN
wxAUI_BUTTON_OPTIONS
wxAUI_BUTTON_WINDOWLIST
wxAUI_BUTTON_LEFT
wxAUI_BUTTON_RIGHT
wxAUI_BUTTON_UP
wxAUI_BUTTON_DOWN
wxAUI_BUTTON_CUSTOM1
wxAUI_BUTTON_CUSTOM2
wxAUI_BUTTON_CUSTOM3
wxAUI_INSERT_PANE
wxAUI_INSERT_ROW
wxAUI_INSERT_DOCK
wxAUI_NB_TOP
wxAUI_NB_LEFT
wxAUI_NB_RIGHT
wxAUI_NB_BOTTOM
wxAUI_NB_TAB_SPLIT
wxAUI_NB_TAB_MOVE
wxAUI_NB_TAB_EXTERNAL_MOVE
wxAUI_NB_TAB_FIXED_WIDTH
wxAUI_NB_SCROLL_BUTTONS
wxAUI_NB_WINDOWLIST_BUTTON
wxAUI_NB_CLOSE_BUTTON
wxAUI_NB_CLOSE_ON_ACTIVE_TAB
wxAUI_NB_CLOSE_ON_ALL_TABS
wxAUI_NB_DEFAULT_STYLE
wxCAL_SUNDAY_FIRST
wxCAL_MONDAY_FIRST
wxCAL_SHOW_HOLIDAYS
wxCAL_NO_YEAR_CHANGE
wxCAL_NO_MONTH_CHANGE
wxCAL_SHOW_SURROUNDING_WEEKS
wxCAL_SHOW_WEEK_NUMBERS
wxCAL_SEQUENTIAL_MONTH_SELECTION
wxCAL_HITTEST_NOWHERE
wxCAL_HITTEST_HEADER
wxCAL_HITTEST_DAY
wxCAL_HITTEST_DECMONTH
wxCAL_HITTEST_INCMONTH
wxCAL_HITTEST_SURROUNDING_WEEK
wxCAL_BORDER_NONE
wxCAL_BORDER_SQUARE
wxCAL_BORDER_ROUND
wxEVT_CALENDAR_SEL_CHANGED
wxEVT_CALENDAR_DAY_CHANGED
wxEVT_CALENDAR_MONTH_CHANGED
wxEVT_CALENDAR_YEAR_CHANGED
wxEVT_CALENDAR_DOUBLECLICKED
wxEVT_CALENDAR_WEEKDAY_CLICKED
wxEVT_DATE_CHANGED
wxEVT_TIME_CHANGED
wxDP_DEFAULT
wxDP_SPIN
wxDP_DROPDOWN
wxDP_SHOWCENTURY
wxDP_ALLOWNONE
wxTP_DEFAULT
wxDV_SINGLE
wxDV_MULTIPLE
wxDV_NO_HEADER
wxDV_HORIZ_RULES
wxDV_VERT_RULES
wxDV_ROW_LINES
wxDVR_DEFAULT_ALIGNMENT
wxDATAVIEW_CELL_INERT
wxDATAVIEW_CELL_ACTIVATABLE
wxDATAVIEW_CELL_EDITABLE
wxDATAVIEW_CELL_SELECTED
wxDATAVIEW_CELL_PRELIT
wxDATAVIEW_CELL_INSENSITIVE
wxDATAVIEW_CELL_FOCUSED
wxDATAVIEW_COL_RESIZABLE
wxDATAVIEW_COL_SORTABLE
wxDATAVIEW_COL_REORDERABLE
wxDATAVIEW_COL_HIDDEN
Both
wxDragError
wxDragNone
wxDragMove
wxDragCopy
wxDragLink
wxDragCancel
wxDrag_CopyOnly
wxDrag_AllowMove
wxDrag_DefaultMove
Get
Set
wxDF_INVALID
wxDF_TEXT
wxDF_UNICODETEXT
wxDF_BITMAP
wxDF_METAFILE
wxDF_FILENAME
wxDEFAULT_TEMPLATE_FLAGS
wxDEFAULT_DOCMAN_FLAGS
wxDOC_SDI
wxDOC_MDI
wxDOC_NEW
wxDOC_SILENT
wxTEMPLATE_VISIBLE
wxTEMPLATE_INVISIBLE
wxMAX_FILE_HISTORY
wxFS_READ
wxFS_SEEKABLE
wxGRIDTABLE_REQUEST_VIEW_GET_VALUES
wxGRIDTABLE_REQUEST_VIEW_SEND_VALUES
wxGRIDTABLE_NOTIFY_ROWS_INSERTED
wxGRIDTABLE_NOTIFY_ROWS_APPENDED
wxGRIDTABLE_NOTIFY_ROWS_DELETED
wxGRIDTABLE_NOTIFY_COLS_INSERTED
wxGRIDTABLE_NOTIFY_COLS_APPENDED
wxGRIDTABLE_NOTIFY_COLS_DELETED
wxGRID_AUTOSIZE
wxGRID_COLUMN
wxGRID_ROW
wxGRID_DRAW_ROWS_HEADER
wxGRID_DRAW_COLS_HEADER
wxGRID_DRAW_CELL_LINES
wxGRID_DRAW_BOX_RECT
wxGRID_DRAW_SELECTION
wxGRID_DRAW_DEFAULT
wxGridSelectCells
wxGridSelectRows
wxGridSelectColumns
wxEVT_COMMAND_HTML_CELL_CLICKED
wxEVT_COMMAND_HTML_CELL_HOVER
wxEVT_COMMAND_HTML_LINK_CLICKED
wxHF_TOOLBAR
wxHF_FLATTOOLBAR
wxHF_FLAT_TOOLBAR
wxHF_CONTENTS
wxHF_INDEX
wxHF_SEARCH
wxHF_BOOKMARKS
wxHF_OPENFILES
wxHF_OPEN_FILES
wxHF_PRINT
wxHF_DEFAULTSTYLE
wxHF_MERGE_BOOKS
wxHF_ICONS_BOOK
wxHF_ICONS_BOOK_CHAPTER
wxHF_ICONS_FOLDER
wxHF_DEFAULT_STYLE
wxHF_DIALOG
wxHF_EMBEDDED
wxHF_FRAME
wxHF_MODAL
wxHW_NO_SELECTION
wxHW_SCROLLBAR_NEVER
wxHW_DEFAULT_STYLE
wxHW_SCROLLBAR_AUTO
wxHTML_ALIGN_LEFT
wxHTML_ALIGN_CENTER
wxHTML_ALIGN_RIGHT
wxHTML_ALIGN_BOTTOM
wxHTML_ALIGN_TOP
wxHTML_CLR_FOREGROUND
wxHTML_CLR_BACKGROUND
wxHTML_UNITS_PIXELS
wxHTML_UNITS_PERCENT
wxHTML_INDENT_LEFT
wxHTML_INDENT_RIGHT
wxHTML_INDENT_TOP
wxHTML_INDENT_BOTTOM
wxHTML_INDENT_HORIZONTAL
wxHTML_INDENT_VERTICAL
wxHTML_INDENT_ALL
wxHTML_COND_ISANCHOR
wxHTML_COND_ISIMAGEMAP
wxHTML_COND_USER
wxHTML_FIND_EXACT
wxHTML_FIND_NEAREST_BEFORE
wxHTML_FIND_NEAREST_AFTER
wxHTML_FONT_SIZE_1
wxHTML_FONT_SIZE_2
wxHTML_FONT_SIZE_3
wxHTML_FONT_SIZE_4
wxHTML_FONT_SIZE_5
wxHTML_FONT_SIZE_6
wxHTML_FONT_SIZE_7
wxHTML_ALIGN_JUSTIFY
wxHTML_BLOCK
wxHTML_BUFLEN
wxHTML_OPEN
wxHTML_PRINT_MAX_PAGES
wxHTML_REDIRECT
wxHTML_SCRIPT_NORMAL
wxHTML_SCRIPT_SUB
wxHTML_SCRIPT_SUP
wxHTML_SCROLL_STEP
wxHTML_SEL_CHANGING
wxHTML_SEL_IN
wxHTML_SEL_OUT
wxHTML_URL_IMAGE
wxHTML_URL_OTHER
wxHTML_URL_PAGE
wxPAGE_ODD
wxPAGE_EVEN
wxPAGE_ALL
wxEVT_MEDIA_FINISHED
wxEVT_MEDIA_STOP
wxEVT_MEDIA_LOADED
wxEVT_MEDIA_STATECHANGED
wxEVT_MEDIA_PLAY
wxEVT_MEDIA_PAUSE
wxMEDIASTATE_STOPPED
wxMEDIASTATE_PAUSED
wxMEDIASTATE_PLAYING
wxMEDIACTRLPLAYERCONTROLS_NONE
wxMEDIACTRLPLAYERCONTROLS_STEP
wxMEDIACTRLPLAYERCONTROLS_VOLUME
wxMEDIACTRLPLAYERCONTROLS_DEFAULT
wxDUPLEX_SIMPLEX
wxDUPLEX_HORIZONTAL
wxDUPLEX_VERTICAL
wxLANDSCAPE
wxPAPER_NONE
wxPAPER_LETTER
wxPAPER_LEGAL
wxPAPER_A4
wxPAPER_CSHEET
wxPAPER_DSHEET
wxPAPER_ESHEET
wxPAPER_LETTERSMALL
wxPAPER_TABLOID
wxPAPER_LEDGER
wxPAPER_STATEMENT
wxPAPER_EXECUTIVE
wxPAPER_A3
wxPAPER_A4SMALL
wxPAPER_A5
wxPAPER_B4
wxPAPER_B5
wxPAPER_FOLIO
wxPAPER_QUARTO
wxPAPER_10X14
wxPAPER_11X17
wxPAPER_NOTE
wxPAPER_ENV_9
wxPAPER_ENV_10
wxPAPER_ENV_11
wxPAPER_ENV_12
wxPAPER_ENV_14
wxPAPER_ENV_DL
wxPAPER_ENV_C5
wxPAPER_ENV_C3
wxPAPER_ENV_C4
wxPAPER_ENV_C6
wxPAPER_ENV_C65
wxPAPER_ENV_B4
wxPAPER_ENV_B5
wxPAPER_ENV_B6
wxPAPER_ENV_ITALY
wxPAPER_ENV_MONARCH
wxPAPER_ENV_PERSONAL
wxPAPER_FANFOLD_US
wxPAPER_FANFOLD_STD_GERMAN
wxPAPER_FANFOLD_LGL_GERMAN
wxPAPER_ISO_B4
wxPAPER_JAPANESE_POSTCARD
wxPAPER_9X11
wxPAPER_10X11
wxPAPER_15X11
wxPAPER_ENV_INVITE
wxPAPER_LETTER_EXTRA
wxPAPER_LEGAL_EXTRA
wxPAPER_TABLOID_EXTRA
wxPAPER_A4_EXTRA
wxPAPER_LETTER_TRANSVERSE
wxPAPER_A4_TRANSVERSE
wxPAPER_LETTER_EXTRA_TRANSVERSE
wxPAPER_A_PLUS
wxPAPER_B_PLUS
wxPAPER_LETTER_PLUS
wxPAPER_A4_PLUS
wxPAPER_A5_TRANSVERSE
wxPAPER_B5_TRANSVERSE
wxPAPER_A3_EXTRA
wxPAPER_A5_EXTRA
wxPAPER_B5_EXTRA
wxPAPER_A2
wxPAPER_A3_TRANSVERSE
wxPAPER_A3_EXTRA_TRANSVERSE
wxPAPER_12X11
wxPAPER_A3_ROTATED
wxPAPER_A4_ROTATED
wxPAPER_A5_ROTATED
wxPAPER_A6
wxPAPER_A6_ROTATED
wxPAPER_B4_JIS_ROTATED
wxPAPER_B5_JIS_ROTATED
wxPAPER_B6_JIS
wxPAPER_B6_JIS_ROTATED
wxPAPER_DBL_JAPANESE_POSTCARD
wxPAPER_DBL_JAPANESE_POSTCARD_ROTATED
wxPAPER_JAPANESE_POSTCARD_ROTATED
wxPAPER_JENV_CHOU3
wxPAPER_JENV_CHOU3_ROTATED
wxPAPER_JENV_CHOU4
wxPAPER_JENV_CHOU4_ROTATED
wxPAPER_JENV_KAKU2
wxPAPER_JENV_KAKU2_ROTATED
wxPAPER_JENV_KAKU3
wxPAPER_JENV_KAKU3_ROTATED
wxPAPER_JENV_YOU4
wxPAPER_JENV_YOU4_ROTATED
wxPAPER_LETTER_ROTATED
wxPAPER_P16K
wxPAPER_P16K_ROTATED
wxPAPER_P32K
wxPAPER_P32KBIG
wxPAPER_P32KBIG_ROTATED
wxPAPER_P32K_ROTATED
wxPAPER_PENV_1
wxPAPER_PENV_10
wxPAPER_PENV_10_ROTATED
wxPAPER_PENV_1_ROTATED
wxPAPER_PENV_2
wxPAPER_PENV_2_ROTATED
wxPAPER_PENV_3
wxPAPER_PENV_3_ROTATED
wxPAPER_PENV_4
wxPAPER_PENV_4_ROTATED
wxPAPER_PENV_5
wxPAPER_PENV_5_ROTATED
wxPAPER_PENV_6
wxPAPER_PENV_6_ROTATED
wxPAPER_PENV_7
wxPAPER_PENV_7_ROTATED
wxPAPER_PENV_8
wxPAPER_PENV_8_ROTATED
wxPAPER_PENV_9
wxPAPER_PENV_9_ROTATED
wxPORTRAIT
wxPREVIEW_PRINT
wxPREVIEW_NEXT
wxPREVIEW_PREVIOUS
wxPREVIEW_ZOOM
wxPREVIEW_DEFAULT
wxPRINT_QUALITY_HIGH
wxPRINT_QUALITY_MEDIUM
wxPRINT_QUALITY_LOW
wxPRINT_QUALITY_DRAFT
wxPRINT_MODE_FILE
wxPRINT_MODE_NONE
wxPRINT_MODE_PREVIEW
wxPRINT_MODE_PRINTER
wxPRINT_MODE_STREAM
wxPRINTER_NO_ERROR
wxPRINTER_CANCELLED
wxPRINTER_ERROR
wxPRINTBIN_DEFAULT
wxPRINTBIN_ONLYONE
wxPRINTBIN_LOWER
wxPRINTBIN_MIDDLE
wxPRINTBIN_MANUAL
wxPRINTBIN_ENVELOPE
wxPRINTBIN_ENVMANUAL
wxPRINTBIN_AUTO
wxPRINTBIN_TRACTOR
wxPRINTBIN_SMALLFMT
wxPRINTBIN_LARGEFMT
wxPRINTBIN_LARGECAPACITY
wxPRINTBIN_CASSETTE
wxPRINTBIN_FORMSOURCE
wxPRINTBIN_USER
wxPG_ITERATE_PROPERTIES
wxPG_ITERATE_HIDDEN
wxPG_ITERATE_FIXED_CHILDREN
wxPG_ITERATE_CATEGORIES
wxPG_ITERATE_ALL_PARENTS
wxPG_ITERATE_ALL_PARENTS_RECURSIVELY
wxPG_ITERATOR_FLAGS_ALL
wxPG_ITERATOR_MASK_OP_ITEM
wxPG_ITERATOR_MASK_OP_PARENT
wxPG_ITERATE_VISIBLE
wxPG_ITERATE_ALL
wxPG_ITERATE_NORMAL
wxPG_ITERATE_DEFAULT
wxPG_PROP_MODIFIED
wxPG_PROP_DISABLED
wxPG_PROP_HIDDEN
wxPG_PROP_CUSTOMIMAGE
wxPG_PROP_NOEDITOR
wxPG_PROP_COLLAPSED
wxPG_PROP_INVALID_VALUE
wxPG_PROP_WAS_MODIFIED
wxPG_PROP_AGGREGATE
wxPG_PROP_CHILDREN_ARE_COPIES
wxPG_PROP_PROPERTY
wxPG_PROP_CATEGORY
wxPG_PROP_MISC_PARENT
wxPG_PROP_READONLY
wxPG_PROP_COMPOSED_VALUE
wxPG_PROP_USES_COMMON_VALUE
wxPG_PROP_AUTO_UNSPECIFIED
wxPG_PROP_CLASS_SPECIFIC_1
wxPG_PROP_CLASS_SPECIFIC_2
wxPG_PROP_BEING_DELETED
wxPG_PROP_MAX
wxPG_PROP_PARENTAL_FLAGS
wxPG_AUTO_SORT
wxPG_HIDE_CATEGORIES
wxPG_ALPHABETIC_MODE
wxPG_BOLD_MODIFIED
wxPG_SPLITTER_AUTO_CENTER
wxPG_TOOLTIPS
wxPG_HIDE_MARGIN
wxPG_STATIC_SPLITTER
wxPG_STATIC_LAYOUT
wxPG_LIMITED_EDITING
wxPG_TOOLBAR
wxPG_DESCRIPTION
wxPG_NO_INTERNAL_BORDER
wxPG_EX_INIT_NOCAT
wxPG_EX_NO_FLAT_TOOLBAR
wxPG_EX_MODE_BUTTONS
wxPG_EX_HELP_AS_TOOLTIPS
wxPG_EX_NATIVE_DOUBLE_BUFFERING
wxPG_EX_AUTO_UNSPECIFIED_VALUES
wxPG_EX_WRITEONLY_BUILTIN_ATTRIBUTES
wxPG_EX_HIDE_PAGE_BUTTONS
wxPG_EX_MULTIPLE_SELECTION
wxPG_EX_ENABLE_TLP_TRACKING
wxPG_EX_NO_TOOLBAR_DIVIDER
wxPG_EX_TOOLBAR_SEPARATOR
wxPG_DEFAULT_STYLE
wxPGMAN_DEFAULT_STYLE
wxPG_VFB_STAY_IN_PROPERTY
wxPG_VFB_BEEP
wxPG_VFB_MARK_CELL
wxPG_VFB_SHOW_MESSAGE
wxPG_VFB_SHOW_MESSAGEBOX
wxPG_VFB_SHOW_MESSAGE_ON_STATUSBAR
wxPG_VFB_DEFAULT
wxPG_ACTION_INVALID
wxPG_ACTION_NEXT_PROPERTY
wxPG_ACTION_PREV_PROPERTY
wxPG_ACTION_EXPAND_PROPERTY
wxPG_ACTION_COLLAPSE_PROPERTY
wxPG_ACTION_CANCEL_EDIT
wxPG_ACTION_EDIT
wxPG_ACTION_PRESS_BUTTON
wxPG_ACTION_MAX
wxPGState_SelectionState
wxPGState_ExpandedState
wxPGState_ScrollPosState
wxPGState_PageState
wxPGState_SplitterPosState
wxPGState_DescBoxState
wxPGState_AllStates
wxPGRender_ChoicePopup
wxPGRender_Control
wxPGRender_Disabled
wxPGRender_DontUseCellFgCol
wxPGRender_DontUseCellBgCol
wxPGRender_DontUseCellColours
wxPG_PROPERTY_VALIDATION_ERROR_MESSAGE
wxPG_PROPERTY_VALIDATION_SATURATE
wxPG_PROPERTY_VALIDATION_WRAP
wxPG_INVALID_VALUE
wxPG_KEEP_STRUCTURE
wxPG_RECURSE
wxPG_INC_ATTRIBUTES
wxPG_RECURSE_STARTS
wxPG_FORCE
wxPG_SORT_TOP_LEVEL_ONLY
wxPG_DONT_RECURSE
wxPG_FULL_VALUE
wxPG_REPORT_ERROR
wxPG_PROPERTY_SPECIFIC
wxPG_EDITABLE_VALUE
wxPG_COMPOSITE_FRAGMENT
wxPG_UNEDITABLE_COMPOSITE_FRAGMENT
wxPG_VALUE_IS_CURRENT
wxPG_PROGRAMMATIC_VALUE
wxPG_SETVAL_REFRESH_EDITOR
wxPG_SETVAL_AGGREGATED
wxPG_SETVAL_FROM_PARENT
wxPG_SETVAL_BY_USER
wxPG_BASE_OCT
wxPG_BASE_DEC
wxPG_BASE_HEX
wxPG_BASE_HEXL
wxPG_PREFIX_NONE
wxPG_PREFIX_0x
wxPG_PREFIX_DOLLAR_SIGN
wxRIBBON_BAR_SHOW_PAGE_LABELS
wxRIBBON_BAR_SHOW_PAGE_ICONS
wxRIBBON_BAR_FLOW_HORIZONTAL
wxRIBBON_BAR_FLOW_VERTICAL
wxRIBBON_BAR_SHOW_PANEL_EXT_BUTTONS
wxRIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS
wxRIBBON_BAR_ALWAYS_SHOW_TABS
wxRIBBON_BAR_DEFAULT_STYLE
wxRIBBON_BAR_FOLDBAR_STYLE
wxRIBBON_PANEL_NO_AUTO_MINIMISE
wxRIBBON_PANEL_EXT_BUTTON
wxRIBBON_PANEL_MINIMISE_BUTTON
wxRIBBON_PANEL_DEFAULT_STYLE
wxRIBBON_TOOLBAR_TOOL_FIRST
wxRIBBON_TOOLBAR_TOOL_LAST
wxRIBBON_TOOLBAR_TOOL_POSITION_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_HOVERED
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_HOVERED
wxRIBBON_TOOLBAR_TOOL_HOVER_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_HOVERED
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_HOVERED
wxRIBBON_TOOLBAR_TOOL_NORMAL_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_ACTIVE
wxRIBBON_TOOLBAR_TOOL_ACTIVE_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DISABLED
wxRIBBON_TOOLBAR_TOOL_STATE_MASK
wxRIBBON_SCROLL_BTN_LEFT
wxRIBBON_SCROLL_BTN_RIGHT
wxRIBBON_SCROLL_BTN_UP
wxRIBBON_SCROLL_BTN_DOWN
wxRIBBON_SCROLL_BTN_DIRECTION_MASK
wxRIBBON_SCROLL_BTN_NORMAL
wxRIBBON_SCROLL_BTN_HOVERED
wxRIBBON_SCROLL_BTN_ACTIVE
wxRIBBON_SCROLL_BTN_STATE_MASK
wxRIBBON_SCROLL_BTN_FOR_OTHER
wxRIBBON_SCROLL_BTN_FOR_TABS
wxRIBBON_SCROLL_BTN_FOR_PAGE
wxRIBBON_SCROLL_BTN_FOR_MASK
wxRIBBON_BUTTON_NORMAL
wxRIBBON_BUTTON_DROPDOWN
wxRIBBON_BUTTON_HYBRID
wxRIBBON_BUTTON_TOGGLE
wxRIBBON_BUTTONBAR_BUTTON_SMALL
wxRIBBON_BUTTONBAR_BUTTON_MEDIUM
wxRIBBON_BUTTONBAR_BUTTON_LARGE
wxRIBBON_BUTTONBAR_BUTTON_SIZE_MASK
wxRIBBON_BUTTONBAR_BUTTON_NORMAL_HOVERED
wxRIBBON_BUTTONBAR_BUTTON_DROPDOWN_HOVERED
wxRIBBON_BUTTONBAR_BUTTON_HOVER_MASK
wxRIBBON_BUTTONBAR_BUTTON_NORMAL_ACTIVE
wxRIBBON_BUTTONBAR_BUTTON_DROPDOWN_ACTIVE
wxRIBBON_BUTTONBAR_BUTTON_DISABLED
wxRIBBON_BUTTONBAR_BUTTON_TOGGLED
wxRIBBON_BUTTONBAR_BUTTON_STATE_MASK
wxRIBBON_GALLERY_BUTTON_NORMAL
wxRIBBON_GALLERY_BUTTON_HOVERED
wxRIBBON_GALLERY_BUTTON_ACTIVE
wxRIBBON_GALLERY_BUTTON_DISABLED
wxEVT_COMMAND_RIBBONBAR_PAGE_CHANGED
wxEVT_COMMAND_RIBBONBAR_PAGE_CHANGING
wxEVT_COMMAND_RIBBONBAR_TAB_MIDDLE_DOWN
wxEVT_COMMAND_RIBBONBAR_TAB_MIDDLE_UP
wxEVT_COMMAND_RIBBONBAR_TAB_RIGHT_DOWN
wxEVT_COMMAND_RIBBONBAR_TAB_RIGHT_UP
wxEVT_COMMAND_RIBBONBAR_TAB_LEFT_DCLICK
wxEVT_COMMAND_RIBBONBUTTON_CLICKED
wxEVT_COMMAND_RIBBONBUTTON_DROPDOWN_CLICKED
wxEVT_COMMAND_RIBBONGALLERY_HOVER_CHANGED
wxEVT_COMMAND_RIBBONGALLERY_SELECTED
wxEVT_COMMAND_RIBBONGALLERY_CLICKED
wxEVT_COMMAND_RIBBONTOOL_CLICKED
wxEVT_COMMAND_RIBBONTOOL_DROPDOWN_CLICKED
wxRichTextLineBreakChar
wxRE_READONLY
wxRE_MULTILINE
wxRICHTEXT_SETSTYLE_NONE
wxRICHTEXT_SETSTYLE_WITH_UNDO
wxRICHTEXT_SETSTYLE_OPTIMIZE
wxRICHTEXT_SETSTYLE_PARAGRAPHS_ONLY
wxRICHTEXT_SETSTYLE_CHARACTERS_ONLY
wxRICHTEXT_SETSTYLE_RENUMBER
wxRICHTEXT_SETSTYLE_SPECIFY_LEVEL
wxRICHTEXT_SETSTYLE_REMOVE
wxRICHTEXT_INSERT_NONE
wxRICHTEXT_INSERT_WITH_PREVIOUS_PARAGRAPH_STYLE
wxRICHTEXT_SETSTYLE_RESET
wxRICHTEXT_FIXED_WIDTH
wxRICHTEXT_FIXED_HEIGHT
wxRICHTEXT_VARIABLE_WIDTH
wxRICHTEXT_VARIABLE_HEIGHT
wxRICHTEXT_LAYOUT_SPECIFIED_RECT
wxRICHTEXT_DRAW_IGNORE_CACHE
wxRICHTEXT_HITTEST_NONE
wxRICHTEXT_HITTEST_BEFORE
wxRICHTEXT_HITTEST_AFTER
wxRICHTEXT_HITTEST_ON
wxRICHTEXT_HITTEST_OUTSIDE
wxRICHTEXT_HANDLER_INCLUDE_STYLESHEET
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_MEMORY
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_FILES
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_BASE64
wxRICHTEXT_HANDLER_NO_HEADER_FOOTER
wxRICHTEXT_HANDLER_CONVERT_FACENAMES
wxRICHTEXT_FORMATTED
wxRICHTEXT_UNFORMATTED
wxRICHTEXT_TYPE_ANY
wxRICHTEXT_TYPE_TEXT
wxRICHTEXT_TYPE_XML
wxRICHTEXT_TYPE_HTML
wxRICHTEXT_TYPE_RTF
wxRICHTEXT_TYPE_PDF
wxRICHTEXT_FORMAT_STYLE_EDITOR
wxRICHTEXT_FORMAT_FONT
wxRICHTEXT_FORMAT_TABS
wxRICHTEXT_FORMAT_BULLETS
wxRICHTEXT_FORMAT_INDENTS_SPACING
wxRICHTEXT_FORMAT_CHARACTER
wxRICHTEXT_FORMAT_HELP_BUTTON
wxRICHTEXT_FORMAT_LIST_STYLE
wxRICHTEXT_FORMAT_PARAGRAPH
wxRICHTEXT_FORMAT_STYLE
wxRICHTEXT_ORGANISER_DELETE_STYLES
wxRICHTEXT_ORGANISER_CREATE_STYLES
wxRICHTEXT_ORGANISER_APPLY_STYLES
wxRICHTEXT_ORGANISER_EDIT_STYLES
wxRICHTEXT_ORGANISER_RENAME_STYLES
wxRICHTEXT_ORGANISER_OK_CANCEL
wxRICHTEXT_ORGANISER_RENUMBER
wxRICHTEXT_ORGANISER_SHOW_CHARACTER
wxRICHTEXT_ORGANISER_SHOW_PARAGRAPH
wxRICHTEXT_ORGANISER_SHOW_LIST
wxRICHTEXT_ORGANISER_SHOW_ALL
wxRICHTEXT_ORGANISER_ORGANISE
wxRICHTEXT_ORGANISER_BROWSE
wxRICHTEXT_ORGANISER_BROWSE_NUMBERING
wxRICHTEXT_PAGE_ALL
wxRICHTEXT_PAGE_CENTRE
wxRICHTEXT_PAGE_EVEN
wxRICHTEXT_PAGE_LEFT
wxRICHTEXT_PAGE_ODD
wxRICHTEXT_PAGE_RIGHT
wxRICHTEXT_STYLE_ALL
wxRICHTEXT_STYLE_CHARACTER
wxRICHTEXT_STYLE_LIST
wxRICHTEXT_STYLE_PARAGRAPH
wxTEXT_ATTR_PARA_SPACING_AFTER
wxTEXT_ATTR_PARA_SPACING_BEFORE
wxTEXT_ATTR_LINE_SPACING
wxTEXT_ATTR_CHARACTER_STYLE_NAME
wxTEXT_ATTR_PARAGRAPH_STYLE_NAME
wxTEXT_ATTR_LIST_STYLE_NAME
wxTEXT_ATTR_BULLET_STYLE
wxTEXT_ATTR_BULLET_NUMBER
wxTEXT_ATTR_BULLET_TEXT
wxTEXT_ATTR_BULLET_NAME
wxTEXT_ATTR_URL
wxTEXT_ATTR_PAGE_BREAK
wxTEXT_ATTR_BULLET_STYLE_NONE
wxTEXT_ATTR_BULLET_STYLE_ARABIC
wxTEXT_ATTR_BULLET_STYLE_LETTERS_UPPER
wxTEXT_ATTR_BULLET_STYLE_LETTERS_LOWER
wxTEXT_ATTR_BULLET_STYLE_ROMAN_UPPER
wxTEXT_ATTR_BULLET_STYLE_ROMAN_LOWER
wxTEXT_ATTR_BULLET_STYLE_SYMBOL
wxTEXT_ATTR_BULLET_STYLE_BITMAP
wxTEXT_ATTR_BULLET_STYLE_PARENTHESES
wxTEXT_ATTR_BULLET_STYLE_PERIOD
wxTEXT_ATTR_BULLET_STYLE_STANDARD
wxTEXT_ATTR_BULLET_STYLE_RIGHT_PARENTHESIS
wxTEXT_ATTR_BULLET_STYLE_OUTLINE
wxTEXT_ATTR_BULLET_STYLE_ALIGN_LEFT
wxTEXT_ATTR_BULLET_STYLE_ALIGN_RIGHT
wxTEXT_ATTR_BULLET_STYLE_ALIGN_CENTRE
wxTEXT_ATTR_LINE_SPACING_NORMAL
wxTEXT_ATTR_LINE_SPACING_HALF
wxTEXT_ATTR_LINE_SPACING_TWICE
wxTEXT_ATTR_CHARACTER
wxTEXT_ATTR_PARAGRAPH
wxTEXT_ATTR_ALL
wxTEXT_ATTR_EFFECT_NONE
wxTEXT_ATTR_EFFECT_CAPITALS
wxTEXT_ATTR_EFFECT_SMALL_CAPITALS
wxTEXT_ATTR_EFFECT_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_SHADOW
wxTEXT_ATTR_EFFECT_EMBOSS
wxTEXT_ATTR_EFFECT_OUTLINE
wxTEXT_ATTR_EFFECT_ENGRAVE
wxTEXT_ATTR_EFFECT_SUPERSCRIPT
wxTEXT_ATTR_EFFECT_SUBSCRIPT
wxTEXT_ATTR_EFFECTS
wxTEXT_ATTR_FONT_ENCODING
wxTEXT_ATTR_KEEP_FIRST_PARA_STYLE
wxTEXT_ATTR_OUTLINE_LEVEL
wxEVT_SOCKET
wxSOCKET_BLOCK
wxSOCKET_NONE
wxSOCKET_NOWAIT
wxSOCKET_WAITALL
wxSOCKET_REUSEADDR
wxSOCKET_NOBIND
wxSOCKET_BROADCAST
wxSOCKET_CONNECTION_FLAG
wxSOCKET_INPUT_FLAG
wxSOCKET_LOST_FLAG
wxSOCKET_OUTPUT_FLAG
wxSOCKET_INPUT
wxSOCKET_OUTPUT
wxSOCKET_CONNECTION
wxSOCKET_LOST
wxSOCKET_UNINIT
wxSOCKET_CLIENT
wxSOCKET_SERVER
wxSOCKET_BASE
wxSOCKET_DATAGRAM
wxSOCKET_NOERROR
wxSOCKET_INVOP
wxSOCKET_IOERR
wxSOCKET_INVADDR
wxSOCKET_INVSOCK
wxSOCKET_NOHOST
wxSOCKET_INVPORT
wxSOCKET_WOULDBLOCK
wxSOCKET_TIMEDOUT
wxSOCKET_MEMERR
wxSTC_4GL_BLOCK
wxSTC_4GL_BLOCK_
wxSTC_4GL_CHARACTER
wxSTC_4GL_CHARACTER_
wxSTC_4GL_COMMENT1
wxSTC_4GL_COMMENT1_
wxSTC_4GL_COMMENT2
wxSTC_4GL_COMMENT2_
wxSTC_4GL_COMMENT3
wxSTC_4GL_COMMENT3_
wxSTC_4GL_COMMENT4
wxSTC_4GL_COMMENT4_
wxSTC_4GL_COMMENT5
wxSTC_4GL_COMMENT5_
wxSTC_4GL_COMMENT6
wxSTC_4GL_COMMENT6_
wxSTC_4GL_DEFAULT
wxSTC_4GL_DEFAULT_
wxSTC_4GL_END
wxSTC_4GL_END_
wxSTC_4GL_IDENTIFIER
wxSTC_4GL_IDENTIFIER_
wxSTC_4GL_NUMBER
wxSTC_4GL_NUMBER_
wxSTC_4GL_OPERATOR
wxSTC_4GL_OPERATOR_
wxSTC_4GL_PREPROCESSOR
wxSTC_4GL_PREPROCESSOR_
wxSTC_4GL_STRING
wxSTC_4GL_STRING_
wxSTC_4GL_WORD
wxSTC_4GL_WORD_
wxSTC_A68K_DEFAULT
wxSTC_A68K_COMMENT
wxSTC_A68K_NUMBER_DEC
wxSTC_A68K_NUMBER_BIN
wxSTC_A68K_NUMBER_HEX
wxSTC_A68K_STRING1
wxSTC_A68K_OPERATOR
wxSTC_A68K_CPUINSTRUCTION
wxSTC_A68K_EXTINSTRUCTION
wxSTC_A68K_REGISTER
wxSTC_A68K_DIRECTIVE
wxSTC_A68K_MACRO_ARG
wxSTC_A68K_LABEL
wxSTC_A68K_STRING2
wxSTC_A68K_IDENTIFIER
wxSTC_A68K_MACRO_DECLARATION
wxSTC_A68K_COMMENT_WORD
wxSTC_A68K_COMMENT_SPECIAL
wxSTC_A68K_COMMENT_DOXYGEN
wxSTC_ASM_COMMENTDIRECTIVE
wxSTC_AVS_DEFAULT
wxSTC_AVS_COMMENTBLOCK
wxSTC_AVS_COMMENTBLOCKN
wxSTC_AVS_COMMENTLINE
wxSTC_AVS_NUMBER
wxSTC_AVS_OPERATOR
wxSTC_AVS_IDENTIFIER
wxSTC_AVS_STRING
wxSTC_AVS_TRIPLESTRING
wxSTC_AVS_KEYWORD
wxSTC_AVS_FILTER
wxSTC_AVS_PLUGIN
wxSTC_AVS_FUNCTION
wxSTC_AVS_CLIPPROP
wxSTC_AVS_USERDFN
wxSTC_AVE_DEFAULT
wxSTC_AVE_COMMENT
wxSTC_AVE_NUMBER
wxSTC_AVE_WORD
wxSTC_AVE_STRING
wxSTC_AVE_ENUM
wxSTC_AVE_STRINGEOL
wxSTC_AVE_IDENTIFIER
wxSTC_AVE_OPERATOR
wxSTC_ADA_DEFAULT
wxSTC_ADA_NUMBER
wxSTC_ADA_WORD
wxSTC_ADA_STRING
wxSTC_ADA_CHARACTER
wxSTC_ADA_IDENTIFIER
wxSTC_ADA_STRINGEOL
wxSTC_ASM_DEFAULT
wxSTC_ASM_COMMENT
wxSTC_ASM_NUMBER
wxSTC_ASM_STRING
wxSTC_ASM_OPERATOR
wxSTC_ASM_IDENTIFIER
wxSTC_ASM_CPUINSTRUCTION
wxSTC_ASM_MATHINSTRUCTION
wxSTC_ASM_REGISTER
wxSTC_ASM_DIRECTIVE
wxSTC_ASM_DIRECTIVEOPERAND
wxSTC_ASM_COMMENTBLOCK
wxSTC_ASM_CHARACTER
wxSTC_ASM_STRINGEOL
wxSTC_ASM_EXTINSTRUCTION
wxSTC_ABAQUS_ARGUMENT
wxSTC_ABAQUS_COMMAND
wxSTC_ABAQUS_COMMENT
wxSTC_ABAQUS_COMMENTBLOCK
wxSTC_ABAQUS_DEFAULT
wxSTC_ABAQUS_FUNCTION
wxSTC_ABAQUS_NUMBER
wxSTC_ABAQUS_OPERATOR
wxSTC_ABAQUS_PROCESSOR
wxSTC_ABAQUS_SLASHCOMMAND
wxSTC_ABAQUS_STARCOMMAND
wxSTC_ABAQUS_STRING
wxSTC_ABAQUS_WORD
wxSTC_ADA_CHARACTEREOL
wxSTC_ADA_COMMENTLINE
wxSTC_ADA_DELIMITER
wxSTC_ADA_ILLEGAL
wxSTC_ADA_LABEL
wxSTC_ALPHA_NOALPHA
wxSTC_ALPHA_OPAQUE
wxSTC_ALPHA_TRANSPARENT
wxSTC_APDL_COMMAND
wxSTC_APDL_COMMENT
wxSTC_APDL_COMMENTBLOCK
wxSTC_APDL_DEFAULT
wxSTC_APDL_FUNCTION
wxSTC_APDL_NUMBER
wxSTC_APDL_PROCESSOR
wxSTC_APDL_ARGUMENT
wxSTC_APDL_OPERATOR
wxSTC_APDL_SLASHCOMMAND
wxSTC_APDL_STARCOMMAND
wxSTC_APDL_STRING
wxSTC_APDL_WORD
wxSTC_ASN1_ATTRIBUTE
wxSTC_ASN1_COMMENT
wxSTC_ASN1_DEFAULT
wxSTC_ASN1_DESCRIPTOR
wxSTC_ASN1_IDENTIFIER
wxSTC_ASN1_KEYWORD
wxSTC_ASN1_OID
wxSTC_ASN1_OPERATOR
wxSTC_ASN1_SCALAR
wxSTC_ASN1_STRING
wxSTC_ASN1_TYPE
wxSTC_ASY_CHARACTER
wxSTC_ASY_COMMENT
wxSTC_ASY_COMMENTLINE
wxSTC_ASY_COMMENTLINEDOC
wxSTC_ASY_DEFAULT
wxSTC_ASY_IDENTIFIER
wxSTC_ASY_NUMBER
wxSTC_ASY_OPERATOR
wxSTC_ASY_STRING
wxSTC_ASY_STRINGEOL
wxSTC_ASY_WORD
wxSTC_ASY_WORD2
wxSTC_AU3_COMMENT
wxSTC_AU3_COMMENTBLOCK
wxSTC_AU3_DEFAULT
wxSTC_AU3_FUNCTION
wxSTC_AU3_KEYWORD
wxSTC_AU3_MACRO
wxSTC_AU3_NUMBER
wxSTC_AU3_OPERATOR
wxSTC_AU3_PREPROCESSOR
wxSTC_AU3_SENT
wxSTC_AU3_SPECIAL
wxSTC_AU3_STRING
wxSTC_AU3_COMOBJ
wxSTC_AU3_EXPAND
wxSTC_AU3_UDF
wxSTC_AU3_VARIABLE
wxSTC_AVE_WORD1
wxSTC_AVE_WORD2
wxSTC_AVE_WORD3
wxSTC_AVE_WORD4
wxSTC_AVE_WORD5
wxSTC_AVE_WORD6
wxSTC_ANNOTATION_HIDDEN
wxSTC_ANNOTATION_STANDARD
wxSTC_ANNOTATION_BOXED
wxSTC_B_DEFAULT
wxSTC_B_COMMENT
wxSTC_B_NUMBER
wxSTC_B_KEYWORD
wxSTC_B_STRING
wxSTC_B_PREPROCESSOR
wxSTC_B_OPERATOR
wxSTC_B_IDENTIFIER
wxSTC_B_DATE
wxSTC_BAT_DEFAULT
wxSTC_BAT_COMMENT
wxSTC_BAT_WORD
wxSTC_BAT_LABEL
wxSTC_BAT_HIDE
wxSTC_BAT_COMMAND
wxSTC_BAT_IDENTIFIER
wxSTC_BAT_OPERATOR
wxSTC_BAAN_DEFAULT
wxSTC_BAAN_COMMENT
wxSTC_BAAN_COMMENTDOC
wxSTC_BAAN_NUMBER
wxSTC_BAAN_WORD
wxSTC_BAAN_STRING
wxSTC_BAAN_PREPROCESSOR
wxSTC_BAAN_OPERATOR
wxSTC_BAAN_IDENTIFIER
wxSTC_BAAN_STRINGEOL
wxSTC_BAAN_WORD2
wxSTC_B_ASM
wxSTC_B_CONSTANT
wxSTC_B_KEYWORD2
wxSTC_B_KEYWORD3
wxSTC_B_KEYWORD4
wxSTC_B_STRINGEOL
wxSTC_B_BINNUMBER
wxSTC_B_ERROR
wxSTC_B_HEXNUMBER
wxSTC_B_LABEL
wxSTC_C_STRINGRAW
wxSTC_C_TRIPLEVERBATIM
wxSTC_C_HASHQUOTEDSTRING
wxSTC_C_PREPROCESSORCOMMENT
wxSTC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE
wxSTC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE
wxSTC_CARETSTICKY_OFF
wxSTC_CARETSTICKY_ON
wxSTC_CARETSTICKY_WHITESPACE
wxSTC_COFFEESCRIPT_DEFAULT
wxSTC_COFFEESCRIPT_COMMENT
wxSTC_COFFEESCRIPT_COMMENTLINE
wxSTC_COFFEESCRIPT_COMMENTDOC
wxSTC_COFFEESCRIPT_NUMBER
wxSTC_COFFEESCRIPT_WORD
wxSTC_COFFEESCRIPT_STRING
wxSTC_COFFEESCRIPT_CHARACTER
wxSTC_COFFEESCRIPT_UUID
wxSTC_COFFEESCRIPT_PREPROCESSOR
wxSTC_COFFEESCRIPT_OPERATOR
wxSTC_COFFEESCRIPT_IDENTIFIER
wxSTC_COFFEESCRIPT_STRINGEOL
wxSTC_COFFEESCRIPT_VERBATIM
wxSTC_COFFEESCRIPT_REGEX
wxSTC_COFFEESCRIPT_COMMENTLINEDOC
wxSTC_COFFEESCRIPT_WORD2
wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORD
wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORDERROR
wxSTC_COFFEESCRIPT_GLOBALCLASS
wxSTC_COFFEESCRIPT_STRINGRAW
wxSTC_COFFEESCRIPT_TRIPLEVERBATIM
wxSTC_COFFEESCRIPT_HASHQUOTEDSTRING
wxSTC_COFFEESCRIPT_COMMENTBLOCK
wxSTC_COFFEESCRIPT_VERBOSE_REGEX
wxSTC_COFFEESCRIPT_VERBOSE_REGEX_COMMENT
wxSTC_CSS_MEDIA
wxSTC_CSS_VARIABLE
wxSTC_CURSORARROW
wxSTC_CURSORREVERSEARROW
wxSTC_CHARSET_ANSI
wxSTC_CHARSET_DEFAULT
wxSTC_CHARSET_BALTIC
wxSTC_CHARSET_CHINESEBIG5
wxSTC_CHARSET_EASTEUROPE
wxSTC_CHARSET_GB2312
wxSTC_CHARSET_GREEK
wxSTC_CHARSET_HANGUL
wxSTC_CHARSET_MAC
wxSTC_CHARSET_OEM
wxSTC_CHARSET_RUSSIAN
wxSTC_CHARSET_SHIFTJIS
wxSTC_CHARSET_SYMBOL
wxSTC_CHARSET_TURKISH
wxSTC_CHARSET_JOHAB
wxSTC_CHARSET_HEBREW
wxSTC_CHARSET_ARABIC
wxSTC_CHARSET_VIETNAMESE
wxSTC_CHARSET_THAI
wxSTC_CHARSET_8859_15
wxSTC_CHARSET_CYRILLIC
wxSTC_CASE_MIXED
wxSTC_CASE_UPPER
wxSTC_CASE_LOWER
wxSTC_CACHE_NONE
wxSTC_CACHE_CARET
wxSTC_CACHE_PAGE
wxSTC_CACHE_DOCUMENT
wxSTC_CURSORNORMAL
wxSTC_CURSORWAIT
wxSTC_CARET_SLOP
wxSTC_CARET_STRICT
wxSTC_CARET_JUMPS
wxSTC_CARET_EVEN
wxSTC_CARETSTYLE_BLOCK
wxSTC_CARETSTYLE_INVISIBLE
wxSTC_CARETSTYLE_LINE
wxSTC_C_DEFAULT
wxSTC_C_COMMENT
wxSTC_C_COMMENTLINE
wxSTC_C_COMMENTDOC
wxSTC_C_NUMBER
wxSTC_C_WORD
wxSTC_C_STRING
wxSTC_C_CHARACTER
wxSTC_C_UUID
wxSTC_C_PREPROCESSOR
wxSTC_C_OPERATOR
wxSTC_C_IDENTIFIER
wxSTC_C_STRINGEOL
wxSTC_C_VERBATIM
wxSTC_C_REGEX
wxSTC_C_COMMENTLINEDOC
wxSTC_C_WORD2
wxSTC_C_COMMENTDOCKEYWORD
wxSTC_C_COMMENTDOCKEYWORDERROR
wxSTC_C_GLOBALCLASS
wxSTC_CONF_DEFAULT
wxSTC_CONF_COMMENT
wxSTC_CONF_NUMBER
wxSTC_CONF_IDENTIFIER
wxSTC_CONF_EXTENSION
wxSTC_CONF_PARAMETER
wxSTC_CONF_STRING
wxSTC_CONF_OPERATOR
wxSTC_CONF_IP
wxSTC_CONF_DIRECTIVE
wxSTC_CMD_REDO
wxSTC_CMD_SELECTALL
wxSTC_CMD_UNDO
wxSTC_CMD_CUT
wxSTC_CMD_COPY
wxSTC_CMD_PASTE
wxSTC_CMD_LINEDOWN
wxSTC_CMD_LINEDOWNEXTEND
wxSTC_CMD_LINEUP
wxSTC_CMD_LINEUPEXTEND
wxSTC_CMD_LINECOPY
wxSTC_CMD_CHARLEFT
wxSTC_CMD_CHARLEFTEXTEND
wxSTC_CMD_CHARRIGHT
wxSTC_CMD_CHARRIGHTEXTEND
wxSTC_CMD_WORDLEFT
wxSTC_CMD_WORDLEFTEXTEND
wxSTC_CMD_WORDRIGHT
wxSTC_CMD_WORDRIGHTEXTEND
wxSTC_CMD_HOME
wxSTC_CMD_HOMEEXTEND
wxSTC_CMD_LINEEND
wxSTC_CMD_LINEENDEXTEND
wxSTC_CMD_DOCUMENTSTART
wxSTC_CMD_DOCUMENTSTARTEXTEND
wxSTC_CMD_DOCUMENTEND
wxSTC_CMD_DOCUMENTENDEXTEND
wxSTC_CMD_PAGEUP
wxSTC_CMD_PAGEUPEXTEND
wxSTC_CMD_PAGEDOWN
wxSTC_CMD_PAGEDOWNEXTEND
wxSTC_CMD_PARADOWN
wxSTC_CMD_PARADOWNEXTEND
wxSTC_CMD_PARAUP
wxSTC_CMD_PARAUPEXTEND
wxSTC_CMD_EDITTOGGLEOVERTYPE
wxSTC_CMD_CANCEL
wxSTC_CMD_DELETEBACK
wxSTC_CMD_TAB
wxSTC_CMD_BACKTAB
wxSTC_CMD_NEWLINE
wxSTC_CMD_FORMFEED
wxSTC_CMD_VCHOME
wxSTC_CMD_VCHOMEEXTEND
wxSTC_CMD_ZOOMIN
wxSTC_CMD_ZOOMOUT
wxSTC_CMD_DELWORDLEFT
wxSTC_CMD_DELWORDRIGHT
wxSTC_CMD_LINECUT
wxSTC_CMD_LINEDELETE
wxSTC_CMD_LINETRANSPOSE
wxSTC_CMD_LOWERCASE
wxSTC_CMD_UPPERCASE
wxSTC_CMD_LINESCROLLDOWN
wxSTC_CMD_LINESCROLLUP
wxSTC_CMD_DELETEBACKNOTLINE
wxSTC_CMD_HOMEDISPLAY
wxSTC_CMD_HOMEDISPLAYEXTEND
wxSTC_CMD_LINEENDDISPLAY
wxSTC_CMD_LINEENDDISPLAYEXTEND
wxSTC_CMD_CLEAR
wxSTC_CMD_WORDPARTLEFT
wxSTC_CMD_WORDPARTLEFTEXTEND
wxSTC_CMD_WORDPARTRIGHT
wxSTC_CMD_WORDPARTRIGHTEXTEND
wxSTC_CMD_DELLINELEFT
wxSTC_CMD_DELLINERIGHT
wxSTC_CSS_DEFAULT
wxSTC_CSS_TAG
wxSTC_CSS_CLASS
wxSTC_CSS_PSEUDOCLASS
wxSTC_CSS_UNKNOWN_PSEUDOCLASS
wxSTC_CSS_OPERATOR
wxSTC_CSS_IDENTIFIER
wxSTC_CSS_UNKNOWN_IDENTIFIER
wxSTC_CSS_VALUE
wxSTC_CSS_COMMENT
wxSTC_CSS_ID
wxSTC_CSS_IMPORTANT
wxSTC_CSS_DIRECTIVE
wxSTC_CSS_DOUBLESTRING
wxSTC_CSS_SINGLESTRING
wxSTC_CSS_ATTRIBUTE
wxSTC_CSS_IDENTIFIER2
wxSTC_CSS_IDENTIFIER3
wxSTC_CSS_PSEUDOELEMENT
wxSTC_CSS_EXTENDED_IDENTIFIER
wxSTC_CSS_EXTENDED_PSEUDOCLASS
wxSTC_CSS_EXTENDED_PSEUDOELEMENT
wxSTC_CAML_CHAR
wxSTC_CAML_COMMENT
wxSTC_CAML_COMMENT1
wxSTC_CAML_COMMENT2
wxSTC_CAML_COMMENT3
wxSTC_CAML_DEFAULT
wxSTC_CAML_IDENTIFIER
wxSTC_CAML_KEYWORD
wxSTC_CAML_KEYWORD2
wxSTC_CAML_KEYWORD3
wxSTC_CAML_LINENUM
wxSTC_CAML_NUMBER
wxSTC_CAML_OPERATOR
wxSTC_CAML_STRING
wxSTC_CAML_TAGNAME
wxSTC_CAML_WHITE
wxSTC_CLW_ATTRIBUTE
wxSTC_CLW_BUILTIN_PROCEDURES_FUNCTION
wxSTC_CLW_COMMENT
wxSTC_CLW_COMPILER_DIRECTIVE
wxSTC_CLW_DEFAULT
wxSTC_CLW_ERROR
wxSTC_CLW_INTEGER_CONSTANT
wxSTC_CLW_KEYWORD
wxSTC_CLW_LABEL
wxSTC_CLW_PICTURE_STRING
wxSTC_CLW_REAL_CONSTANT
wxSTC_CLW_DEPRECATED
wxSTC_CLW_RUNTIME_EXPRESSIONS
wxSTC_CLW_STANDARD_EQUATE
wxSTC_CLW_STRING
wxSTC_CLW_STRUCTURE_DATA_TYPE
wxSTC_CLW_USER_IDENTIFIER
wxSTC_CMAKE_COMMANDS
wxSTC_CMAKE_COMMENT
wxSTC_CMAKE_DEFAULT
wxSTC_CMAKE_FOREACHDEF
wxSTC_CMAKE_IFDEFINEDEF
wxSTC_CMAKE_MACRODEF
wxSTC_CMAKE_NUMBER
wxSTC_CMAKE_PARAMETERS
wxSTC_CMAKE_STRINGDQ
wxSTC_CMAKE_STRINGLQ
wxSTC_CMAKE_STRINGRQ
wxSTC_CMAKE_STRINGVAR
wxSTC_CMAKE_USERDEFINED
wxSTC_CMAKE_VARIABLE
wxSTC_CMAKE_WHILEDEF
wxSTC_CMD_CHARLEFTRECTEXTEND
wxSTC_CMD_CHARRIGHTRECTEXTEND
wxSTC_CMD_DELWORDRIGHTEND
wxSTC_CMD_HOMERECTEXTEND
wxSTC_CMD_HOMEWRAP
wxSTC_CMD_HOMEWRAPEXTEND
wxSTC_CMD_LINEDOWNRECTEXTEND
wxSTC_CMD_LINEDUPLICATE
wxSTC_CMD_LINEENDRECTEXTEND
wxSTC_CMD_LINEENDWRAP
wxSTC_CMD_LINEENDWRAPEXTEND
wxSTC_CMD_LINEUPRECTEXTEND
wxSTC_CMD_PAGEDOWNRECTEXTEND
wxSTC_CMD_PAGEUPRECTEXTEND
wxSTC_CMD_STUTTEREDPAGEDOWN
wxSTC_CMD_STUTTEREDPAGEDOWNEXTEND
wxSTC_CMD_STUTTEREDPAGEUP
wxSTC_CMD_STUTTEREDPAGEUPEXTEND
wxSTC_CMD_VCHOMERECTEXTEND
wxSTC_CMD_VCHOMEWRAP
wxSTC_CMD_VCHOMEWRAPEXTEND
wxSTC_CMD_WORDLEFTEND
wxSTC_CMD_WORDLEFTENDEXTEND
wxSTC_CMD_WORDRIGHTEND
wxSTC_CMD_WORDRIGHTENDEXTEND
wxSTC_CP_DBCS
wxSTC_CP_UTF8
wxSTC_CSOUND_ARATE_VAR
wxSTC_CSOUND_COMMENT
wxSTC_CSOUND_COMMENTBLOCK
wxSTC_CSOUND_DEFAULT
wxSTC_CSOUND_GLOBAL_VAR
wxSTC_CSOUND_HEADERSTMT
wxSTC_CSOUND_IDENTIFIER
wxSTC_CSOUND_INSTR
wxSTC_CSOUND_IRATE_VAR
wxSTC_CSOUND_KRATE_VAR
wxSTC_CSOUND_NUMBER
wxSTC_CSOUND_OPCODE
wxSTC_CSOUND_OPERATOR
wxSTC_CSOUND_PARAM
wxSTC_CSOUND_STRINGEOL
wxSTC_CSOUND_USERKEYWORD
wxSTC_DIFF_DEFAULT
wxSTC_DIFF_COMMENT
wxSTC_DIFF_COMMAND
wxSTC_DIFF_HEADER
wxSTC_DIFF_POSITION
wxSTC_DIFF_DELETED
wxSTC_DIFF_ADDED
wxSTC_DIFF_CHANGED
wxSTC_D_CHARACTER
wxSTC_D_COMMENT
wxSTC_D_COMMENTDOC
wxSTC_D_COMMENTDOCKEYWORD
wxSTC_D_COMMENTDOCKEYWORDERROR
wxSTC_D_COMMENTLINE
wxSTC_D_COMMENTLINEDOC
wxSTC_D_COMMENTNESTED
wxSTC_D_DEFAULT
wxSTC_D_IDENTIFIER
wxSTC_D_NUMBER
wxSTC_D_OPERATOR
wxSTC_D_STRING
wxSTC_D_STRINGEOL
wxSTC_D_TYPEDEF
wxSTC_D_WORD
wxSTC_D_WORD2
wxSTC_D_WORD3
wxSTC_D_STRINGR
wxSTC_D_WORD5
wxSTC_D_WORD6
wxSTC_D_WORD7
wxSTC_ECL_DEFAULT
wxSTC_ECL_COMMENT
wxSTC_ECL_COMMENTLINE
wxSTC_ECL_NUMBER
wxSTC_ECL_STRING
wxSTC_ECL_WORD0
wxSTC_ECL_OPERATOR
wxSTC_ECL_CHARACTER
wxSTC_ECL_UUID
wxSTC_ECL_PREPROCESSOR
wxSTC_ECL_UNKNOWN
wxSTC_ECL_IDENTIFIER
wxSTC_ECL_STRINGEOL
wxSTC_ECL_VERBATIM
wxSTC_ECL_REGEX
wxSTC_ECL_COMMENTLINEDOC
wxSTC_ECL_WORD1
wxSTC_ECL_COMMENTDOCKEYWORD
wxSTC_ECL_COMMENTDOCKEYWORDERROR
wxSTC_ECL_WORD2
wxSTC_ECL_WORD3
wxSTC_ECL_WORD4
wxSTC_ECL_WORD5
wxSTC_ECL_COMMENTDOC
wxSTC_ECL_ADDED
wxSTC_ECL_DELETED
wxSTC_ECL_CHANGED
wxSTC_ECL_MOVED
wxSTC_EOL_CR
wxSTC_EOL_LF
wxSTC_EOL_CRLF
wxSTC_EDGE_NONE
wxSTC_EDGE_LINE
wxSTC_EDGE_BACKGROUND
wxSTC_ERR_DEFAULT
wxSTC_ERR_PYTHON
wxSTC_ERR_GCC
wxSTC_ERR_MS
wxSTC_ERR_CMD
wxSTC_ERR_BORLAND
wxSTC_ERR_PERL
wxSTC_ERR_NET
wxSTC_ERR_LUA
wxSTC_ERR_CTAG
wxSTC_ERR_DIFF_CHANGED
wxSTC_ERR_DIFF_ADDITION
wxSTC_ERR_DIFF_DELETION
wxSTC_ERR_DIFF_MESSAGE
wxSTC_EIFFEL_DEFAULT
wxSTC_EIFFEL_COMMENTLINE
wxSTC_EIFFEL_NUMBER
wxSTC_EIFFEL_WORD
wxSTC_EIFFEL_STRING
wxSTC_EIFFEL_CHARACTER
wxSTC_EIFFEL_OPERATOR
wxSTC_EIFFEL_IDENTIFIER
wxSTC_EIFFEL_STRINGEOL
wxSTC_ERLANG_ATOM
wxSTC_ERLANG_CHARACTER
wxSTC_ERLANG_COMMENT
wxSTC_ERLANG_DEFAULT
wxSTC_ERLANG_FUNCTION_NAME
wxSTC_ERLANG_KEYWORD
wxSTC_ERLANG_MACRO
wxSTC_ERLANG_NODE_NAME
wxSTC_ERLANG_NUMBER
wxSTC_ERLANG_OPERATOR
wxSTC_ERLANG_RECORD
wxSTC_ERLANG_SEPARATOR
wxSTC_ERLANG_STRING
wxSTC_ERLANG_UNKNOWN
wxSTC_ERLANG_VARIABLE
wxSTC_ERLANG_PREPROC
wxSTC_ERLANG_COMMENT_FUNCTION
wxSTC_ERLANG_COMMENT_MODULE
wxSTC_ERLANG_COMMENT_DOC
wxSTC_ERLANG_COMMENT_DOC
wxSTC_ERLANG_ATOM_QUOTED
wxSTC_ERLANG_MACRO_QUOTED
wxSTC_ERLANG_RECORD_QUOTED
wxSTC_ERLANG_NODE_NAME_QUOTED
wxSTC_ERLANG_BIFS
wxSTC_ERLANG_MODULES
wxSTC_ERLANG_MODULES_ATT
wxSTC_ERR_ABSF
wxSTC_ERR_ELF
wxSTC_ERR_IFC
wxSTC_ERR_IFORT
wxSTC_ERR_JAVA_STACK
wxSTC_ERR_PHP
wxSTC_ERR_TIDY
wxSTC_ERR_VALUE
wxSTC_ESCRIPT_BRACE
wxSTC_ESCRIPT_COMMENT
wxSTC_ESCRIPT_COMMENTDOC
wxSTC_ESCRIPT_COMMENTLINE
wxSTC_ESCRIPT_DEFAULT
wxSTC_ESCRIPT_IDENTIFIER
wxSTC_ESCRIPT_NUMBER
wxSTC_ESCRIPT_OPERATOR
wxSTC_ESCRIPT_STRING
wxSTC_ESCRIPT_WORD
wxSTC_ESCRIPT_WORD2
wxSTC_ESCRIPT_WORD3
wxSTC_EFF_QUALITY_MASK
wxSTC_EFF_QUALITY_DEFAULT
wxSTC_EFF_QUALITY_NON_ANTIALIASED
wxSTC_EFF_QUALITY_ANTIALIASED
wxSTC_EFF_QUALITY_LCD_OPTIMIZED
wxSTC_FONT_SIZE_MULTIPLIER
wxSTC_FIND_WHOLEWORD
wxSTC_FIND_MATCHCASE
wxSTC_FIND_WORDSTART
wxSTC_FIND_REGEXP
wxSTC_FOLDLEVELBASE
wxSTC_FOLDLEVELWHITEFLAG
wxSTC_FOLDLEVELHEADERFLAG
wxSTC_FOLDLEVELNUMBERMASK
wxSTC_FORTH_DEFAULT
wxSTC_FORTH_COMMENT
wxSTC_FORTH_COMMENT_ML
wxSTC_FORTH_IDENTIFIER
wxSTC_FORTH_CONTROL
wxSTC_FORTH_KEYWORD
wxSTC_FORTH_DEFWORD
wxSTC_FORTH_PREWORD1
wxSTC_FORTH_PREWORD2
wxSTC_FORTH_NUMBER
wxSTC_FORTH_STRING
wxSTC_FORTH_LOCALE
wxSTC_F_DEFAULT
wxSTC_F_COMMENT
wxSTC_F_NUMBER
wxSTC_F_STRING1
wxSTC_F_STRING2
wxSTC_F_STRINGEOL
wxSTC_F_OPERATOR
wxSTC_F_IDENTIFIER
wxSTC_F_WORD
wxSTC_F_WORD2
wxSTC_F_WORD3
wxSTC_F_PREPROCESSOR
wxSTC_F_OPERATOR2
wxSTC_F_LABEL
wxSTC_F_CONTINUATION
wxSTC_FIND_POSIX
wxSTC_FOLDFLAG_BOX
wxSTC_FOLDFLAG_LEVELNUMBERS
wxSTC_FOLDFLAG_LINEAFTER_CONTRACTED
wxSTC_FOLDFLAG_LINEAFTER_EXPANDED
wxSTC_FOLDFLAG_LINEBEFORE_CONTRACTED
wxSTC_FOLDFLAG_LINEBEFORE_EXPANDED
wxSTC_FOLDLEVELBOXFOOTERFLAG
wxSTC_FOLDLEVELBOXHEADERFLAG
wxSTC_FOLDLEVELCONTRACTED
wxSTC_FOLDLEVELUNINDENT
wxSTC_FS_ASM
wxSTC_FS_BINNUMBER
wxSTC_FS_ERROR
wxSTC_FS_HEXNUMBER
wxSTC_FS_LABEL
wxSTC_FS_WORDOPERATOR
wxSTC_FS_DISABLEDCODE
wxSTC_FS_DEFAULT_C
wxSTC_FS_COMMENTDOC_C
wxSTC_FS_COMMENTLINEDOC_C
wxSTC_FS_KEYWORD_C
wxSTC_FS_KEYWORD2_C
wxSTC_FS_NUMBER_C
wxSTC_FS_STRING_C
wxSTC_FS_PREPROCESSOR_C
wxSTC_FS_OPERATOR_C
wxSTC_FS_IDENTIFIER_C
wxSTC_FS_STRINGEOL_C
wxSTC_FS_COMMENT
wxSTC_FS_COMMENTDOC
wxSTC_FS_COMMENTDOCKEYWORD
wxSTC_FS_COMMENTDOCKEYWORDERROR
wxSTC_FS_COMMENTLINE
wxSTC_FS_COMMENTLINEDOC
wxSTC_FS_CONSTANT
wxSTC_FS_DATE
wxSTC_FS_DEFAULT
wxSTC_FS_IDENTIFIER
wxSTC_FS_KEYWORD
wxSTC_FS_KEYWORD2
wxSTC_FS_KEYWORD3
wxSTC_FS_KEYWORD4
wxSTC_FS_NUMBER
wxSTC_FS_OPERATOR
wxSTC_FS_PREPROCESSOR
wxSTC_FS_STRING
wxSTC_FS_STRINGEOL
wxSTC_GAP_CHAR
wxSTC_GAP_COMMENT
wxSTC_GAP_DEFAULT
wxSTC_GAP_IDENTIFIER
wxSTC_GAP_KEYWORD
wxSTC_GAP_KEYWORD2
wxSTC_GAP_KEYWORD3
wxSTC_GAP_KEYWORD4
wxSTC_GAP_NUMBER
wxSTC_GAP_OPERATOR
wxSTC_GAP_STRING
wxSTC_GAP_STRINGEOL
wxSTC_GC_ATTRIBUTE
wxSTC_GC_COMMAND
wxSTC_GC_COMMENTBLOCK
wxSTC_GC_COMMENTLINE
wxSTC_GC_CONTROL
wxSTC_GC_DEFAULT
wxSTC_GC_EVENT
wxSTC_GC_GLOBAL
wxSTC_GC_OPERATOR
wxSTC_GC_STRING
wxSTC_H_DEFAULT
wxSTC_H_TAG
wxSTC_H_TAGUNKNOWN
wxSTC_H_ATTRIBUTE
wxSTC_H_ATTRIBUTEUNKNOWN
wxSTC_H_NUMBER
wxSTC_H_DOUBLESTRING
wxSTC_H_SINGLESTRING
wxSTC_H_OTHER
wxSTC_H_COMMENT
wxSTC_H_ENTITY
wxSTC_H_TAGEND
wxSTC_H_XMLSTART
wxSTC_H_XMLEND
wxSTC_H_SCRIPT
wxSTC_H_ASP
wxSTC_H_ASPAT
wxSTC_H_CDATA
wxSTC_H_QUESTION
wxSTC_H_VALUE
wxSTC_H_XCCOMMENT
wxSTC_H_SGML_DEFAULT
wxSTC_H_SGML_COMMAND
wxSTC_H_SGML_1ST_PARAM
wxSTC_H_SGML_DOUBLESTRING
wxSTC_H_SGML_SIMPLESTRING
wxSTC_H_SGML_ERROR
wxSTC_H_SGML_SPECIAL
wxSTC_H_SGML_ENTITY
wxSTC_H_SGML_COMMENT
wxSTC_H_SGML_1ST_PARAM_COMMENT
wxSTC_H_SGML_BLOCK_DEFAULT
wxSTC_HJ_START
wxSTC_HJ_DEFAULT
wxSTC_HJ_COMMENT
wxSTC_HJ_COMMENTLINE
wxSTC_HJ_COMMENTDOC
wxSTC_HJ_NUMBER
wxSTC_HJ_WORD
wxSTC_HJ_KEYWORD
wxSTC_HJ_DOUBLESTRING
wxSTC_HJ_SINGLESTRING
wxSTC_HJ_SYMBOLS
wxSTC_HJ_STRINGEOL
wxSTC_HJ_REGEX
wxSTC_HJA_START
wxSTC_HJA_DEFAULT
wxSTC_HJA_COMMENT
wxSTC_HJA_COMMENTLINE
wxSTC_HJA_COMMENTDOC
wxSTC_HJA_NUMBER
wxSTC_HJA_WORD
wxSTC_HJA_KEYWORD
wxSTC_HJA_DOUBLESTRING
wxSTC_HJA_SINGLESTRING
wxSTC_HJA_SYMBOLS
wxSTC_HJA_STRINGEOL
wxSTC_HJA_REGEX
wxSTC_HB_START
wxSTC_HB_DEFAULT
wxSTC_HB_COMMENTLINE
wxSTC_HB_NUMBER
wxSTC_HB_WORD
wxSTC_HB_STRING
wxSTC_HB_IDENTIFIER
wxSTC_HB_STRINGEOL
wxSTC_HBA_START
wxSTC_HBA_DEFAULT
wxSTC_HBA_COMMENTLINE
wxSTC_HBA_NUMBER
wxSTC_HBA_WORD
wxSTC_HBA_STRING
wxSTC_HBA_IDENTIFIER
wxSTC_HBA_STRINGEOL
wxSTC_HP_START
wxSTC_HP_DEFAULT
wxSTC_HP_COMMENTLINE
wxSTC_HP_NUMBER
wxSTC_HP_STRING
wxSTC_HP_CHARACTER
wxSTC_HP_WORD
wxSTC_HP_TRIPLE
wxSTC_HP_TRIPLEDOUBLE
wxSTC_HP_CLASSNAME
wxSTC_HP_DEFNAME
wxSTC_HP_OPERATOR
wxSTC_HP_IDENTIFIER
wxSTC_HPA_START
wxSTC_HPA_DEFAULT
wxSTC_HPA_COMMENTLINE
wxSTC_HPA_NUMBER
wxSTC_HPA_STRING
wxSTC_HPA_CHARACTER
wxSTC_HPA_WORD
wxSTC_HPA_TRIPLE
wxSTC_HPA_TRIPLEDOUBLE
wxSTC_HPA_CLASSNAME
wxSTC_HPA_DEFNAME
wxSTC_HPA_OPERATOR
wxSTC_HPA_IDENTIFIER
wxSTC_HPHP_DEFAULT
wxSTC_HPHP_HSTRING
wxSTC_HPHP_SIMPLESTRING
wxSTC_HPHP_WORD
wxSTC_HPHP_NUMBER
wxSTC_HPHP_VARIABLE
wxSTC_HPHP_COMMENT
wxSTC_HPHP_COMMENTLINE
wxSTC_HPHP_HSTRING_VARIABLE
wxSTC_HPHP_OPERATOR
wxSTC_HPHP_COMPLEX_VARIABLE
wxSTC_HA_CAPITAL
wxSTC_HA_CHARACTER
wxSTC_HA_CLASS
wxSTC_HA_COMMENTBLOCK
wxSTC_HA_COMMENTBLOCK2
wxSTC_HA_COMMENTBLOCK3
wxSTC_HA_COMMENTLINE
wxSTC_HA_DATA
wxSTC_HA_DEFAULT
wxSTC_HA_IDENTIFIER
wxSTC_HA_IMPORT
wxSTC_HA_INSTANCE
wxSTC_HA_KEYWORD
wxSTC_HA_MODULE
wxSTC_HA_NUMBER
wxSTC_HA_OPERATOR
wxSTC_HA_STRING
wxSTC_INDIC_MAX
wxSTC_INDIC_PLAIN
wxSTC_INDIC_SQUIGGLE
wxSTC_INDIC_TT
wxSTC_INDIC_DIAGONAL
wxSTC_INDIC_STRIKE
wxSTC_INDIC0_MASK
wxSTC_INDIC1_MASK
wxSTC_INDIC2_MASK
wxSTC_INDICS_MASK
wxSTC_INDIC_BOX
wxSTC_INDIC_CONTAINER
wxSTC_INDIC_HIDDEN
wxSTC_INDIC_ROUNDBOX
wxSTC_INDIC_STRAIGHTBOX
wxSTC_INDIC_DASH
wxSTC_INDIC_DOTS
wxSTC_INDIC_SQUIGGLELOW
wxSTC_INDIC_DOTBOX
wxSTC_INNO_COMMENT
wxSTC_INNO_COMMENT_PASCAL
wxSTC_INNO_DEFAULT
wxSTC_INNO_IDENTIFIER
wxSTC_INNO_KEYWORD
wxSTC_INNO_KEYWORD_PASCAL
wxSTC_INNO_KEYWORD_USER
wxSTC_INNO_PARAMETER
wxSTC_INNO_PREPROC
wxSTC_INNO_PREPROC_INLINE
wxSTC_INNO_INLINE_EXPANSION
wxSTC_INNO_SECTION
wxSTC_INNO_STRING_DOUBLE
wxSTC_INNO_STRING_SINGLE
wxSTC_INVALID_POSITION
wxSTC_IV_LOOKBOTH
wxSTC_IV_LOOKFORWARD
wxSTC_IV_NONE
wxSTC_IV_REAL
wxSTC_KEY_DOWN
wxSTC_KEY_UP
wxSTC_KEY_LEFT
wxSTC_KEY_RIGHT
wxSTC_KEY_HOME
wxSTC_KEY_END
wxSTC_KEY_PRIOR
wxSTC_KEY_NEXT
wxSTC_KEY_DELETE
wxSTC_KEY_INSERT
wxSTC_KEY_ESCAPE
wxSTC_KEY_BACK
wxSTC_KEY_TAB
wxSTC_KEY_RETURN
wxSTC_KEY_ADD
wxSTC_KEY_SUBTRACT
wxSTC_KEY_DIVIDE
wxSTC_KEYWORDSET_MAX
wxSTC_KEY_MENU
wxSTC_KEY_RWIN
wxSTC_KEY_WIN
wxSTC_KIX_COMMENT
wxSTC_KIX_DEFAULT
wxSTC_KIX_FUNCTIONS
wxSTC_KIX_IDENTIFIER
wxSTC_KIX_KEYWORD
wxSTC_KIX_MACRO
wxSTC_KIX_NUMBER
wxSTC_KIX_OPERATOR
wxSTC_KIX_STRING1
wxSTC_KIX_STRING2
wxSTC_KIX_VAR
wxSTC_L_TAG2
wxSTC_L_MATH2
wxSTC_L_COMMENT2
wxSTC_L_VERBATIM
wxSTC_L_SHORTCMD
wxSTC_L_SPECIAL
wxSTC_L_CMDOPT
wxSTC_L_ERROR
wxSTC_LUA_LABEL
wxSTC_LEX_TXT2TAGS
wxSTC_LEX_A68K
wxSTC_LEX_MODULA
wxSTC_LEX_COFFEESCRIPT
wxSTC_LEX_TCMD
wxSTC_LEX_AVS
wxSTC_LEX_ECL
wxSTC_LEX_OSCRIPT
wxSTC_LEX_VISUALPROLOG
wxSTC_LEX_ADA
wxSTC_LEX_ASM
wxSTC_LEX_ASP
wxSTC_LEX_AUTOMATIC
wxSTC_LEX_AVE
wxSTC_LEX_BAAN
wxSTC_LEX_BATCH
wxSTC_LEX_BULLANT
wxSTC_LEX_CONF
wxSTC_LEX_CONTAINER
wxSTC_LEX_CPP
wxSTC_LEX_CSS
wxSTC_LEX_DIFF
wxSTC_LEX_EIFFEL
wxSTC_LEX_EIFFELKW
wxSTC_LEX_ERRORLIST
wxSTC_LEX_FORTH
wxSTC_LEX_FORTRAN
wxSTC_LEX_HTML
wxSTC_LEX_LATEX
wxSTC_LEX_LISP
wxSTC_LEX_LUA
wxSTC_LEX_MAKEFILE
wxSTC_LEX_MATLAB
wxSTC_LEX_NNCRONTAB
wxSTC_LEX_NULL
wxSTC_LEX_NSIS
wxSTC_LEX_PASCAL
wxSTC_LEX_PERL
wxSTC_LEX_PHP
wxSTC_LEX_PHPSCRIPT
wxSTC_LEX_PROPERTIES
wxSTC_LEX_PS
wxSTC_LEX_PYTHON
wxSTC_LEX_RUBY
wxSTC_LEX_SCRIPTOL
wxSTC_LEX_SQL
wxSTC_LEX_TCL
wxSTC_LEX_YAML
wxSTC_LEX_TEX
wxSTC_LEX_VB
wxSTC_LEX_VBSCRIPT
wxSTC_LEX_XCODE
wxSTC_LEX_XML
wxSTC_LEX_ABAQUS
wxSTC_LEX_APDL
wxSTC_LEX_ASN1
wxSTC_LEX_ASYMPTOTE
wxSTC_LEX_AU3
wxSTC_LEX_BASH
wxSTC_LEX_BLITZBASIC
wxSTC_LEX_CAML
wxSTC_LEX_CLW
wxSTC_LEX_CLWNOCASE
wxSTC_LEX_CMAKE
wxSTC_LEX_CPPNOCASE
wxSTC_LEX_CSOUND
wxSTC_LEX_D
wxSTC_LEX_ERLANG
wxSTC_LEX_ESCRIPT
wxSTC_LEX_F77
wxSTC_LEX_FLAGSHIP
wxSTC_LEX_FREEBASIC
wxSTC_LEX_GAP
wxSTC_LEX_GUI4CLI
wxSTC_LEX_HASKELL
wxSTC_LEX_INNOSETUP
wxSTC_LEX_KIX
wxSTC_LEX_LOT
wxSTC_LEX_LOUT
wxSTC_LEX_METAPOST
wxSTC_LEX_MMIXAL
wxSTC_LEX_MSSQL
wxSTC_LEX_OCTAVE
wxSTC_LEX_OPAL
wxSTC_LEX_PLM
wxSTC_LEX_POV
wxSTC_LEX_POWERBASIC
wxSTC_LEX_PROGRESS
wxSTC_LEX_PUREBASIC
wxSTC_LEX_R
wxSTC_LEX_REBOL
wxSTC_LEX_SMALLTALK
wxSTC_LEX_SPECMAN
wxSTC_LEX_SPICE
wxSTC_LEX_TADS3
wxSTC_LEX_VERILOG
wxSTC_LEX_VHDL
wxSTC_LEX_MAGIK
wxSTC_LEX_POWERSHELL
wxSTC_LEX_MYSQL
wxSTC_LEX_PO
wxSTC_LEX_TAL
wxSTC_LEX_COBOL
wxSTC_LEX_TACL
wxSTC_LEX_SORCUS
wxSTC_LEX_POWERPRO
wxSTC_LEX_NIMROD
wxSTC_LEX_SML
wxSTC_LEX_MARKDOWN
wxSTC_LASTSTEPINUNDOREDO
wxSTC_L_DEFAULT
wxSTC_L_COMMAND
wxSTC_L_TAG
wxSTC_L_MATH
wxSTC_L_COMMENT
wxSTC_LUA_DEFAULT
wxSTC_LUA_COMMENT
wxSTC_LUA_COMMENTLINE
wxSTC_LUA_COMMENTDOC
wxSTC_LUA_NUMBER
wxSTC_LUA_WORD
wxSTC_LUA_STRING
wxSTC_LUA_CHARACTER
wxSTC_LUA_LITERALSTRING
wxSTC_LUA_PREPROCESSOR
wxSTC_LUA_OPERATOR
wxSTC_LUA_IDENTIFIER
wxSTC_LUA_STRINGEOL
wxSTC_LUA_WORD2
wxSTC_LUA_WORD3
wxSTC_LUA_WORD4
wxSTC_LUA_WORD5
wxSTC_LUA_WORD6
wxSTC_LISP_DEFAULT
wxSTC_LISP_COMMENT
wxSTC_LISP_NUMBER
wxSTC_LISP_KEYWORD
wxSTC_LISP_STRING
wxSTC_LISP_STRINGEOL
wxSTC_LISP_IDENTIFIER
wxSTC_LISP_OPERATOR
wxSTC_LISP_KEYWORD_KW
wxSTC_LISP_MULTI_COMMENT
wxSTC_LISP_SPECIAL
wxSTC_LISP_SYMBOL
wxSTC_LEXER_START
wxSTC_LOT_ABORT
wxSTC_LOT_BREAK
wxSTC_LOT_DEFAULT
wxSTC_LOT_FAIL
wxSTC_LOT_HEADER
wxSTC_LOT_PASS
wxSTC_LOT_SET
wxSTC_LOUT_COMMENT
wxSTC_LOUT_DEFAULT
wxSTC_LOUT_IDENTIFIER
wxSTC_LOUT_NUMBER
wxSTC_LOUT_OPERATOR
wxSTC_LOUT_STRING
wxSTC_LOUT_STRINGEOL
wxSTC_LOUT_WORD
wxSTC_LOUT_WORD2
wxSTC_LOUT_WORD3
wxSTC_LOUT_WORD4
wxSTC_LUA_WORD7
wxSTC_LUA_WORD8
wxSTC_MARGINOPTION_NONE
wxSTC_MARGINOPTION_SUBLINESELECT
wxSTC_MARK_RGBAIMAGE
wxSTC_MOD_LEXERSTATE
wxSTC_MODEVENTMASKALL
wxSTC_MODULA_DEFAULT
wxSTC_MODULA_COMMENT
wxSTC_MODULA_DOXYCOMM
wxSTC_MODULA_DOXYKEY
wxSTC_MODULA_KEYWORD
wxSTC_MODULA_RESERVED
wxSTC_MODULA_NUMBER
wxSTC_MODULA_BASENUM
wxSTC_MODULA_FLOAT
wxSTC_MODULA_STRING
wxSTC_MODULA_STRSPEC
wxSTC_MODULA_CHAR
wxSTC_MODULA_CHARSPEC
wxSTC_MODULA_PROC
wxSTC_MODULA_PRAGMA
wxSTC_MODULA_PRGKEY
wxSTC_MODULA_OPERATOR
wxSTC_MODULA_BADSTR
wxSTC_MULTIPASTE_ONCE
wxSTC_MULTIPASTE_EACH
wxSTC_MARKER_MAX
wxSTC_MARK_CIRCLE
wxSTC_MARK_ROUNDRECT
wxSTC_MARK_ARROW
wxSTC_MARK_SMALLRECT
wxSTC_MARK_SHORTARROW
wxSTC_MARK_EMPTY
wxSTC_MARK_ARROWDOWN
wxSTC_MARK_MINUS
wxSTC_MARK_PLUS
wxSTC_MARK_VLINE
wxSTC_MARK_LCORNER
wxSTC_MARK_TCORNER
wxSTC_MARK_BOXPLUS
wxSTC_MARK_BOXPLUSCONNECTED
wxSTC_MARK_BOXMINUS
wxSTC_MARK_BOXMINUSCONNECTED
wxSTC_MARK_LCORNERCURVE
wxSTC_MARK_TCORNERCURVE
wxSTC_MARK_CIRCLEPLUS
wxSTC_MARK_CIRCLEPLUSCONNECTED
wxSTC_MARK_CIRCLEMINUS
wxSTC_MARK_CIRCLEMINUSCONNECTED
wxSTC_MARK_BACKGROUND
wxSTC_MARK_DOTDOTDOT
wxSTC_MARK_ARROWS
wxSTC_MARK_CHARACTER
wxSTC_MARK_FULLRECT
wxSTC_MARK_LEFTRECT
wxSTC_MARK_AVAILABLE
wxSTC_MARK_UNDERLINE
wxSTC_MARGIN_TEXT
wxSTC_MARGIN_RTEXT
wxSTC_MOD_CHANGEMARGIN
wxSTC_MOD_CHANGEANNOTATION
wxSTC_MOD_CONTAINER
wxSTC_MAGIK_DEFAULT
wxSTC_MAGIK_COMMENT
wxSTC_MAGIK_HYPER_COMMENT
wxSTC_MAGIK_STRING
wxSTC_MAGIK_CHARACTER
wxSTC_MAGIK_NUMBER
wxSTC_MAGIK_IDENTIFIER
wxSTC_MAGIK_OPERATOR
wxSTC_MAGIK_FLOW
wxSTC_MAGIK_CONTAINER
wxSTC_MAGIK_BRACKET_BLOCK
wxSTC_MAGIK_BRACE_BLOCK
wxSTC_MAGIK_SQBRACKET_BLOCK
wxSTC_MAGIK_UNKNOWN_KEYWORD
wxSTC_MAGIK_KEYWORD
wxSTC_MAGIK_PRAGMA
wxSTC_MAGIK_SYMBOL
wxSTC_MYSQL_DEFAULT
wxSTC_MYSQL_COMMENT
wxSTC_MYSQL_COMMENTLINE
wxSTC_MYSQL_VARIABLE
wxSTC_MYSQL_SYSTEMVARIABLE
wxSTC_MYSQL_KNOWNSYSTEMVARIABLE
wxSTC_MYSQL_NUMBER
wxSTC_MYSQL_MAJORKEYWORD
wxSTC_MYSQL_KEYWORD
wxSTC_MYSQL_DATABASEOBJECT
wxSTC_MYSQL_PROCEDUREKEYWORD
wxSTC_MYSQL_STRING
wxSTC_MYSQL_SQSTRING
wxSTC_MYSQL_DQSTRING
wxSTC_MYSQL_OPERATOR
wxSTC_MYSQL_FUNCTION
wxSTC_MYSQL_IDENTIFIER
wxSTC_MYSQL_QUOTEDIDENTIFIER
wxSTC_MYSQL_USER1
wxSTC_MYSQL_USER2
wxSTC_MYSQL_USER3
wxSTC_MYSQL_HIDDENCOMMAND
wxSTC_MARKDOWN_DEFAULT
wxSTC_MARKDOWN_LINE_BEGIN
wxSTC_MARKDOWN_STRONG1
wxSTC_MARKDOWN_STRONG2
wxSTC_MARKDOWN_EM1
wxSTC_MARKDOWN_EM2
wxSTC_MARKDOWN_HEADER1
wxSTC_MARKDOWN_HEADER2
wxSTC_MARKDOWN_HEADER3
wxSTC_MARKDOWN_HEADER4
wxSTC_MARKDOWN_HEADER5
wxSTC_MARKDOWN_HEADER6
wxSTC_MARKDOWN_PRECHAR
wxSTC_MARKDOWN_ULIST_ITEM
wxSTC_MARKDOWN_OLIST_ITEM
wxSTC_MARKDOWN_BLOCKQUOTE
wxSTC_MARKDOWN_STRIKEOUT
wxSTC_MARKDOWN_HRULE
wxSTC_MARKDOWN_LINK
wxSTC_MARKDOWN_CODE
wxSTC_MARKDOWN_CODE2
wxSTC_MARKDOWN_CODEBK
wxSTC_MARK_PIXMAP
wxSTC_MARKNUM_FOLDEREND
wxSTC_MARKNUM_FOLDEROPENMID
wxSTC_MARKNUM_FOLDERMIDTAIL
wxSTC_MARKNUM_FOLDERTAIL
wxSTC_MARKNUM_FOLDERSUB
wxSTC_MARKNUM_FOLDER
wxSTC_MARKNUM_FOLDEROPEN
wxSTC_MASK_FOLDERS
wxSTC_MARGIN_SYMBOL
wxSTC_MARGIN_NUMBER
wxSTC_MARGIN_BACK
wxSTC_MARGIN_FORE
wxSTC_MOD_INSERTTEXT
wxSTC_MOD_DELETETEXT
wxSTC_MOD_CHANGESTYLE
wxSTC_MOD_CHANGEFOLD
wxSTC_MOD_CHANGEMARKER
wxSTC_MOD_BEFOREINSERT
wxSTC_MOD_BEFOREDELETE
wxSTC_MODEVENTMASKALL
wxSTC_MAKE_DEFAULT
wxSTC_MAKE_COMMENT
wxSTC_MAKE_PREPROCESSOR
wxSTC_MAKE_IDENTIFIER
wxSTC_MAKE_OPERATOR
wxSTC_MAKE_TARGET
wxSTC_MAKE_IDEOL
wxSTC_MATLAB_DEFAULT
wxSTC_MATLAB_COMMENT
wxSTC_MATLAB_COMMAND
wxSTC_MATLAB_NUMBER
wxSTC_MATLAB_KEYWORD
wxSTC_MATLAB_STRING
wxSTC_MATLAB_OPERATOR
wxSTC_MATLAB_IDENTIFIER
wxSTC_MATLAB_DOUBLEQUOTESTRING
wxSTC_METAPOST_COMMAND
wxSTC_METAPOST_DEFAULT
wxSTC_METAPOST_EXTRA
wxSTC_METAPOST_GROUP
wxSTC_METAPOST_SPECIAL
wxSTC_METAPOST_SYMBOL
wxSTC_METAPOST_TEXT
wxSTC_MMIXAL_CHAR
wxSTC_MMIXAL_COMMENT
wxSTC_MMIXAL_HEX
wxSTC_MMIXAL_INCLUDE
wxSTC_MMIXAL_LABEL
wxSTC_MMIXAL_LEADWS
wxSTC_MMIXAL_NUMBER
wxSTC_MMIXAL_OPCODE
wxSTC_MMIXAL_OPCODE_POST
wxSTC_MMIXAL_OPCODE_PRE
wxSTC_MMIXAL_OPCODE_UNKNOWN
wxSTC_MMIXAL_OPCODE_VALID
wxSTC_MMIXAL_OPERANDS
wxSTC_MMIXAL_OPERATOR
wxSTC_MMIXAL_REF
wxSTC_MMIXAL_REGISTER
wxSTC_MMIXAL_STRING
wxSTC_MMIXAL_SYMBOL
wxSTC_MOD_CHANGEINDICATOR
wxSTC_MOD_CHANGELINESTATE
wxSTC_MSSQL_COLUMN_NAME
wxSTC_MSSQL_COLUMN_NAME_2
wxSTC_MSSQL_COMMENT
wxSTC_MSSQL_DATATYPE
wxSTC_MSSQL_DEFAULT
wxSTC_MSSQL_DEFAULT_PREF_DATATYPE
wxSTC_MSSQL_FUNCTION
wxSTC_MSSQL_GLOBAL_VARIABLE
wxSTC_MSSQL_IDENTIFIER
wxSTC_MSSQL_LINE_COMMENT
wxSTC_MSSQL_NUMBER
wxSTC_MSSQL_OPERATOR
wxSTC_MSSQL_STATEMENT
wxSTC_MSSQL_STORED_PROCEDURE
wxSTC_MSSQL_STRING
wxSTC_MSSQL_SYSTABLE
wxSTC_MSSQL_VARIABLE
wxSTC_MULTILINEUNDOREDO
wxSTC_MULTISTEPUNDOREDO
wxSTC_NNCRONTAB_DEFAULT
wxSTC_NNCRONTAB_COMMENT
wxSTC_NNCRONTAB_TASK
wxSTC_NNCRONTAB_SECTION
wxSTC_NNCRONTAB_KEYWORD
wxSTC_NNCRONTAB_MODIFIER
wxSTC_NNCRONTAB_ASTERISK
wxSTC_NNCRONTAB_NUMBER
wxSTC_NNCRONTAB_STRING
wxSTC_NNCRONTAB_ENVIRONMENT
wxSTC_NNCRONTAB_IDENTIFIER
wxSTC_NSIS_DEFAULT
wxSTC_NSIS_COMMENT
wxSTC_NSIS_STRINGDQ
wxSTC_NSIS_STRINGLQ
wxSTC_NSIS_STRINGRQ
wxSTC_NSIS_FUNCTION
wxSTC_NSIS_VARIABLE
wxSTC_NSIS_LABEL
wxSTC_NSIS_USERDEFINED
wxSTC_NSIS_SECTIONDEF
wxSTC_NSIS_SUBSECTIONDEF
wxSTC_NSIS_IFDEFINEDEF
wxSTC_NSIS_MACRODEF
wxSTC_NSIS_STRINGVAR
wxSTC_NSIS_NUMBER
wxSTC_NSIS_COMMENTBOX
wxSTC_NSIS_FUNCTIONDEF
wxSTC_NSIS_PAGEEX
wxSTC_NSIS_SECTIONGROUP
wxSTC_OSCRIPT_DEFAULT
wxSTC_OSCRIPT_LINE_COMMENT
wxSTC_OSCRIPT_BLOCK_COMMENT
wxSTC_OSCRIPT_DOC_COMMENT
wxSTC_OSCRIPT_PREPROCESSOR
wxSTC_OSCRIPT_NUMBER
wxSTC_OSCRIPT_SINGLEQUOTE_STRING
wxSTC_OSCRIPT_DOUBLEQUOTE_STRING
wxSTC_OSCRIPT_CONSTANT
wxSTC_OSCRIPT_IDENTIFIER
wxSTC_OSCRIPT_GLOBAL
wxSTC_OSCRIPT_KEYWORD
wxSTC_OSCRIPT_OPERATOR
wxSTC_OSCRIPT_LABEL
wxSTC_OSCRIPT_TYPE
wxSTC_OSCRIPT_FUNCTION
wxSTC_OSCRIPT_OBJECT
wxSTC_OSCRIPT_PROPERTY
wxSTC_OSCRIPT_METHOD
wxSTC_OPAL_BOOL_CONST
wxSTC_OPAL_COMMENT_BLOCK
wxSTC_OPAL_COMMENT_LINE
wxSTC_OPAL_DEFAULT
wxSTC_OPAL_INTEGER
wxSTC_OPAL_KEYWORD
wxSTC_OPAL_PAR
wxSTC_OPAL_SORT
wxSTC_OPAL_SPACE
wxSTC_OPAL_STRING
wxSTC_OPTIONAL_START
wxSTC_PRINT_NORMAL
wxSTC_PRINT_INVERTLIGHT
wxSTC_PRINT_BLACKONWHITE
wxSTC_PRINT_COLOURONWHITE
wxSTC_PRINT_COLOURONWHITEDEFAULTBG
wxSTC_PERFORMED_USER
wxSTC_PERFORMED_UNDO
wxSTC_PERFORMED_REDO
wxSTC_P_DEFAULT
wxSTC_P_COMMENTLINE
wxSTC_P_NUMBER
wxSTC_P_STRING
wxSTC_P_CHARACTER
wxSTC_P_WORD
wxSTC_P_TRIPLE
wxSTC_P_TRIPLEDOUBLE
wxSTC_P_CLASSNAME
wxSTC_P_DEFNAME
wxSTC_P_OPERATOR
wxSTC_P_IDENTIFIER
wxSTC_P_COMMENTBLOCK
wxSTC_P_STRINGEOL
wxSTC_P_DECORATOR
wxSTC_P_WORD2
wxSTC_PL_DEFAULT
wxSTC_PL_ERROR
wxSTC_PL_COMMENTLINE
wxSTC_PL_POD
wxSTC_PL_NUMBER
wxSTC_PL_WORD
wxSTC_PL_STRING
wxSTC_PL_CHARACTER
wxSTC_PL_PUNCTUATION
wxSTC_PL_PREPROCESSOR
wxSTC_PL_OPERATOR
wxSTC_PL_IDENTIFIER
wxSTC_PL_SCALAR
wxSTC_PL_ARRAY
wxSTC_PL_HASH
wxSTC_PL_SYMBOLTABLE
wxSTC_PL_REGEX
wxSTC_PL_REGSUBST
wxSTC_PL_LONGQUOTE
wxSTC_PL_BACKTICKS
wxSTC_PL_DATASECTION
wxSTC_PL_HERE_DELIM
wxSTC_PL_HERE_Q
wxSTC_PL_HERE_QQ
wxSTC_PL_HERE_QX
wxSTC_PL_STRING_Q
wxSTC_PL_STRING_QQ
wxSTC_PL_STRING_QX
wxSTC_PL_STRING_QR
wxSTC_PL_STRING_QW
wxSTC_PL_FORMAT
wxSTC_PL_FORMAT_IDENT
wxSTC_PL_SUB_PROTOTYPE
wxSTC_PL_STRING_VAR
wxSTC_PL_XLAT
wxSTC_PL_REGEX_VAR
wxSTC_PL_REGSUBST_VAR
wxSTC_PL_BACKTICKS_VAR
wxSTC_PL_HERE_QQ_VAR
wxSTC_PL_HERE_QX_VAR
wxSTC_PL_STRING_QQ_VAR
wxSTC_PL_STRING_QX_VAR
wxSTC_PL_STRING_QR_VAR
wxSTC_POWERSHELL_FUNCTION
wxSTC_POWERSHELL_USER1
wxSTC_POWERSHELL_COMMENTSTREAM
wxSTC_PL_POD_VERB
wxSTC_PL_VARIABLE_INDEXER
wxSTC_PROPS_DEFAULT
wxSTC_PROPS_COMMENT
wxSTC_PROPS_SECTION
wxSTC_PROPS_ASSIGNMENT
wxSTC_PROPS_DEFVAL
wxSTC_PROPS_KEY
wxSTC_PS_DEFAULT
wxSTC_PS_COMMENT
wxSTC_PS_DSC_COMMENT
wxSTC_PS_DSC_VALUE
wxSTC_PS_NUMBER
wxSTC_PS_NAME
wxSTC_PS_KEYWORD
wxSTC_PS_LITERAL
wxSTC_PS_IMMEVAL
wxSTC_PS_PAREN_ARRAY
wxSTC_PS_PAREN_DICT
wxSTC_PS_PAREN_PROC
wxSTC_PS_TEXT
wxSTC_PS_HEXSTRING
wxSTC_PS_BASE85STRING
wxSTC_PS_BADSTRINGCHAR
wxSTC_PLM_COMMENT
wxSTC_PLM_CONTROL
wxSTC_PLM_DEFAULT
wxSTC_PLM_IDENTIFIER
wxSTC_PLM_KEYWORD
wxSTC_PLM_NUMBER
wxSTC_PLM_OPERATOR
wxSTC_PLM_STRING
wxSTC_POV_BADDIRECTIVE
wxSTC_POV_COMMENT
wxSTC_POV_COMMENTLINE
wxSTC_POV_DEFAULT
wxSTC_POV_DIRECTIVE
wxSTC_POV_IDENTIFIER
wxSTC_POV_NUMBER
wxSTC_POV_OPERATOR
wxSTC_POV_STRING
wxSTC_POV_STRINGEOL
wxSTC_POV_WORD2
wxSTC_POV_WORD3
wxSTC_POV_WORD4
wxSTC_POV_WORD5
wxSTC_POV_WORD6
wxSTC_POV_WORD7
wxSTC_POV_WORD8
wxSTC_POWERSHELL_DEFAULT
wxSTC_POWERSHELL_COMMENT
wxSTC_POWERSHELL_STRING
wxSTC_POWERSHELL_CHARACTER
wxSTC_POWERSHELL_NUMBER
wxSTC_POWERSHELL_VARIABLE
wxSTC_POWERSHELL_OPERATOR
wxSTC_POWERSHELL_IDENTIFIER
wxSTC_POWERSHELL_KEYWORD
wxSTC_POWERSHELL_CMDLET
wxSTC_POWERSHELL_ALIAS
wxSTC_PO_DEFAULT
wxSTC_PO_COMMENT
wxSTC_PO_MSGID
wxSTC_PO_MSGID_TEXT
wxSTC_PO_MSGSTR
wxSTC_PO_MSGSTR_TEXT
wxSTC_PO_MSGCTXT
wxSTC_PO_MSGCTXT_TEXT
wxSTC_PO_FUZZY
wxSTC_PAS_DEFAULT
wxSTC_PAS_IDENTIFIER
wxSTC_PAS_COMMENT
wxSTC_PAS_COMMENT2
wxSTC_PAS_COMMENTLINE
wxSTC_PAS_PREPROCESSOR
wxSTC_PAS_PREPROCESSOR2
wxSTC_PAS_NUMBER
wxSTC_PAS_HEXNUMBER
wxSTC_PAS_WORD
wxSTC_PAS_STRING
wxSTC_PAS_STRINGEOL
wxSTC_PAS_CHARACTER
wxSTC_PAS_OPERATOR
wxSTC_PAS_ASM
wxSTC_POWERPRO_DEFAULT
wxSTC_POWERPRO_COMMENTBLOCK
wxSTC_POWERPRO_COMMENTLINE
wxSTC_POWERPRO_NUMBER
wxSTC_POWERPRO_WORD
wxSTC_POWERPRO_WORD2
wxSTC_POWERPRO_WORD3
wxSTC_POWERPRO_WORD4
wxSTC_POWERPRO_DOUBLEQUOTEDSTRING
wxSTC_POWERPRO_SINGLEQUOTEDSTRING
wxSTC_POWERPRO_LINECONTINUE
wxSTC_POWERPRO_OPERATOR
wxSTC_POWERPRO_IDENTIFIER
wxSTC_POWERPRO_STRINGEOL
wxSTC_POWERPRO_VERBATIM
wxSTC_POWERPRO_ALTQUOTE
wxSTC_POWERPRO_FUNCTION
wxSTC_RB_BACKTICKS
wxSTC_RB_CHARACTER
wxSTC_RB_CLASSNAME
wxSTC_RB_CLASS_VAR
wxSTC_RB_COMMENTLINE
wxSTC_RB_DATASECTION
wxSTC_RB_DEFAULT
wxSTC_RB_DEFNAME
wxSTC_RB_ERROR
wxSTC_RB_GLOBAL
wxSTC_RB_HERE_DELIM
wxSTC_RB_HERE_Q
wxSTC_RB_HERE_QQ
wxSTC_RB_HERE_QX
wxSTC_RB_IDENTIFIER
wxSTC_RB_INSTANCE_VAR
wxSTC_RB_MODULE_NAME
wxSTC_RB_NUMBER
wxSTC_RB_OPERATOR
wxSTC_RB_POD
wxSTC_RB_REGEX
wxSTC_RB_STDERR
wxSTC_RB_STDIN
wxSTC_RB_STDOUT
wxSTC_RB_STRING
wxSTC_RB_STRING_Q
wxSTC_RB_STRING_QQ
wxSTC_RB_STRING_QR
wxSTC_RB_STRING_QW
wxSTC_RB_STRING_QX
wxSTC_RB_SYMBOL
wxSTC_RB_UPPER_BOUND
wxSTC_RB_WORD
wxSTC_RB_WORD_DEMOTED
wxSTC_REBOL_BINARY
wxSTC_REBOL_BRACEDSTRING
wxSTC_REBOL_CHARACTER
wxSTC_REBOL_COMMENTBLOCK
wxSTC_REBOL_COMMENTLINE
wxSTC_REBOL_DATE
wxSTC_REBOL_DEFAULT
wxSTC_REBOL_EMAIL
wxSTC_REBOL_FILE
wxSTC_REBOL_IDENTIFIER
wxSTC_REBOL_ISSUE
wxSTC_REBOL_MONEY
wxSTC_REBOL_NUMBER
wxSTC_REBOL_OPERATOR
wxSTC_REBOL_PAIR
wxSTC_REBOL_PREFACE
wxSTC_REBOL_QUOTEDSTRING
wxSTC_REBOL_TAG
wxSTC_REBOL_TIME
wxSTC_REBOL_TUPLE
wxSTC_REBOL_URL
wxSTC_REBOL_WORD
wxSTC_REBOL_WORD2
wxSTC_REBOL_WORD3
wxSTC_REBOL_WORD4
wxSTC_REBOL_WORD5
wxSTC_REBOL_WORD6
wxSTC_REBOL_WORD7
wxSTC_REBOL_WORD8
wxSTC_R_BASEKWORD
wxSTC_R_COMMENT
wxSTC_R_DEFAULT
wxSTC_R_IDENTIFIER
wxSTC_R_INFIX
wxSTC_R_INFIXEOL
wxSTC_R_KWORD
wxSTC_R_NUMBER
wxSTC_R_OPERATOR
wxSTC_R_OTHERKWORD
wxSTC_R_STRING
wxSTC_R_STRING2
wxSTC_SCMOD_META
wxSTC_STATUS_OK
wxSTC_STATUS_FAILURE
wxSTC_STATUS_BADALLOC
wxSTC_SCVS_NONE
wxSTC_SCVS_RECTANGULARSELECTION
wxSTC_SCVS_USERACCESSIBLE
wxSTC_SORCUS_DEFAULT
wxSTC_SORCUS_COMMAND
wxSTC_SORCUS_PARAMETER
wxSTC_SORCUS_COMMENTLINE
wxSTC_SORCUS_STRING
wxSTC_SORCUS_STRINGEOL
wxSTC_SORCUS_IDENTIFIER
wxSTC_SORCUS_OPERATOR
wxSTC_SORCUS_NUMBER
wxSTC_SORCUS_CONSTANT
wxSTC_SML_DEFAULT
wxSTC_SML_IDENTIFIER
wxSTC_SML_TAGNAME
wxSTC_SML_KEYWORD
wxSTC_SML_KEYWORD2
wxSTC_SML_KEYWORD3
wxSTC_SML_LINENUM
wxSTC_SML_OPERATOR
wxSTC_SML_NUMBER
wxSTC_SML_CHAR
wxSTC_SML_STRING
wxSTC_SML_COMMENT
wxSTC_SML_COMMENT1
wxSTC_SML_COMMENT2
wxSTC_SML_COMMENT3
wxSTC_STYLE_DEFAULT
wxSTC_STYLE_LINENUMBER
wxSTC_STYLE_BRACELIGHT
wxSTC_STYLE_BRACEBAD
wxSTC_STYLE_CONTROLCHAR
wxSTC_STYLE_INDENTGUIDE
wxSTC_STYLE_LASTPREDEFINED
wxSTC_STYLE_CALLTIP
wxSTC_STYLE_MAX
wxSTC_SCMOD_SHIFT
wxSTC_SCMOD_CTRL
wxSTC_SCMOD_ALT
wxSTC_SCMOD_NORM
wxSTC_SCMOD_SUPER
wxSTC_SCRIPTOL_DEFAULT
wxSTC_SCRIPTOL_COMMENTLINE
wxSTC_SCRIPTOL_NUMBER
wxSTC_SCRIPTOL_STRING
wxSTC_SCRIPTOL_CHARACTER
wxSTC_SCRIPTOL_PREPROCESSOR
wxSTC_SCRIPTOL_OPERATOR
wxSTC_SCRIPTOL_IDENTIFIER
wxSTC_SCRIPTOL_STRINGEOL
wxSTC_SCRIPTOL_CLASSNAME
wxSTC_SCRIPTOL_COMMENTBLOCK
wxSTC_SCRIPTOL_CSTYLE
wxSTC_SCRIPTOL_KEYWORD
wxSTC_SCRIPTOL_PERSISTENT
wxSTC_SCRIPTOL_TRIPLE
wxSTC_SCRIPTOL_WHITE
wxSTC_SH_BACKTICKS
wxSTC_SH_CHARACTER
wxSTC_SH_COMMENTLINE
wxSTC_SH_DEFAULT
wxSTC_SH_ERROR
wxSTC_SH_HERE_DELIM
wxSTC_SH_HERE_Q
wxSTC_SH_IDENTIFIER
wxSTC_SH_NUMBER
wxSTC_SH_OPERATOR
wxSTC_SH_PARAM
wxSTC_SH_SCALAR
wxSTC_SH_STRING
wxSTC_SH_WORD
wxSTC_SN_CODE
wxSTC_SN_COMMENTLINE
wxSTC_SN_COMMENTLINEBANG
wxSTC_SN_DEFAULT
wxSTC_SN_IDENTIFIER
wxSTC_SN_NUMBER
wxSTC_SN_OPERATOR
wxSTC_SN_PREPROCESSOR
wxSTC_SN_REGEXTAG
wxSTC_SN_SIGNAL
wxSTC_SN_STRING
wxSTC_SN_STRINGEOL
wxSTC_SN_USER
wxSTC_SN_WORD
wxSTC_SN_WORD2
wxSTC_SN_WORD3
wxSTC_SPICE_COMMENTLINE
wxSTC_SPICE_DEFAULT
wxSTC_SPICE_DELIMITER
wxSTC_SPICE_IDENTIFIER
wxSTC_SPICE_KEYWORD
wxSTC_SPICE_KEYWORD2
wxSTC_SPICE_KEYWORD3
wxSTC_SPICE_NUMBER
wxSTC_SPICE_VALUE
wxSTC_SQL_CHARACTER
wxSTC_SQL_COMMENT
wxSTC_SQL_COMMENTDOC
wxSTC_SQL_COMMENTDOCKEYWORD
wxSTC_SQL_COMMENTDOCKEYWORDERROR
wxSTC_SQL_COMMENTLINE
wxSTC_SQL_COMMENTLINEDOC
wxSTC_SQL_DEFAULT
wxSTC_SQL_IDENTIFIER
wxSTC_SQL_NUMBER
wxSTC_SQL_OPERATOR
wxSTC_SQL_QUOTEDIDENTIFIER
wxSTC_SQL_SQLPLUS
wxSTC_SQL_SQLPLUS_COMMENT
wxSTC_SQL_SQLPLUS_PROMPT
wxSTC_SQL_STRING
wxSTC_SQL_USER1
wxSTC_SQL_USER2
wxSTC_SQL_USER3
wxSTC_SQL_USER4
wxSTC_SQL_WORD
wxSTC_SQL_WORD2
wxSTC_ST_ASSIGN
wxSTC_ST_BINARY
wxSTC_ST_BOOL
wxSTC_ST_CHARACTER
wxSTC_ST_COMMENT
wxSTC_ST_DEFAULT
wxSTC_ST_GLOBAL
wxSTC_ST_KWSEND
wxSTC_ST_NIL
wxSTC_ST_NUMBER
wxSTC_ST_RETURN
wxSTC_ST_SELF
wxSTC_ST_SPECIAL
wxSTC_ST_SPEC_SEL
wxSTC_ST_STRING
wxSTC_ST_SUPER
wxSTC_ST_SYMBOL
wxSTC_START
wxSTC_STARTACTION
wxSTC_SEL_STREAM
wxSTC_SEL_RECTANGLE
wxSTC_SEL_LINES
wxSTC_SEL_THIN
wxEVT_STC_CHANGE
wxEVT_STC_STYLENEEDED
wxEVT_STC_CHARADDED
wxEVT_STC_SAVEPOINTREACHED
wxEVT_STC_SAVEPOINTLEFT
wxEVT_STC_ROMODIFYATTEMPT
wxEVT_STC_KEY
wxEVT_STC_DOUBLECLICK
wxEVT_STC_UPDATEUI
wxEVT_STC_MODIFIED
wxEVT_STC_MACRORECORD
wxEVT_STC_MARGINCLICK
wxEVT_STC_NEEDSHOWN
wxEVT_STC_POSCHANGED
wxEVT_STC_PAINTED
wxEVT_STC_USERLISTSELECTION
wxEVT_STC_URIDROPPED
wxEVT_STC_DWELLSTART
wxEVT_STC_DWELLEND
wxEVT_STC_START_DRAG
wxEVT_STC_DRAG_OVER
wxEVT_STC_DO_DROP
wxEVT_STC_ZOOM
wxEVT_STC_HOTSPOT_CLICK
wxEVT_STC_HOTSPOT_DCLICK
wxEVT_STC_CALLTIP_CLICK
wxEVT_STC_AUTOCOMP_CANCELLED
wxEVT_STC_AUTOCOMP_CHAR_DELETED
wxSTC_TCMD_DEFAULT
wxSTC_TCMD_COMMENT
wxSTC_TCMD_WORD
wxSTC_TCMD_LABEL
wxSTC_TCMD_HIDE
wxSTC_TCMD_COMMAND
wxSTC_TCMD_IDENTIFIER
wxSTC_TCMD_OPERATOR
wxSTC_TCMD_ENVIRONMENT
wxSTC_TCMD_EXPANSION
wxSTC_TCMD_CLABEL
wxSTC_TECHNOLOGY_DEFAULT
wxSTC_TECHNOLOGY_DIRECTWRITE
wxSTC_TXT2TAGS_DEFAULT
wxSTC_TXT2TAGS_LINE_BEGIN
wxSTC_TXT2TAGS_STRONG1
wxSTC_TXT2TAGS_STRONG2
wxSTC_TXT2TAGS_EM1
wxSTC_TXT2TAGS_EM2
wxSTC_TXT2TAGS_HEADER1
wxSTC_TXT2TAGS_HEADER2
wxSTC_TXT2TAGS_HEADER3
wxSTC_TXT2TAGS_HEADER4
wxSTC_TXT2TAGS_HEADER5
wxSTC_TXT2TAGS_HEADER6
wxSTC_TXT2TAGS_PRECHAR
wxSTC_TXT2TAGS_ULIST_ITEM
wxSTC_TXT2TAGS_OLIST_ITEM
wxSTC_TXT2TAGS_BLOCKQUOTE
wxSTC_TXT2TAGS_STRIKEOUT
wxSTC_TXT2TAGS_HRULE
wxSTC_TXT2TAGS_LINK
wxSTC_TXT2TAGS_CODE
wxSTC_TXT2TAGS_CODE2
wxSTC_TXT2TAGS_CODEBK
wxSTC_TXT2TAGS_COMMENT
wxSTC_TXT2TAGS_OPTION
wxSTC_TXT2TAGS_PREPROC
wxSTC_TXT2TAGS_POSTPROC
wxSTC_TYPE_BOOLEAN
wxSTC_TYPE_INTEGER
wxSTC_TYPE_STRING
wxSTC_TIME_FOREVER
wxSTC_TEX_DEFAULT
wxSTC_TEX_SPECIAL
wxSTC_TEX_GROUP
wxSTC_TEX_SYMBOL
wxSTC_TEX_COMMAND
wxSTC_TEX_TEXT
wxSTC_T3_BLOCK_COMMENT
wxSTC_T3_BRACE
wxSTC_T3_DEFAULT
wxSTC_T3_D_STRING
wxSTC_T3_HTML_DEFAULT
wxSTC_T3_HTML_STRING
wxSTC_T3_HTML_TAG
wxSTC_T3_IDENTIFIER
wxSTC_T3_KEYWORD
wxSTC_T3_LIB_DIRECTIVE
wxSTC_T3_LINE_COMMENT
wxSTC_T3_MSG_PARAM
wxSTC_T3_NUMBER
wxSTC_T3_OPERATOR
wxSTC_T3_PREPROCESSOR
wxSTC_T3_S_STRING
wxSTC_T3_USER1
wxSTC_T3_USER2
wxSTC_T3_USER3
wxSTC_T3_X_DEFAULT
wxSTC_T3_X_STRING
wxSTC_TCL_BLOCK_COMMENT
wxSTC_TCL_COMMENT
wxSTC_TCL_COMMENTLINE
wxSTC_TCL_COMMENT_BOX
wxSTC_TCL_DEFAULT
wxSTC_TCL_EXPAND
wxSTC_TCL_IDENTIFIER
wxSTC_TCL_IN_QUOTE
wxSTC_TCL_MODIFIER
wxSTC_TCL_NUMBER
wxSTC_TCL_OPERATOR
wxSTC_TCL_SUBSTITUTION
wxSTC_TCL_SUB_BRACE
wxSTC_TCL_WORD
wxSTC_TCL_WORD2
wxSTC_TCL_WORD3
wxSTC_TCL_WORD4
wxSTC_TCL_WORD5
wxSTC_TCL_WORD6
wxSTC_TCL_WORD7
wxSTC_TCL_WORD8
wxSTC_TCL_WORD_IN_QUOTE
wxSTC_UNDO_MAY_COALESCE
wxSTC_UPDATE_CONTENT
wxSTC_UPDATE_SELECTION
wxSTC_UPDATE_V_SCROLL
wxSTC_UPDATE_H_SCROLL
wxSTC_VISUALPROLOG_DEFAULT
wxSTC_VISUALPROLOG_KEY_MAJOR
wxSTC_VISUALPROLOG_KEY_MINOR
wxSTC_VISUALPROLOG_KEY_DIRECTIVE
wxSTC_VISUALPROLOG_COMMENT_BLOCK
wxSTC_VISUALPROLOG_COMMENT_LINE
wxSTC_VISUALPROLOG_COMMENT_KEY
wxSTC_VISUALPROLOG_COMMENT_KEY_ERROR
wxSTC_VISUALPROLOG_IDENTIFIER
wxSTC_VISUALPROLOG_VARIABLE
wxSTC_VISUALPROLOG_ANONYMOUS
wxSTC_VISUALPROLOG_NUMBER
wxSTC_VISUALPROLOG_OPERATOR
wxSTC_VISUALPROLOG_CHARACTER
wxSTC_VISUALPROLOG_CHARACTER_TOO_MANY
wxSTC_VISUALPROLOG_CHARACTER_ESCAPE_ERROR
wxSTC_VISUALPROLOG_STRING
wxSTC_VISUALPROLOG_STRING_ESCAPE
wxSTC_VISUALPROLOG_STRING_ESCAPE_ERROR
wxSTC_VISUALPROLOG_STRING_EOL_OPEN
wxSTC_VISUALPROLOG_STRING_VERBATIM
wxSTC_VISUALPROLOG_STRING_VERBATIM_SPECIAL
wxSTC_VISUALPROLOG_STRING_VERBATIM_EOL
wxSTC_VISIBLE_SLOP
wxSTC_VISIBLE_STRICT
wxSTC_VHDL_ATTRIBUTE
wxSTC_VHDL_COMMENT
wxSTC_VHDL_COMMENTLINEBANG
wxSTC_VHDL_DEFAULT
wxSTC_VHDL_IDENTIFIER
wxSTC_VHDL_KEYWORD
wxSTC_VHDL_NUMBER
wxSTC_VHDL_OPERATOR
wxSTC_VHDL_STDFUNCTION
wxSTC_VHDL_STDOPERATOR
wxSTC_VHDL_STDPACKAGE
wxSTC_VHDL_STDTYPE
wxSTC_VHDL_STRING
wxSTC_VHDL_STRINGEOL
wxSTC_VHDL_USERWORD
wxSTC_V_COMMENT
wxSTC_V_COMMENTLINE
wxSTC_V_COMMENTLINEBANG
wxSTC_V_DEFAULT
wxSTC_V_IDENTIFIER
wxSTC_V_NUMBER
wxSTC_V_OPERATOR
wxSTC_V_PREPROCESSOR
wxSTC_V_STRING
wxSTC_V_STRINGEOL
wxSTC_V_USER
wxSTC_V_WORD
wxSTC_V_WORD2
wxSTC_V_WORD3
wxSTC_WEIGHT_NORMAL
wxSTC_WEIGHT_SEMIBOLD
wxSTC_WEIGHT_BOLD
wxSTC_WRAPVISUALFLAG_MARGIN
wxSTC_WRAP_NONE
wxSTC_WRAP_WORD
wxSTC_WRAP_CHAR
wxSTC_WRAPVISUALFLAGLOC_DEFAULT
wxSTC_WRAPVISUALFLAGLOC_END_BY_TEXT
wxSTC_WRAPVISUALFLAGLOC_START_BY_TEXT
wxSTC_WRAPVISUALFLAG_END
wxSTC_WRAPVISUALFLAG_NONE
wxSTC_WRAPVISUALFLAG_START
wxSTC_WS_INVISIBLE
wxSTC_WS_VISIBLEALWAYS
wxSTC_WS_VISIBLEAFTERINDENT
wxSTC_WRAPINDENT_FIXED
wxSTC_WRAPINDENT_SAME
wxSTC_WRAPINDENT_INDENT
wxSTC_YAML_COMMENT
wxSTC_YAML_DEFAULT
wxSTC_YAML_DOCUMENT
wxSTC_YAML_ERROR
wxSTC_YAML_IDENTIFIER
wxSTC_YAML_KEYWORD
wxSTC_YAML_NUMBER
wxSTC_YAML_OPERATOR
wxSTC_YAML_REFERENCE
wxSTC_YAML_TEXT
wxXRC_USE_LOCALE
wxXRC_NO_SUBCLASSING
wxXRC_NO_RELOADING
wxXML_ELEMENT_NODE
wxXML_ATTRIBUTE_NODE
wxXML_TEXT_NODE
wxXML_CDATA_SECTION_NODE
wxXML_ENTITY_REF_NODE
wxXML_ENTITY_NODE
wxXML_PI_NODE
wxXML_COMMENT_NODE
wxXML_DOCUMENT_NODE
wxXML_DOCUMENT_TYPE_NODE
wxXML_DOCUMENT_FRAG_NODE
wxXML_NOTATION_NODE
wxXML_HTML_DOCUMENT_NODE
wxCOL_WIDTH_AUTOSIZE
wxCOL_SORTABLE
wxCOL_DEFAULT_FLAGS
wxCOL_WIDTH_DEFAULT
wxCOL_RESIZABLE
wxCOL_REORDERABLE
wxCOL_HIDDEN
wxHD_DEFAULT_STYLE
wxHD_ALLOW_REORDER
wxHD_ALLOW_HIDE
wxTipKind_Top
wxTipKind_BottomLeft
wxTipKind_TopRight
wxTipKind_Bottom
wxTipKind_BottomRight
wxTipKind_Auto
wxTipKind_TopLeft
wxTipKind_None
wxTL_STYLE_MASK
wxTL_MULTIPLE
wxTL_DEFAULT_STYLE
wxTL_USER_3STATE
wxTL_NO_HEADER
wxTL_SINGLE
wxTL_CHECKBOX
wxTL_3STATE
wxIPC_WAVE
wxIPC_FILENAME
wxIPC_ENHMETAFILE
wxIPC_LOCALE
wxIPC_UNICODETEXT
wxIPC_UTF8TEXT
wxIPC_PENDATA
wxIPC_METAFILE
wxIPC_DIB
wxIPC_OEMTEXT
wxIPC_UTF32TEXT
wxIPC_PALETTE
wxIPC_PRIVATE
wxIPC_TIFF
wxIPC_UTF16TEXT
wxIPC_BITMAP
wxIPC_TEXT
wxIPC_SYLK
wxIPC_INVALID
wxIPC_DIF
wxIPC_RIFF);

$EXPORT_TAGS{'everything'} = \@EXPORT_OK;

$EXPORT_TAGS{'animation'} = [ qw(wxANIMATION_TYPE_ANI
wxANIMATION_TYPE_ANY
wxANIMATION_TYPE_GIF
wxANIMATION_TYPE_INVALID
wxNullAnimation) ];
$EXPORT_TAGS{'animationctrl'} = [ qw(wxAC_DEFAULT_STYLE
wxAC_NO_AUTORESIZE) ];
$EXPORT_TAGS{'aui'} = [ qw(wxAUI_DOCK_NONE
wxAUI_DOCK_TOP
wxAUI_DOCK_RIGHT
wxAUI_DOCK_BOTTOM
wxAUI_DOCK_LEFT
wxAUI_DOCK_CENTER
wxAUI_DOCK_CENTRE
wxAUI_MGR_ALLOW_FLOATING
wxAUI_MGR_ALLOW_ACTIVE_PANE
wxAUI_MGR_TRANSPARENT_DRAG
wxAUI_MGR_TRANSPARENT_HINT
wxAUI_MGR_VENETIAN_BLINDS_HINT
wxAUI_MGR_RECTANGLE_HINT
wxAUI_MGR_HINT_FADE
wxAUI_MGR_NO_VENETIAN_BLINDS_FADE
wxAUI_MGR_DEFAULT
wxAUI_ART_SASH_SIZE
wxAUI_ART_CAPTION_SIZE
wxAUI_ART_GRIPPER_SIZE
wxAUI_ART_PANE_BORDER_SIZE
wxAUI_ART_PANE_BUTTON_SIZE
wxAUI_ART_BACKGROUND_COLOUR
wxAUI_ART_SASH_COLOUR
wxAUI_ART_ACTIVE_CAPTION_COLOUR
wxAUI_ART_ACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_ART_INACTIVE_CAPTION_COLOUR
wxAUI_ART_INACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_ART_ACTIVE_CAPTION_TEXT_COLOUR
wxAUI_ART_INACTIVE_CAPTION_TEXT_COLOUR
wxAUI_ART_BORDER_COLOUR
wxAUI_ART_GRIPPER_COLOUR
wxAUI_ART_CAPTION_FONT
wxAUI_ART_GRADIENT_TYPE
wxAUI_DOCKART_SASH_SIZE
wxAUI_DOCKART_CAPTION_SIZE
wxAUI_DOCKART_GRIPPER_SIZE
wxAUI_DOCKART_PANE_BORDER_SIZE
wxAUI_DOCKART_PANE_BUTTON_SIZE
wxAUI_DOCKART_BACKGROUND_COLOUR
wxAUI_DOCKART_SASH_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_GRADIENT_COLOUR
wxAUI_DOCKART_ACTIVE_CAPTION_TEXT_COLOUR
wxAUI_DOCKART_INACTIVE_CAPTION_TEXT_COLOUR
wxAUI_DOCKART_BORDER_COLOUR
wxAUI_DOCKART_GRIPPER_COLOUR
wxAUI_DOCKART_CAPTION_FONT
wxAUI_DOCKART_GRADIENT_TYPE
wxAUI_GRADIENT_NONE
wxAUI_GRADIENT_VERTICAL
wxAUI_GRADIENT_HORIZONTAL
wxAUI_BUTTON_STATE_NORMAL
wxAUI_BUTTON_STATE_HOVER
wxAUI_BUTTON_STATE_PRESSED
wxAUI_BUTTON_STATE_DISABLED
wxAUI_BUTTON_STATE_HIDDEN
wxAUI_BUTTON_CLOSE
wxAUI_BUTTON_MAXIMIZE_RESTORE
wxAUI_BUTTON_MINIMIZE
wxAUI_BUTTON_PIN
wxAUI_BUTTON_OPTIONS
wxAUI_BUTTON_WINDOWLIST
wxAUI_BUTTON_LEFT
wxAUI_BUTTON_RIGHT
wxAUI_BUTTON_UP
wxAUI_BUTTON_DOWN
wxAUI_BUTTON_CUSTOM1
wxAUI_BUTTON_CUSTOM2
wxAUI_BUTTON_CUSTOM3
wxAUI_INSERT_PANE
wxAUI_INSERT_ROW
wxAUI_INSERT_DOCK
wxAUI_NB_TOP
wxAUI_NB_LEFT
wxAUI_NB_RIGHT
wxAUI_NB_BOTTOM
wxAUI_NB_TAB_SPLIT
wxAUI_NB_TAB_MOVE
wxAUI_NB_TAB_EXTERNAL_MOVE
wxAUI_NB_TAB_FIXED_WIDTH
wxAUI_NB_SCROLL_BUTTONS
wxAUI_NB_WINDOWLIST_BUTTON
wxAUI_NB_CLOSE_BUTTON
wxAUI_NB_CLOSE_ON_ACTIVE_TAB
wxAUI_NB_CLOSE_ON_ALL_TABS
wxAUI_NB_DEFAULT_STYLE) ];
$EXPORT_TAGS{'bitmap'} = [ qw(wxBITMAP_TYPE_BMP
wxBITMAP_TYPE_BMP_RESOURCE
wxBITMAP_TYPE_CUR
wxBITMAP_TYPE_CUR_RESOURCE
wxBITMAP_TYPE_ICO
wxBITMAP_TYPE_ICO_RESOURCE
wxBITMAP_TYPE_GIF
wxBITMAP_TYPE_XBM
wxBITMAP_TYPE_XPM
wxBITMAP_TYPE_JPEG
wxBITMAP_TYPE_PNG
wxBITMAP_TYPE_PNM
wxBITMAP_TYPE_PCX
wxBITMAP_TYPE_ANY
wxBITMAP_TYPE_TIF
wxBITMAP_TYPE_ANI
wxBITMAP_TYPE_GIF_RESOURCE
wxBITMAP_TYPE_ICON
wxBITMAP_TYPE_ICON_RESOURCE
wxBITMAP_TYPE_IFF
wxBITMAP_TYPE_INVALID
wxBITMAP_TYPE_JPEG_RESOURCE
wxBITMAP_TYPE_MACCURSOR
wxBITMAP_TYPE_MACCURSOR_RESOURCE
wxBITMAP_TYPE_PCX_RESOURCE
wxBITMAP_TYPE_PICT
wxBITMAP_TYPE_PICT_RESOURCE
wxBITMAP_TYPE_PNG_RESOURCE
wxBITMAP_TYPE_PNM_RESOURCE
wxBITMAP_TYPE_RESOURCE
wxBITMAP_TYPE_TGA
wxBITMAP_TYPE_TIF_RESOURCE
wxBITMAP_TYPE_XBM_DATA
wxBITMAP_TYPE_XPM_DATA
wxNullBitmap) ];
$EXPORT_TAGS{'bookctrl'} = [ qw(wxBK_DEFAULT
wxBK_TOP
wxBK_BOTTOM
wxBK_LEFT
wxBK_RIGHT
wxBK_HITTEST_NOWHERE
wxBK_HITTEST_ONICON
wxBK_HITTEST_ONLABEL
wxBK_HITTEST_ONITEM
wxBK_HITTEST_ONPAGE) ];
$EXPORT_TAGS{'brush'} = [ qw(wxBDIAGONAL_HATCH
wxBRUSHSTYLE_BDIAGONAL_HATCH
wxBRUSHSTYLE_CROSSDIAG_HATCH
wxBRUSHSTYLE_CROSS_HATCH
wxBRUSHSTYLE_FDIAGONAL_HATCH
wxBRUSHSTYLE_FIRST_HATCH
wxBRUSHSTYLE_HORIZONTAL_HATCH
wxBRUSHSTYLE_INVALID
wxBRUSHSTYLE_LAST_HATCH
wxBRUSHSTYLE_SOLID
wxBRUSHSTYLE_STIPPLE
wxBRUSHSTYLE_STIPPLE_MASK
wxBRUSHSTYLE_STIPPLE_MASK_OPAQUE
wxBRUSHSTYLE_TRANSPARENT
wxBRUSHSTYLE_VERTICAL_HATCH
wxCROSSDIAG_HATCH
wxCROSS_HATCH
wxFDIAGONAL_HATCH
wxSTIPPLE
wxSTIPPLE_MASK_OPAQUE
wxSOLID
wxTRANSPARENT
wxVERTICAL_HATCH
wxNullBrush
wxBLUE_BRUSH
wxGREEN_BRUSH
wxWHITE_BRUSH
wxBLACK_BRUSH
wxGREY_BRUSH
wxMEDIUM_GREY_BRUSH
wxLIGHT_GREY_BRUSH
wxTRANSPARENT_BRUSH
wxCYAN_BRUSH
wxRED_BRUSH) ];
$EXPORT_TAGS{'button'} = [ qw(wxBU_TOP
wxBU_LEFT
wxBU_BOTTOM
wxBU_AUTODRAW
wxBU_RIGHT
wxBU_NOAUTODRAW
wxBU_EXACTFIT) ];
$EXPORT_TAGS{'calendar'} = [ qw(wxCAL_SUNDAY_FIRST
wxCAL_MONDAY_FIRST
wxCAL_SHOW_HOLIDAYS
wxCAL_NO_YEAR_CHANGE
wxCAL_NO_MONTH_CHANGE
wxCAL_SHOW_SURROUNDING_WEEKS
wxCAL_SHOW_WEEK_NUMBERS
wxCAL_SEQUENTIAL_MONTH_SELECTION
wxCAL_HITTEST_NOWHERE
wxCAL_HITTEST_HEADER
wxCAL_HITTEST_DAY
wxCAL_HITTEST_DECMONTH
wxCAL_HITTEST_INCMONTH
wxCAL_HITTEST_SURROUNDING_WEEK
wxCAL_BORDER_NONE
wxCAL_BORDER_SQUARE
wxCAL_BORDER_ROUND
wxEVT_CALENDAR_SEL_CHANGED
wxEVT_CALENDAR_DAY_CHANGED
wxEVT_CALENDAR_MONTH_CHANGED
wxEVT_CALENDAR_YEAR_CHANGED
wxEVT_CALENDAR_DOUBLECLICKED
wxEVT_CALENDAR_WEEKDAY_CLICKED
wxEVT_DATE_CHANGED
wxEVT_TIME_CHANGED) ];
$EXPORT_TAGS{'checkbox'} = [ qw(wxCHK_2STATE
wxCHK_3STATE
wxCHK_ALLOW_3RD_STATE_FOR_USER
wxCHK_UNCHECKED
wxCHK_CHECKED
wxCHK_UNDETERMINED) ];
$EXPORT_TAGS{'choicebook'} = [ qw(wxCHB_BOTTOM
wxCHB_TOP
wxCHB_ALIGN_MASK
wxCHB_DEFAULT
wxCHB_LEFT
wxCHB_RIGHT) ];
$EXPORT_TAGS{'clipboard'} = [ qw(wxTheClipboard
wxDF_INVALID
wxDF_TEXT
wxDF_UNICODETEXT
wxDF_BITMAP
wxDF_METAFILE
wxDF_FILENAME) ];
$EXPORT_TAGS{'collapsiblepane'} = [ qw(wxCP_DEFAULT_STYLE
wxCP_NO_TLW_RESIZE) ];
$EXPORT_TAGS{'color'} = [ qw(wxALPHA_OPAQUE
wxALPHA_TRANSPARENT
wxC2S_NAME
wxC2S_CSS_SYNTAX
wxC2S_HTML_SYNTAX
wxNullColour
wxRED
wxGREEN
wxBLUE
wxBLACK
wxWHITE
wxCYAN
wxLIGHT_GREY) ];
$EXPORT_TAGS{'colour'} = [ qw(wxALPHA_OPAQUE
wxALPHA_TRANSPARENT
wxC2S_NAME
wxC2S_CSS_SYNTAX
wxC2S_HTML_SYNTAX
wxNullColour
wxRED
wxGREEN
wxBLUE
wxBLACK
wxWHITE
wxCYAN
wxLIGHT_GREY) ];
$EXPORT_TAGS{'combobox'} = [ qw(wxCB_SIMPLE
wxCB_DROPDOWN
wxCB_READONLY
wxCB_SORT
wxTE_PROCESS_ENTER) ];
$EXPORT_TAGS{'comboctrl'} = [ qw(wxCB_READONLY
wxCB_SORT
wxCC_SPECIAL_DCLICK
wxCC_STD_BUTTON
wxTE_PROCESS_ENTER) ];
$EXPORT_TAGS{'config'} = [ qw(wxCONFIG_USE_SUBDIR
wxCONFIG_USE_LOCAL_FILE
wxCONFIG_USE_GLOBAL_FILE
wxCONFIG_USE_RELATIVE_PATH) ];
$EXPORT_TAGS{'constraints'} = [ qw(wxAbove
wxAbsolute
wxAsIs
wxBottom
wxBelow
wxCentreX
wxCentreY
wxCenterX
wxCenterY
wxHeight
wxLEFT
wxLeft
wxLeftOf
wxPercentOf
wxPartRegion
wxRIGHT
wxRight
wxRightOf
wxSameAs
wxTOP
wxTop
wxUnconstrained
wxWidth) ];
$EXPORT_TAGS{'control'} = [ qw(wxDEFAULT_CONTROL_BORDER) ];
$EXPORT_TAGS{'cursor'} = [ qw(wxCURSOR_ARROW
wxCURSOR_ARROWWAIT
wxCURSOR_RIGHT_ARROW
wxCURSOR_BULLSEYE
wxCURSOR_CHAR
wxCURSOR_CROSS
wxCURSOR_HAND
wxCURSOR_IBEAM
wxCURSOR_LEFT_BUTTON
wxCURSOR_MAGNIFIER
wxCURSOR_MIDDLE_BUTTON
wxCURSOR_NO_ENTRY
wxCURSOR_PAINT_BRUSH
wxCURSOR_PENCIL
wxCURSOR_POINT_LEFT
wxCURSOR_POINT_RIGHT
wxCURSOR_QUESTION_ARROW
wxCURSOR_RIGHT_BUTTON
wxCURSOR_SIZENESW
wxCURSOR_SIZENS
wxCURSOR_SIZENWSE
wxCURSOR_SIZEWE
wxCURSOR_SIZING
wxCURSOR_SPRAYCAN
wxCURSOR_WAIT
wxCURSOR_WATCH
wxCURSOR_BLANK
wxCURSOR_DEFAULT
wxCURSOR_COPY_ARROW
wxCURSOR_BASED_ARROW_DOWN
wxCURSOR_BASED_ARROW_UP
wxCURSOR_CROSS_REVERSE
wxCURSOR_DOUBLE_ARROW
wxNullCursor
wxSTANDARD_CURSOR
wxHOURGLASS_CURSOR
wxCROSS_CURSOR) ];
$EXPORT_TAGS{'dataview'} = [ qw(wxDV_SINGLE
wxDV_MULTIPLE
wxDV_NO_HEADER
wxDV_HORIZ_RULES
wxDV_VERT_RULES
wxDV_ROW_LINES
wxDVR_DEFAULT_ALIGNMENT
wxDATAVIEW_CELL_INERT
wxDATAVIEW_CELL_ACTIVATABLE
wxDATAVIEW_CELL_EDITABLE
wxDATAVIEW_CELL_SELECTED
wxDATAVIEW_CELL_PRELIT
wxDATAVIEW_CELL_INSENSITIVE
wxDATAVIEW_CELL_FOCUSED
wxDATAVIEW_COL_RESIZABLE
wxDATAVIEW_COL_SORTABLE
wxDATAVIEW_COL_REORDERABLE
wxDATAVIEW_COL_HIDDEN) ];
$EXPORT_TAGS{'datepicker'} = [ qw(wxDP_DEFAULT
wxDP_SPIN
wxDP_DROPDOWN
wxDP_SHOWCENTURY
wxDP_ALLOWNONE) ];
$EXPORT_TAGS{'dc'} = [ qw(wxAND
wxAND_INVERT
wxAND_REVERSE
wxBUFFER_VIRTUAL_AREA
wxBUFFER_CLIENT_AREA
wxBLIT_00220326
wxBLIT_007700E6
wxBLIT_00990066
wxBLIT_00AA0029
wxBLIT_00DD0228
wxBLIT_BLACKNESS
wxBLIT_DSTINVERT
wxBLIT_MERGEPAINT
wxBLIT_NOTSCRCOPY
wxBLIT_NOTSRCERASE
wxBLIT_SRCAND
wxBLIT_SRCCOPY
wxBLIT_SRCERASE
wxBLIT_SRCINVERT
wxBLIT_SRCPAINT
wxBLIT_WHITENESS
wxCLEAR
wxCOPY
wxEQUIV
wxFLOOD_SURFACE
wxFLOOD_BORDER
wxHORIZONTAL_HATCH
wxINVERT
wxMM_TWIPS
wxMM_POINTS
wxMM_METRIC
wxMM_LOMETRIC
wxMM_TEXT
wxNAND
wxNOR
wxNO_OP
wxODDEVEN_RULE
wxOR
wxOR_INVERT
wxOR_REVERSE
wxROP_BLACK
wxROP_COPYPEN
wxROP_MASKNOTPEN
wxROP_MASKPEN
wxROP_MASKPENNOT
wxROP_MERGENOTPEN
wxROP_MERGEPEN
wxROP_MERGEPENNOT
wxROP_NOP
wxROP_NOT
wxROP_NOTCOPYPEN
wxROP_NOTMASKPEN
wxROP_NOTMERGEPEN
wxROP_NOTXORPEN
wxROP_WHITE
wxROP_XORPEN
wxSET
wxSRC_INVERT
wxSOLID
wxTRANSPARENT
wxWINDING_RULE
wxXOR) ];
$EXPORT_TAGS{'dialog'} = [ qw(wxAPPLY
wxBOTH
wxCANCEL
wxCAPTION
wxCENTER
wxCENTRE
wxCLOSE
wxDEFAULT_DIALOG_STYLE
wxDIALOG_MODAL
wxDIALOG_EX_METAL
wxDIALOG_NO_PARENT
wxDIALOG_EX_CONTEXTHELP
wxFULLSCREEN_NOMENUBAR
wxFULLSCREEN_NOTOOLBAR
wxFULLSCREEN_NOSTATUSBAR
wxFULLSCREEN_NOBORDER
wxFULLSCREEN_NOCAPTION
wxFULLSCREEN_ALL
wxHELP
wxNO
wxNO_3D
wxNO_DEFAULT
wxOK
wxRESIZE_BORDER
wxSTAY_ON_TOP
wxSYSTEM_MENU
wxTHICK_FRAME
wxVERTICAL
wxYES
wxYES_NO
wxYES_DEFAULT) ];
$EXPORT_TAGS{'dirctrl'} = [ qw(wxDIRCTRL_DIR_ONLY
wxDIRCTRL_SELECT_FIRST
wxDIRCTRL_SHOW_FILTERS
wxDIRCTRL_3D_INTERNAL
wxDIRCTRL_EDIT_LABELS) ];
$EXPORT_TAGS{'dirdialog'} = [ qw(wxDD_NEW_DIR_BUTTON
wxDD_DEFAULT_STYLE
wxDD_CHANGE_DIR
wxDD_DIR_MUST_EXIST) ];
$EXPORT_TAGS{'dnd'} = [ qw(wxFormatInvalid
Both
wxDragError
wxDragNone
wxDragMove
wxDragCopy
wxDragLink
wxDragCancel
wxDrag_CopyOnly
wxDrag_AllowMove
wxDrag_DefaultMove
Get
Set
wxDF_INVALID
wxDF_TEXT
wxDF_UNICODETEXT
wxDF_BITMAP
wxDF_METAFILE
wxDF_FILENAME) ];
$EXPORT_TAGS{'docview'} = [ qw(wxDEFAULT_TEMPLATE_FLAGS
wxDEFAULT_DOCMAN_FLAGS
wxDOC_SDI
wxDOC_MDI
wxDOC_NEW
wxDOC_SILENT
wxTEMPLATE_VISIBLE
wxTEMPLATE_INVISIBLE
wxMAX_FILE_HISTORY) ];
$EXPORT_TAGS{'editablelistbox'} = [ qw(wxEL_ALLOW_NEW
wxEL_ALLOW_EDIT
wxEL_ALLOW_DELETE
wxEL_NO_REORDER
wxEL_DEFAULT_STYLE) ];
$EXPORT_TAGS{'execute'} = [ qw(wxEXEC_SYNC
wxEXEC_ASYNC
wxEXEC_NOHIDE
wxEXEC_NODISABLE
wxEXEC_BLOCK
wxEXEC_NOEVENTS
wxEXEC_MAKE_GROUP_LEADER) ];
$EXPORT_TAGS{'filectrl'} = [ qw(wxFC_OPEN
wxFC_SAVE
wxFC_MULTIPLE
wxFC_NOSHOWHIDDEN) ];
$EXPORT_TAGS{'filedialog'} = [ qw(wxCHANGE_DIR
wxFD_OPEN
wxFD_SAVE
wxFD_OVERWRITE_PROMPT
wxFD_FILE_MUST_EXIST
wxFD_MULTIPLE
wxFD_CHANGE_DIR
wxFD_DEFAULT_STYLE
wxFD_PREVIEW
wxHIDE_READONLY
wxMULTIPLE
wxOPEN
wxOVERWRITE_PROMPT
wxSAVE
wxFileSelectorDefaultWildcardStr) ];
$EXPORT_TAGS{'filesystem'} = [ qw(wxFS_READ
wxFS_SEEKABLE) ];
$EXPORT_TAGS{'findreplace'} = [ qw(wxFR_DOWN
wxFR_WHOLEWORD
wxFR_MATCHCASE
wxFR_REPLACEDIALOG
wxFR_NOUPDOWN
wxFR_NOMATCHCASE
wxFR_NOWHOLEWORD) ];
$EXPORT_TAGS{'font'} = [ qw(wxBOLD
wxDECORATIVE
wxDEFAULT
wxFONTFAMILY_DEFAULT
wxFONTFAMILY_DECORATIVE
wxFONTFAMILY_ROMAN
wxFONTFAMILY_SCRIPT
wxFONTFAMILY_SWISS
wxFONTFAMILY_MODERN
wxFONTFAMILY_TELETYPE
wxFONTFAMILY_MAX
wxFONTFAMILY_UNKNOWN
wxFONTSTYLE_NORMAL
wxFONTSTYLE_ITALIC
wxFONTSTYLE_SLANT
wxFONTSTYLE_MAX
wxFONTWEIGHT_NORMAL
wxFONTWEIGHT_LIGHT
wxFONTWEIGHT_BOLD
wxFONTWEIGHT_MAX
wxFONTFLAG_DEFAULT
wxFONTFLAG_ITALIC
wxFONTFLAG_SLANT
wxFONTFLAG_LIGHT
wxFONTFLAG_BOLD
wxFONTFLAG_ANTIALIASED
wxFONTFLAG_NOT_ANTIALIASED
wxFONTFLAG_UNDERLINED
wxFONTFLAG_STRIKETHROUGH
wxFONTFLAG_MASK
wxFONTENCODING_DEFAULT
wxFONTENCODING_SYSTEM
wxFONTENCODING_ISO8859_1
wxFONTENCODING_ISO8859_2
wxFONTENCODING_ISO8859_3
wxFONTENCODING_ISO8859_4
wxFONTENCODING_ISO8859_5
wxFONTENCODING_ISO8859_6
wxFONTENCODING_ISO8859_7
wxFONTENCODING_ISO8859_8
wxFONTENCODING_ISO8859_9
wxFONTENCODING_ISO8859_10
wxFONTENCODING_ISO8859_11
wxFONTENCODING_ISO8859_12
wxFONTENCODING_ISO8859_13
wxFONTENCODING_ISO8859_14
wxFONTENCODING_ISO8859_15
wxFONTENCODING_KOI8
wxFONTENCODING_ALTERNATIVE
wxFONTENCODING_BULGARIAN
wxFONTENCODING_CP437
wxFONTENCODING_CP850
wxFONTENCODING_CP852
wxFONTENCODING_CP855
wxFONTENCODING_CP866
wxFONTENCODING_CP874
wxFONTENCODING_CP1250
wxFONTENCODING_CP1251
wxFONTENCODING_CP1252
wxFONTENCODING_CP1253
wxFONTENCODING_CP1254
wxFONTENCODING_CP1255
wxFONTENCODING_CP1256
wxFONTENCODING_CP1257
wxFONTENCODING_UTF7
wxFONTENCODING_UTF8
wxFONTENCODING_UNICODE
wxFONTENCODING_BIG5
wxFONTENCODING_CP12_MAX
wxFONTENCODING_CP932
wxFONTENCODING_CP936
wxFONTENCODING_CP949
wxFONTENCODING_CP950
wxFONTENCODING_EUC_JP
wxFONTENCODING_GB2312
wxFONTENCODING_ISO2022_JP
wxFONTENCODING_ISO8859_MAX
wxFONTENCODING_KOI8_U
wxFONTENCODING_MACARABIC
wxFONTENCODING_MACARABICEXT
wxFONTENCODING_MACARMENIAN
wxFONTENCODING_MACBENGALI
wxFONTENCODING_MACBURMESE
wxFONTENCODING_MACCELTIC
wxFONTENCODING_MACCENTRALEUR
wxFONTENCODING_MACCHINESESIMP
wxFONTENCODING_MACCHINESETRAD
wxFONTENCODING_MACCROATIAN
wxFONTENCODING_MACCYRILLIC
wxFONTENCODING_MACDEVANAGARI
wxFONTENCODING_MACDINGBATS
wxFONTENCODING_MACETHIOPIC
wxFONTENCODING_MACGAELIC
wxFONTENCODING_MACGEORGIAN
wxFONTENCODING_MACGREEK
wxFONTENCODING_MACGUJARATI
wxFONTENCODING_MACGURMUKHI
wxFONTENCODING_MACHEBREW
wxFONTENCODING_MACICELANDIC
wxFONTENCODING_MACJAPANESE
wxFONTENCODING_MACKANNADA
wxFONTENCODING_MACKEYBOARD
wxFONTENCODING_MACKHMER
wxFONTENCODING_MACKOREAN
wxFONTENCODING_MACLAOTIAN
wxFONTENCODING_MACMALAJALAM
wxFONTENCODING_MACMAX
wxFONTENCODING_MACMIN
wxFONTENCODING_MACMONGOLIAN
wxFONTENCODING_MACORIYA
wxFONTENCODING_MACROMAN
wxFONTENCODING_MACROMANIAN
wxFONTENCODING_MACSINHALESE
wxFONTENCODING_MACSYMBOL
wxFONTENCODING_MACTAMIL
wxFONTENCODING_MACTELUGU
wxFONTENCODING_MACTHAI
wxFONTENCODING_MACTIBETAN
wxFONTENCODING_MACTURKISH
wxFONTENCODING_MACVIATNAMESE
wxFONTENCODING_MAX
wxFONTENCODING_SHIFT_JIS
wxFONTENCODING_UTF16
wxFONTENCODING_UTF16BE
wxFONTENCODING_UTF16LE
wxFONTENCODING_UTF32
wxFONTENCODING_UTF32BE
wxFONTENCODING_UTF32LE
wxITALIC
wxLIGHT
wxMODERN
wxNORMAL
wxROMAN
wxSCRIPT
wxSLANT
wxSWISS
wxTELETYPE
wxNullFont
wxNORMAL_FONT
wxSMALL_FONT
wxITALIC_FONT
wxSWISS_FONT) ];
$EXPORT_TAGS{'frame'} = [ qw(wxBOTH
wxCAPTION
wxCLOSE_BOX
wxDEFAULT_FRAME_STYLE
wxFRAME_FLOAT_ON_PARENT
wxFRAME_NO_WINDOW_MENU
wxFRAME_NO_TASKBAR
wxFRAME_TOOL_WINDOW
wxFRAME_EX_CONTEXTHELP
wxFRAME_EX_METAL
wxFRAME_SHAPED
wxFULLSCREEN_NOMENUBAR
wxFULLSCREEN_NOTOOLBAR
wxFULLSCREEN_NOSTATUSBAR
wxFULLSCREEN_NOBORDER
wxFULLSCREEN_NOCAPTION
wxFULLSCREEN_ALL
wxICONIZE
wxMAXIMIZE
wxMAXIMIZE_BOX
wxMINIMIZE
wxMINIMIZE_BOX
wxNO_BORDER
wxRESIZE_BORDER
wxSTAY_ON_TOP
wxSYSTEM_MENU
wxTHICK_FRAME
wxVERTICAL) ];
$EXPORT_TAGS{'gauge'} = [ qw(wxGA_HORIZONTAL
wxGA_VERTICAL
wxGA_PROGRESSBAR
wxGA_SMOOTH) ];
$EXPORT_TAGS{'grid'} = [ qw(wxALIGN_LEFT
wxALIGN_CENTRE
wxALIGN_CENTER
wxALIGN_RIGHT
wxALIGN_TOP
wxALIGN_BOTTOM
wxGRID_VALUE_STRING
wxGRID_VALUE_BOOL
wxGRID_VALUE_NUMBER
wxGRID_VALUE_FLOAT
wxGRID_VALUE_CHOICE
wxGRID_VALUE_TEXT
wxGRID_VALUE_LONG
wxGRIDTABLE_REQUEST_VIEW_GET_VALUES
wxGRIDTABLE_REQUEST_VIEW_SEND_VALUES
wxGRIDTABLE_NOTIFY_ROWS_INSERTED
wxGRIDTABLE_NOTIFY_ROWS_APPENDED
wxGRIDTABLE_NOTIFY_ROWS_DELETED
wxGRIDTABLE_NOTIFY_COLS_INSERTED
wxGRIDTABLE_NOTIFY_COLS_APPENDED
wxGRIDTABLE_NOTIFY_COLS_DELETED
wxGRID_AUTOSIZE
wxGRID_COLUMN
wxGRID_ROW
wxGRID_DRAW_ROWS_HEADER
wxGRID_DRAW_COLS_HEADER
wxGRID_DRAW_CELL_LINES
wxGRID_DRAW_BOX_RECT
wxGRID_DRAW_SELECTION
wxGRID_DRAW_DEFAULT
wxGridSelectCells
wxGridSelectRows
wxGridSelectColumns) ];
$EXPORT_TAGS{'html'} = [ qw(wxEVT_COMMAND_HTML_CELL_CLICKED
wxEVT_COMMAND_HTML_CELL_HOVER
wxEVT_COMMAND_HTML_LINK_CLICKED
wxHF_TOOLBAR
wxHF_FLATTOOLBAR
wxHF_FLAT_TOOLBAR
wxHF_CONTENTS
wxHF_INDEX
wxHF_SEARCH
wxHF_BOOKMARKS
wxHF_OPENFILES
wxHF_OPEN_FILES
wxHF_PRINT
wxHF_DEFAULTSTYLE
wxHF_MERGE_BOOKS
wxHF_ICONS_BOOK
wxHF_ICONS_BOOK_CHAPTER
wxHF_ICONS_FOLDER
wxHF_DEFAULT_STYLE
wxHF_DIALOG
wxHF_EMBEDDED
wxHF_FRAME
wxHF_MODAL
wxHW_NO_SELECTION
wxHW_SCROLLBAR_NEVER
wxHW_DEFAULT_STYLE
wxHW_SCROLLBAR_AUTO
wxHTML_ALIGN_LEFT
wxHTML_ALIGN_CENTER
wxHTML_ALIGN_RIGHT
wxHTML_ALIGN_BOTTOM
wxHTML_ALIGN_TOP
wxHTML_CLR_FOREGROUND
wxHTML_CLR_BACKGROUND
wxHTML_UNITS_PIXELS
wxHTML_UNITS_PERCENT
wxHTML_INDENT_LEFT
wxHTML_INDENT_RIGHT
wxHTML_INDENT_TOP
wxHTML_INDENT_BOTTOM
wxHTML_INDENT_HORIZONTAL
wxHTML_INDENT_VERTICAL
wxHTML_INDENT_ALL
wxHTML_COND_ISANCHOR
wxHTML_COND_ISIMAGEMAP
wxHTML_COND_USER
wxHTML_FIND_EXACT
wxHTML_FIND_NEAREST_BEFORE
wxHTML_FIND_NEAREST_AFTER
wxHTML_FONT_SIZE_1
wxHTML_FONT_SIZE_2
wxHTML_FONT_SIZE_3
wxHTML_FONT_SIZE_4
wxHTML_FONT_SIZE_5
wxHTML_FONT_SIZE_6
wxHTML_FONT_SIZE_7
wxHTML_ALIGN_JUSTIFY
wxHTML_BLOCK
wxHTML_BUFLEN
wxHTML_OPEN
wxHTML_PRINT_MAX_PAGES
wxHTML_REDIRECT
wxHTML_SCRIPT_NORMAL
wxHTML_SCRIPT_SUB
wxHTML_SCRIPT_SUP
wxHTML_SCROLL_STEP
wxHTML_SEL_CHANGING
wxHTML_SEL_IN
wxHTML_SEL_OUT
wxHTML_URL_IMAGE
wxHTML_URL_OTHER
wxHTML_URL_PAGE
wxPAGE_ODD
wxPAGE_EVEN
wxPAGE_ALL) ];
$EXPORT_TAGS{'htmllistbox'} = [ qw(wxHLB_DEFAULT_STYLE
wxHLB_MULTIPLE) ];
$EXPORT_TAGS{'hyperlink'} = [ qw(wxHL_CONTEXTMENU
wxHL_ALIGN_LEFT
wxHL_ALIGN_RIGHT
wxHL_ALIGN_CENTRE
wxHL_DEFAULT_STYLE) ];
$EXPORT_TAGS{'icon'} = [ qw(wxBITMAP_TYPE_BMP
wxBITMAP_TYPE_BMP_RESOURCE
wxBITMAP_TYPE_CUR
wxBITMAP_TYPE_CUR_RESOURCE
wxBITMAP_TYPE_ICO
wxBITMAP_TYPE_ICO_RESOURCE
wxBITMAP_TYPE_GIF
wxBITMAP_TYPE_XBM
wxBITMAP_TYPE_XPM
wxBITMAP_TYPE_JPEG
wxBITMAP_TYPE_PNG
wxBITMAP_TYPE_PNM
wxBITMAP_TYPE_PCX
wxBITMAP_TYPE_ANY
wxBITMAP_TYPE_TIF
wxBITMAP_TYPE_ANI
wxBITMAP_TYPE_GIF_RESOURCE
wxBITMAP_TYPE_ICON
wxBITMAP_TYPE_ICON_RESOURCE
wxBITMAP_TYPE_IFF
wxBITMAP_TYPE_INVALID
wxBITMAP_TYPE_JPEG_RESOURCE
wxBITMAP_TYPE_MACCURSOR
wxBITMAP_TYPE_MACCURSOR_RESOURCE
wxBITMAP_TYPE_PCX_RESOURCE
wxBITMAP_TYPE_PICT
wxBITMAP_TYPE_PICT_RESOURCE
wxBITMAP_TYPE_PNG_RESOURCE
wxBITMAP_TYPE_PNM_RESOURCE
wxBITMAP_TYPE_RESOURCE
wxBITMAP_TYPE_TGA
wxBITMAP_TYPE_TIF_RESOURCE
wxBITMAP_TYPE_XBM_DATA
wxBITMAP_TYPE_XPM_DATA
wxICON_EXCLAMATION
wxICON_HAND
wxICON_QUESTION
wxICON_INFORMATION
wxICON_WARNING
wxICON_ERROR
wxNullIcon) ];
$EXPORT_TAGS{'id'} = [ qw(wxID_ANY
wxID_OPEN
wxID_CLOSE
wxID_NEW
wxID_SAVE
wxID_SAVEAS
wxID_REVERT
wxID_EXIT
wxID_UNDO
wxID_REDO
wxID_PRINT
wxID_PRINT_SETUP
wxID_PREVIEW
wxID_ABOUT
wxID_HELP_CONTENTS
wxID_HELP_COMMANDS
wxID_HELP_PROCEDURES
wxID_HELP_CONTEXT
wxID_HELP_SEARCH
wxID_HELP_INDEX
wxID_PAGE_SETUP
wxID_HELP
wxID_HIGHEST
wxID_LOWEST
wxID_CUT
wxID_COPY
wxID_PASTE
wxID_CLEAR
wxID_FIND
wxID_DUPLICATE
wxID_SELECTALL
wxID_FILE1
wxID_FILE2
wxID_FILE3
wxID_FILE4
wxID_FILE5
wxID_FILE6
wxID_FILE7
wxID_FILE8
wxID_FILE9
wxID_OK
wxID_CANCEL
wxID_APPLY
wxID_YES
wxID_NO
wxID_STATIC
wxID_CONTEXT_HELP
wxID_YESTOALL
wxID_NOTOALL
wxID_ABORT
wxID_RETRY
wxID_IGNORE
wxID_ADD
wxID_BOLD
wxID_BACKWARD
wxID_DOWN
wxID_UP
wxID_FORWARD
wxID_HOME
wxID_INDENT
wxID_INDEX
wxID_ITALIC
wxID_JUSTIFY_CENTER
wxID_JUSTIFY_LEFT
wxID_JUSTIFY_FILL
wxID_JUSTIFY_RIGHT
wxID_PREFERENCES
wxID_PROPERTIES
wxID_REFRESH
wxID_REMOVE
wxID_REVERT_TO_SAVED
wxID_STOP
wxID_SYSTEM_MENU
wxID_UNDELETE
wxID_UNDERLINE
wxID_UNINDENT
wxID_ZOOM_100
wxID_ZOOM_FIT
wxID_ZOOM_IN
wxID_ZOOM_OUT
wxID_CLOSE_ALL
wxID_CLOSE_FRAME
wxID_DEFAULT
wxID_DELETE
wxID_EDIT
wxID_FILE
wxID_FILEDLGG
wxID_ICONIZE_FRAME
wxID_MAXIMIZE_FRAME
wxID_MORE
wxID_MOVE_FRAME
wxID_REPLACE
wxID_REPLACE_ALL
wxID_RESET
wxID_RESIZE_FRAME
wxID_RESTORE_FRAME
wxID_SETUP
wxID_VIEW_DETAILS
wxID_VIEW_LARGEICONS
wxID_VIEW_LIST
wxID_VIEW_SMALLICONS
wxID_VIEW_SORTDATE
wxID_VIEW_SORTNAME
wxID_VIEW_SORTSIZE
wxID_VIEW_SORTTYPE
wxID_SEPARATOR) ];
$EXPORT_TAGS{'image'} = [ qw(wxBITMAP_TYPE_BMP
wxBITMAP_TYPE_BMP_RESOURCE
wxBITMAP_TYPE_CUR
wxBITMAP_TYPE_CUR_RESOURCE
wxBITMAP_TYPE_ICO
wxBITMAP_TYPE_ICO_RESOURCE
wxBITMAP_TYPE_GIF
wxBITMAP_TYPE_XBM
wxBITMAP_TYPE_XPM
wxBITMAP_TYPE_JPEG
wxBITMAP_TYPE_PNG
wxBITMAP_TYPE_PNM
wxBITMAP_TYPE_PCX
wxBITMAP_TYPE_ANY
wxBITMAP_TYPE_TIF
wxBITMAP_TYPE_ANI
wxBITMAP_TYPE_GIF_RESOURCE
wxBITMAP_TYPE_ICON
wxBITMAP_TYPE_ICON_RESOURCE
wxBITMAP_TYPE_IFF
wxBITMAP_TYPE_INVALID
wxBITMAP_TYPE_JPEG_RESOURCE
wxBITMAP_TYPE_MACCURSOR
wxBITMAP_TYPE_MACCURSOR_RESOURCE
wxBITMAP_TYPE_PCX_RESOURCE
wxBITMAP_TYPE_PICT
wxBITMAP_TYPE_PICT_RESOURCE
wxBITMAP_TYPE_PNG_RESOURCE
wxBITMAP_TYPE_PNM_RESOURCE
wxBITMAP_TYPE_RESOURCE
wxBITMAP_TYPE_TGA
wxBITMAP_TYPE_TIF_RESOURCE
wxBITMAP_TYPE_XBM_DATA
wxBITMAP_TYPE_XPM_DATA
wxIMAGE_RESOLUTION_INCHES
wxIMAGE_RESOLUTION_CM
wxIMAGE_QUALITY_NORMAL
wxIMAGE_QUALITY_HIGH
wxIMAGE_OPTION_BMP_FORMAT
wxIMAGE_OPTION_CUR_HOTSPOT_X
wxIMAGE_OPTION_CUR_HOTSPOT_Y
wxIMAGE_OPTION_FILENAME
wxIMAGE_OPTION_QUALITY
wxIMAGE_OPTION_RESOLUTION
wxIMAGE_OPTION_RESOLUTIONX
wxIMAGE_OPTION_RESOLUTIONY
wxIMAGE_OPTION_RESOLUTIONUNIT
wxIMAGE_OPTION_BITSPERSAMPLE
wxIMAGE_OPTION_COMPRESSION
wxIMAGE_OPTION_IMAGEDESCRIPTOR
wxIMAGE_OPTION_PNG_BITDEPTH
wxIMAGE_OPTION_PNG_FORMAT
wxIMAGE_OPTION_SAMPLESPERPIXEL) ];
$EXPORT_TAGS{'imagelist'} = [ qw(wxIMAGELIST_DRAW_NORMAL
wxIMAGELIST_DRAW_TRANSPARENT
wxIMAGELIST_DRAW_SELECTED
wxIMAGELIST_DRAW_FOCUSED) ];
$EXPORT_TAGS{'ipc'} = [ qw(wxIPC_WAVE
wxIPC_FILENAME
wxIPC_ENHMETAFILE
wxIPC_LOCALE
wxIPC_UNICODETEXT
wxIPC_UTF8TEXT
wxIPC_PENDATA
wxIPC_METAFILE
wxIPC_DIB
wxIPC_OEMTEXT
wxIPC_UTF32TEXT
wxIPC_PALETTE
wxIPC_PRIVATE
wxIPC_TIFF
wxIPC_UTF16TEXT
wxIPC_BITMAP
wxIPC_TEXT
wxIPC_SYLK
wxIPC_INVALID
wxIPC_DIF
wxIPC_RIFF) ];
$EXPORT_TAGS{'joystick'} = [ qw(wxJOYSTICK1
wxJOYSTICK2
wxJOY_BUTTON1
wxJOY_BUTTON2
wxJOY_BUTTON3
wxJOY_BUTTON4
wxJOY_BUTTON_ANY) ];
$EXPORT_TAGS{'keycode'} = [ qw(WXK_NONE
WXK_CONTROL_A
WXK_CONTROL_B
WXK_CONTROL_C
WXK_CONTROL_D
WXK_CONTROL_E
WXK_CONTROL_F
WXK_CONTROL_G
WXK_CONTROL_H
WXK_CONTROL_I
WXK_CONTROL_J
WXK_CONTROL_K
WXK_CONTROL_L
WXK_CONTROL_M
WXK_CONTROL_N
WXK_CONTROL_O
WXK_CONTROL_P
WXK_CONTROL_Q
WXK_CONTROL_R
WXK_CONTROL_S
WXK_CONTROL_U
WXK_CONTROL_V
WXK_CONTROL_W
WXK_CONTROL_X
WXK_CONTROL_Y
WXK_CONTROL_Z
WXK_RAW_CONTROL
WXK_WINDOWS_LEFT
WXK_WINDOWS_RIGHT
WXK_WINDOWS_MENU
WXK_COMMAND
WXK_WINDOWS_LEFT
WXK_WINDOWS_RIGHT
WXK_WINDOWS_MENU
WXK_COMMAND
WXK_BACK
WXK_TAB
WXK_RETURN
WXK_ESCAPE
WXK_SPACE
WXK_DELETE
WXK_START
WXK_LBUTTON
WXK_RBUTTON
WXK_CANCEL
WXK_MBUTTON
WXK_CLEAR
WXK_SHIFT
WXK_ALT
WXK_CONTROL
WXK_MENU
WXK_PAUSE
WXK_CAPITAL
WXK_PRIOR
WXK_NEXT
WXK_END
WXK_HOME
WXK_LEFT
WXK_UP
WXK_RIGHT
WXK_DOWN
WXK_SELECT
WXK_PRINT
WXK_EXECUTE
WXK_SNAPSHOT
WXK_INSERT
WXK_HELP
WXK_NUMPAD0
WXK_NUMPAD1
WXK_NUMPAD2
WXK_NUMPAD3
WXK_NUMPAD4
WXK_NUMPAD5
WXK_NUMPAD6
WXK_NUMPAD7
WXK_NUMPAD8
WXK_NUMPAD9
WXK_MULTIPLY
WXK_ADD
WXK_SEPARATOR
WXK_SUBTRACT
WXK_DECIMAL
WXK_DIVIDE
WXK_F1
WXK_F2
WXK_F3
WXK_F4
WXK_F5
WXK_F6
WXK_F7
WXK_F8
WXK_F9
WXK_F10
WXK_F11
WXK_F12
WXK_F13
WXK_F14
WXK_F15
WXK_F16
WXK_F17
WXK_F18
WXK_F19
WXK_F20
WXK_F21
WXK_F22
WXK_F23
WXK_F24
WXK_NUMLOCK
WXK_SCROLL
WXK_NUMPAD_SPACE
WXK_NUMPAD_TAB
WXK_NUMPAD_ENTER
WXK_NUMPAD_F1
WXK_NUMPAD_F2
WXK_NUMPAD_F3
WXK_NUMPAD_F4
WXK_NUMPAD_HOME
WXK_NUMPAD_LEFT
WXK_NUMPAD_UP
WXK_NUMPAD_RIGHT
WXK_NUMPAD_DOWN
WXK_NUMPAD_PAGEUP
WXK_NUMPAD_PAGEDOWN
WXK_NUMPAD_END
WXK_NUMPAD_BEGIN
WXK_NUMPAD_INSERT
WXK_NUMPAD_DELETE
WXK_NUMPAD_EQUAL
WXK_NUMPAD_MULTIPLY
WXK_NUMPAD_ADD
WXK_NUMPAD_SEPARATOR
WXK_NUMPAD_SUBTRACT
WXK_NUMPAD_DECIMAL
WXK_NUMPAD_DIVIDE
WXK_SPECIAL1
WXK_SPECIAL2
WXK_SPECIAL3
WXK_SPECIAL4
WXK_SPECIAL5
WXK_SPECIAL6
WXK_SPECIAL7
WXK_SPECIAL8
WXK_SPECIAL9
WXK_SPECIAL10
WXK_SPECIAL11
WXK_SPECIAL12
WXK_SPECIAL13
WXK_SPECIAL14
WXK_SPECIAL15
WXK_SPECIAL16
WXK_SPECIAL17
WXK_SPECIAL18
WXK_SPECIAL19
WXK_SPECIAL20
WXK_PAGEUP
WXK_PAGEDOWN
WXK_PRIOR
WXK_NEXT
WXK_NUMPAD_PRIOR
WXK_NUMPAD_NEXT) ];
$EXPORT_TAGS{'layout'} = [ qw(wxADJUST_MINSIZE
wxAbove
wxAbsolute
wxAsIs
wxBottom
wxBelow
wxCentreX
wxCentreY
wxCenterX
wxCenterY
wxHeight
wxLEFT
wxLeft
wxLeftOf
wxPercentOf
wxPartRegion
wxRIGHT
wxRight
wxRightOf
wxSameAs
wxTOP
wxTop
wxUnconstrained
wxWidth) ];
$EXPORT_TAGS{'listbook'} = [ qw(wxLB_DEFAULT
wxLB_TOP
wxLB_BOTTOM
wxLB_LEFT
wxLB_RIGHT
wxLB_ALIGN_MASK) ];
$EXPORT_TAGS{'listbox'} = [ qw(wxLB_SINGLE
wxLB_MULTIPLE
wxLB_EXTENDED
wxLB_HSCROLL
wxLB_ALWAYS_SB
wxLB_NEEDED_SB
wxLB_OWNERDRAW
wxLB_SORT
wxLB_INT_HEIGHT) ];
$EXPORT_TAGS{'listctrl'} = [ qw(wxIMAGE_LIST_NORMAL
wxIMAGE_LIST_SMALL
wxIMAGE_LIST_STATE
wxLIST_AUTOSIZE
wxLIST_AUTOSIZE_USEHEADER
wxLIST_ALIGN_DEFAULT
wxLIST_ALIGN_LEFT
wxLIST_ALIGN_TOP
wxLIST_ALIGN_SNAP_TO_GRID
wxLIST_FIND_UP
wxLIST_FIND_DOWN
wxLIST_FIND_LEFT
wxLIST_FIND_RIGHT
wxLIST_FORMAT_LEFT
wxLIST_FORMAT_RIGHT
wxLIST_FORMAT_CENTRE
wxLIST_FORMAT_CENTER
wxLIST_HITTEST_ABOVE
wxLIST_HITTEST_BELOW
wxLIST_HITTEST_NOWHERE
wxLIST_HITTEST_ONITEMICON
wxLIST_HITTEST_ONITEMLABEL
wxLIST_HITTEST_ONITEMRIGHT
wxLIST_HITTEST_ONITEMSTATEICON
wxLIST_HITTEST_TOLEFT
wxLIST_HITTEST_TORIGHT
wxLIST_HITTEST_ONITEM
wxLIST_GETSUBITEMRECT_WHOLEITEM
wxLIST_MASK_STATE
wxLIST_MASK_TEXT
wxLIST_MASK_IMAGE
wxLIST_MASK_DATA
wxLIST_MASK_WIDTH
wxLIST_MASK_FORMAT
wxLIST_NEXT_ABOVE
wxLIST_NEXT_ALL
wxLIST_NEXT_BELOW
wxLIST_NEXT_LEFT
wxLIST_NEXT_RIGHT
wxLIST_RECT_BOUNDS
wxLIST_RECT_ICON
wxLIST_RECT_LABEL
wxLIST_STATE_DONTCARE
wxLIST_STATE_DROPHILITED
wxLIST_STATE_FOCUSED
wxLIST_STATE_SELECTED
wxLIST_STATE_CUT
wxLIST_SET_ITEM
wxLC_VRULES
wxLC_HRULES
wxLC_ICON
wxLC_SMALL_ICON
wxLC_LIST
wxLC_REPORT
wxLC_ALIGN_TOP
wxLC_ALIGN_LEFT
wxLC_AUTOARRANGE
wxLC_USER_TEXT
wxLC_EDIT_LABELS
wxLC_NO_HEADER
wxLC_NO_SORT_HEADER
wxLC_SINGLE_SEL
wxLC_SORT_ASCENDING
wxLC_SORT_DESCENDING
wxLC_VIRTUAL) ];
$EXPORT_TAGS{'locale'} = [ qw(wxLOCALE_LOAD_DEFAULT
wxLOCALE_CONV_ENCODING
wxLANGUAGE_DEFAULT
wxLANGUAGE_UNKNOWN
wxLANGUAGE_ABKHAZIAN
wxLANGUAGE_AFAR
wxLANGUAGE_AFRIKAANS
wxLANGUAGE_ALBANIAN
wxLANGUAGE_AMHARIC
wxLANGUAGE_ARABIC
wxLANGUAGE_ARABIC_ALGERIA
wxLANGUAGE_ARABIC_BAHRAIN
wxLANGUAGE_ARABIC_EGYPT
wxLANGUAGE_ARABIC_IRAQ
wxLANGUAGE_ARABIC_JORDAN
wxLANGUAGE_ARABIC_KUWAIT
wxLANGUAGE_ARABIC_LEBANON
wxLANGUAGE_ARABIC_LIBYA
wxLANGUAGE_ARABIC_MOROCCO
wxLANGUAGE_ARABIC_OMAN
wxLANGUAGE_ARABIC_QATAR
wxLANGUAGE_ARABIC_SAUDI_ARABIA
wxLANGUAGE_ARABIC_SUDAN
wxLANGUAGE_ARABIC_SYRIA
wxLANGUAGE_ARABIC_TUNISIA
wxLANGUAGE_ARABIC_UAE
wxLANGUAGE_ARABIC_YEMEN
wxLANGUAGE_ARMENIAN
wxLANGUAGE_ASSAMESE
wxLANGUAGE_AYMARA
wxLANGUAGE_AZERI
wxLANGUAGE_AZERI_CYRILLIC
wxLANGUAGE_AZERI_LATIN
wxLANGUAGE_BASHKIR
wxLANGUAGE_BASQUE
wxLANGUAGE_BELARUSIAN
wxLANGUAGE_BENGALI
wxLANGUAGE_BHUTANI
wxLANGUAGE_BIHARI
wxLANGUAGE_BISLAMA
wxLANGUAGE_BRETON
wxLANGUAGE_BULGARIAN
wxLANGUAGE_BURMESE
wxLANGUAGE_CAMBODIAN
wxLANGUAGE_CATALAN
wxLANGUAGE_CHINESE
wxLANGUAGE_CHINESE_SIMPLIFIED
wxLANGUAGE_CHINESE_TRADITIONAL
wxLANGUAGE_CHINESE_HONGKONG
wxLANGUAGE_CHINESE_MACAU
wxLANGUAGE_CHINESE_SINGAPORE
wxLANGUAGE_CHINESE_TAIWAN
wxLANGUAGE_CORSICAN
wxLANGUAGE_CROATIAN
wxLANGUAGE_CZECH
wxLANGUAGE_DANISH
wxLANGUAGE_DUTCH
wxLANGUAGE_DUTCH_BELGIAN
wxLANGUAGE_ENGLISH
wxLANGUAGE_ENGLISH_UK
wxLANGUAGE_ENGLISH_US
wxLANGUAGE_ENGLISH_AUSTRALIA
wxLANGUAGE_ENGLISH_BELIZE
wxLANGUAGE_ENGLISH_BOTSWANA
wxLANGUAGE_ENGLISH_CANADA
wxLANGUAGE_ENGLISH_CARIBBEAN
wxLANGUAGE_ENGLISH_DENMARK
wxLANGUAGE_ENGLISH_EIRE
wxLANGUAGE_ENGLISH_JAMAICA
wxLANGUAGE_ENGLISH_NEW_ZEALAND
wxLANGUAGE_ENGLISH_PHILIPPINES
wxLANGUAGE_ENGLISH_SOUTH_AFRICA
wxLANGUAGE_ENGLISH_TRINIDAD
wxLANGUAGE_ENGLISH_ZIMBABWE
wxLANGUAGE_ESPERANTO
wxLANGUAGE_ESTONIAN
wxLANGUAGE_FAEROESE
wxLANGUAGE_FARSI
wxLANGUAGE_FIJI
wxLANGUAGE_FINNISH
wxLANGUAGE_FRENCH
wxLANGUAGE_FRENCH_BELGIAN
wxLANGUAGE_FRENCH_CANADIAN
wxLANGUAGE_FRENCH_LUXEMBOURG
wxLANGUAGE_FRENCH_MONACO
wxLANGUAGE_FRENCH_SWISS
wxLANGUAGE_FRISIAN
wxLANGUAGE_GALICIAN
wxLANGUAGE_GEORGIAN
wxLANGUAGE_GERMAN
wxLANGUAGE_GERMAN_AUSTRIAN
wxLANGUAGE_GERMAN_BELGIUM
wxLANGUAGE_GERMAN_LIECHTENSTEIN
wxLANGUAGE_GERMAN_LUXEMBOURG
wxLANGUAGE_GERMAN_SWISS
wxLANGUAGE_GREEK
wxLANGUAGE_GREENLANDIC
wxLANGUAGE_GUARANI
wxLANGUAGE_GUJARATI
wxLANGUAGE_HAUSA
wxLANGUAGE_HEBREW
wxLANGUAGE_HINDI
wxLANGUAGE_HUNGARIAN
wxLANGUAGE_ICELANDIC
wxLANGUAGE_INDONESIAN
wxLANGUAGE_INTERLINGUA
wxLANGUAGE_INTERLINGUE
wxLANGUAGE_INUKTITUT
wxLANGUAGE_INUPIAK
wxLANGUAGE_IRISH
wxLANGUAGE_ITALIAN
wxLANGUAGE_ITALIAN_SWISS
wxLANGUAGE_JAPANESE
wxLANGUAGE_JAVANESE
wxLANGUAGE_KANNADA
wxLANGUAGE_KASHMIRI
wxLANGUAGE_KASHMIRI_INDIA
wxLANGUAGE_KAZAKH
wxLANGUAGE_KERNEWEK
wxLANGUAGE_KINYARWANDA
wxLANGUAGE_KIRGHIZ
wxLANGUAGE_KIRUNDI
wxLANGUAGE_KONKANI
wxLANGUAGE_KOREAN
wxLANGUAGE_KURDISH
wxLANGUAGE_LAOTHIAN
wxLANGUAGE_LATIN
wxLANGUAGE_LATVIAN
wxLANGUAGE_LINGALA
wxLANGUAGE_LITHUANIAN
wxLANGUAGE_MACEDONIAN
wxLANGUAGE_MALAGASY
wxLANGUAGE_MALAY
wxLANGUAGE_MALAYALAM
wxLANGUAGE_MALAY_BRUNEI_DARUSSALAM
wxLANGUAGE_MALAY_MALAYSIA
wxLANGUAGE_MALTESE
wxLANGUAGE_MANIPURI
wxLANGUAGE_MAORI
wxLANGUAGE_MARATHI
wxLANGUAGE_MOLDAVIAN
wxLANGUAGE_MONGOLIAN
wxLANGUAGE_NAURU
wxLANGUAGE_NEPALI
wxLANGUAGE_NEPALI_INDIA
wxLANGUAGE_NORWEGIAN_BOKMAL
wxLANGUAGE_NORWEGIAN_NYNORSK
wxLANGUAGE_OCCITAN
wxLANGUAGE_ORIYA
wxLANGUAGE_OROMO
wxLANGUAGE_PASHTO
wxLANGUAGE_POLISH
wxLANGUAGE_PORTUGUESE
wxLANGUAGE_PORTUGUESE_BRAZILIAN
wxLANGUAGE_PUNJABI
wxLANGUAGE_QUECHUA
wxLANGUAGE_RHAETO_ROMANCE
wxLANGUAGE_ROMANIAN
wxLANGUAGE_RUSSIAN
wxLANGUAGE_RUSSIAN_UKRAINE
wxLANGUAGE_SAMI
wxLANGUAGE_SAMOAN
wxLANGUAGE_SANGHO
wxLANGUAGE_SANSKRIT
wxLANGUAGE_SCOTS_GAELIC
wxLANGUAGE_SERBIAN
wxLANGUAGE_SERBIAN_CYRILLIC
wxLANGUAGE_SERBIAN_LATIN
wxLANGUAGE_SERBO_CROATIAN
wxLANGUAGE_SESOTHO
wxLANGUAGE_SETSWANA
wxLANGUAGE_SHONA
wxLANGUAGE_SINDHI
wxLANGUAGE_SINHALESE
wxLANGUAGE_SISWATI
wxLANGUAGE_SLOVAK
wxLANGUAGE_SLOVENIAN
wxLANGUAGE_SOMALI
wxLANGUAGE_SPANISH
wxLANGUAGE_SPANISH_ARGENTINA
wxLANGUAGE_SPANISH_BOLIVIA
wxLANGUAGE_SPANISH_CHILE
wxLANGUAGE_SPANISH_COLOMBIA
wxLANGUAGE_SPANISH_COSTA_RICA
wxLANGUAGE_SPANISH_DOMINICAN_REPUBLIC
wxLANGUAGE_SPANISH_ECUADOR
wxLANGUAGE_SPANISH_EL_SALVADOR
wxLANGUAGE_SPANISH_GUATEMALA
wxLANGUAGE_SPANISH_HONDURAS
wxLANGUAGE_SPANISH_MEXICAN
wxLANGUAGE_SPANISH_MODERN
wxLANGUAGE_SPANISH_NICARAGUA
wxLANGUAGE_SPANISH_PANAMA
wxLANGUAGE_SPANISH_PARAGUAY
wxLANGUAGE_SPANISH_PERU
wxLANGUAGE_SPANISH_PUERTO_RICO
wxLANGUAGE_SPANISH_URUGUAY
wxLANGUAGE_SPANISH_US
wxLANGUAGE_SPANISH_VENEZUELA
wxLANGUAGE_SUNDANESE
wxLANGUAGE_SWAHILI
wxLANGUAGE_SWEDISH
wxLANGUAGE_SWEDISH_FINLAND
wxLANGUAGE_TAGALOG
wxLANGUAGE_TAJIK
wxLANGUAGE_TAMIL
wxLANGUAGE_TATAR
wxLANGUAGE_TELUGU
wxLANGUAGE_THAI
wxLANGUAGE_TIBETAN
wxLANGUAGE_TIGRINYA
wxLANGUAGE_TONGA
wxLANGUAGE_TSONGA
wxLANGUAGE_TURKISH
wxLANGUAGE_TURKMEN
wxLANGUAGE_TWI
wxLANGUAGE_UIGHUR
wxLANGUAGE_UKRAINIAN
wxLANGUAGE_URDU
wxLANGUAGE_URDU_INDIA
wxLANGUAGE_URDU_PAKISTAN
wxLANGUAGE_UZBEK
wxLANGUAGE_UZBEK_CYRILLIC
wxLANGUAGE_UZBEK_LATIN
wxLANGUAGE_VALENCIAN
wxLANGUAGE_VIETNAMESE
wxLANGUAGE_VOLAPUK
wxLANGUAGE_WELSH
wxLANGUAGE_WOLOF
wxLANGUAGE_XHOSA
wxLANGUAGE_YIDDISH
wxLANGUAGE_YORUBA
wxLANGUAGE_ZHUANG
wxLANGUAGE_ZULU
wxLANGUAGE_USER_DEFINED) ];
$EXPORT_TAGS{'media'} = [ qw(wxMEDIABACKEND_DIRECTSHOW
wxMEDIABACKEND_QUICKTIME
wxMEDIABACKEND_MCI
wxMEDIABACKEND_GSTREAMER
wxMEDIABACKEND_REALPLAYER
wxMEDIABACKEND_WMP10
wxEVT_MEDIA_FINISHED
wxEVT_MEDIA_STOP
wxEVT_MEDIA_LOADED
wxEVT_MEDIA_STATECHANGED
wxEVT_MEDIA_PLAY
wxEVT_MEDIA_PAUSE
wxMEDIASTATE_STOPPED
wxMEDIASTATE_PAUSED
wxMEDIASTATE_PLAYING
wxMEDIACTRLPLAYERCONTROLS_NONE
wxMEDIACTRLPLAYERCONTROLS_STEP
wxMEDIACTRLPLAYERCONTROLS_VOLUME
wxMEDIACTRLPLAYERCONTROLS_DEFAULT) ];
$EXPORT_TAGS{'menu'} = [ qw(wxITEM_SEPARATOR
wxITEM_NORMAL
wxITEM_CHECK
wxITEM_RADIO
wxMENU_TEAROFF
wxMB_DOCKABLE) ];
$EXPORT_TAGS{'miniframe'} = [ qw(wxTINY_CAPTION_HORIZ
wxTINY_CAPTION_VERT) ];
$EXPORT_TAGS{'misc'} = [ qw(wxDefaultValidator
wxDefaultPosition
wxDefaultSize) ];
$EXPORT_TAGS{'notebook'} = [ qw(wxNB_FIXEDWIDTH
wxNB_LEFT
wxNB_RIGHT
wxNB_BOTTOM
wxNB_TOP
wxNB_MULTILINE
wxNB_HITTEST_NOWHERE
wxNB_HITTEST_ONICON
wxNB_HITTEST_ONLABEL
wxNB_HITTEST_ONITEM
wxNB_HITTEST_ONPAGE
wxNB_DEFAULT
wxNB_FLAT
wxNB_NOPAGETHEME) ];
$EXPORT_TAGS{'ownerdrawncombobox'} = [ qw(wxODCB_DCLICK_CYCLES
wxODCB_STD_CONTROL_PAINT
wxODCB_PAINTING_CONTROL
wxODCB_PAINTING_SELECTED) ];
$EXPORT_TAGS{'palette'} = [ qw(wxNullPalette) ];
$EXPORT_TAGS{'panel'} = [ qw(wxTAB_TRAVERSAL) ];
$EXPORT_TAGS{'pen'} = [ qw(wxBDIAGONAL_HATCH
wxCAP_ROUND
wxCAP_PROJECTING
wxCAP_BUTT
wxCROSSDIAG_HATCH
wxCROSS_HATCH
wxDOT
wxDOT_DASH
wxFDIAGONAL_HATCH
wxJOIN_BEVEL
wxJOIN_ROUND
wxJOIN_MITER
wxLONG_DASH
wxPENSTYLE_BDIAGONAL_HATCH
wxPENSTYLE_CROSSDIAG_HATCH
wxPENSTYLE_CROSS_HATCH
wxPENSTYLE_DOT
wxPENSTYLE_DOT_DASH
wxPENSTYLE_FDIAGONAL_HATCH
wxPENSTYLE_FIRST_HATCH
wxPENSTYLE_HORIZONTAL_HATCH
wxPENSTYLE_INVALID
wxPENSTYLE_LAST_HATCH
wxPENSTYLE_LONG_DASH
wxPENSTYLE_SHORT_DASH
wxPENSTYLE_SOLID
wxPENSTYLE_STIPPLE
wxPENSTYLE_STIPPLE_MASK
wxPENSTYLE_STIPPLE_MASK_OPAQUE
wxPENSTYLE_TRANSPARENT
wxPENSTYLE_USER_DASH
wxPENSTYLE_VERTICAL_HATCH
wxSHORT_DASH
wxSTIPPLE
wxSTIPPLE_MASK_OPAQUE
wxSOLID
wxTRANSPARENT
wxUSER_DASH
wxVERTICAL_HATCH
wxNullPen
wxRED_PEN
wxGREEN_PEN
wxCYAN_PEN
wxBLACK_PEN
wxWHITE_PEN
wxTRANSPARENT_PEN
wxBLACK_DASHED_PEN
wxGREY_PEN
wxMEDIUM_GREY_PEN
wxLIGHT_GREY_PEN) ];
$EXPORT_TAGS{'power'} = [ qw(wxBATTERY_NORMAL_STATE
wxBATTERY_LOW_STATE
wxBATTERY_CRITICAL_STATE
wxBATTERY_SHUTDOWN_STATE
wxBATTERY_UNKNOWN_STATE
wxPOWER_SOCKET
wxPOWER_BATTERY
wxPOWER_UNKNOWN) ];
$EXPORT_TAGS{'print'} = [ qw(wxThePrintPaperDatabase
wxDUPLEX_SIMPLEX
wxDUPLEX_HORIZONTAL
wxDUPLEX_VERTICAL
wxLANDSCAPE
wxPAPER_NONE
wxPAPER_LETTER
wxPAPER_LEGAL
wxPAPER_A4
wxPAPER_CSHEET
wxPAPER_DSHEET
wxPAPER_ESHEET
wxPAPER_LETTERSMALL
wxPAPER_TABLOID
wxPAPER_LEDGER
wxPAPER_STATEMENT
wxPAPER_EXECUTIVE
wxPAPER_A3
wxPAPER_A4SMALL
wxPAPER_A5
wxPAPER_B4
wxPAPER_B5
wxPAPER_FOLIO
wxPAPER_QUARTO
wxPAPER_10X14
wxPAPER_11X17
wxPAPER_NOTE
wxPAPER_ENV_9
wxPAPER_ENV_10
wxPAPER_ENV_11
wxPAPER_ENV_12
wxPAPER_ENV_14
wxPAPER_ENV_DL
wxPAPER_ENV_C5
wxPAPER_ENV_C3
wxPAPER_ENV_C4
wxPAPER_ENV_C6
wxPAPER_ENV_C65
wxPAPER_ENV_B4
wxPAPER_ENV_B5
wxPAPER_ENV_B6
wxPAPER_ENV_ITALY
wxPAPER_ENV_MONARCH
wxPAPER_ENV_PERSONAL
wxPAPER_FANFOLD_US
wxPAPER_FANFOLD_STD_GERMAN
wxPAPER_FANFOLD_LGL_GERMAN
wxPAPER_ISO_B4
wxPAPER_JAPANESE_POSTCARD
wxPAPER_9X11
wxPAPER_10X11
wxPAPER_15X11
wxPAPER_ENV_INVITE
wxPAPER_LETTER_EXTRA
wxPAPER_LEGAL_EXTRA
wxPAPER_TABLOID_EXTRA
wxPAPER_A4_EXTRA
wxPAPER_LETTER_TRANSVERSE
wxPAPER_A4_TRANSVERSE
wxPAPER_LETTER_EXTRA_TRANSVERSE
wxPAPER_A_PLUS
wxPAPER_B_PLUS
wxPAPER_LETTER_PLUS
wxPAPER_A4_PLUS
wxPAPER_A5_TRANSVERSE
wxPAPER_B5_TRANSVERSE
wxPAPER_A3_EXTRA
wxPAPER_A5_EXTRA
wxPAPER_B5_EXTRA
wxPAPER_A2
wxPAPER_A3_TRANSVERSE
wxPAPER_A3_EXTRA_TRANSVERSE
wxPAPER_12X11
wxPAPER_A3_ROTATED
wxPAPER_A4_ROTATED
wxPAPER_A5_ROTATED
wxPAPER_A6
wxPAPER_A6_ROTATED
wxPAPER_B4_JIS_ROTATED
wxPAPER_B5_JIS_ROTATED
wxPAPER_B6_JIS
wxPAPER_B6_JIS_ROTATED
wxPAPER_DBL_JAPANESE_POSTCARD
wxPAPER_DBL_JAPANESE_POSTCARD_ROTATED
wxPAPER_JAPANESE_POSTCARD_ROTATED
wxPAPER_JENV_CHOU3
wxPAPER_JENV_CHOU3_ROTATED
wxPAPER_JENV_CHOU4
wxPAPER_JENV_CHOU4_ROTATED
wxPAPER_JENV_KAKU2
wxPAPER_JENV_KAKU2_ROTATED
wxPAPER_JENV_KAKU3
wxPAPER_JENV_KAKU3_ROTATED
wxPAPER_JENV_YOU4
wxPAPER_JENV_YOU4_ROTATED
wxPAPER_LETTER_ROTATED
wxPAPER_P16K
wxPAPER_P16K_ROTATED
wxPAPER_P32K
wxPAPER_P32KBIG
wxPAPER_P32KBIG_ROTATED
wxPAPER_P32K_ROTATED
wxPAPER_PENV_1
wxPAPER_PENV_10
wxPAPER_PENV_10_ROTATED
wxPAPER_PENV_1_ROTATED
wxPAPER_PENV_2
wxPAPER_PENV_2_ROTATED
wxPAPER_PENV_3
wxPAPER_PENV_3_ROTATED
wxPAPER_PENV_4
wxPAPER_PENV_4_ROTATED
wxPAPER_PENV_5
wxPAPER_PENV_5_ROTATED
wxPAPER_PENV_6
wxPAPER_PENV_6_ROTATED
wxPAPER_PENV_7
wxPAPER_PENV_7_ROTATED
wxPAPER_PENV_8
wxPAPER_PENV_8_ROTATED
wxPAPER_PENV_9
wxPAPER_PENV_9_ROTATED
wxPORTRAIT
wxPREVIEW_PRINT
wxPREVIEW_NEXT
wxPREVIEW_PREVIOUS
wxPREVIEW_ZOOM
wxPREVIEW_DEFAULT
wxPRINT_QUALITY_HIGH
wxPRINT_QUALITY_MEDIUM
wxPRINT_QUALITY_LOW
wxPRINT_QUALITY_DRAFT
wxPRINT_MODE_FILE
wxPRINT_MODE_NONE
wxPRINT_MODE_PREVIEW
wxPRINT_MODE_PRINTER
wxPRINT_MODE_STREAM
wxPRINTER_NO_ERROR
wxPRINTER_CANCELLED
wxPRINTER_ERROR
wxPRINTBIN_DEFAULT
wxPRINTBIN_ONLYONE
wxPRINTBIN_LOWER
wxPRINTBIN_MIDDLE
wxPRINTBIN_MANUAL
wxPRINTBIN_ENVELOPE
wxPRINTBIN_ENVMANUAL
wxPRINTBIN_AUTO
wxPRINTBIN_TRACTOR
wxPRINTBIN_SMALLFMT
wxPRINTBIN_LARGEFMT
wxPRINTBIN_LARGECAPACITY
wxPRINTBIN_CASSETTE
wxPRINTBIN_FORMSOURCE
wxPRINTBIN_USER) ];
$EXPORT_TAGS{'process'} = [ qw(wxKILL_OK
wxKILL_BAD_SIGNAL
wxKILL_ACCESS_DENIED
wxKILL_NO_PROCESS
wxKILL_ERROR
wxKILL_NOCHILDREN
wxKILL_CHILDREN
wxSIGNONE
wxSIGHUP
wxSIGINT
wxSIGQUIT
wxSIGILL
wxSIGTRAP
wxSIGABRT
wxSIGEMT
wxSIGFPE
wxSIGKILL
wxSIGBUS
wxSIGSEGV
wxSIGSYS
wxSIGPIPE
wxSIGALRM
wxSIGTERM) ];
$EXPORT_TAGS{'progressdialog'} = [ qw(wxPD_APP_MODAL
wxPD_AUTO_HIDE
wxPD_CAN_ABORT
wxPD_ELAPSED_TIME
wxPD_ESTIMATED_TIME
wxPD_REMAINING_TIME
wxPD_SMOOTH
wxPD_CAN_SKIP) ];
$EXPORT_TAGS{'propertysheet'} = [ qw(wxPROPSHEET_DEFAULT
wxPROPSHEET_NOTEBOOK
wxPROPSHEET_TOOLBOOK
wxPROPSHEET_CHOICEBOOK
wxPROPSHEET_LISTBOOK
wxPROPSHEET_BUTTONTOOLBOOK
wxPROPSHEET_TREEBOOK
wxPROPSHEET_SHRINKTOFIT) ];
$EXPORT_TAGS{'propgrid'} = [ qw(wxPG_ATTR_AUTOCOMPLETE
wxPG_BOOL_USE_CHECKBOX
wxPG_BOOL_USE_DOUBLE_CLICK_CYCLING
wxPG_FLOAT_PRECISION
wxPG_STRING_PASSWORD
wxPG_UINT_BASE
wxPG_UINT_PREFIX
wxPG_FILE_WILDCARD
wxPG_FILE_SHOW_FULL_PATH
wxPG_FILE_SHOW_RELATIVE_PATH
wxPG_FILE_INITIAL_PATH
wxPG_FILE_DIALOG_TITLE
wxPG_DIR_DIALOG_MESSAGE
wxPG_ARRAY_DELIMITER
wxPG_DATE_FORMAT
wxPG_DATE_PICKER_STYLE
wxPG_ATTR_SPINCTRL_STEP
wxPG_ATTR_SPINCTRL_WRAP
wxPG_ATTR_MULTICHOICE_USERSTRINGMODE
wxPG_COLOUR_ALLOW_CUSTOM
wxPG_COLOUR_HAS_ALPHA
wxPG_ITERATE_PROPERTIES
wxPG_ITERATE_HIDDEN
wxPG_ITERATE_FIXED_CHILDREN
wxPG_ITERATE_CATEGORIES
wxPG_ITERATE_ALL_PARENTS
wxPG_ITERATE_ALL_PARENTS_RECURSIVELY
wxPG_ITERATOR_FLAGS_ALL
wxPG_ITERATOR_MASK_OP_ITEM
wxPG_ITERATOR_MASK_OP_PARENT
wxPG_ITERATE_VISIBLE
wxPG_ITERATE_ALL
wxPG_ITERATE_NORMAL
wxPG_ITERATE_DEFAULT
wxPG_PROP_MODIFIED
wxPG_PROP_DISABLED
wxPG_PROP_HIDDEN
wxPG_PROP_CUSTOMIMAGE
wxPG_PROP_NOEDITOR
wxPG_PROP_COLLAPSED
wxPG_PROP_INVALID_VALUE
wxPG_PROP_WAS_MODIFIED
wxPG_PROP_AGGREGATE
wxPG_PROP_CHILDREN_ARE_COPIES
wxPG_PROP_PROPERTY
wxPG_PROP_CATEGORY
wxPG_PROP_MISC_PARENT
wxPG_PROP_READONLY
wxPG_PROP_COMPOSED_VALUE
wxPG_PROP_USES_COMMON_VALUE
wxPG_PROP_AUTO_UNSPECIFIED
wxPG_PROP_CLASS_SPECIFIC_1
wxPG_PROP_CLASS_SPECIFIC_2
wxPG_PROP_BEING_DELETED
wxPG_PROP_MAX
wxPG_PROP_PARENTAL_FLAGS
wxPG_AUTO_SORT
wxPG_HIDE_CATEGORIES
wxPG_ALPHABETIC_MODE
wxPG_BOLD_MODIFIED
wxPG_SPLITTER_AUTO_CENTER
wxPG_TOOLTIPS
wxPG_HIDE_MARGIN
wxPG_STATIC_SPLITTER
wxPG_STATIC_LAYOUT
wxPG_LIMITED_EDITING
wxPG_TOOLBAR
wxPG_DESCRIPTION
wxPG_NO_INTERNAL_BORDER
wxPG_EX_INIT_NOCAT
wxPG_EX_NO_FLAT_TOOLBAR
wxPG_EX_MODE_BUTTONS
wxPG_EX_HELP_AS_TOOLTIPS
wxPG_EX_NATIVE_DOUBLE_BUFFERING
wxPG_EX_AUTO_UNSPECIFIED_VALUES
wxPG_EX_WRITEONLY_BUILTIN_ATTRIBUTES
wxPG_EX_HIDE_PAGE_BUTTONS
wxPG_EX_MULTIPLE_SELECTION
wxPG_EX_ENABLE_TLP_TRACKING
wxPG_EX_NO_TOOLBAR_DIVIDER
wxPG_EX_TOOLBAR_SEPARATOR
wxPG_DEFAULT_STYLE
wxPGMAN_DEFAULT_STYLE
wxPG_VFB_STAY_IN_PROPERTY
wxPG_VFB_BEEP
wxPG_VFB_MARK_CELL
wxPG_VFB_SHOW_MESSAGE
wxPG_VFB_SHOW_MESSAGEBOX
wxPG_VFB_SHOW_MESSAGE_ON_STATUSBAR
wxPG_VFB_DEFAULT
wxPG_ACTION_INVALID
wxPG_ACTION_NEXT_PROPERTY
wxPG_ACTION_PREV_PROPERTY
wxPG_ACTION_EXPAND_PROPERTY
wxPG_ACTION_COLLAPSE_PROPERTY
wxPG_ACTION_CANCEL_EDIT
wxPG_ACTION_EDIT
wxPG_ACTION_PRESS_BUTTON
wxPG_ACTION_MAX
wxPGState_SelectionState
wxPGState_ExpandedState
wxPGState_ScrollPosState
wxPGState_PageState
wxPGState_SplitterPosState
wxPGState_DescBoxState
wxPGState_AllStates
wxPGRender_ChoicePopup
wxPGRender_Control
wxPGRender_Disabled
wxPGRender_DontUseCellFgCol
wxPGRender_DontUseCellBgCol
wxPGRender_DontUseCellColours
wxPG_PROPERTY_VALIDATION_ERROR_MESSAGE
wxPG_PROPERTY_VALIDATION_SATURATE
wxPG_PROPERTY_VALIDATION_WRAP
wxPG_INVALID_VALUE
wxPG_KEEP_STRUCTURE
wxPG_RECURSE
wxPG_INC_ATTRIBUTES
wxPG_RECURSE_STARTS
wxPG_FORCE
wxPG_SORT_TOP_LEVEL_ONLY
wxPG_DONT_RECURSE
wxPG_FULL_VALUE
wxPG_REPORT_ERROR
wxPG_PROPERTY_SPECIFIC
wxPG_EDITABLE_VALUE
wxPG_COMPOSITE_FRAGMENT
wxPG_UNEDITABLE_COMPOSITE_FRAGMENT
wxPG_VALUE_IS_CURRENT
wxPG_PROGRAMMATIC_VALUE
wxPG_SETVAL_REFRESH_EDITOR
wxPG_SETVAL_AGGREGATED
wxPG_SETVAL_FROM_PARENT
wxPG_SETVAL_BY_USER
wxPG_BASE_OCT
wxPG_BASE_DEC
wxPG_BASE_HEX
wxPG_BASE_HEXL
wxPG_PREFIX_NONE
wxPG_PREFIX_0x
wxPG_PREFIX_DOLLAR_SIGN) ];
$EXPORT_TAGS{'radiobox'} = [ qw(wxRA_SPECIFY_ROWS
wxRA_SPECIFY_COLS
wxRA_HORIZONTAL
wxRA_LEFTTORIGHT
wxRA_TOPTOBOTTOM
wxRA_USE_CHECKBOX
wxRA_VERTICAL) ];
$EXPORT_TAGS{'radiobutton'} = [ qw(wxRB_GROUP
wxRB_SINGLE
wxRB_USE_CHECKBOX) ];
$EXPORT_TAGS{'region'} = [ qw(wxInRegion
wxOutRegion) ];
$EXPORT_TAGS{'ribbon'} = [ qw(wxRIBBON_BAR_SHOW_PAGE_LABELS
wxRIBBON_BAR_SHOW_PAGE_ICONS
wxRIBBON_BAR_FLOW_HORIZONTAL
wxRIBBON_BAR_FLOW_VERTICAL
wxRIBBON_BAR_SHOW_PANEL_EXT_BUTTONS
wxRIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS
wxRIBBON_BAR_ALWAYS_SHOW_TABS
wxRIBBON_BAR_DEFAULT_STYLE
wxRIBBON_BAR_FOLDBAR_STYLE
wxRIBBON_PANEL_NO_AUTO_MINIMISE
wxRIBBON_PANEL_EXT_BUTTON
wxRIBBON_PANEL_MINIMISE_BUTTON
wxRIBBON_PANEL_DEFAULT_STYLE
wxRIBBON_TOOLBAR_TOOL_FIRST
wxRIBBON_TOOLBAR_TOOL_LAST
wxRIBBON_TOOLBAR_TOOL_POSITION_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_HOVERED
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_HOVERED
wxRIBBON_TOOLBAR_TOOL_HOVER_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_HOVERED
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_HOVERED
wxRIBBON_TOOLBAR_TOOL_NORMAL_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_ACTIVE
wxRIBBON_TOOLBAR_TOOL_ACTIVE_MASK
wxRIBBON_TOOLBAR_TOOL_NORMAL_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DROPDOWN_ACTIVE
wxRIBBON_TOOLBAR_TOOL_DISABLED
wxRIBBON_TOOLBAR_TOOL_STATE_MASK
wxRIBBON_SCROLL_BTN_LEFT
wxRIBBON_SCROLL_BTN_RIGHT
wxRIBBON_SCROLL_BTN_UP
wxRIBBON_SCROLL_BTN_DOWN
wxRIBBON_SCROLL_BTN_DIRECTION_MASK
wxRIBBON_SCROLL_BTN_NORMAL
wxRIBBON_SCROLL_BTN_HOVERED
wxRIBBON_SCROLL_BTN_ACTIVE
wxRIBBON_SCROLL_BTN_STATE_MASK
wxRIBBON_SCROLL_BTN_FOR_OTHER
wxRIBBON_SCROLL_BTN_FOR_TABS
wxRIBBON_SCROLL_BTN_FOR_PAGE
wxRIBBON_SCROLL_BTN_FOR_MASK
wxRIBBON_BUTTON_NORMAL
wxRIBBON_BUTTON_DROPDOWN
wxRIBBON_BUTTON_HYBRID
wxRIBBON_BUTTON_TOGGLE
wxRIBBON_BUTTONBAR_BUTTON_SMALL
wxRIBBON_BUTTONBAR_BUTTON_MEDIUM
wxRIBBON_BUTTONBAR_BUTTON_LARGE
wxRIBBON_BUTTONBAR_BUTTON_SIZE_MASK
wxRIBBON_BUTTONBAR_BUTTON_NORMAL_HOVERED
wxRIBBON_BUTTONBAR_BUTTON_DROPDOWN_HOVERED
wxRIBBON_BUTTONBAR_BUTTON_HOVER_MASK
wxRIBBON_BUTTONBAR_BUTTON_NORMAL_ACTIVE
wxRIBBON_BUTTONBAR_BUTTON_DROPDOWN_ACTIVE
wxRIBBON_BUTTONBAR_BUTTON_DISABLED
wxRIBBON_BUTTONBAR_BUTTON_TOGGLED
wxRIBBON_BUTTONBAR_BUTTON_STATE_MASK
wxRIBBON_GALLERY_BUTTON_NORMAL
wxRIBBON_GALLERY_BUTTON_HOVERED
wxRIBBON_GALLERY_BUTTON_ACTIVE
wxRIBBON_GALLERY_BUTTON_DISABLED
wxEVT_COMMAND_RIBBONBAR_PAGE_CHANGED
wxEVT_COMMAND_RIBBONBAR_PAGE_CHANGING
wxEVT_COMMAND_RIBBONBAR_TAB_MIDDLE_DOWN
wxEVT_COMMAND_RIBBONBAR_TAB_MIDDLE_UP
wxEVT_COMMAND_RIBBONBAR_TAB_RIGHT_DOWN
wxEVT_COMMAND_RIBBONBAR_TAB_RIGHT_UP
wxEVT_COMMAND_RIBBONBAR_TAB_LEFT_DCLICK
wxEVT_COMMAND_RIBBONBUTTON_CLICKED
wxEVT_COMMAND_RIBBONBUTTON_DROPDOWN_CLICKED
wxEVT_COMMAND_RIBBONGALLERY_HOVER_CHANGED
wxEVT_COMMAND_RIBBONGALLERY_SELECTED
wxEVT_COMMAND_RIBBONGALLERY_CLICKED
wxEVT_COMMAND_RIBBONTOOL_CLICKED
wxEVT_COMMAND_RIBBONTOOL_DROPDOWN_CLICKED) ];
$EXPORT_TAGS{'richtextctrl'} = [ qw(wxRichTextLineBreakChar
wxRE_READONLY
wxRE_MULTILINE
wxRICHTEXT_SETSTYLE_NONE
wxRICHTEXT_SETSTYLE_WITH_UNDO
wxRICHTEXT_SETSTYLE_OPTIMIZE
wxRICHTEXT_SETSTYLE_PARAGRAPHS_ONLY
wxRICHTEXT_SETSTYLE_CHARACTERS_ONLY
wxRICHTEXT_SETSTYLE_RENUMBER
wxRICHTEXT_SETSTYLE_SPECIFY_LEVEL
wxRICHTEXT_SETSTYLE_REMOVE
wxRICHTEXT_INSERT_NONE
wxRICHTEXT_INSERT_WITH_PREVIOUS_PARAGRAPH_STYLE
wxRICHTEXT_SETSTYLE_RESET
wxRICHTEXT_FIXED_WIDTH
wxRICHTEXT_FIXED_HEIGHT
wxRICHTEXT_VARIABLE_WIDTH
wxRICHTEXT_VARIABLE_HEIGHT
wxRICHTEXT_LAYOUT_SPECIFIED_RECT
wxRICHTEXT_DRAW_IGNORE_CACHE
wxRICHTEXT_HITTEST_NONE
wxRICHTEXT_HITTEST_BEFORE
wxRICHTEXT_HITTEST_AFTER
wxRICHTEXT_HITTEST_ON
wxRICHTEXT_HITTEST_OUTSIDE
wxRICHTEXT_HANDLER_INCLUDE_STYLESHEET
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_MEMORY
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_FILES
wxRICHTEXT_HANDLER_SAVE_IMAGES_TO_BASE64
wxRICHTEXT_HANDLER_NO_HEADER_FOOTER
wxRICHTEXT_HANDLER_CONVERT_FACENAMES
wxRICHTEXT_FORMATTED
wxRICHTEXT_UNFORMATTED
wxRICHTEXT_TYPE_ANY
wxRICHTEXT_TYPE_TEXT
wxRICHTEXT_TYPE_XML
wxRICHTEXT_TYPE_HTML
wxRICHTEXT_TYPE_RTF
wxRICHTEXT_TYPE_PDF
wxRICHTEXT_FORMAT_STYLE_EDITOR
wxRICHTEXT_FORMAT_FONT
wxRICHTEXT_FORMAT_TABS
wxRICHTEXT_FORMAT_BULLETS
wxRICHTEXT_FORMAT_INDENTS_SPACING
wxRICHTEXT_FORMAT_CHARACTER
wxRICHTEXT_FORMAT_HELP_BUTTON
wxRICHTEXT_FORMAT_LIST_STYLE
wxRICHTEXT_FORMAT_PARAGRAPH
wxRICHTEXT_FORMAT_STYLE
wxRICHTEXT_ORGANISER_DELETE_STYLES
wxRICHTEXT_ORGANISER_CREATE_STYLES
wxRICHTEXT_ORGANISER_APPLY_STYLES
wxRICHTEXT_ORGANISER_EDIT_STYLES
wxRICHTEXT_ORGANISER_RENAME_STYLES
wxRICHTEXT_ORGANISER_OK_CANCEL
wxRICHTEXT_ORGANISER_RENUMBER
wxRICHTEXT_ORGANISER_SHOW_CHARACTER
wxRICHTEXT_ORGANISER_SHOW_PARAGRAPH
wxRICHTEXT_ORGANISER_SHOW_LIST
wxRICHTEXT_ORGANISER_SHOW_ALL
wxRICHTEXT_ORGANISER_ORGANISE
wxRICHTEXT_ORGANISER_BROWSE
wxRICHTEXT_ORGANISER_BROWSE_NUMBERING
wxRICHTEXT_PAGE_ALL
wxRICHTEXT_PAGE_CENTRE
wxRICHTEXT_PAGE_EVEN
wxRICHTEXT_PAGE_LEFT
wxRICHTEXT_PAGE_ODD
wxRICHTEXT_PAGE_RIGHT
wxRICHTEXT_STYLE_ALL
wxRICHTEXT_STYLE_CHARACTER
wxRICHTEXT_STYLE_LIST
wxRICHTEXT_STYLE_PARAGRAPH
wxTEXT_ATTR_PARA_SPACING_AFTER
wxTEXT_ATTR_PARA_SPACING_BEFORE
wxTEXT_ATTR_LINE_SPACING
wxTEXT_ATTR_CHARACTER_STYLE_NAME
wxTEXT_ATTR_PARAGRAPH_STYLE_NAME
wxTEXT_ATTR_LIST_STYLE_NAME
wxTEXT_ATTR_BULLET_STYLE
wxTEXT_ATTR_BULLET_NUMBER
wxTEXT_ATTR_BULLET_TEXT
wxTEXT_ATTR_BULLET_NAME
wxTEXT_ATTR_URL
wxTEXT_ATTR_PAGE_BREAK
wxTEXT_ATTR_BULLET_STYLE_NONE
wxTEXT_ATTR_BULLET_STYLE_ARABIC
wxTEXT_ATTR_BULLET_STYLE_LETTERS_UPPER
wxTEXT_ATTR_BULLET_STYLE_LETTERS_LOWER
wxTEXT_ATTR_BULLET_STYLE_ROMAN_UPPER
wxTEXT_ATTR_BULLET_STYLE_ROMAN_LOWER
wxTEXT_ATTR_BULLET_STYLE_SYMBOL
wxTEXT_ATTR_BULLET_STYLE_BITMAP
wxTEXT_ATTR_BULLET_STYLE_PARENTHESES
wxTEXT_ATTR_BULLET_STYLE_PERIOD
wxTEXT_ATTR_BULLET_STYLE_STANDARD
wxTEXT_ATTR_BULLET_STYLE_RIGHT_PARENTHESIS
wxTEXT_ATTR_BULLET_STYLE_OUTLINE
wxTEXT_ATTR_BULLET_STYLE_ALIGN_LEFT
wxTEXT_ATTR_BULLET_STYLE_ALIGN_RIGHT
wxTEXT_ATTR_BULLET_STYLE_ALIGN_CENTRE
wxTEXT_ATTR_LINE_SPACING_NORMAL
wxTEXT_ATTR_LINE_SPACING_HALF
wxTEXT_ATTR_LINE_SPACING_TWICE
wxTEXT_ATTR_CHARACTER
wxTEXT_ATTR_PARAGRAPH
wxTEXT_ATTR_ALL
wxTEXT_ATTR_EFFECT_NONE
wxTEXT_ATTR_EFFECT_CAPITALS
wxTEXT_ATTR_EFFECT_SMALL_CAPITALS
wxTEXT_ATTR_EFFECT_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_SHADOW
wxTEXT_ATTR_EFFECT_EMBOSS
wxTEXT_ATTR_EFFECT_OUTLINE
wxTEXT_ATTR_EFFECT_ENGRAVE
wxTEXT_ATTR_EFFECT_SUPERSCRIPT
wxTEXT_ATTR_EFFECT_SUBSCRIPT
wxTEXT_ATTR_EFFECTS
wxTEXT_ATTR_FONT_ENCODING
wxTEXT_ATTR_KEEP_FIRST_PARA_STYLE
wxTEXT_ATTR_OUTLINE_LEVEL) ];
$EXPORT_TAGS{'sashwindow'} = [ qw(wxSASH_STATUS_OK
wxSASH_STATUS_OUT_OF_RANGE
wxSASH_TOP
wxSASH_RIGHT
wxSASH_BOTTOM
wxSASH_LEFT
wxSASH_NONE
wxSW_3D
wxSW_3DSASH
wxSW_3DBORDER
wxSW_BORDER) ];
$EXPORT_TAGS{'scrollbar'} = [ qw(wxSB_HORIZONTAL
wxSB_VERTICAL) ];
$EXPORT_TAGS{'scrolledwindow'} = [ qw(wxRETAINED
wxSHOW_SB_ALWAYS
wxSHOW_SB_NEVER
wxSHOW_SB_DEFAULT) ];
$EXPORT_TAGS{'sizer'} = [ qw(wxALIGN_LEFT
wxALIGN_CENTRE
wxALIGN_CENTER
wxALIGN_RIGHT
wxALIGN_TOP
wxALIGN_BOTTOM
wxALIGN_CENTER_VERTICAL
wxALIGN_CENTER_HORIZONTAL
wxALIGN_CENTRE_VERTICAL
wxALIGN_CENTRE_HORIZONTAL
wxALL
wxADJUST_MINSIZE
wxBOTTOM
wxBACKWARD
wxCENTER
wxCENTRE
wxEXPAND
wxEXTEND_LAST_ON_EACH_LINE
wxFIXED_MINSIZE
wxFLEX_GROWMODE_NONE
wxFLEX_GROWMODE_SPECIFIED
wxFLEX_GROWMODE_ALL
wxFORWARD
wxGROW
wxHORIZONTAL
wxLEFT
wxMORE
wxRIGHT
wxRESET
wxSHAPED
wxSETUP
wxTOP
wxVERTICAL) ];
$EXPORT_TAGS{'slider'} = [ qw(wxSL_HORIZONTAL
wxSL_VERTICAL
wxSL_AUTOTICKS
wxSL_LABELS
wxSL_LEFT
wxSL_RIGHT
wxSL_TOP
wxSL_SELRANGE
wxSL_BOTH
wxSL_BOTTOM
wxSL_TICKS
wxSL_INVERSE) ];
$EXPORT_TAGS{'socket'} = [ qw(wxEVT_SOCKET
wxSOCKET_BLOCK
wxSOCKET_NONE
wxSOCKET_NOWAIT
wxSOCKET_WAITALL
wxSOCKET_REUSEADDR
wxSOCKET_NOBIND
wxSOCKET_BROADCAST
wxSOCKET_CONNECTION_FLAG
wxSOCKET_INPUT_FLAG
wxSOCKET_LOST_FLAG
wxSOCKET_OUTPUT_FLAG
wxSOCKET_INPUT
wxSOCKET_OUTPUT
wxSOCKET_CONNECTION
wxSOCKET_LOST
wxSOCKET_UNINIT
wxSOCKET_CLIENT
wxSOCKET_SERVER
wxSOCKET_BASE
wxSOCKET_DATAGRAM
wxSOCKET_NOERROR
wxSOCKET_INVOP
wxSOCKET_IOERR
wxSOCKET_INVADDR
wxSOCKET_INVSOCK
wxSOCKET_NOHOST
wxSOCKET_INVPORT
wxSOCKET_WOULDBLOCK
wxSOCKET_TIMEDOUT
wxSOCKET_MEMERR) ];
$EXPORT_TAGS{'sound'} = [ qw(wxSOUND_SYNC
wxSOUND_ASYNC
wxSOUND_LOOP) ];
$EXPORT_TAGS{'spinbutton'} = [ qw(wxSP_HORIZONTAL
wxSP_VERTICAL
wxSP_ARROW_KEYS
wxSP_WRAP) ];
$EXPORT_TAGS{'spinctrl'} = [ qw(wxSP_ARROW_KEYS
wxSP_WRAP) ];
$EXPORT_TAGS{'splashscreen'} = [ qw(wxSPLASH_CENTRE_ON_PARENT
wxSPLASH_CENTRE_ON_SCREEN
wxSPLASH_NO_CENTRE
wxSPLASH_CENTER_ON_PARENT
wxSPLASH_CENTER_ON_SCREEN
wxSPLASH_NO_CENTER
wxSPLASH_TIMEOUT
wxSPLASH_NO_TIMEOUT) ];
$EXPORT_TAGS{'splitterwindow'} = [ qw(wxSP_3D
wxSP_3DSASH
wxSP_3DBORDER
wxSP_FULLSASH
wxSP_BORDER
wxSP_NOBORDER
wxSP_PERMIT_UNSPLIT
wxSP_LIVE_UPDATE
wxSP_NOSASH
wxSP_NO_XP_THEME
wxSPLIT_HORIZONTAL
wxSPLIT_VERTICAL) ];
$EXPORT_TAGS{'staticline'} = [ qw(wxLI_HORIZONTAL
wxLI_VERTICAL) ];
$EXPORT_TAGS{'statictext'} = [ qw(wxALIGN_LEFT
wxALIGN_CENTRE
wxALIGN_CENTER
wxALIGN_RIGHT
wxST_NO_AUTORESIZE
wxST_ELLIPSIZE_START
wxST_ELLIPSIZE_MIDDLE
wxST_ELLIPSIZE_END
wxST_MARKUP) ];
$EXPORT_TAGS{'statusbar'} = [ qw(wxSB_NORMAL
wxSB_FLAT
wxSB_RAISED
wxST_SIZEGRIP) ];
$EXPORT_TAGS{'stc'} = [ qw(wxSTC_4GL_BLOCK
wxSTC_4GL_BLOCK_
wxSTC_4GL_CHARACTER
wxSTC_4GL_CHARACTER_
wxSTC_4GL_COMMENT1
wxSTC_4GL_COMMENT1_
wxSTC_4GL_COMMENT2
wxSTC_4GL_COMMENT2_
wxSTC_4GL_COMMENT3
wxSTC_4GL_COMMENT3_
wxSTC_4GL_COMMENT4
wxSTC_4GL_COMMENT4_
wxSTC_4GL_COMMENT5
wxSTC_4GL_COMMENT5_
wxSTC_4GL_COMMENT6
wxSTC_4GL_COMMENT6_
wxSTC_4GL_DEFAULT
wxSTC_4GL_DEFAULT_
wxSTC_4GL_END
wxSTC_4GL_END_
wxSTC_4GL_IDENTIFIER
wxSTC_4GL_IDENTIFIER_
wxSTC_4GL_NUMBER
wxSTC_4GL_NUMBER_
wxSTC_4GL_OPERATOR
wxSTC_4GL_OPERATOR_
wxSTC_4GL_PREPROCESSOR
wxSTC_4GL_PREPROCESSOR_
wxSTC_4GL_STRING
wxSTC_4GL_STRING_
wxSTC_4GL_WORD
wxSTC_4GL_WORD_
wxSTC_A68K_DEFAULT
wxSTC_A68K_COMMENT
wxSTC_A68K_NUMBER_DEC
wxSTC_A68K_NUMBER_BIN
wxSTC_A68K_NUMBER_HEX
wxSTC_A68K_STRING1
wxSTC_A68K_OPERATOR
wxSTC_A68K_CPUINSTRUCTION
wxSTC_A68K_EXTINSTRUCTION
wxSTC_A68K_REGISTER
wxSTC_A68K_DIRECTIVE
wxSTC_A68K_MACRO_ARG
wxSTC_A68K_LABEL
wxSTC_A68K_STRING2
wxSTC_A68K_IDENTIFIER
wxSTC_A68K_MACRO_DECLARATION
wxSTC_A68K_COMMENT_WORD
wxSTC_A68K_COMMENT_SPECIAL
wxSTC_A68K_COMMENT_DOXYGEN
wxSTC_ASM_COMMENTDIRECTIVE
wxSTC_AVS_DEFAULT
wxSTC_AVS_COMMENTBLOCK
wxSTC_AVS_COMMENTBLOCKN
wxSTC_AVS_COMMENTLINE
wxSTC_AVS_NUMBER
wxSTC_AVS_OPERATOR
wxSTC_AVS_IDENTIFIER
wxSTC_AVS_STRING
wxSTC_AVS_TRIPLESTRING
wxSTC_AVS_KEYWORD
wxSTC_AVS_FILTER
wxSTC_AVS_PLUGIN
wxSTC_AVS_FUNCTION
wxSTC_AVS_CLIPPROP
wxSTC_AVS_USERDFN
wxSTC_AVE_DEFAULT
wxSTC_AVE_COMMENT
wxSTC_AVE_NUMBER
wxSTC_AVE_WORD
wxSTC_AVE_STRING
wxSTC_AVE_ENUM
wxSTC_AVE_STRINGEOL
wxSTC_AVE_IDENTIFIER
wxSTC_AVE_OPERATOR
wxSTC_ADA_DEFAULT
wxSTC_ADA_NUMBER
wxSTC_ADA_WORD
wxSTC_ADA_STRING
wxSTC_ADA_CHARACTER
wxSTC_ADA_IDENTIFIER
wxSTC_ADA_STRINGEOL
wxSTC_ASM_DEFAULT
wxSTC_ASM_COMMENT
wxSTC_ASM_NUMBER
wxSTC_ASM_STRING
wxSTC_ASM_OPERATOR
wxSTC_ASM_IDENTIFIER
wxSTC_ASM_CPUINSTRUCTION
wxSTC_ASM_MATHINSTRUCTION
wxSTC_ASM_REGISTER
wxSTC_ASM_DIRECTIVE
wxSTC_ASM_DIRECTIVEOPERAND
wxSTC_ASM_COMMENTBLOCK
wxSTC_ASM_CHARACTER
wxSTC_ASM_STRINGEOL
wxSTC_ASM_EXTINSTRUCTION
wxSTC_ABAQUS_ARGUMENT
wxSTC_ABAQUS_COMMAND
wxSTC_ABAQUS_COMMENT
wxSTC_ABAQUS_COMMENTBLOCK
wxSTC_ABAQUS_DEFAULT
wxSTC_ABAQUS_FUNCTION
wxSTC_ABAQUS_NUMBER
wxSTC_ABAQUS_OPERATOR
wxSTC_ABAQUS_PROCESSOR
wxSTC_ABAQUS_SLASHCOMMAND
wxSTC_ABAQUS_STARCOMMAND
wxSTC_ABAQUS_STRING
wxSTC_ABAQUS_WORD
wxSTC_ADA_CHARACTEREOL
wxSTC_ADA_COMMENTLINE
wxSTC_ADA_DELIMITER
wxSTC_ADA_ILLEGAL
wxSTC_ADA_LABEL
wxSTC_ALPHA_NOALPHA
wxSTC_ALPHA_OPAQUE
wxSTC_ALPHA_TRANSPARENT
wxSTC_APDL_COMMAND
wxSTC_APDL_COMMENT
wxSTC_APDL_COMMENTBLOCK
wxSTC_APDL_DEFAULT
wxSTC_APDL_FUNCTION
wxSTC_APDL_NUMBER
wxSTC_APDL_PROCESSOR
wxSTC_APDL_ARGUMENT
wxSTC_APDL_OPERATOR
wxSTC_APDL_SLASHCOMMAND
wxSTC_APDL_STARCOMMAND
wxSTC_APDL_STRING
wxSTC_APDL_WORD
wxSTC_ASN1_ATTRIBUTE
wxSTC_ASN1_COMMENT
wxSTC_ASN1_DEFAULT
wxSTC_ASN1_DESCRIPTOR
wxSTC_ASN1_IDENTIFIER
wxSTC_ASN1_KEYWORD
wxSTC_ASN1_OID
wxSTC_ASN1_OPERATOR
wxSTC_ASN1_SCALAR
wxSTC_ASN1_STRING
wxSTC_ASN1_TYPE
wxSTC_ASY_CHARACTER
wxSTC_ASY_COMMENT
wxSTC_ASY_COMMENTLINE
wxSTC_ASY_COMMENTLINEDOC
wxSTC_ASY_DEFAULT
wxSTC_ASY_IDENTIFIER
wxSTC_ASY_NUMBER
wxSTC_ASY_OPERATOR
wxSTC_ASY_STRING
wxSTC_ASY_STRINGEOL
wxSTC_ASY_WORD
wxSTC_ASY_WORD2
wxSTC_AU3_COMMENT
wxSTC_AU3_COMMENTBLOCK
wxSTC_AU3_DEFAULT
wxSTC_AU3_FUNCTION
wxSTC_AU3_KEYWORD
wxSTC_AU3_MACRO
wxSTC_AU3_NUMBER
wxSTC_AU3_OPERATOR
wxSTC_AU3_PREPROCESSOR
wxSTC_AU3_SENT
wxSTC_AU3_SPECIAL
wxSTC_AU3_STRING
wxSTC_AU3_COMOBJ
wxSTC_AU3_EXPAND
wxSTC_AU3_UDF
wxSTC_AU3_VARIABLE
wxSTC_AVE_WORD1
wxSTC_AVE_WORD2
wxSTC_AVE_WORD3
wxSTC_AVE_WORD4
wxSTC_AVE_WORD5
wxSTC_AVE_WORD6
wxSTC_ANNOTATION_HIDDEN
wxSTC_ANNOTATION_STANDARD
wxSTC_ANNOTATION_BOXED
wxSTC_B_DEFAULT
wxSTC_B_COMMENT
wxSTC_B_NUMBER
wxSTC_B_KEYWORD
wxSTC_B_STRING
wxSTC_B_PREPROCESSOR
wxSTC_B_OPERATOR
wxSTC_B_IDENTIFIER
wxSTC_B_DATE
wxSTC_BAT_DEFAULT
wxSTC_BAT_COMMENT
wxSTC_BAT_WORD
wxSTC_BAT_LABEL
wxSTC_BAT_HIDE
wxSTC_BAT_COMMAND
wxSTC_BAT_IDENTIFIER
wxSTC_BAT_OPERATOR
wxSTC_BAAN_DEFAULT
wxSTC_BAAN_COMMENT
wxSTC_BAAN_COMMENTDOC
wxSTC_BAAN_NUMBER
wxSTC_BAAN_WORD
wxSTC_BAAN_STRING
wxSTC_BAAN_PREPROCESSOR
wxSTC_BAAN_OPERATOR
wxSTC_BAAN_IDENTIFIER
wxSTC_BAAN_STRINGEOL
wxSTC_BAAN_WORD2
wxSTC_B_ASM
wxSTC_B_CONSTANT
wxSTC_B_KEYWORD2
wxSTC_B_KEYWORD3
wxSTC_B_KEYWORD4
wxSTC_B_STRINGEOL
wxSTC_B_BINNUMBER
wxSTC_B_ERROR
wxSTC_B_HEXNUMBER
wxSTC_B_LABEL
wxSTC_C_STRINGRAW
wxSTC_C_TRIPLEVERBATIM
wxSTC_C_HASHQUOTEDSTRING
wxSTC_C_PREPROCESSORCOMMENT
wxSTC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE
wxSTC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE
wxSTC_CARETSTICKY_OFF
wxSTC_CARETSTICKY_ON
wxSTC_CARETSTICKY_WHITESPACE
wxSTC_COFFEESCRIPT_DEFAULT
wxSTC_COFFEESCRIPT_COMMENT
wxSTC_COFFEESCRIPT_COMMENTLINE
wxSTC_COFFEESCRIPT_COMMENTDOC
wxSTC_COFFEESCRIPT_NUMBER
wxSTC_COFFEESCRIPT_WORD
wxSTC_COFFEESCRIPT_STRING
wxSTC_COFFEESCRIPT_CHARACTER
wxSTC_COFFEESCRIPT_UUID
wxSTC_COFFEESCRIPT_PREPROCESSOR
wxSTC_COFFEESCRIPT_OPERATOR
wxSTC_COFFEESCRIPT_IDENTIFIER
wxSTC_COFFEESCRIPT_STRINGEOL
wxSTC_COFFEESCRIPT_VERBATIM
wxSTC_COFFEESCRIPT_REGEX
wxSTC_COFFEESCRIPT_COMMENTLINEDOC
wxSTC_COFFEESCRIPT_WORD2
wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORD
wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORDERROR
wxSTC_COFFEESCRIPT_GLOBALCLASS
wxSTC_COFFEESCRIPT_STRINGRAW
wxSTC_COFFEESCRIPT_TRIPLEVERBATIM
wxSTC_COFFEESCRIPT_HASHQUOTEDSTRING
wxSTC_COFFEESCRIPT_COMMENTBLOCK
wxSTC_COFFEESCRIPT_VERBOSE_REGEX
wxSTC_COFFEESCRIPT_VERBOSE_REGEX_COMMENT
wxSTC_CSS_MEDIA
wxSTC_CSS_VARIABLE
wxSTC_CURSORARROW
wxSTC_CURSORREVERSEARROW
wxSTC_CHARSET_ANSI
wxSTC_CHARSET_DEFAULT
wxSTC_CHARSET_BALTIC
wxSTC_CHARSET_CHINESEBIG5
wxSTC_CHARSET_EASTEUROPE
wxSTC_CHARSET_GB2312
wxSTC_CHARSET_GREEK
wxSTC_CHARSET_HANGUL
wxSTC_CHARSET_MAC
wxSTC_CHARSET_OEM
wxSTC_CHARSET_RUSSIAN
wxSTC_CHARSET_SHIFTJIS
wxSTC_CHARSET_SYMBOL
wxSTC_CHARSET_TURKISH
wxSTC_CHARSET_JOHAB
wxSTC_CHARSET_HEBREW
wxSTC_CHARSET_ARABIC
wxSTC_CHARSET_VIETNAMESE
wxSTC_CHARSET_THAI
wxSTC_CHARSET_8859_15
wxSTC_CHARSET_CYRILLIC
wxSTC_CASE_MIXED
wxSTC_CASE_UPPER
wxSTC_CASE_LOWER
wxSTC_CACHE_NONE
wxSTC_CACHE_CARET
wxSTC_CACHE_PAGE
wxSTC_CACHE_DOCUMENT
wxSTC_CURSORNORMAL
wxSTC_CURSORWAIT
wxSTC_CARET_SLOP
wxSTC_CARET_STRICT
wxSTC_CARET_JUMPS
wxSTC_CARET_EVEN
wxSTC_CARETSTYLE_BLOCK
wxSTC_CARETSTYLE_INVISIBLE
wxSTC_CARETSTYLE_LINE
wxSTC_C_DEFAULT
wxSTC_C_COMMENT
wxSTC_C_COMMENTLINE
wxSTC_C_COMMENTDOC
wxSTC_C_NUMBER
wxSTC_C_WORD
wxSTC_C_STRING
wxSTC_C_CHARACTER
wxSTC_C_UUID
wxSTC_C_PREPROCESSOR
wxSTC_C_OPERATOR
wxSTC_C_IDENTIFIER
wxSTC_C_STRINGEOL
wxSTC_C_VERBATIM
wxSTC_C_REGEX
wxSTC_C_COMMENTLINEDOC
wxSTC_C_WORD2
wxSTC_C_COMMENTDOCKEYWORD
wxSTC_C_COMMENTDOCKEYWORDERROR
wxSTC_C_GLOBALCLASS
wxSTC_CONF_DEFAULT
wxSTC_CONF_COMMENT
wxSTC_CONF_NUMBER
wxSTC_CONF_IDENTIFIER
wxSTC_CONF_EXTENSION
wxSTC_CONF_PARAMETER
wxSTC_CONF_STRING
wxSTC_CONF_OPERATOR
wxSTC_CONF_IP
wxSTC_CONF_DIRECTIVE
wxSTC_CMD_REDO
wxSTC_CMD_SELECTALL
wxSTC_CMD_UNDO
wxSTC_CMD_CUT
wxSTC_CMD_COPY
wxSTC_CMD_PASTE
wxSTC_CMD_LINEDOWN
wxSTC_CMD_LINEDOWNEXTEND
wxSTC_CMD_LINEUP
wxSTC_CMD_LINEUPEXTEND
wxSTC_CMD_LINECOPY
wxSTC_CMD_CHARLEFT
wxSTC_CMD_CHARLEFTEXTEND
wxSTC_CMD_CHARRIGHT
wxSTC_CMD_CHARRIGHTEXTEND
wxSTC_CMD_WORDLEFT
wxSTC_CMD_WORDLEFTEXTEND
wxSTC_CMD_WORDRIGHT
wxSTC_CMD_WORDRIGHTEXTEND
wxSTC_CMD_HOME
wxSTC_CMD_HOMEEXTEND
wxSTC_CMD_LINEEND
wxSTC_CMD_LINEENDEXTEND
wxSTC_CMD_DOCUMENTSTART
wxSTC_CMD_DOCUMENTSTARTEXTEND
wxSTC_CMD_DOCUMENTEND
wxSTC_CMD_DOCUMENTENDEXTEND
wxSTC_CMD_PAGEUP
wxSTC_CMD_PAGEUPEXTEND
wxSTC_CMD_PAGEDOWN
wxSTC_CMD_PAGEDOWNEXTEND
wxSTC_CMD_PARADOWN
wxSTC_CMD_PARADOWNEXTEND
wxSTC_CMD_PARAUP
wxSTC_CMD_PARAUPEXTEND
wxSTC_CMD_EDITTOGGLEOVERTYPE
wxSTC_CMD_CANCEL
wxSTC_CMD_DELETEBACK
wxSTC_CMD_TAB
wxSTC_CMD_BACKTAB
wxSTC_CMD_NEWLINE
wxSTC_CMD_FORMFEED
wxSTC_CMD_VCHOME
wxSTC_CMD_VCHOMEEXTEND
wxSTC_CMD_ZOOMIN
wxSTC_CMD_ZOOMOUT
wxSTC_CMD_DELWORDLEFT
wxSTC_CMD_DELWORDRIGHT
wxSTC_CMD_LINECUT
wxSTC_CMD_LINEDELETE
wxSTC_CMD_LINETRANSPOSE
wxSTC_CMD_LOWERCASE
wxSTC_CMD_UPPERCASE
wxSTC_CMD_LINESCROLLDOWN
wxSTC_CMD_LINESCROLLUP
wxSTC_CMD_DELETEBACKNOTLINE
wxSTC_CMD_HOMEDISPLAY
wxSTC_CMD_HOMEDISPLAYEXTEND
wxSTC_CMD_LINEENDDISPLAY
wxSTC_CMD_LINEENDDISPLAYEXTEND
wxSTC_CMD_CLEAR
wxSTC_CMD_WORDPARTLEFT
wxSTC_CMD_WORDPARTLEFTEXTEND
wxSTC_CMD_WORDPARTRIGHT
wxSTC_CMD_WORDPARTRIGHTEXTEND
wxSTC_CMD_DELLINELEFT
wxSTC_CMD_DELLINERIGHT
wxSTC_CSS_DEFAULT
wxSTC_CSS_TAG
wxSTC_CSS_CLASS
wxSTC_CSS_PSEUDOCLASS
wxSTC_CSS_UNKNOWN_PSEUDOCLASS
wxSTC_CSS_OPERATOR
wxSTC_CSS_IDENTIFIER
wxSTC_CSS_UNKNOWN_IDENTIFIER
wxSTC_CSS_VALUE
wxSTC_CSS_COMMENT
wxSTC_CSS_ID
wxSTC_CSS_IMPORTANT
wxSTC_CSS_DIRECTIVE
wxSTC_CSS_DOUBLESTRING
wxSTC_CSS_SINGLESTRING
wxSTC_CSS_ATTRIBUTE
wxSTC_CSS_IDENTIFIER2
wxSTC_CSS_IDENTIFIER3
wxSTC_CSS_PSEUDOELEMENT
wxSTC_CSS_EXTENDED_IDENTIFIER
wxSTC_CSS_EXTENDED_PSEUDOCLASS
wxSTC_CSS_EXTENDED_PSEUDOELEMENT
wxSTC_CAML_CHAR
wxSTC_CAML_COMMENT
wxSTC_CAML_COMMENT1
wxSTC_CAML_COMMENT2
wxSTC_CAML_COMMENT3
wxSTC_CAML_DEFAULT
wxSTC_CAML_IDENTIFIER
wxSTC_CAML_KEYWORD
wxSTC_CAML_KEYWORD2
wxSTC_CAML_KEYWORD3
wxSTC_CAML_LINENUM
wxSTC_CAML_NUMBER
wxSTC_CAML_OPERATOR
wxSTC_CAML_STRING
wxSTC_CAML_TAGNAME
wxSTC_CAML_WHITE
wxSTC_CLW_ATTRIBUTE
wxSTC_CLW_BUILTIN_PROCEDURES_FUNCTION
wxSTC_CLW_COMMENT
wxSTC_CLW_COMPILER_DIRECTIVE
wxSTC_CLW_DEFAULT
wxSTC_CLW_ERROR
wxSTC_CLW_INTEGER_CONSTANT
wxSTC_CLW_KEYWORD
wxSTC_CLW_LABEL
wxSTC_CLW_PICTURE_STRING
wxSTC_CLW_REAL_CONSTANT
wxSTC_CLW_DEPRECATED
wxSTC_CLW_RUNTIME_EXPRESSIONS
wxSTC_CLW_STANDARD_EQUATE
wxSTC_CLW_STRING
wxSTC_CLW_STRUCTURE_DATA_TYPE
wxSTC_CLW_USER_IDENTIFIER
wxSTC_CMAKE_COMMANDS
wxSTC_CMAKE_COMMENT
wxSTC_CMAKE_DEFAULT
wxSTC_CMAKE_FOREACHDEF
wxSTC_CMAKE_IFDEFINEDEF
wxSTC_CMAKE_MACRODEF
wxSTC_CMAKE_NUMBER
wxSTC_CMAKE_PARAMETERS
wxSTC_CMAKE_STRINGDQ
wxSTC_CMAKE_STRINGLQ
wxSTC_CMAKE_STRINGRQ
wxSTC_CMAKE_STRINGVAR
wxSTC_CMAKE_USERDEFINED
wxSTC_CMAKE_VARIABLE
wxSTC_CMAKE_WHILEDEF
wxSTC_CMD_CHARLEFTRECTEXTEND
wxSTC_CMD_CHARRIGHTRECTEXTEND
wxSTC_CMD_DELWORDRIGHTEND
wxSTC_CMD_HOMERECTEXTEND
wxSTC_CMD_HOMEWRAP
wxSTC_CMD_HOMEWRAPEXTEND
wxSTC_CMD_LINEDOWNRECTEXTEND
wxSTC_CMD_LINEDUPLICATE
wxSTC_CMD_LINEENDRECTEXTEND
wxSTC_CMD_LINEENDWRAP
wxSTC_CMD_LINEENDWRAPEXTEND
wxSTC_CMD_LINEUPRECTEXTEND
wxSTC_CMD_PAGEDOWNRECTEXTEND
wxSTC_CMD_PAGEUPRECTEXTEND
wxSTC_CMD_STUTTEREDPAGEDOWN
wxSTC_CMD_STUTTEREDPAGEDOWNEXTEND
wxSTC_CMD_STUTTEREDPAGEUP
wxSTC_CMD_STUTTEREDPAGEUPEXTEND
wxSTC_CMD_VCHOMERECTEXTEND
wxSTC_CMD_VCHOMEWRAP
wxSTC_CMD_VCHOMEWRAPEXTEND
wxSTC_CMD_WORDLEFTEND
wxSTC_CMD_WORDLEFTENDEXTEND
wxSTC_CMD_WORDRIGHTEND
wxSTC_CMD_WORDRIGHTENDEXTEND
wxSTC_CP_DBCS
wxSTC_CP_UTF8
wxSTC_CSOUND_ARATE_VAR
wxSTC_CSOUND_COMMENT
wxSTC_CSOUND_COMMENTBLOCK
wxSTC_CSOUND_DEFAULT
wxSTC_CSOUND_GLOBAL_VAR
wxSTC_CSOUND_HEADERSTMT
wxSTC_CSOUND_IDENTIFIER
wxSTC_CSOUND_INSTR
wxSTC_CSOUND_IRATE_VAR
wxSTC_CSOUND_KRATE_VAR
wxSTC_CSOUND_NUMBER
wxSTC_CSOUND_OPCODE
wxSTC_CSOUND_OPERATOR
wxSTC_CSOUND_PARAM
wxSTC_CSOUND_STRINGEOL
wxSTC_CSOUND_USERKEYWORD
wxSTC_DIFF_DEFAULT
wxSTC_DIFF_COMMENT
wxSTC_DIFF_COMMAND
wxSTC_DIFF_HEADER
wxSTC_DIFF_POSITION
wxSTC_DIFF_DELETED
wxSTC_DIFF_ADDED
wxSTC_DIFF_CHANGED
wxSTC_D_CHARACTER
wxSTC_D_COMMENT
wxSTC_D_COMMENTDOC
wxSTC_D_COMMENTDOCKEYWORD
wxSTC_D_COMMENTDOCKEYWORDERROR
wxSTC_D_COMMENTLINE
wxSTC_D_COMMENTLINEDOC
wxSTC_D_COMMENTNESTED
wxSTC_D_DEFAULT
wxSTC_D_IDENTIFIER
wxSTC_D_NUMBER
wxSTC_D_OPERATOR
wxSTC_D_STRING
wxSTC_D_STRINGEOL
wxSTC_D_TYPEDEF
wxSTC_D_WORD
wxSTC_D_WORD2
wxSTC_D_WORD3
wxSTC_D_STRINGR
wxSTC_D_WORD5
wxSTC_D_WORD6
wxSTC_D_WORD7
wxSTC_ECL_DEFAULT
wxSTC_ECL_COMMENT
wxSTC_ECL_COMMENTLINE
wxSTC_ECL_NUMBER
wxSTC_ECL_STRING
wxSTC_ECL_WORD0
wxSTC_ECL_OPERATOR
wxSTC_ECL_CHARACTER
wxSTC_ECL_UUID
wxSTC_ECL_PREPROCESSOR
wxSTC_ECL_UNKNOWN
wxSTC_ECL_IDENTIFIER
wxSTC_ECL_STRINGEOL
wxSTC_ECL_VERBATIM
wxSTC_ECL_REGEX
wxSTC_ECL_COMMENTLINEDOC
wxSTC_ECL_WORD1
wxSTC_ECL_COMMENTDOCKEYWORD
wxSTC_ECL_COMMENTDOCKEYWORDERROR
wxSTC_ECL_WORD2
wxSTC_ECL_WORD3
wxSTC_ECL_WORD4
wxSTC_ECL_WORD5
wxSTC_ECL_COMMENTDOC
wxSTC_ECL_ADDED
wxSTC_ECL_DELETED
wxSTC_ECL_CHANGED
wxSTC_ECL_MOVED
wxSTC_EOL_CR
wxSTC_EOL_LF
wxSTC_EOL_CRLF
wxSTC_EDGE_NONE
wxSTC_EDGE_LINE
wxSTC_EDGE_BACKGROUND
wxSTC_ERR_DEFAULT
wxSTC_ERR_PYTHON
wxSTC_ERR_GCC
wxSTC_ERR_MS
wxSTC_ERR_CMD
wxSTC_ERR_BORLAND
wxSTC_ERR_PERL
wxSTC_ERR_NET
wxSTC_ERR_LUA
wxSTC_ERR_CTAG
wxSTC_ERR_DIFF_CHANGED
wxSTC_ERR_DIFF_ADDITION
wxSTC_ERR_DIFF_DELETION
wxSTC_ERR_DIFF_MESSAGE
wxSTC_EIFFEL_DEFAULT
wxSTC_EIFFEL_COMMENTLINE
wxSTC_EIFFEL_NUMBER
wxSTC_EIFFEL_WORD
wxSTC_EIFFEL_STRING
wxSTC_EIFFEL_CHARACTER
wxSTC_EIFFEL_OPERATOR
wxSTC_EIFFEL_IDENTIFIER
wxSTC_EIFFEL_STRINGEOL
wxSTC_ERLANG_ATOM
wxSTC_ERLANG_CHARACTER
wxSTC_ERLANG_COMMENT
wxSTC_ERLANG_DEFAULT
wxSTC_ERLANG_FUNCTION_NAME
wxSTC_ERLANG_KEYWORD
wxSTC_ERLANG_MACRO
wxSTC_ERLANG_NODE_NAME
wxSTC_ERLANG_NUMBER
wxSTC_ERLANG_OPERATOR
wxSTC_ERLANG_RECORD
wxSTC_ERLANG_SEPARATOR
wxSTC_ERLANG_STRING
wxSTC_ERLANG_UNKNOWN
wxSTC_ERLANG_VARIABLE
wxSTC_ERLANG_PREPROC
wxSTC_ERLANG_COMMENT_FUNCTION
wxSTC_ERLANG_COMMENT_MODULE
wxSTC_ERLANG_COMMENT_DOC
wxSTC_ERLANG_COMMENT_DOC
wxSTC_ERLANG_ATOM_QUOTED
wxSTC_ERLANG_MACRO_QUOTED
wxSTC_ERLANG_RECORD_QUOTED
wxSTC_ERLANG_NODE_NAME_QUOTED
wxSTC_ERLANG_BIFS
wxSTC_ERLANG_MODULES
wxSTC_ERLANG_MODULES_ATT
wxSTC_ERR_ABSF
wxSTC_ERR_ELF
wxSTC_ERR_IFC
wxSTC_ERR_IFORT
wxSTC_ERR_JAVA_STACK
wxSTC_ERR_PHP
wxSTC_ERR_TIDY
wxSTC_ERR_VALUE
wxSTC_ESCRIPT_BRACE
wxSTC_ESCRIPT_COMMENT
wxSTC_ESCRIPT_COMMENTDOC
wxSTC_ESCRIPT_COMMENTLINE
wxSTC_ESCRIPT_DEFAULT
wxSTC_ESCRIPT_IDENTIFIER
wxSTC_ESCRIPT_NUMBER
wxSTC_ESCRIPT_OPERATOR
wxSTC_ESCRIPT_STRING
wxSTC_ESCRIPT_WORD
wxSTC_ESCRIPT_WORD2
wxSTC_ESCRIPT_WORD3
wxSTC_EFF_QUALITY_MASK
wxSTC_EFF_QUALITY_DEFAULT
wxSTC_EFF_QUALITY_NON_ANTIALIASED
wxSTC_EFF_QUALITY_ANTIALIASED
wxSTC_EFF_QUALITY_LCD_OPTIMIZED
wxSTC_FONT_SIZE_MULTIPLIER
wxSTC_FIND_WHOLEWORD
wxSTC_FIND_MATCHCASE
wxSTC_FIND_WORDSTART
wxSTC_FIND_REGEXP
wxSTC_FOLDLEVELBASE
wxSTC_FOLDLEVELWHITEFLAG
wxSTC_FOLDLEVELHEADERFLAG
wxSTC_FOLDLEVELNUMBERMASK
wxSTC_FORTH_DEFAULT
wxSTC_FORTH_COMMENT
wxSTC_FORTH_COMMENT_ML
wxSTC_FORTH_IDENTIFIER
wxSTC_FORTH_CONTROL
wxSTC_FORTH_KEYWORD
wxSTC_FORTH_DEFWORD
wxSTC_FORTH_PREWORD1
wxSTC_FORTH_PREWORD2
wxSTC_FORTH_NUMBER
wxSTC_FORTH_STRING
wxSTC_FORTH_LOCALE
wxSTC_F_DEFAULT
wxSTC_F_COMMENT
wxSTC_F_NUMBER
wxSTC_F_STRING1
wxSTC_F_STRING2
wxSTC_F_STRINGEOL
wxSTC_F_OPERATOR
wxSTC_F_IDENTIFIER
wxSTC_F_WORD
wxSTC_F_WORD2
wxSTC_F_WORD3
wxSTC_F_PREPROCESSOR
wxSTC_F_OPERATOR2
wxSTC_F_LABEL
wxSTC_F_CONTINUATION
wxSTC_FIND_POSIX
wxSTC_FOLDFLAG_BOX
wxSTC_FOLDFLAG_LEVELNUMBERS
wxSTC_FOLDFLAG_LINEAFTER_CONTRACTED
wxSTC_FOLDFLAG_LINEAFTER_EXPANDED
wxSTC_FOLDFLAG_LINEBEFORE_CONTRACTED
wxSTC_FOLDFLAG_LINEBEFORE_EXPANDED
wxSTC_FOLDLEVELBOXFOOTERFLAG
wxSTC_FOLDLEVELBOXHEADERFLAG
wxSTC_FOLDLEVELCONTRACTED
wxSTC_FOLDLEVELUNINDENT
wxSTC_FS_ASM
wxSTC_FS_BINNUMBER
wxSTC_FS_ERROR
wxSTC_FS_HEXNUMBER
wxSTC_FS_LABEL
wxSTC_FS_WORDOPERATOR
wxSTC_FS_DISABLEDCODE
wxSTC_FS_DEFAULT_C
wxSTC_FS_COMMENTDOC_C
wxSTC_FS_COMMENTLINEDOC_C
wxSTC_FS_KEYWORD_C
wxSTC_FS_KEYWORD2_C
wxSTC_FS_NUMBER_C
wxSTC_FS_STRING_C
wxSTC_FS_PREPROCESSOR_C
wxSTC_FS_OPERATOR_C
wxSTC_FS_IDENTIFIER_C
wxSTC_FS_STRINGEOL_C
wxSTC_FS_COMMENT
wxSTC_FS_COMMENTDOC
wxSTC_FS_COMMENTDOCKEYWORD
wxSTC_FS_COMMENTDOCKEYWORDERROR
wxSTC_FS_COMMENTLINE
wxSTC_FS_COMMENTLINEDOC
wxSTC_FS_CONSTANT
wxSTC_FS_DATE
wxSTC_FS_DEFAULT
wxSTC_FS_IDENTIFIER
wxSTC_FS_KEYWORD
wxSTC_FS_KEYWORD2
wxSTC_FS_KEYWORD3
wxSTC_FS_KEYWORD4
wxSTC_FS_NUMBER
wxSTC_FS_OPERATOR
wxSTC_FS_PREPROCESSOR
wxSTC_FS_STRING
wxSTC_FS_STRINGEOL
wxSTC_GAP_CHAR
wxSTC_GAP_COMMENT
wxSTC_GAP_DEFAULT
wxSTC_GAP_IDENTIFIER
wxSTC_GAP_KEYWORD
wxSTC_GAP_KEYWORD2
wxSTC_GAP_KEYWORD3
wxSTC_GAP_KEYWORD4
wxSTC_GAP_NUMBER
wxSTC_GAP_OPERATOR
wxSTC_GAP_STRING
wxSTC_GAP_STRINGEOL
wxSTC_GC_ATTRIBUTE
wxSTC_GC_COMMAND
wxSTC_GC_COMMENTBLOCK
wxSTC_GC_COMMENTLINE
wxSTC_GC_CONTROL
wxSTC_GC_DEFAULT
wxSTC_GC_EVENT
wxSTC_GC_GLOBAL
wxSTC_GC_OPERATOR
wxSTC_GC_STRING
wxSTC_H_DEFAULT
wxSTC_H_TAG
wxSTC_H_TAGUNKNOWN
wxSTC_H_ATTRIBUTE
wxSTC_H_ATTRIBUTEUNKNOWN
wxSTC_H_NUMBER
wxSTC_H_DOUBLESTRING
wxSTC_H_SINGLESTRING
wxSTC_H_OTHER
wxSTC_H_COMMENT
wxSTC_H_ENTITY
wxSTC_H_TAGEND
wxSTC_H_XMLSTART
wxSTC_H_XMLEND
wxSTC_H_SCRIPT
wxSTC_H_ASP
wxSTC_H_ASPAT
wxSTC_H_CDATA
wxSTC_H_QUESTION
wxSTC_H_VALUE
wxSTC_H_XCCOMMENT
wxSTC_H_SGML_DEFAULT
wxSTC_H_SGML_COMMAND
wxSTC_H_SGML_1ST_PARAM
wxSTC_H_SGML_DOUBLESTRING
wxSTC_H_SGML_SIMPLESTRING
wxSTC_H_SGML_ERROR
wxSTC_H_SGML_SPECIAL
wxSTC_H_SGML_ENTITY
wxSTC_H_SGML_COMMENT
wxSTC_H_SGML_1ST_PARAM_COMMENT
wxSTC_H_SGML_BLOCK_DEFAULT
wxSTC_HJ_START
wxSTC_HJ_DEFAULT
wxSTC_HJ_COMMENT
wxSTC_HJ_COMMENTLINE
wxSTC_HJ_COMMENTDOC
wxSTC_HJ_NUMBER
wxSTC_HJ_WORD
wxSTC_HJ_KEYWORD
wxSTC_HJ_DOUBLESTRING
wxSTC_HJ_SINGLESTRING
wxSTC_HJ_SYMBOLS
wxSTC_HJ_STRINGEOL
wxSTC_HJ_REGEX
wxSTC_HJA_START
wxSTC_HJA_DEFAULT
wxSTC_HJA_COMMENT
wxSTC_HJA_COMMENTLINE
wxSTC_HJA_COMMENTDOC
wxSTC_HJA_NUMBER
wxSTC_HJA_WORD
wxSTC_HJA_KEYWORD
wxSTC_HJA_DOUBLESTRING
wxSTC_HJA_SINGLESTRING
wxSTC_HJA_SYMBOLS
wxSTC_HJA_STRINGEOL
wxSTC_HJA_REGEX
wxSTC_HB_START
wxSTC_HB_DEFAULT
wxSTC_HB_COMMENTLINE
wxSTC_HB_NUMBER
wxSTC_HB_WORD
wxSTC_HB_STRING
wxSTC_HB_IDENTIFIER
wxSTC_HB_STRINGEOL
wxSTC_HBA_START
wxSTC_HBA_DEFAULT
wxSTC_HBA_COMMENTLINE
wxSTC_HBA_NUMBER
wxSTC_HBA_WORD
wxSTC_HBA_STRING
wxSTC_HBA_IDENTIFIER
wxSTC_HBA_STRINGEOL
wxSTC_HP_START
wxSTC_HP_DEFAULT
wxSTC_HP_COMMENTLINE
wxSTC_HP_NUMBER
wxSTC_HP_STRING
wxSTC_HP_CHARACTER
wxSTC_HP_WORD
wxSTC_HP_TRIPLE
wxSTC_HP_TRIPLEDOUBLE
wxSTC_HP_CLASSNAME
wxSTC_HP_DEFNAME
wxSTC_HP_OPERATOR
wxSTC_HP_IDENTIFIER
wxSTC_HPA_START
wxSTC_HPA_DEFAULT
wxSTC_HPA_COMMENTLINE
wxSTC_HPA_NUMBER
wxSTC_HPA_STRING
wxSTC_HPA_CHARACTER
wxSTC_HPA_WORD
wxSTC_HPA_TRIPLE
wxSTC_HPA_TRIPLEDOUBLE
wxSTC_HPA_CLASSNAME
wxSTC_HPA_DEFNAME
wxSTC_HPA_OPERATOR
wxSTC_HPA_IDENTIFIER
wxSTC_HPHP_DEFAULT
wxSTC_HPHP_HSTRING
wxSTC_HPHP_SIMPLESTRING
wxSTC_HPHP_WORD
wxSTC_HPHP_NUMBER
wxSTC_HPHP_VARIABLE
wxSTC_HPHP_COMMENT
wxSTC_HPHP_COMMENTLINE
wxSTC_HPHP_HSTRING_VARIABLE
wxSTC_HPHP_OPERATOR
wxSTC_HPHP_COMPLEX_VARIABLE
wxSTC_HA_CAPITAL
wxSTC_HA_CHARACTER
wxSTC_HA_CLASS
wxSTC_HA_COMMENTBLOCK
wxSTC_HA_COMMENTBLOCK2
wxSTC_HA_COMMENTBLOCK3
wxSTC_HA_COMMENTLINE
wxSTC_HA_DATA
wxSTC_HA_DEFAULT
wxSTC_HA_IDENTIFIER
wxSTC_HA_IMPORT
wxSTC_HA_INSTANCE
wxSTC_HA_KEYWORD
wxSTC_HA_MODULE
wxSTC_HA_NUMBER
wxSTC_HA_OPERATOR
wxSTC_HA_STRING
wxSTC_INDIC_MAX
wxSTC_INDIC_PLAIN
wxSTC_INDIC_SQUIGGLE
wxSTC_INDIC_TT
wxSTC_INDIC_DIAGONAL
wxSTC_INDIC_STRIKE
wxSTC_INDIC0_MASK
wxSTC_INDIC1_MASK
wxSTC_INDIC2_MASK
wxSTC_INDICS_MASK
wxSTC_INDIC_BOX
wxSTC_INDIC_CONTAINER
wxSTC_INDIC_HIDDEN
wxSTC_INDIC_ROUNDBOX
wxSTC_INDIC_STRAIGHTBOX
wxSTC_INDIC_DASH
wxSTC_INDIC_DOTS
wxSTC_INDIC_SQUIGGLELOW
wxSTC_INDIC_DOTBOX
wxSTC_INNO_COMMENT
wxSTC_INNO_COMMENT_PASCAL
wxSTC_INNO_DEFAULT
wxSTC_INNO_IDENTIFIER
wxSTC_INNO_KEYWORD
wxSTC_INNO_KEYWORD_PASCAL
wxSTC_INNO_KEYWORD_USER
wxSTC_INNO_PARAMETER
wxSTC_INNO_PREPROC
wxSTC_INNO_PREPROC_INLINE
wxSTC_INNO_INLINE_EXPANSION
wxSTC_INNO_SECTION
wxSTC_INNO_STRING_DOUBLE
wxSTC_INNO_STRING_SINGLE
wxSTC_INVALID_POSITION
wxSTC_IV_LOOKBOTH
wxSTC_IV_LOOKFORWARD
wxSTC_IV_NONE
wxSTC_IV_REAL
wxSTC_KEY_DOWN
wxSTC_KEY_UP
wxSTC_KEY_LEFT
wxSTC_KEY_RIGHT
wxSTC_KEY_HOME
wxSTC_KEY_END
wxSTC_KEY_PRIOR
wxSTC_KEY_NEXT
wxSTC_KEY_DELETE
wxSTC_KEY_INSERT
wxSTC_KEY_ESCAPE
wxSTC_KEY_BACK
wxSTC_KEY_TAB
wxSTC_KEY_RETURN
wxSTC_KEY_ADD
wxSTC_KEY_SUBTRACT
wxSTC_KEY_DIVIDE
wxSTC_KEYWORDSET_MAX
wxSTC_KEY_MENU
wxSTC_KEY_RWIN
wxSTC_KEY_WIN
wxSTC_KIX_COMMENT
wxSTC_KIX_DEFAULT
wxSTC_KIX_FUNCTIONS
wxSTC_KIX_IDENTIFIER
wxSTC_KIX_KEYWORD
wxSTC_KIX_MACRO
wxSTC_KIX_NUMBER
wxSTC_KIX_OPERATOR
wxSTC_KIX_STRING1
wxSTC_KIX_STRING2
wxSTC_KIX_VAR
wxSTC_L_TAG2
wxSTC_L_MATH2
wxSTC_L_COMMENT2
wxSTC_L_VERBATIM
wxSTC_L_SHORTCMD
wxSTC_L_SPECIAL
wxSTC_L_CMDOPT
wxSTC_L_ERROR
wxSTC_LUA_LABEL
wxSTC_LEX_TXT2TAGS
wxSTC_LEX_A68K
wxSTC_LEX_MODULA
wxSTC_LEX_COFFEESCRIPT
wxSTC_LEX_TCMD
wxSTC_LEX_AVS
wxSTC_LEX_ECL
wxSTC_LEX_OSCRIPT
wxSTC_LEX_VISUALPROLOG
wxSTC_LEX_ADA
wxSTC_LEX_ASM
wxSTC_LEX_ASP
wxSTC_LEX_AUTOMATIC
wxSTC_LEX_AVE
wxSTC_LEX_BAAN
wxSTC_LEX_BATCH
wxSTC_LEX_BULLANT
wxSTC_LEX_CONF
wxSTC_LEX_CONTAINER
wxSTC_LEX_CPP
wxSTC_LEX_CSS
wxSTC_LEX_DIFF
wxSTC_LEX_EIFFEL
wxSTC_LEX_EIFFELKW
wxSTC_LEX_ERRORLIST
wxSTC_LEX_FORTH
wxSTC_LEX_FORTRAN
wxSTC_LEX_HTML
wxSTC_LEX_LATEX
wxSTC_LEX_LISP
wxSTC_LEX_LUA
wxSTC_LEX_MAKEFILE
wxSTC_LEX_MATLAB
wxSTC_LEX_NNCRONTAB
wxSTC_LEX_NULL
wxSTC_LEX_NSIS
wxSTC_LEX_PASCAL
wxSTC_LEX_PERL
wxSTC_LEX_PHP
wxSTC_LEX_PHPSCRIPT
wxSTC_LEX_PROPERTIES
wxSTC_LEX_PS
wxSTC_LEX_PYTHON
wxSTC_LEX_RUBY
wxSTC_LEX_SCRIPTOL
wxSTC_LEX_SQL
wxSTC_LEX_TCL
wxSTC_LEX_YAML
wxSTC_LEX_TEX
wxSTC_LEX_VB
wxSTC_LEX_VBSCRIPT
wxSTC_LEX_XCODE
wxSTC_LEX_XML
wxSTC_LEX_ABAQUS
wxSTC_LEX_APDL
wxSTC_LEX_ASN1
wxSTC_LEX_ASYMPTOTE
wxSTC_LEX_AU3
wxSTC_LEX_BASH
wxSTC_LEX_BLITZBASIC
wxSTC_LEX_CAML
wxSTC_LEX_CLW
wxSTC_LEX_CLWNOCASE
wxSTC_LEX_CMAKE
wxSTC_LEX_CPPNOCASE
wxSTC_LEX_CSOUND
wxSTC_LEX_D
wxSTC_LEX_ERLANG
wxSTC_LEX_ESCRIPT
wxSTC_LEX_F77
wxSTC_LEX_FLAGSHIP
wxSTC_LEX_FREEBASIC
wxSTC_LEX_GAP
wxSTC_LEX_GUI4CLI
wxSTC_LEX_HASKELL
wxSTC_LEX_INNOSETUP
wxSTC_LEX_KIX
wxSTC_LEX_LOT
wxSTC_LEX_LOUT
wxSTC_LEX_METAPOST
wxSTC_LEX_MMIXAL
wxSTC_LEX_MSSQL
wxSTC_LEX_OCTAVE
wxSTC_LEX_OPAL
wxSTC_LEX_PLM
wxSTC_LEX_POV
wxSTC_LEX_POWERBASIC
wxSTC_LEX_PROGRESS
wxSTC_LEX_PUREBASIC
wxSTC_LEX_R
wxSTC_LEX_REBOL
wxSTC_LEX_SMALLTALK
wxSTC_LEX_SPECMAN
wxSTC_LEX_SPICE
wxSTC_LEX_TADS3
wxSTC_LEX_VERILOG
wxSTC_LEX_VHDL
wxSTC_LEX_MAGIK
wxSTC_LEX_POWERSHELL
wxSTC_LEX_MYSQL
wxSTC_LEX_PO
wxSTC_LEX_TAL
wxSTC_LEX_COBOL
wxSTC_LEX_TACL
wxSTC_LEX_SORCUS
wxSTC_LEX_POWERPRO
wxSTC_LEX_NIMROD
wxSTC_LEX_SML
wxSTC_LEX_MARKDOWN
wxSTC_LASTSTEPINUNDOREDO
wxSTC_L_DEFAULT
wxSTC_L_COMMAND
wxSTC_L_TAG
wxSTC_L_MATH
wxSTC_L_COMMENT
wxSTC_LUA_DEFAULT
wxSTC_LUA_COMMENT
wxSTC_LUA_COMMENTLINE
wxSTC_LUA_COMMENTDOC
wxSTC_LUA_NUMBER
wxSTC_LUA_WORD
wxSTC_LUA_STRING
wxSTC_LUA_CHARACTER
wxSTC_LUA_LITERALSTRING
wxSTC_LUA_PREPROCESSOR
wxSTC_LUA_OPERATOR
wxSTC_LUA_IDENTIFIER
wxSTC_LUA_STRINGEOL
wxSTC_LUA_WORD2
wxSTC_LUA_WORD3
wxSTC_LUA_WORD4
wxSTC_LUA_WORD5
wxSTC_LUA_WORD6
wxSTC_LISP_DEFAULT
wxSTC_LISP_COMMENT
wxSTC_LISP_NUMBER
wxSTC_LISP_KEYWORD
wxSTC_LISP_STRING
wxSTC_LISP_STRINGEOL
wxSTC_LISP_IDENTIFIER
wxSTC_LISP_OPERATOR
wxSTC_LISP_KEYWORD_KW
wxSTC_LISP_MULTI_COMMENT
wxSTC_LISP_SPECIAL
wxSTC_LISP_SYMBOL
wxSTC_LEXER_START
wxSTC_LOT_ABORT
wxSTC_LOT_BREAK
wxSTC_LOT_DEFAULT
wxSTC_LOT_FAIL
wxSTC_LOT_HEADER
wxSTC_LOT_PASS
wxSTC_LOT_SET
wxSTC_LOUT_COMMENT
wxSTC_LOUT_DEFAULT
wxSTC_LOUT_IDENTIFIER
wxSTC_LOUT_NUMBER
wxSTC_LOUT_OPERATOR
wxSTC_LOUT_STRING
wxSTC_LOUT_STRINGEOL
wxSTC_LOUT_WORD
wxSTC_LOUT_WORD2
wxSTC_LOUT_WORD3
wxSTC_LOUT_WORD4
wxSTC_LUA_WORD7
wxSTC_LUA_WORD8
wxSTC_MARGINOPTION_NONE
wxSTC_MARGINOPTION_SUBLINESELECT
wxSTC_MARK_RGBAIMAGE
wxSTC_MOD_LEXERSTATE
wxSTC_MODEVENTMASKALL
wxSTC_MODULA_DEFAULT
wxSTC_MODULA_COMMENT
wxSTC_MODULA_DOXYCOMM
wxSTC_MODULA_DOXYKEY
wxSTC_MODULA_KEYWORD
wxSTC_MODULA_RESERVED
wxSTC_MODULA_NUMBER
wxSTC_MODULA_BASENUM
wxSTC_MODULA_FLOAT
wxSTC_MODULA_STRING
wxSTC_MODULA_STRSPEC
wxSTC_MODULA_CHAR
wxSTC_MODULA_CHARSPEC
wxSTC_MODULA_PROC
wxSTC_MODULA_PRAGMA
wxSTC_MODULA_PRGKEY
wxSTC_MODULA_OPERATOR
wxSTC_MODULA_BADSTR
wxSTC_MULTIPASTE_ONCE
wxSTC_MULTIPASTE_EACH
wxSTC_MARKER_MAX
wxSTC_MARK_CIRCLE
wxSTC_MARK_ROUNDRECT
wxSTC_MARK_ARROW
wxSTC_MARK_SMALLRECT
wxSTC_MARK_SHORTARROW
wxSTC_MARK_EMPTY
wxSTC_MARK_ARROWDOWN
wxSTC_MARK_MINUS
wxSTC_MARK_PLUS
wxSTC_MARK_VLINE
wxSTC_MARK_LCORNER
wxSTC_MARK_TCORNER
wxSTC_MARK_BOXPLUS
wxSTC_MARK_BOXPLUSCONNECTED
wxSTC_MARK_BOXMINUS
wxSTC_MARK_BOXMINUSCONNECTED
wxSTC_MARK_LCORNERCURVE
wxSTC_MARK_TCORNERCURVE
wxSTC_MARK_CIRCLEPLUS
wxSTC_MARK_CIRCLEPLUSCONNECTED
wxSTC_MARK_CIRCLEMINUS
wxSTC_MARK_CIRCLEMINUSCONNECTED
wxSTC_MARK_BACKGROUND
wxSTC_MARK_DOTDOTDOT
wxSTC_MARK_ARROWS
wxSTC_MARK_CHARACTER
wxSTC_MARK_FULLRECT
wxSTC_MARK_LEFTRECT
wxSTC_MARK_AVAILABLE
wxSTC_MARK_UNDERLINE
wxSTC_MARGIN_TEXT
wxSTC_MARGIN_RTEXT
wxSTC_MOD_CHANGEMARGIN
wxSTC_MOD_CHANGEANNOTATION
wxSTC_MOD_CONTAINER
wxSTC_MAGIK_DEFAULT
wxSTC_MAGIK_COMMENT
wxSTC_MAGIK_HYPER_COMMENT
wxSTC_MAGIK_STRING
wxSTC_MAGIK_CHARACTER
wxSTC_MAGIK_NUMBER
wxSTC_MAGIK_IDENTIFIER
wxSTC_MAGIK_OPERATOR
wxSTC_MAGIK_FLOW
wxSTC_MAGIK_CONTAINER
wxSTC_MAGIK_BRACKET_BLOCK
wxSTC_MAGIK_BRACE_BLOCK
wxSTC_MAGIK_SQBRACKET_BLOCK
wxSTC_MAGIK_UNKNOWN_KEYWORD
wxSTC_MAGIK_KEYWORD
wxSTC_MAGIK_PRAGMA
wxSTC_MAGIK_SYMBOL
wxSTC_MYSQL_DEFAULT
wxSTC_MYSQL_COMMENT
wxSTC_MYSQL_COMMENTLINE
wxSTC_MYSQL_VARIABLE
wxSTC_MYSQL_SYSTEMVARIABLE
wxSTC_MYSQL_KNOWNSYSTEMVARIABLE
wxSTC_MYSQL_NUMBER
wxSTC_MYSQL_MAJORKEYWORD
wxSTC_MYSQL_KEYWORD
wxSTC_MYSQL_DATABASEOBJECT
wxSTC_MYSQL_PROCEDUREKEYWORD
wxSTC_MYSQL_STRING
wxSTC_MYSQL_SQSTRING
wxSTC_MYSQL_DQSTRING
wxSTC_MYSQL_OPERATOR
wxSTC_MYSQL_FUNCTION
wxSTC_MYSQL_IDENTIFIER
wxSTC_MYSQL_QUOTEDIDENTIFIER
wxSTC_MYSQL_USER1
wxSTC_MYSQL_USER2
wxSTC_MYSQL_USER3
wxSTC_MYSQL_HIDDENCOMMAND
wxSTC_MARKDOWN_DEFAULT
wxSTC_MARKDOWN_LINE_BEGIN
wxSTC_MARKDOWN_STRONG1
wxSTC_MARKDOWN_STRONG2
wxSTC_MARKDOWN_EM1
wxSTC_MARKDOWN_EM2
wxSTC_MARKDOWN_HEADER1
wxSTC_MARKDOWN_HEADER2
wxSTC_MARKDOWN_HEADER3
wxSTC_MARKDOWN_HEADER4
wxSTC_MARKDOWN_HEADER5
wxSTC_MARKDOWN_HEADER6
wxSTC_MARKDOWN_PRECHAR
wxSTC_MARKDOWN_ULIST_ITEM
wxSTC_MARKDOWN_OLIST_ITEM
wxSTC_MARKDOWN_BLOCKQUOTE
wxSTC_MARKDOWN_STRIKEOUT
wxSTC_MARKDOWN_HRULE
wxSTC_MARKDOWN_LINK
wxSTC_MARKDOWN_CODE
wxSTC_MARKDOWN_CODE2
wxSTC_MARKDOWN_CODEBK
wxSTC_MARK_PIXMAP
wxSTC_MARKNUM_FOLDEREND
wxSTC_MARKNUM_FOLDEROPENMID
wxSTC_MARKNUM_FOLDERMIDTAIL
wxSTC_MARKNUM_FOLDERTAIL
wxSTC_MARKNUM_FOLDERSUB
wxSTC_MARKNUM_FOLDER
wxSTC_MARKNUM_FOLDEROPEN
wxSTC_MASK_FOLDERS
wxSTC_MARGIN_SYMBOL
wxSTC_MARGIN_NUMBER
wxSTC_MARGIN_BACK
wxSTC_MARGIN_FORE
wxSTC_MOD_INSERTTEXT
wxSTC_MOD_DELETETEXT
wxSTC_MOD_CHANGESTYLE
wxSTC_MOD_CHANGEFOLD
wxSTC_MOD_CHANGEMARKER
wxSTC_MOD_BEFOREINSERT
wxSTC_MOD_BEFOREDELETE
wxSTC_MODEVENTMASKALL
wxSTC_MAKE_DEFAULT
wxSTC_MAKE_COMMENT
wxSTC_MAKE_PREPROCESSOR
wxSTC_MAKE_IDENTIFIER
wxSTC_MAKE_OPERATOR
wxSTC_MAKE_TARGET
wxSTC_MAKE_IDEOL
wxSTC_MATLAB_DEFAULT
wxSTC_MATLAB_COMMENT
wxSTC_MATLAB_COMMAND
wxSTC_MATLAB_NUMBER
wxSTC_MATLAB_KEYWORD
wxSTC_MATLAB_STRING
wxSTC_MATLAB_OPERATOR
wxSTC_MATLAB_IDENTIFIER
wxSTC_MATLAB_DOUBLEQUOTESTRING
wxSTC_METAPOST_COMMAND
wxSTC_METAPOST_DEFAULT
wxSTC_METAPOST_EXTRA
wxSTC_METAPOST_GROUP
wxSTC_METAPOST_SPECIAL
wxSTC_METAPOST_SYMBOL
wxSTC_METAPOST_TEXT
wxSTC_MMIXAL_CHAR
wxSTC_MMIXAL_COMMENT
wxSTC_MMIXAL_HEX
wxSTC_MMIXAL_INCLUDE
wxSTC_MMIXAL_LABEL
wxSTC_MMIXAL_LEADWS
wxSTC_MMIXAL_NUMBER
wxSTC_MMIXAL_OPCODE
wxSTC_MMIXAL_OPCODE_POST
wxSTC_MMIXAL_OPCODE_PRE
wxSTC_MMIXAL_OPCODE_UNKNOWN
wxSTC_MMIXAL_OPCODE_VALID
wxSTC_MMIXAL_OPERANDS
wxSTC_MMIXAL_OPERATOR
wxSTC_MMIXAL_REF
wxSTC_MMIXAL_REGISTER
wxSTC_MMIXAL_STRING
wxSTC_MMIXAL_SYMBOL
wxSTC_MOD_CHANGEINDICATOR
wxSTC_MOD_CHANGELINESTATE
wxSTC_MSSQL_COLUMN_NAME
wxSTC_MSSQL_COLUMN_NAME_2
wxSTC_MSSQL_COMMENT
wxSTC_MSSQL_DATATYPE
wxSTC_MSSQL_DEFAULT
wxSTC_MSSQL_DEFAULT_PREF_DATATYPE
wxSTC_MSSQL_FUNCTION
wxSTC_MSSQL_GLOBAL_VARIABLE
wxSTC_MSSQL_IDENTIFIER
wxSTC_MSSQL_LINE_COMMENT
wxSTC_MSSQL_NUMBER
wxSTC_MSSQL_OPERATOR
wxSTC_MSSQL_STATEMENT
wxSTC_MSSQL_STORED_PROCEDURE
wxSTC_MSSQL_STRING
wxSTC_MSSQL_SYSTABLE
wxSTC_MSSQL_VARIABLE
wxSTC_MULTILINEUNDOREDO
wxSTC_MULTISTEPUNDOREDO
wxSTC_NNCRONTAB_DEFAULT
wxSTC_NNCRONTAB_COMMENT
wxSTC_NNCRONTAB_TASK
wxSTC_NNCRONTAB_SECTION
wxSTC_NNCRONTAB_KEYWORD
wxSTC_NNCRONTAB_MODIFIER
wxSTC_NNCRONTAB_ASTERISK
wxSTC_NNCRONTAB_NUMBER
wxSTC_NNCRONTAB_STRING
wxSTC_NNCRONTAB_ENVIRONMENT
wxSTC_NNCRONTAB_IDENTIFIER
wxSTC_NSIS_DEFAULT
wxSTC_NSIS_COMMENT
wxSTC_NSIS_STRINGDQ
wxSTC_NSIS_STRINGLQ
wxSTC_NSIS_STRINGRQ
wxSTC_NSIS_FUNCTION
wxSTC_NSIS_VARIABLE
wxSTC_NSIS_LABEL
wxSTC_NSIS_USERDEFINED
wxSTC_NSIS_SECTIONDEF
wxSTC_NSIS_SUBSECTIONDEF
wxSTC_NSIS_IFDEFINEDEF
wxSTC_NSIS_MACRODEF
wxSTC_NSIS_STRINGVAR
wxSTC_NSIS_NUMBER
wxSTC_NSIS_COMMENTBOX
wxSTC_NSIS_FUNCTIONDEF
wxSTC_NSIS_PAGEEX
wxSTC_NSIS_SECTIONGROUP
wxSTC_OSCRIPT_DEFAULT
wxSTC_OSCRIPT_LINE_COMMENT
wxSTC_OSCRIPT_BLOCK_COMMENT
wxSTC_OSCRIPT_DOC_COMMENT
wxSTC_OSCRIPT_PREPROCESSOR
wxSTC_OSCRIPT_NUMBER
wxSTC_OSCRIPT_SINGLEQUOTE_STRING
wxSTC_OSCRIPT_DOUBLEQUOTE_STRING
wxSTC_OSCRIPT_CONSTANT
wxSTC_OSCRIPT_IDENTIFIER
wxSTC_OSCRIPT_GLOBAL
wxSTC_OSCRIPT_KEYWORD
wxSTC_OSCRIPT_OPERATOR
wxSTC_OSCRIPT_LABEL
wxSTC_OSCRIPT_TYPE
wxSTC_OSCRIPT_FUNCTION
wxSTC_OSCRIPT_OBJECT
wxSTC_OSCRIPT_PROPERTY
wxSTC_OSCRIPT_METHOD
wxSTC_OPAL_BOOL_CONST
wxSTC_OPAL_COMMENT_BLOCK
wxSTC_OPAL_COMMENT_LINE
wxSTC_OPAL_DEFAULT
wxSTC_OPAL_INTEGER
wxSTC_OPAL_KEYWORD
wxSTC_OPAL_PAR
wxSTC_OPAL_SORT
wxSTC_OPAL_SPACE
wxSTC_OPAL_STRING
wxSTC_OPTIONAL_START
wxSTC_PRINT_NORMAL
wxSTC_PRINT_INVERTLIGHT
wxSTC_PRINT_BLACKONWHITE
wxSTC_PRINT_COLOURONWHITE
wxSTC_PRINT_COLOURONWHITEDEFAULTBG
wxSTC_PERFORMED_USER
wxSTC_PERFORMED_UNDO
wxSTC_PERFORMED_REDO
wxSTC_P_DEFAULT
wxSTC_P_COMMENTLINE
wxSTC_P_NUMBER
wxSTC_P_STRING
wxSTC_P_CHARACTER
wxSTC_P_WORD
wxSTC_P_TRIPLE
wxSTC_P_TRIPLEDOUBLE
wxSTC_P_CLASSNAME
wxSTC_P_DEFNAME
wxSTC_P_OPERATOR
wxSTC_P_IDENTIFIER
wxSTC_P_COMMENTBLOCK
wxSTC_P_STRINGEOL
wxSTC_P_DECORATOR
wxSTC_P_WORD2
wxSTC_PL_DEFAULT
wxSTC_PL_ERROR
wxSTC_PL_COMMENTLINE
wxSTC_PL_POD
wxSTC_PL_NUMBER
wxSTC_PL_WORD
wxSTC_PL_STRING
wxSTC_PL_CHARACTER
wxSTC_PL_PUNCTUATION
wxSTC_PL_PREPROCESSOR
wxSTC_PL_OPERATOR
wxSTC_PL_IDENTIFIER
wxSTC_PL_SCALAR
wxSTC_PL_ARRAY
wxSTC_PL_HASH
wxSTC_PL_SYMBOLTABLE
wxSTC_PL_REGEX
wxSTC_PL_REGSUBST
wxSTC_PL_LONGQUOTE
wxSTC_PL_BACKTICKS
wxSTC_PL_DATASECTION
wxSTC_PL_HERE_DELIM
wxSTC_PL_HERE_Q
wxSTC_PL_HERE_QQ
wxSTC_PL_HERE_QX
wxSTC_PL_STRING_Q
wxSTC_PL_STRING_QQ
wxSTC_PL_STRING_QX
wxSTC_PL_STRING_QR
wxSTC_PL_STRING_QW
wxSTC_PL_FORMAT
wxSTC_PL_FORMAT_IDENT
wxSTC_PL_SUB_PROTOTYPE
wxSTC_PL_STRING_VAR
wxSTC_PL_XLAT
wxSTC_PL_REGEX_VAR
wxSTC_PL_REGSUBST_VAR
wxSTC_PL_BACKTICKS_VAR
wxSTC_PL_HERE_QQ_VAR
wxSTC_PL_HERE_QX_VAR
wxSTC_PL_STRING_QQ_VAR
wxSTC_PL_STRING_QX_VAR
wxSTC_PL_STRING_QR_VAR
wxSTC_POWERSHELL_FUNCTION
wxSTC_POWERSHELL_USER1
wxSTC_POWERSHELL_COMMENTSTREAM
wxSTC_PL_POD_VERB
wxSTC_PL_VARIABLE_INDEXER
wxSTC_PROPS_DEFAULT
wxSTC_PROPS_COMMENT
wxSTC_PROPS_SECTION
wxSTC_PROPS_ASSIGNMENT
wxSTC_PROPS_DEFVAL
wxSTC_PROPS_KEY
wxSTC_PS_DEFAULT
wxSTC_PS_COMMENT
wxSTC_PS_DSC_COMMENT
wxSTC_PS_DSC_VALUE
wxSTC_PS_NUMBER
wxSTC_PS_NAME
wxSTC_PS_KEYWORD
wxSTC_PS_LITERAL
wxSTC_PS_IMMEVAL
wxSTC_PS_PAREN_ARRAY
wxSTC_PS_PAREN_DICT
wxSTC_PS_PAREN_PROC
wxSTC_PS_TEXT
wxSTC_PS_HEXSTRING
wxSTC_PS_BASE85STRING
wxSTC_PS_BADSTRINGCHAR
wxSTC_PLM_COMMENT
wxSTC_PLM_CONTROL
wxSTC_PLM_DEFAULT
wxSTC_PLM_IDENTIFIER
wxSTC_PLM_KEYWORD
wxSTC_PLM_NUMBER
wxSTC_PLM_OPERATOR
wxSTC_PLM_STRING
wxSTC_POV_BADDIRECTIVE
wxSTC_POV_COMMENT
wxSTC_POV_COMMENTLINE
wxSTC_POV_DEFAULT
wxSTC_POV_DIRECTIVE
wxSTC_POV_IDENTIFIER
wxSTC_POV_NUMBER
wxSTC_POV_OPERATOR
wxSTC_POV_STRING
wxSTC_POV_STRINGEOL
wxSTC_POV_WORD2
wxSTC_POV_WORD3
wxSTC_POV_WORD4
wxSTC_POV_WORD5
wxSTC_POV_WORD6
wxSTC_POV_WORD7
wxSTC_POV_WORD8
wxSTC_POWERSHELL_DEFAULT
wxSTC_POWERSHELL_COMMENT
wxSTC_POWERSHELL_STRING
wxSTC_POWERSHELL_CHARACTER
wxSTC_POWERSHELL_NUMBER
wxSTC_POWERSHELL_VARIABLE
wxSTC_POWERSHELL_OPERATOR
wxSTC_POWERSHELL_IDENTIFIER
wxSTC_POWERSHELL_KEYWORD
wxSTC_POWERSHELL_CMDLET
wxSTC_POWERSHELL_ALIAS
wxSTC_PO_DEFAULT
wxSTC_PO_COMMENT
wxSTC_PO_MSGID
wxSTC_PO_MSGID_TEXT
wxSTC_PO_MSGSTR
wxSTC_PO_MSGSTR_TEXT
wxSTC_PO_MSGCTXT
wxSTC_PO_MSGCTXT_TEXT
wxSTC_PO_FUZZY
wxSTC_PAS_DEFAULT
wxSTC_PAS_IDENTIFIER
wxSTC_PAS_COMMENT
wxSTC_PAS_COMMENT2
wxSTC_PAS_COMMENTLINE
wxSTC_PAS_PREPROCESSOR
wxSTC_PAS_PREPROCESSOR2
wxSTC_PAS_NUMBER
wxSTC_PAS_HEXNUMBER
wxSTC_PAS_WORD
wxSTC_PAS_STRING
wxSTC_PAS_STRINGEOL
wxSTC_PAS_CHARACTER
wxSTC_PAS_OPERATOR
wxSTC_PAS_ASM
wxSTC_POWERPRO_DEFAULT
wxSTC_POWERPRO_COMMENTBLOCK
wxSTC_POWERPRO_COMMENTLINE
wxSTC_POWERPRO_NUMBER
wxSTC_POWERPRO_WORD
wxSTC_POWERPRO_WORD2
wxSTC_POWERPRO_WORD3
wxSTC_POWERPRO_WORD4
wxSTC_POWERPRO_DOUBLEQUOTEDSTRING
wxSTC_POWERPRO_SINGLEQUOTEDSTRING
wxSTC_POWERPRO_LINECONTINUE
wxSTC_POWERPRO_OPERATOR
wxSTC_POWERPRO_IDENTIFIER
wxSTC_POWERPRO_STRINGEOL
wxSTC_POWERPRO_VERBATIM
wxSTC_POWERPRO_ALTQUOTE
wxSTC_POWERPRO_FUNCTION
wxSTC_RB_BACKTICKS
wxSTC_RB_CHARACTER
wxSTC_RB_CLASSNAME
wxSTC_RB_CLASS_VAR
wxSTC_RB_COMMENTLINE
wxSTC_RB_DATASECTION
wxSTC_RB_DEFAULT
wxSTC_RB_DEFNAME
wxSTC_RB_ERROR
wxSTC_RB_GLOBAL
wxSTC_RB_HERE_DELIM
wxSTC_RB_HERE_Q
wxSTC_RB_HERE_QQ
wxSTC_RB_HERE_QX
wxSTC_RB_IDENTIFIER
wxSTC_RB_INSTANCE_VAR
wxSTC_RB_MODULE_NAME
wxSTC_RB_NUMBER
wxSTC_RB_OPERATOR
wxSTC_RB_POD
wxSTC_RB_REGEX
wxSTC_RB_STDERR
wxSTC_RB_STDIN
wxSTC_RB_STDOUT
wxSTC_RB_STRING
wxSTC_RB_STRING_Q
wxSTC_RB_STRING_QQ
wxSTC_RB_STRING_QR
wxSTC_RB_STRING_QW
wxSTC_RB_STRING_QX
wxSTC_RB_SYMBOL
wxSTC_RB_UPPER_BOUND
wxSTC_RB_WORD
wxSTC_RB_WORD_DEMOTED
wxSTC_REBOL_BINARY
wxSTC_REBOL_BRACEDSTRING
wxSTC_REBOL_CHARACTER
wxSTC_REBOL_COMMENTBLOCK
wxSTC_REBOL_COMMENTLINE
wxSTC_REBOL_DATE
wxSTC_REBOL_DEFAULT
wxSTC_REBOL_EMAIL
wxSTC_REBOL_FILE
wxSTC_REBOL_IDENTIFIER
wxSTC_REBOL_ISSUE
wxSTC_REBOL_MONEY
wxSTC_REBOL_NUMBER
wxSTC_REBOL_OPERATOR
wxSTC_REBOL_PAIR
wxSTC_REBOL_PREFACE
wxSTC_REBOL_QUOTEDSTRING
wxSTC_REBOL_TAG
wxSTC_REBOL_TIME
wxSTC_REBOL_TUPLE
wxSTC_REBOL_URL
wxSTC_REBOL_WORD
wxSTC_REBOL_WORD2
wxSTC_REBOL_WORD3
wxSTC_REBOL_WORD4
wxSTC_REBOL_WORD5
wxSTC_REBOL_WORD6
wxSTC_REBOL_WORD7
wxSTC_REBOL_WORD8
wxSTC_R_BASEKWORD
wxSTC_R_COMMENT
wxSTC_R_DEFAULT
wxSTC_R_IDENTIFIER
wxSTC_R_INFIX
wxSTC_R_INFIXEOL
wxSTC_R_KWORD
wxSTC_R_NUMBER
wxSTC_R_OPERATOR
wxSTC_R_OTHERKWORD
wxSTC_R_STRING
wxSTC_R_STRING2
wxSTC_SCMOD_META
wxSTC_STATUS_OK
wxSTC_STATUS_FAILURE
wxSTC_STATUS_BADALLOC
wxSTC_SCVS_NONE
wxSTC_SCVS_RECTANGULARSELECTION
wxSTC_SCVS_USERACCESSIBLE
wxSTC_SORCUS_DEFAULT
wxSTC_SORCUS_COMMAND
wxSTC_SORCUS_PARAMETER
wxSTC_SORCUS_COMMENTLINE
wxSTC_SORCUS_STRING
wxSTC_SORCUS_STRINGEOL
wxSTC_SORCUS_IDENTIFIER
wxSTC_SORCUS_OPERATOR
wxSTC_SORCUS_NUMBER
wxSTC_SORCUS_CONSTANT
wxSTC_SML_DEFAULT
wxSTC_SML_IDENTIFIER
wxSTC_SML_TAGNAME
wxSTC_SML_KEYWORD
wxSTC_SML_KEYWORD2
wxSTC_SML_KEYWORD3
wxSTC_SML_LINENUM
wxSTC_SML_OPERATOR
wxSTC_SML_NUMBER
wxSTC_SML_CHAR
wxSTC_SML_STRING
wxSTC_SML_COMMENT
wxSTC_SML_COMMENT1
wxSTC_SML_COMMENT2
wxSTC_SML_COMMENT3
wxSTC_STYLE_DEFAULT
wxSTC_STYLE_LINENUMBER
wxSTC_STYLE_BRACELIGHT
wxSTC_STYLE_BRACEBAD
wxSTC_STYLE_CONTROLCHAR
wxSTC_STYLE_INDENTGUIDE
wxSTC_STYLE_LASTPREDEFINED
wxSTC_STYLE_CALLTIP
wxSTC_STYLE_MAX
wxSTC_SCMOD_SHIFT
wxSTC_SCMOD_CTRL
wxSTC_SCMOD_ALT
wxSTC_SCMOD_NORM
wxSTC_SCMOD_SUPER
wxSTC_SCRIPTOL_DEFAULT
wxSTC_SCRIPTOL_COMMENTLINE
wxSTC_SCRIPTOL_NUMBER
wxSTC_SCRIPTOL_STRING
wxSTC_SCRIPTOL_CHARACTER
wxSTC_SCRIPTOL_PREPROCESSOR
wxSTC_SCRIPTOL_OPERATOR
wxSTC_SCRIPTOL_IDENTIFIER
wxSTC_SCRIPTOL_STRINGEOL
wxSTC_SCRIPTOL_CLASSNAME
wxSTC_SCRIPTOL_COMMENTBLOCK
wxSTC_SCRIPTOL_CSTYLE
wxSTC_SCRIPTOL_KEYWORD
wxSTC_SCRIPTOL_PERSISTENT
wxSTC_SCRIPTOL_TRIPLE
wxSTC_SCRIPTOL_WHITE
wxSTC_SH_BACKTICKS
wxSTC_SH_CHARACTER
wxSTC_SH_COMMENTLINE
wxSTC_SH_DEFAULT
wxSTC_SH_ERROR
wxSTC_SH_HERE_DELIM
wxSTC_SH_HERE_Q
wxSTC_SH_IDENTIFIER
wxSTC_SH_NUMBER
wxSTC_SH_OPERATOR
wxSTC_SH_PARAM
wxSTC_SH_SCALAR
wxSTC_SH_STRING
wxSTC_SH_WORD
wxSTC_SN_CODE
wxSTC_SN_COMMENTLINE
wxSTC_SN_COMMENTLINEBANG
wxSTC_SN_DEFAULT
wxSTC_SN_IDENTIFIER
wxSTC_SN_NUMBER
wxSTC_SN_OPERATOR
wxSTC_SN_PREPROCESSOR
wxSTC_SN_REGEXTAG
wxSTC_SN_SIGNAL
wxSTC_SN_STRING
wxSTC_SN_STRINGEOL
wxSTC_SN_USER
wxSTC_SN_WORD
wxSTC_SN_WORD2
wxSTC_SN_WORD3
wxSTC_SPICE_COMMENTLINE
wxSTC_SPICE_DEFAULT
wxSTC_SPICE_DELIMITER
wxSTC_SPICE_IDENTIFIER
wxSTC_SPICE_KEYWORD
wxSTC_SPICE_KEYWORD2
wxSTC_SPICE_KEYWORD3
wxSTC_SPICE_NUMBER
wxSTC_SPICE_VALUE
wxSTC_SQL_CHARACTER
wxSTC_SQL_COMMENT
wxSTC_SQL_COMMENTDOC
wxSTC_SQL_COMMENTDOCKEYWORD
wxSTC_SQL_COMMENTDOCKEYWORDERROR
wxSTC_SQL_COMMENTLINE
wxSTC_SQL_COMMENTLINEDOC
wxSTC_SQL_DEFAULT
wxSTC_SQL_IDENTIFIER
wxSTC_SQL_NUMBER
wxSTC_SQL_OPERATOR
wxSTC_SQL_QUOTEDIDENTIFIER
wxSTC_SQL_SQLPLUS
wxSTC_SQL_SQLPLUS_COMMENT
wxSTC_SQL_SQLPLUS_PROMPT
wxSTC_SQL_STRING
wxSTC_SQL_USER1
wxSTC_SQL_USER2
wxSTC_SQL_USER3
wxSTC_SQL_USER4
wxSTC_SQL_WORD
wxSTC_SQL_WORD2
wxSTC_ST_ASSIGN
wxSTC_ST_BINARY
wxSTC_ST_BOOL
wxSTC_ST_CHARACTER
wxSTC_ST_COMMENT
wxSTC_ST_DEFAULT
wxSTC_ST_GLOBAL
wxSTC_ST_KWSEND
wxSTC_ST_NIL
wxSTC_ST_NUMBER
wxSTC_ST_RETURN
wxSTC_ST_SELF
wxSTC_ST_SPECIAL
wxSTC_ST_SPEC_SEL
wxSTC_ST_STRING
wxSTC_ST_SUPER
wxSTC_ST_SYMBOL
wxSTC_START
wxSTC_STARTACTION
wxSTC_SEL_STREAM
wxSTC_SEL_RECTANGLE
wxSTC_SEL_LINES
wxSTC_SEL_THIN
wxEVT_STC_CHANGE
wxEVT_STC_STYLENEEDED
wxEVT_STC_CHARADDED
wxEVT_STC_SAVEPOINTREACHED
wxEVT_STC_SAVEPOINTLEFT
wxEVT_STC_ROMODIFYATTEMPT
wxEVT_STC_KEY
wxEVT_STC_DOUBLECLICK
wxEVT_STC_UPDATEUI
wxEVT_STC_MODIFIED
wxEVT_STC_MACRORECORD
wxEVT_STC_MARGINCLICK
wxEVT_STC_NEEDSHOWN
wxEVT_STC_POSCHANGED
wxEVT_STC_PAINTED
wxEVT_STC_USERLISTSELECTION
wxEVT_STC_URIDROPPED
wxEVT_STC_DWELLSTART
wxEVT_STC_DWELLEND
wxEVT_STC_START_DRAG
wxEVT_STC_DRAG_OVER
wxEVT_STC_DO_DROP
wxEVT_STC_ZOOM
wxEVT_STC_HOTSPOT_CLICK
wxEVT_STC_HOTSPOT_DCLICK
wxEVT_STC_CALLTIP_CLICK
wxEVT_STC_AUTOCOMP_CANCELLED
wxEVT_STC_AUTOCOMP_CHAR_DELETED
wxSTC_TCMD_DEFAULT
wxSTC_TCMD_COMMENT
wxSTC_TCMD_WORD
wxSTC_TCMD_LABEL
wxSTC_TCMD_HIDE
wxSTC_TCMD_COMMAND
wxSTC_TCMD_IDENTIFIER
wxSTC_TCMD_OPERATOR
wxSTC_TCMD_ENVIRONMENT
wxSTC_TCMD_EXPANSION
wxSTC_TCMD_CLABEL
wxSTC_TECHNOLOGY_DEFAULT
wxSTC_TECHNOLOGY_DIRECTWRITE
wxSTC_TXT2TAGS_DEFAULT
wxSTC_TXT2TAGS_LINE_BEGIN
wxSTC_TXT2TAGS_STRONG1
wxSTC_TXT2TAGS_STRONG2
wxSTC_TXT2TAGS_EM1
wxSTC_TXT2TAGS_EM2
wxSTC_TXT2TAGS_HEADER1
wxSTC_TXT2TAGS_HEADER2
wxSTC_TXT2TAGS_HEADER3
wxSTC_TXT2TAGS_HEADER4
wxSTC_TXT2TAGS_HEADER5
wxSTC_TXT2TAGS_HEADER6
wxSTC_TXT2TAGS_PRECHAR
wxSTC_TXT2TAGS_ULIST_ITEM
wxSTC_TXT2TAGS_OLIST_ITEM
wxSTC_TXT2TAGS_BLOCKQUOTE
wxSTC_TXT2TAGS_STRIKEOUT
wxSTC_TXT2TAGS_HRULE
wxSTC_TXT2TAGS_LINK
wxSTC_TXT2TAGS_CODE
wxSTC_TXT2TAGS_CODE2
wxSTC_TXT2TAGS_CODEBK
wxSTC_TXT2TAGS_COMMENT
wxSTC_TXT2TAGS_OPTION
wxSTC_TXT2TAGS_PREPROC
wxSTC_TXT2TAGS_POSTPROC
wxSTC_TYPE_BOOLEAN
wxSTC_TYPE_INTEGER
wxSTC_TYPE_STRING
wxSTC_TIME_FOREVER
wxSTC_TEX_DEFAULT
wxSTC_TEX_SPECIAL
wxSTC_TEX_GROUP
wxSTC_TEX_SYMBOL
wxSTC_TEX_COMMAND
wxSTC_TEX_TEXT
wxSTC_T3_BLOCK_COMMENT
wxSTC_T3_BRACE
wxSTC_T3_DEFAULT
wxSTC_T3_D_STRING
wxSTC_T3_HTML_DEFAULT
wxSTC_T3_HTML_STRING
wxSTC_T3_HTML_TAG
wxSTC_T3_IDENTIFIER
wxSTC_T3_KEYWORD
wxSTC_T3_LIB_DIRECTIVE
wxSTC_T3_LINE_COMMENT
wxSTC_T3_MSG_PARAM
wxSTC_T3_NUMBER
wxSTC_T3_OPERATOR
wxSTC_T3_PREPROCESSOR
wxSTC_T3_S_STRING
wxSTC_T3_USER1
wxSTC_T3_USER2
wxSTC_T3_USER3
wxSTC_T3_X_DEFAULT
wxSTC_T3_X_STRING
wxSTC_TCL_BLOCK_COMMENT
wxSTC_TCL_COMMENT
wxSTC_TCL_COMMENTLINE
wxSTC_TCL_COMMENT_BOX
wxSTC_TCL_DEFAULT
wxSTC_TCL_EXPAND
wxSTC_TCL_IDENTIFIER
wxSTC_TCL_IN_QUOTE
wxSTC_TCL_MODIFIER
wxSTC_TCL_NUMBER
wxSTC_TCL_OPERATOR
wxSTC_TCL_SUBSTITUTION
wxSTC_TCL_SUB_BRACE
wxSTC_TCL_WORD
wxSTC_TCL_WORD2
wxSTC_TCL_WORD3
wxSTC_TCL_WORD4
wxSTC_TCL_WORD5
wxSTC_TCL_WORD6
wxSTC_TCL_WORD7
wxSTC_TCL_WORD8
wxSTC_TCL_WORD_IN_QUOTE
wxSTC_UNDO_MAY_COALESCE
wxSTC_UPDATE_CONTENT
wxSTC_UPDATE_SELECTION
wxSTC_UPDATE_V_SCROLL
wxSTC_UPDATE_H_SCROLL
wxSTC_VISUALPROLOG_DEFAULT
wxSTC_VISUALPROLOG_KEY_MAJOR
wxSTC_VISUALPROLOG_KEY_MINOR
wxSTC_VISUALPROLOG_KEY_DIRECTIVE
wxSTC_VISUALPROLOG_COMMENT_BLOCK
wxSTC_VISUALPROLOG_COMMENT_LINE
wxSTC_VISUALPROLOG_COMMENT_KEY
wxSTC_VISUALPROLOG_COMMENT_KEY_ERROR
wxSTC_VISUALPROLOG_IDENTIFIER
wxSTC_VISUALPROLOG_VARIABLE
wxSTC_VISUALPROLOG_ANONYMOUS
wxSTC_VISUALPROLOG_NUMBER
wxSTC_VISUALPROLOG_OPERATOR
wxSTC_VISUALPROLOG_CHARACTER
wxSTC_VISUALPROLOG_CHARACTER_TOO_MANY
wxSTC_VISUALPROLOG_CHARACTER_ESCAPE_ERROR
wxSTC_VISUALPROLOG_STRING
wxSTC_VISUALPROLOG_STRING_ESCAPE
wxSTC_VISUALPROLOG_STRING_ESCAPE_ERROR
wxSTC_VISUALPROLOG_STRING_EOL_OPEN
wxSTC_VISUALPROLOG_STRING_VERBATIM
wxSTC_VISUALPROLOG_STRING_VERBATIM_SPECIAL
wxSTC_VISUALPROLOG_STRING_VERBATIM_EOL
wxSTC_VISIBLE_SLOP
wxSTC_VISIBLE_STRICT
wxSTC_VHDL_ATTRIBUTE
wxSTC_VHDL_COMMENT
wxSTC_VHDL_COMMENTLINEBANG
wxSTC_VHDL_DEFAULT
wxSTC_VHDL_IDENTIFIER
wxSTC_VHDL_KEYWORD
wxSTC_VHDL_NUMBER
wxSTC_VHDL_OPERATOR
wxSTC_VHDL_STDFUNCTION
wxSTC_VHDL_STDOPERATOR
wxSTC_VHDL_STDPACKAGE
wxSTC_VHDL_STDTYPE
wxSTC_VHDL_STRING
wxSTC_VHDL_STRINGEOL
wxSTC_VHDL_USERWORD
wxSTC_V_COMMENT
wxSTC_V_COMMENTLINE
wxSTC_V_COMMENTLINEBANG
wxSTC_V_DEFAULT
wxSTC_V_IDENTIFIER
wxSTC_V_NUMBER
wxSTC_V_OPERATOR
wxSTC_V_PREPROCESSOR
wxSTC_V_STRING
wxSTC_V_STRINGEOL
wxSTC_V_USER
wxSTC_V_WORD
wxSTC_V_WORD2
wxSTC_V_WORD3
wxSTC_WEIGHT_NORMAL
wxSTC_WEIGHT_SEMIBOLD
wxSTC_WEIGHT_BOLD
wxSTC_WRAPVISUALFLAG_MARGIN
wxSTC_WRAP_NONE
wxSTC_WRAP_WORD
wxSTC_WRAP_CHAR
wxSTC_WRAPVISUALFLAGLOC_DEFAULT
wxSTC_WRAPVISUALFLAGLOC_END_BY_TEXT
wxSTC_WRAPVISUALFLAGLOC_START_BY_TEXT
wxSTC_WRAPVISUALFLAG_END
wxSTC_WRAPVISUALFLAG_NONE
wxSTC_WRAPVISUALFLAG_START
wxSTC_WS_INVISIBLE
wxSTC_WS_VISIBLEALWAYS
wxSTC_WS_VISIBLEAFTERINDENT
wxSTC_WRAPINDENT_FIXED
wxSTC_WRAPINDENT_SAME
wxSTC_WRAPINDENT_INDENT
wxSTC_YAML_COMMENT
wxSTC_YAML_DEFAULT
wxSTC_YAML_DOCUMENT
wxSTC_YAML_ERROR
wxSTC_YAML_IDENTIFIER
wxSTC_YAML_KEYWORD
wxSTC_YAML_NUMBER
wxSTC_YAML_OPERATOR
wxSTC_YAML_REFERENCE
wxSTC_YAML_TEXT) ];
$EXPORT_TAGS{'systemsettings'} = [ qw(wxSYS_OEM_FIXED_FONT
wxSYS_ANSI_FIXED_FONT
wxSYS_ANSI_VAR_FONT
wxSYS_SYSTEM_FONT
wxSYS_DEVICE_DEFAULT_FONT
wxSYS_DEFAULT_GUI_FONT
wxSYS_ICONTITLE_FONT
wxSYS_SYSTEM_FIXED_FONT
wxSYS_COLOUR_SCROLLBAR
wxSYS_COLOUR_BACKGROUND
wxSYS_COLOUR_ACTIVECAPTION
wxSYS_COLOUR_INACTIVECAPTION
wxSYS_COLOUR_MENU
wxSYS_COLOUR_WINDOW
wxSYS_COLOUR_WINDOWFRAME
wxSYS_COLOUR_MENUTEXT
wxSYS_COLOUR_WINDOWTEXT
wxSYS_COLOUR_CAPTIONTEXT
wxSYS_COLOUR_ACTIVEBORDER
wxSYS_COLOUR_INACTIVEBORDER
wxSYS_COLOUR_APPWORKSPACE
wxSYS_COLOUR_HIGHLIGHT
wxSYS_COLOUR_HIGHLIGHTTEXT
wxSYS_COLOUR_BTNFACE
wxSYS_COLOUR_BTNSHADOW
wxSYS_COLOUR_GRAYTEXT
wxSYS_COLOUR_BTNTEXT
wxSYS_COLOUR_INACTIVECAPTIONTEXT
wxSYS_COLOUR_BTNHIGHLIGHT
wxSYS_COLOUR_3DDKSHADOW
wxSYS_COLOUR_3DLIGHT
wxSYS_COLOUR_INFOTEXT
wxSYS_COLOUR_INFOBK
wxSYS_COLOUR_LISTBOX
wxSYS_COLOUR_DESKTOP
wxSYS_COLOUR_3DFACE
wxSYS_COLOUR_3DSHADOW
wxSYS_COLOUR_3DHIGHLIGHT
wxSYS_COLOUR_3DHILIGHT
wxSYS_COLOUR_BTNHILIGHT
wxSYS_COLOUR_MAX
wxSYS_MOUSE_BUTTONS
wxSYS_BORDER_X
wxSYS_BORDER_Y
wxSYS_CURSOR_X
wxSYS_CURSOR_Y
wxSYS_DCLICK_X
wxSYS_DCLICK_Y
wxSYS_DRAG_X
wxSYS_DRAG_Y
wxSYS_EDGE_X
wxSYS_EDGE_Y
wxSYS_HSCROLL_ARROW_X
wxSYS_HSCROLL_ARROW_Y
wxSYS_HTHUMB_X
wxSYS_ICON_X
wxSYS_ICON_Y
wxSYS_ICONSPACING_X
wxSYS_ICONSPACING_Y
wxSYS_WINDOWMIN_X
wxSYS_WINDOWMIN_Y
wxSYS_SCREEN_X
wxSYS_SCREEN_Y
wxSYS_FRAMESIZE_X
wxSYS_FRAMESIZE_Y
wxSYS_SMALLICON_X
wxSYS_SMALLICON_Y
wxSYS_HSCROLL_Y
wxSYS_VSCROLL_X
wxSYS_VSCROLL_ARROW_X
wxSYS_VSCROLL_ARROW_Y
wxSYS_VTHUMB_Y
wxSYS_CAPTION_Y
wxSYS_MENU_Y
wxSYS_NETWORK_PRESENT
wxSYS_PENWINDOWS_PRESENT
wxSYS_SHOW_SOUNDS
wxSYS_SWAP_BUTTONS
wxSYS_SCREEN_NONE
wxSYS_SCREEN_TINY
wxSYS_SCREEN_PDA
wxSYS_SCREEN_SMALL
wxSYS_SCREEN_DESKTOP
wxSYS_DCLICK_MSEC
wxSYS_DEFAULT_PALETTE
wxSYS_TABLET_PRESENT
wxSYS_COLOUR_HOTLIGHT
wxSYS_COLOUR_GRADIENTACTIVECAPTION
wxSYS_COLOUR_GRADIENTINACTIVECAPTION
wxSYS_COLOUR_MENUHILIGHT
wxSYS_COLOUR_MENUBAR) ];
$EXPORT_TAGS{'textctrl'} = [ qw(wxHSCROLL
wxTE_PROCESS_ENTER
wxTE_PROCESS_TAB
wxTE_MULTILINE
wxTE_NOHIDESEL
wxTE_NO_VSCROLL
wxTE_PASSWORD
wxTE_READONLY
wxTE_RICH
wxTE_RICH2
wxTE_LEFT
wxTE_RIGHT
wxTE_CENTRE
wxTE_CENTER
wxTE_AUTO_URL
wxTE_DONTWRAP
wxTE_WORDWRAP
wxTE_CHARWRAP
wxTE_BESTWRAP
wxTE_HT_UNKNOWN
wxTE_HT_BEFORE
wxTE_HT_ON_TEXT
wxTE_HT_BELOW
wxTE_HT_BEYOND
wxTE_AUTO_SCROLL
wxTE_CAPITALIZE
wxTEXT_ALIGNMENT_DEFAULT
wxTEXT_ALIGNMENT_LEFT
wxTEXT_ALIGNMENT_CENTRE
wxTEXT_ALIGNMENT_CENTER
wxTEXT_ALIGNMENT_RIGHT
wxTEXT_ALIGNMENT_JUSTIFIED
wxTEXT_ATTR_TEXT_COLOUR
wxTEXT_ATTR_BACKGROUND_COLOUR
wxTEXT_ATTR_FONT_FACE
wxTEXT_ATTR_FONT_SIZE
wxTEXT_ATTR_FONT_WEIGHT
wxTEXT_ATTR_FONT_ITALIC
wxTEXT_ATTR_FONT_UNDERLINE
wxTEXT_ATTR_FONT
wxTEXT_ATTR_ALIGNMENT
wxTEXT_ATTR_LEFT_INDENT
wxTEXT_ATTR_RIGHT_INDENT
wxTEXT_ATTR_TABS
wxTEXT_ATTR_EFFECT_NONE
wxTEXT_ATTR_EFFECT_CAPITALS
wxTEXT_ATTR_EFFECT_SMALL_CAPITALS
wxTEXT_ATTR_EFFECT_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_DOUBLE_STRIKETHROUGH
wxTEXT_ATTR_EFFECT_SHADOW
wxTEXT_ATTR_EFFECT_EMBOSS
wxTEXT_ATTR_EFFECT_OUTLINE
wxTEXT_ATTR_EFFECT_ENGRAVE
wxTEXT_ATTR_EFFECT_SUPERSCRIPT
wxTEXT_ATTR_EFFECT_SUBSCRIPT
wxTEXT_ATTR_EFFECTS
wxTEXT_ATTR_FONT_ENCODING
wxTEXT_ATTR_OUTLINE_LEVEL
wxTEXT_TYPE_ANY) ];
$EXPORT_TAGS{'timepicker'} = [ qw(wxTP_DEFAULT) ];
$EXPORT_TAGS{'timer'} = [ qw(wxTIMER_CONTINUOUS
wxTIMER_ONE_SHOT) ];
$EXPORT_TAGS{'toolbar'} = [ qw(wxHORIZONTAL
wxITEM_SEPARATOR
wxITEM_NORMAL
wxITEM_CHECK
wxITEM_RADIO
wxITEM_DROPDOWN
wxNO_BORDER
wxTB_FLAT
wxTB_DOCKABLE
wxTB_HORIZONTAL
wxTB_VERTICAL
wxTB_3DBUTTONS
wxTB_TEXT
wxTB_NOICONS
wxTB_HORZ_LAYOUT
wxTB_HORZ_TEXT
wxTB_NO_TOOLTIPS
wxTB_RIGHT
wxTB_BOTTOM
wxTB_LEFT
wxTB_TOP
wxTB_NOALIGN
wxTB_NODIVIDER
wxTOOL_STYLE_BUTTON
wxTOOL_STYLE_CONTROL
wxTOOL_STYLE_SEPARATOR) ];
$EXPORT_TAGS{'toolbook'} = [ qw(wxBK_BUTTONBAR
wxTBK_HORZ_LAYOUT
wxTBK_BUTTONBAR) ];
$EXPORT_TAGS{'toplevelwindow'} = [ qw(wxUSER_ATTENTION_INFO
wxUSER_ATTENTION_ERROR) ];
$EXPORT_TAGS{'treectrl'} = [ qw(wxTR_DEFAULT_STYLE
wxTR_EDIT_LABELS
wxTR_EXTENDED
wxTR_FULL_ROW_HIGHLIGHT
wxTR_HAS_BUTTONS
wxTR_HAS_VARIABLE_ROW_HEIGHT
wxTR_HIDE_ROOT
wxTR_LINES_AT_ROOT
wxTR_MULTIPLE
wxTR_NO_BUTTONS
wxTR_NO_LINES
wxTR_ROW_LINES
wxTR_SINGLE
wxTR_TWIST_BUTTONS
wxTreeItemIcon_Normal
wxTreeItemIcon_Selected
wxTreeItemIcon_Expanded
wxTreeItemIcon_SelectedExpanded
wxTREE_HITTEST_ABOVE
wxTREE_HITTEST_BELOW
wxTREE_HITTEST_NOWHERE
wxTREE_HITTEST_ONITEMBUTTON
wxTREE_HITTEST_ONITEMICON
wxTREE_HITTEST_ONITEMINDENT
wxTREE_HITTEST_ONITEMLABEL
wxTREE_HITTEST_ONITEMRIGHT
wxTREE_HITTEST_ONITEMSTATEICON
wxTREE_HITTEST_TOLEFT
wxTREE_HITTEST_TORIGHT
wxTREE_HITTEST_ONITEMUPPERPART
wxTREE_HITTEST_ONITEMLOWERPART
wxTREE_HITTEST_ONITEM) ];
$EXPORT_TAGS{'window'} = [ qw(wxALWAYS_SHOW_SB
wxBOTH
wxBG_STYLE_SYSTEM
wxBG_STYLE_COLOUR
wxBG_STYLE_CUSTOM
wxBORDER_DEFAULT
wxBORDER_DOUBLE
wxBORDER_MASK
wxBORDER_RAISED
wxBORDER_SIMPLE
wxBORDER_STATIC
wxBORDER_SUNKEN
wxBORDER_THEME
wxBORDER_NONE
wxCENTER_ON_SCREEN
wxCENTRE_ON_SCREEN
wxCLIP_CHILDREN
wxCLIP_SIBLINGS
wxDOUBLE_BORDER
wxFULL_REPAINT_ON_RESIZE
wxHSCROLL
wxNO_3D
wxNO_FULL_REPAINT_ON_RESIZE
wxRAISED_BORDER
wxSIMPLE_BORDER
wxSTATIC_BORDER
wxSUNKEN_BORDER
wxSIZE_AUTO_WIDTH
wxSIZE_AUTO_HEIGHT
wxSIZE_AUTO
wxSIZE_USE_EXISTING
wxSIZE_ALLOW_MINUS_ONE
wxSIZE_FORCE
wxTRANSPARENT_WINDOW
wxUPDATE_UI_NONE
wxUPDATE_UI_RECURSE
wxUPDATE_UI_FROMIDLE
wxVERTICAL
wxVSCROLL
wxWANTS_CHARS
wxWS_EX_VALIDATE_RECURSIVELY
wxWS_EX_BLOCK_EVENTS
wxWS_EX_TRANSIENT
wxWS_EX_PROCESS_IDLE
wxWS_EX_PROCESS_UI_UPDATES
wxWS_EX_CONTEXTHELP
wxWINDOW_VARIANT_NORMAL
wxWINDOW_VARIANT_SMALL
wxWINDOW_VARIANT_MINI
wxWINDOW_VARIANT_LARGE) ];
$EXPORT_TAGS{'wizard'} = [ qw(wxWIZARD_EX_HELPBUTTON
wxWIZARD_HALIGN_CENTRE
wxWIZARD_HALIGN_LEFT
wxWIZARD_HALIGN_RIGHT
wxWIZARD_TILE
wxWIZARD_VALIGN_BOTTOM
wxWIZARD_VALIGN_CENTRE
wxWIZARD_VALIGN_TOP) ];
$EXPORT_TAGS{'xrc'} = [ qw(wxXRC_USE_LOCALE
wxXRC_NO_SUBCLASSING
wxXRC_NO_RELOADING
wxXML_ELEMENT_NODE
wxXML_ATTRIBUTE_NODE
wxXML_TEXT_NODE
wxXML_CDATA_SECTION_NODE
wxXML_ENTITY_REF_NODE
wxXML_ENTITY_NODE
wxXML_PI_NODE
wxXML_COMMENT_NODE
wxXML_DOCUMENT_NODE
wxXML_DOCUMENT_TYPE_NODE
wxXML_DOCUMENT_FRAG_NODE
wxXML_NOTATION_NODE
wxXML_HTML_DOCUMENT_NODE) ];

package Wx::Event;

push @EXPORT_OK, qw(EVT_COMMAND
EVT_TIMER
EVT_WIZARD_PAGE_CHANGED
EVT_WIZARD_PAGE_CHANGING
EVT_WIZARD_CANCEL
EVT_WIZARD_HELP
EVT_CHILD_FOCUS
EVT_WIZARD_FINISHED
EVT_ICONIZE
EVT_MAXIMIZE
EVT_MOUSE_CAPTURE_CHANGED
EVT_CREATE
EVT_DESTROY
EVT_WINDOW_CREATE
EVT_WINDOW_DESTROY
EVT_MOUSE_CAPTURE_LOST
EVT_SET_CURSOR
EVT_COLOURPICKER_CHANGED
EVT_FILEPICKER_CHANGED
EVT_DIRPICKER_CHANGED
EVT_FONTPICKER_CHANGED
EVT_MENU_HIGHLIGHT_ALL
EVT_TREE_STATE_IMAGE_CLICK
EVT_TREE_ITEM_GETTOOLTIP
EVT_TASKBAR_MOVE
EVT_TASKBAR_LEFT_DOWN
EVT_TASKBAR_LEFT_UP
EVT_TASKBAR_RIGHT_DOWN
EVT_TASKBAR_RIGHT_UP
EVT_TASKBAR_LEFT_DCLICK
EVT_TASKBAR_RIGHT_DCLICK
EVT_TASKBAR_CLICK
EVT_LEFT_DOWN
EVT_LEFT_UP
EVT_LEFT_DCLICK
EVT_MIDDLE_DOWN
EVT_MIDDLE_UP
EVT_MIDDLE_DCLICK
EVT_RIGHT_DOWN
EVT_RIGHT_UP
EVT_RIGHT_DCLICK
EVT_MOVE_START
EVT_MOVE_END
EVT_AUX1_DOWN
EVT_AUX1_UP
EVT_AUX1_DCLICK
EVT_AUX2_DOWN
EVT_AUX2_UP
EVT_AUX2_DCLICK
EVT_SEARCHCTRL_CANCEL_BTN
EVT_SEARCHCTRL_SEARCH_BTN
EVT_COLLAPSIBLEPANE_CHANGED
EVT_HYPERLINK
EVT_FILECTRL_FILEACTIVATED
EVT_FILECTRL_SELECTIONCHANGED
EVT_FILECTRL_FOLDERCHANGED
EVT_AUI_PANE_BUTTON
EVT_AUI_PANE_CLOSE
EVT_AUI_PANE_MAXIMIZE
EVT_AUI_PANE_RESTORE
EVT_AUI_PANE_ACTIVATED
EVT_AUI_RENDER
EVT_AUINOTEBOOK_PAGE_CLOSE
EVT_AUINOTEBOOK_PAGE_CLOSED
EVT_AUINOTEBOOK_PAGE_CHANGED
EVT_AUINOTEBOOK_PAGE_CHANGING
EVT_AUINOTEBOOK_BUTTON
EVT_AUINOTEBOOK_BEGIN_DRAG
EVT_AUINOTEBOOK_END_DRAG
EVT_AUINOTEBOOK_DRAG_MOTION
EVT_AUINOTEBOOK_ALLOW_DND
EVT_AUINOTEBOOK_DRAG_DONE
EVT_AUINOTEBOOK_TAB_MIDDLE_DOWN
EVT_AUINOTEBOOK_TAB_MIDDLE_UP
EVT_AUINOTEBOOK_TAB_RIGHT_DOWN
EVT_AUINOTEBOOK_TAB_RIGHT_UP
EVT_AUINOTEBOOK_BG_DCLICK
EVT_CALENDAR
EVT_CALENDAR_SEL_CHANGED
EVT_CALENDAR_DAY
EVT_CALENDAR_MONTH
EVT_CALENDAR_YEAR
EVT_CALENDAR_WEEKDAY_CLICKED
EVT_DATE_CHANGED
EVT_TIME_CHANGED
EVT_GRID_CMD_CELL_LEFT_CLICK
EVT_GRID_CMD_CELL_RIGHT_CLICK
EVT_GRID_CMD_CELL_LEFT_DCLICK
EVT_GRID_CMD_CELL_RIGHT_DCLICK
EVT_GRID_CMD_LABEL_LEFT_CLICK
EVT_GRID_CMD_LABEL_RIGHT_CLICK
EVT_GRID_CMD_LABEL_LEFT_DCLICK
EVT_GRID_CMD_LABEL_RIGHT_DCLICK
EVT_GRID_CMD_ROW_SIZE
EVT_GRID_CMD_COL_SIZE
EVT_GRID_CMD_RANGE_SELECT
EVT_GRID_CMD_CELL_CHANGE
EVT_GRID_CMD_CELL_CHANGED
EVT_GRID_CMD_CELL_CHANGING
EVT_GRID_CMD_SELECT_CELL
EVT_GRID_CMD_EDITOR_SHOWN
EVT_GRID_CMD_EDITOR_HIDDEN
EVT_GRID_CMD_EDITOR_CREATED
EVT_GRID_CMD_CELL_BEGIN_DRAG
EVT_GRID_CELL_LEFT_CLICK
EVT_GRID_CELL_RIGHT_CLICK
EVT_GRID_CELL_LEFT_DCLICK
EVT_GRID_CELL_RIGHT_DCLICK
EVT_GRID_LABEL_LEFT_CLICK
EVT_GRID_LABEL_RIGHT_CLICK
EVT_GRID_LABEL_LEFT_DCLICK
EVT_GRID_LABEL_RIGHT_DCLICK
EVT_GRID_ROW_SIZE
EVT_GRID_COL_SIZE
EVT_GRID_RANGE_SELECT
EVT_GRID_CELL_CHANGE
EVT_GRID_CELL_CHANGING
EVT_GRID_CELL_CHANGED
EVT_GRID_SELECT_CELL
EVT_GRID_EDITOR_SHOWN
EVT_GRID_EDITOR_HIDDEN
EVT_GRID_EDITOR_CREATED
EVT_GRID_CELL_BEGIN_DRAG
EVT_HTML_CELL_CLICKED
EVT_HTML_CELL_HOVER
EVT_HTML_LINK_CLICKED
EVT_MEDIA_LOADED
EVT_MEDIA_FINISHED
EVT_MEDIA_STOP
EVT_MEDIA_PAUSE
EVT_MEDIA_PLAY
EVT_MEDIA_STATECHANGED
EVT_RICHTEXT_ITEM_SELECTED
EVT_RICHTEXT_ITEM_DESELECTED
EVT_RICHTEXT_LEFT_CLICK
EVT_RICHTEXT_RIGHT_CLICK
EVT_RICHTEXT_MIDDLE_CLICK
EVT_RICHTEXT_LEFT_DCLICK
EVT_RICHTEXT_RETURN
EVT_RICHTEXT_STYLESHEET_CHANGING
EVT_RICHTEXT_STYLESHEET_CHANGED
EVT_RICHTEXT_STYLESHEET_REPLACING
EVT_RICHTEXT_STYLESHEET_REPLACED
EVT_RICHTEXT_CHARACTER
EVT_RICHTEXT_DELETE
EVT_RICHTEXT_STYLE_CHANGED
EVT_RICHTEXT_CONTENT_INSERTED
EVT_RICHTEXT_CONTENT_DELETED
EVT_STC_CHANGE
EVT_STC_STYLENEEDED
EVT_STC_CHARADDED
EVT_STC_SAVEPOINTREACHED
EVT_STC_SAVEPOINTLEFT
EVT_STC_ROMODIFYATTEMPT
EVT_STC_KEY
EVT_STC_DOUBLECLICK
EVT_STC_UPDATEUI
EVT_STC_MODIFIED
EVT_STC_MACRORECORD
EVT_STC_MARGINCLICK
EVT_STC_NEEDSHOWN
EVT_STC_POSCHANGED
EVT_STC_PAINTED
EVT_STC_USERLISTSELECTION
EVT_STC_URIDROPPED
EVT_STC_DWELLSTART
EVT_STC_DWELLEND
EVT_STC_START_DRAG
EVT_STC_DRAG_OVER
EVT_STC_DO_DROP
EVT_STC_ZOOM
EVT_STC_HOTSPOT_CLICK
EVT_STC_HOTSPOT_DCLICK
EVT_STC_CALLTIP_CLICK
EVT_STC_AUTOCOMP_SELECTION
EVT_STC_INDICATOR_CLICK
EVT_STC_INDICATOR_RELEASE
EVT_STC_AUTOCOMP_CANCELLED
EVT_STC_AUTOCOMP_CHAR_DELETED
EVT_ACTIVATE
EVT_ACTIVATE_APP
EVT_COMMAND_RANGE
EVT_BUTTON
EVT_CHECKBOX
EVT_CHOICE
EVT_LISTBOX
EVT_LISTBOX_DCLICK
EVT_TEXT
EVT_TEXT_ENTER
EVT_TEXT_MAXLEN
EVT_TEXT_URL
EVT_MENU
EVT_MENU_RANGE
EVT_SLIDER
EVT_RADIOBOX
EVT_RADIOBUTTON
EVT_SCROLLBAR
EVT_COMBOBOX
EVT_TOOL
EVT_TOOL_RANGE
EVT_TOOL_RCLICKED
EVT_TOOL_RCLICKED_RANGE
EVT_TOOL_ENTER
EVT_COMMAND_LEFT_CLICK
EVT_COMMAND_LEFT_DCLICK
EVT_COMMAND_RIGHT_CLICK
EVT_COMMAND_SET_FOCUS
EVT_COMMAND_KILL_FOCUS
EVT_COMMAND_ENTER
EVT_TOGGLEBUTTON
EVT_CHECKLISTBOX
EVT_TEXT_CUT
EVT_TEXT_COPY
EVT_TEXT_PASTE
EVT_CLOSE
EVT_END_SESSION
EVT_QUERY_END_SESSION
EVT_DROP_FILES
EVT_ERASE_BACKGROUND
EVT_FIND
EVT_FIND_NEXT
EVT_FIND_REPLACE
EVT_FIND_REPLACE_ALL
EVT_FIND_CLOSE
EVT_SET_FOCUS
EVT_KILL_FOCUS
EVT_CHAR
EVT_CHAR_HOOK
EVT_KEY_DOWN
EVT_KEY_UP
EVT_HELP
EVT_HELP_RANGE
EVT_DETAILED_HELP
EVT_DETAILED_HELP_RANGE
EVT_IDLE
EVT_INIT_DIALOG
EVT_JOY_BUTTON_DOWN
EVT_JOY_BUTTON_UP
EVT_JOY_MOVE
EVT_JOY_ZMOVE
EVT_LISTBOOK_PAGE_CHANGING
EVT_LISTBOOK_PAGE_CHANGED
EVT_CHOICEBOOK_PAGE_CHANGING
EVT_CHOICEBOOK_PAGE_CHANGED
EVT_TOOLBOOK_PAGE_CHANGING
EVT_TOOLBOOK_PAGE_CHANGED
EVT_TREEBOOK_PAGE_CHANGING
EVT_TREEBOOK_PAGE_CHANGED
EVT_TREEBOOK_NODE_COLLAPSED
EVT_TREEBOOK_NODE_EXPANDED
EVT_LIST_BEGIN_DRAG
EVT_LIST_BEGIN_RDRAG
EVT_LIST_BEGIN_LABEL_EDIT
EVT_LIST_CACHE_HINT
EVT_LIST_END_LABEL_EDIT
EVT_LIST_DELETE_ITEM
EVT_LIST_DELETE_ALL_ITEMS
EVT_LIST_GET_INFO
EVT_LIST_SET_INFO
EVT_LIST_ITEM_SELECTED
EVT_LIST_ITEM_DESELECTED
EVT_LIST_KEY_DOWN
EVT_LIST_INSERT_ITEM
EVT_LIST_COL_CLICK
EVT_LIST_RIGHT_CLICK
EVT_LIST_MIDDLE_CLICK
EVT_LIST_ITEM_ACTIVATED
EVT_LIST_COL_RIGHT_CLICK
EVT_LIST_COL_BEGIN_DRAG
EVT_LIST_COL_DRAGGING
EVT_LIST_COL_END_DRAG
EVT_LIST_ITEM_FOCUSED
EVT_LIST_ITEM_RIGHT_CLICK
EVT_MENU_CHAR
EVT_MENU_INIT
EVT_MENU_HIGHLIGHT
EVT_POPUP_MENU
EVT_CONTEXT_MENU
EVT_MENU_OPEN
EVT_MENU_CLOSE
EVT_MOTION
EVT_ENTER_WINDOW
EVT_LEAVE_WINDOW
EVT_MOUSEWHEEL
EVT_MOUSE_EVENTS
EVT_MOVE
EVT_MOVING
EVT_NOTEBOOK_PAGE_CHANGING
EVT_NOTEBOOK_PAGE_CHANGED
EVT_PAINT
EVT_END_PROCESS
EVT_SASH_DRAGGED
EVT_SASH_DRAGGED_RANGE
EVT_SIZE
EVT_SIZING
EVT_SCROLL_TOP
EVT_SCROLL_BOTTOM
EVT_SCROLL_LINEUP
EVT_SCROLL_LINEDOWN
EVT_SCROLL_PAGEUP
EVT_SCROLL_PAGEDOWN
EVT_SCROLL_THUMBTRACK
EVT_SCROLL_THUMBRELEASE
EVT_SCROLL
EVT_COMMAND_SCROLL_TOP
EVT_COMMAND_SCROLL_BOTTOM
EVT_COMMAND_SCROLL_LINEUP
EVT_COMMAND_SCROLL_LINEDOWN
EVT_COMMAND_SCROLL_PAGEUP
EVT_COMMAND_SCROLL_PAGEDOWN
EVT_COMMAND_SCROLL_THUMBTRACK
EVT_COMMAND_SCROLL_THUMBRELEASE
EVT_COMMAND_SCROLL
EVT_SCROLLWIN_TOP
EVT_SCROLLWIN_BOTTOM
EVT_SCROLLWIN_LINEUP
EVT_SCROLLWIN_LINEDOWN
EVT_SCROLLWIN_PAGEUP
EVT_SCROLLWIN_PAGEDOWN
EVT_SCROLLWIN_THUMBTRACK
EVT_SCROLLWIN_THUMBRELEASE
EVT_SCROLLWIN
EVT_SPIN_UP
EVT_SPIN_DOWN
EVT_SPIN
EVT_SPINCTRL
EVT_SPLITTER_SASH_POS_CHANGING
EVT_SPLITTER_SASH_POS_CHANGED
EVT_SPLITTER_UNSPLIT
EVT_SPLITTER_DOUBLECLICKED
EVT_SPLITTER_DCLICK
EVT_SYS_COLOUR_CHANGED
EVT_TREE_BEGIN_DRAG
EVT_TREE_BEGIN_RDRAG
EVT_TREE_END_DRAG
EVT_TREE_BEGIN_LABEL_EDIT
EVT_TREE_END_LABEL_EDIT
EVT_TREE_GET_INFO
EVT_TREE_SET_INFO
EVT_TREE_ITEM_EXPANDED
EVT_TREE_ITEM_EXPANDING
EVT_TREE_ITEM_COLLAPSED
EVT_TREE_ITEM_COLLAPSING
EVT_TREE_SEL_CHANGED
EVT_TREE_SEL_CHANGING
EVT_TREE_KEY_DOWN
EVT_TREE_DELETE_ITEM
EVT_TREE_ITEM_ACTIVATED
EVT_TREE_ITEM_RIGHT_CLICK
EVT_TREE_ITEM_MIDDLE_CLICK
EVT_TREE_ITEM_MENU
EVT_UPDATE_UI
EVT_UPDATE_UI_RANGE
EVT_SOCKET
EVT_SOCKET_ALL
EVT_SOCKET_INPUT
EVT_SOCKET_OUTPUT
EVT_SOCKET_CONNECTION
EVT_SOCKET_LOST
EVT_CALENDAR
EVT_CALENDAR_SEL_CHANGED
EVT_CALENDAR_DAY
EVT_CALENDAR_MONTH
EVT_CALENDAR_YEAR
EVT_CALENDAR_WEEKDAY_CLICKED
EVT_STC_CHANGE
EVT_STC_STYLENEEDED
EVT_STC_CHARADDED
EVT_STC_SAVEPOINTREACHED
EVT_STC_SAVEPOINTLEFT
EVT_STC_ROMODIFYATTEMPT
EVT_STC_KEY
EVT_STC_DOUBLECLICK
EVT_STC_UPDATEUI
EVT_STC_MODIFIED
EVT_STC_MACRORECORD
EVT_STC_MARGINCLICK
EVT_STC_NEEDSHOWN
EVT_STC_POSCHANGED
EVT_STC_PAINTED
EVT_STC_USERLISTSELECTION
EVT_STC_URIDROPPED
EVT_STC_DWELLSTART
EVT_STC_DWELLEND
EVT_STC_START_DRAG
EVT_STC_DRAG_OVER
EVT_STC_DO_DROP
EVT_STC_ZOOM
EVT_STC_HOTSPOT_CLICK
EVT_STC_HOTSPOT_DCLICK
EVT_STC_CALLTIP_CLICK
EVT_HEADER_CLICK
EVT_HEADER_RIGHT_CLICK
EVT_HEADER_MIDDLE_CLICK
EVT_HEADER_DCLICK
EVT_HEADER_RIGHT_DCLICK
EVT_HEADER_MIDDLE_DCLICK
EVT_HEADER_SEPARATOR_DCLICK
EVT_HEADER_BEGIN_RESIZE
EVT_HEADER_RESIZING
EVT_HEADER_END_RESIZE
EVT_HEADER_BEGIN_REORDER
EVT_HEADER_END_REORDER
EVT_HEADER_DRAGGING_CANCELLED
EVT_TREELIST_SELECTION_CHANGED
EVT_TREELIST_ITEM_EXPANDING
EVT_TREELIST_ITEM_EXPANDED
EVT_TREELIST_ITEM_CHECKED
EVT_TREELIST_ITEM_ACTIVATED
EVT_TREELIST_ITEM_CONTEXT_MENU
EVT_TREELIST_COLUMN_SORTED);

$EXPORT_TAGS{'everything'} = \@EXPORT_OK;

1;

# Local variables: #
# mode: cperl #
# End: #
